import React, { useState, useCallback, useEffect } from 'react'
import { Button, Input, Space, Table, DatePicker, Tag, Modal, message } from 'antd'
import tableConfig from './tableConfig'
import { useAjax } from '@/Hook/useAjax'
import { getCorpComplainList } from '@/services/enterpriseWeChat/complaint'
import { SearchOutlined } from '@ant-design/icons'
import moment from 'moment'
import useCopy from '@/Hook/useCopy'
const { RangePicker } = DatePicker;
function Complaint() {
    let listData = useAjax((params) => getCorpComplainList(params))
    let [visible, setVisible] = useState(false)
    let [kf, setKf] = useState('')
    let [kfLink, setKfLink] = useState('')
    let { copy } = useCopy()
    let link = 'http://corp.complaint.zanxiangnet.com/html/index.html?kf='
    // 企微列表搜索条件
    const [queryValue, setQueryValue] = useState({
        operateSign: '',//运营
        startTime: moment(new Date()).format('YYYY-MM-DD'),//开始日期
        endTime: moment(new Date()).format('YYYY-MM-DD'),//结束日期
    })
    useEffect(() => {
        getList(1, 20)
    }, [])
    const getList = useCallback((pageNum, pageSize) => {
        listData.run({ ...queryValue, pageNum, pageSize })
    }, [queryValue])
    return <div>
        {/* 头部 */}
        <div style={{ display: 'flex', justifyContent: 'space-between', marginBottom: 15 }}>
            <Space>
                <Input placeholder='请输入客服标记筛选' allowClear value={queryValue?.operateSign} onChange={(e: any) => {
                    let value = e.target.value?.replace(/\s/ig, '')
                    setQueryValue({ ...queryValue, operateSign: value })
                }} />
                <RangePicker onChange={(date, dataString) => {
                    setQueryValue({ ...queryValue, startTime: dataString[0], endTime: dataString[1] })
                }} value={[queryValue.startTime ? moment(queryValue.startTime) : null, queryValue.endTime ? moment(queryValue.endTime) : null]} />
                <Button onClick={() => { getList(1, 20) }} type='primary'><SearchOutlined />查询</Button>
            </Space>
            <Button onClick={() => { setVisible(true) }} type='primary'>生成客服专属投诉链接</Button>
        </div>
        <Table
            dataSource={listData?.data?.records}
            size='small'
            columns={tableConfig()}
            pagination={{
                total: listData?.data?.total,
                current: listData?.data?.current,
                pageSize: listData?.data?.size,
                showSizeChanger: true,
                pageSizeOptions: ['10', '20', '50', '70', '100'],
                showTotal: (total) => <Tag color="cyan">总共{total}数据</Tag>,
                onChange: (page, pageSize) => {
                    getList(page, pageSize)
                }
            }}
        />
        <Modal
            visible={visible}
            width={400}
            closable={false}
            onOk={() => {
                if (kf) {
                    copy(link + kf)
                    setVisible(false)
                } else {
                    message.error('请输入客服标记')
                }
            }}
            onCancel={() => {
                setVisible(false)
            }}
        >
            <Input value={kf} onChange={(e) => {
                let v = e.target.value;
                if(!v.match(/[\u4e00-\u9fa5',.。\s]/)){
                    setKf(v)
                }
            }
            } placeholder='请输入客服标记,确定生成后直接粘贴就行！' />
            <div>
                <strong>注：</strong>
                <span style={{ color: 'red' }}>客服标记与投诉信息挂钩,用来查询对应客服的投诉记录，请勿输入中文。支持26位字母和数字！！！</span>
            </div>
        </Modal>
    </div>
}
export default Complaint