import { useAjax } from '@/Hook/useAjax';
import { addCorpAccount, addRelation, getAdAccountAll, getCorpAccountList, getListByCorpAccount, getActionSet, configReportDefault } from '@/services/enterpriseWeChat/userMange';
import { Button, Space, Table, Tag, Modal, Input, Form, Transfer } from 'antd';
import React, { useEffect, useState, useCallback } from 'react';
import indexTableConfig from './indexTableConfig';
import style from './index.less'
import useCopy from '@/Hook/useCopy';
import { HeartFilled, HeartOutlined, PlusOutlined, SearchOutlined } from '@ant-design/icons';
import { TransferDirection } from 'antd/lib/transfer';
import expandedRowRenderConfig from './expandedRowRenderConfig';
import upConfig from './upConfig';
function userManage() {
    // =====变量========
    // 复制
    const { copy } = useCopy()
    // 配置参数详情弹窗
    const [dtVisible, setDtVisible] = useState(false)
    // add账号弹窗
    const [addVisible, setAddVisible] = useState(false)
    // 绑定微信弹窗
    const [showWx, setShowWx] = useState(false)
    //上报选择弹窗
    const [showUp, setShowUp] = useState(false)
    // 设置当前操作的企微
    const [actionQw, setActionQw] = useState<any>(null)
    // 设置当前展开的企微
    const [targetQw, setTargetQw] = useState<any>(null)
    // 企微列表搜索条件
    const [queryValue, setQueryValue] = useState({ corpName: '', corpId: '' })
    // 公众号列表
    const [wxList, setWxList] = useState<any>([])
    // 默认上报公众号
    const [dWx, setDwx] = useState<any>(0)
    // 当前企微绑定的公众号
    const [allWx, setAllWx] = useState<any>([])
    // 选中默认上报公众号数据源
    const [userActionSetId, setUserActionSetId] = useState<any>(0)
    // 当前选中的公众号
    const [acWx, setAcWx] = useState<any>(null)
    // form表单
    const [form] = Form.useForm();

    // ============接口==============
    // 获取企业微信列表
    const get_corpAccount_list = useAjax((params) => getCorpAccountList(params))
    // 新增企业微信接口
    const add_corpAccount = useAjax((params) => addCorpAccount(params), { msgNmae: '新增' })
    // 获取公众列表
    const get_adAccount_all = useAjax(() => getAdAccountAll())
    // 获取企业下绑定的公众号列表
    const get_listByCorpAccount = useAjax((corpAccountId) => getListByCorpAccount(corpAccountId))
    // 绑定公众号
    const add_relation = useAjax((params) => addRelation(params))
    // 获取当前公众号的数据源
    const get_actionSet = useAjax((adAccountId) => getActionSet(adAccountId))
    //设置上报源
    const config_report_default = useAjax((params) => configReportDefault(params))

    // ===========操作事件==============
    // 首次加载获取对应数据
    useEffect(() => {
        get_adAccount_all.run().then(res => {
            res = res?.map((item: { [x: string]: any; id: any; }) => { return { ...item, key: item.id } })
            setWxList(res)
        })
        get_corpAccount_list.run({ pageNum: 1, pageSize: 20 })
    }, [])
    //查看配置参数
    const lock = useCallback((value: any) => {
        setActionQw(value)
        setDtVisible(true)
    }, [])
    // 新增企业微信操作
    const add = useCallback(async () => {
        let values = await form.validateFields()
        add_corpAccount.run(values).then(res => {
            if (res) {
                setAddVisible(false)
                form.setFieldsValue({ corpName: '', corpId: '', userSecret: '', externalUserSecret: '', remark: '' })
            }
        })
    }, [])
    //条件查询企微列表
    const query = useCallback((params: any) => {
        Object.keys(queryValue).forEach(key => {
            if (!queryValue[key]) {
                delete queryValue[key]
            }
        })
        get_corpAccount_list.run({ ...params, ...queryValue })
    }, [queryValue])
    // 获取当前企微下的公众号
    const getWx = useCallback((record: any) => {
        let corpAccountId = record?.id
        get_listByCorpAccount.run(corpAccountId).then(res => {
            setTargetQw(record)//设置当前展开的企微数据
            let values = res?.map((item: { adAccountId: any; }) => item.adAccountId)
            let updef = res?.filter((item: { userActionSetId: any, reportDefaulted: boolean }) => item.userActionSetId && item.reportDefaulted)[0]//查找哪个是默认上报
            setAllWx(values)//设置默认当前企微绑定公众号
            setUserActionSetId(updef?.userActionSetId)
        })
    }, [])
    // 绑定公众号
    const bind = useCallback(() => {
        add_relation.run({ corpAccountId: actionQw.id, adAccountIds: allWx }).then(res => {
            if (res) {
                setShowWx(false)
                setAllWx([])
                setActionQw(null)
                setDwx(0)
                get_listByCorpAccount.refresh()
            }
        })
    }, [dWx, allWx, actionQw, get_listByCorpAccount])
    // 微信公众弹窗
    const wxShow = useCallback((value: any) => {
        setShowWx(true)
        setActionQw(value)
        setTargetQw(value)
    }, [])
    // 公众号选择事件
    const wxSelect = useCallback((targetKeys: string[], direction: TransferDirection, moveKeys: string[]) => {
        setAllWx(targetKeys)
    }, [allWx])
    // 获取当前公众号下的数据源
    const handelGetActionSet = useCallback((value: any) => {
        get_actionSet.run(value?.adAccountId).then(res => {
            if (res) {
                setShowUp(true)
                setAcWx(value)
            }
        })
    }, [])
    // 设置上报数据源
    const setY = useCallback(() => {
        config_report_default.run({ corpAccountId: targetQw?.id, adAccountId: acWx?.adAccountId, userActionSetId }).then(res => {
            if (res) {
                setShowUp(false)
                get_listByCorpAccount.refresh()
            }
        })
    }, [userActionSetId, acWx, targetQw, get_listByCorpAccount])
    // ============== dom渲染==============
    return <div>
        {/* 头部 */}
        <div style={{ display: 'flex', justifyContent: 'space-between', marginBottom: 15 }}>
            <Space>
                <Input placeholder='企业名称搜索' allowClear value={queryValue?.corpName} onChange={(e: any) => {
                    let value = e.target.value?.replace(/\s/ig, '')
                    setQueryValue({ ...queryValue, corpName: value })
                }} />
                <Input placeholder='企业ID搜索' allowClear value={queryValue?.corpId} onChange={(e: any) => {
                    let value = e.target.value?.replace(/\s/ig, '')
                    setQueryValue({ ...queryValue, corpId: value })
                }} />
                <Button onClick={() => { query({ pageNum: 1, pageSize: 20 }) }}><SearchOutlined />查询</Button>
            </Space>
            <Button onClick={() => { setAddVisible(true) }} type='primary'><PlusOutlined />新增企业微信</Button>
        </div>
        {/* table表 */}
        <Table
            size='small'
            columns={indexTableConfig(lock, wxShow)}
            dataSource={get_corpAccount_list?.data?.records || []}
            loading={get_adAccount_all?.loading}
            rowKey={(record) => {
                return record?.id
            }}
            bordered
            pagination={{ current: get_corpAccount_list?.data?.current, pageSize: get_corpAccount_list?.data?.size, total: get_corpAccount_list?.data?.total, showTotal: () => <Tag color="cyan">总共{get_corpAccount_list?.data?.total}数据</Tag>, defaultPageSize: 20 }}
            onChange={(pagination) => {
                query({ pageNum: pagination.current, pageSize: pagination.pageSize })
            }}
            expandable={{
                expandRowByClick: true,
                expandedRowKeys: targetQw !== null ? [targetQw?.id] : [],
                onExpand: (expanded, record) => {
                    expanded && getWx(record)
                    !expanded && setTargetQw(null)
                },
                expandedRowRender: (record, index, indent, expanded) => {
                    return <div style={{ marginLeft: 18 }}>
                        <Table bordered columns={expandedRowRenderConfig(handelGetActionSet)} dataSource={get_listByCorpAccount?.data} pagination={false} loading={get_listByCorpAccount?.loading} rowKey={(record) => {
                            return record?.adAccountId
                        }} />
                    </div>
                }
            }}
        />
        {/* 配置参数展示弹窗 */}
        <Modal
            visible={dtVisible}
            title='配置参数'
            width={600}
            maskClosable={false}
            footer={null}
            onCancel={() => {
                setDtVisible(false)
                setActionQw(null)
            }}
        >
            {actionQw && <div className={style.dtcs}>
                {
                    ['aesKey', 'eventNotifyUrl', 'token'].map((name) => {
                        let newName = name === 'token' ? 'Token' : name === 'eventNotifyUrl' ? '回调URL' : 'EncodingAESKey'
                        return <div key={name}><strong >{newName}:</strong><a onClick={() => { copy(actionQw[name]) }}>{actionQw[name]}</a></div>
                    })
                }
            </div>}
        </Modal>
        {/* 添加企微弹窗 */}
        <Modal
            visible={addVisible}
            title='新增企业微信'
            width={480}
            maskClosable={false}
            onCancel={() => {
                setAddVisible(false)
            }}
            onOk={add}
            confirmLoading={add_corpAccount?.loading}
        >
            <Form
                form={form}
                name="basic"
                labelCol={{ span: 5 }}
                wrapperCol={{ span: 19 }}
                autoComplete="off"
            >
                <Form.Item
                    label="企业名称"
                    name="corpName"
                    rules={[{ required: true, message: '请输入企业名称!' }]}
                >
                    <Input allowClear />
                </Form.Item>
                <Form.Item
                    label="企业ID"
                    name="corpId"
                    rules={[{ required: true, message: '请输入企业ID!' }]}
                >
                    <Input allowClear />
                </Form.Item>
                <Form.Item
                    label="通讯录密钥"
                    name="userSecret"
                    rules={[{ required: true, message: '请输入通讯录密钥!' }]}
                >
                    <Input allowClear />
                </Form.Item>
                <Form.Item
                    label="客户密钥"
                    name="externalUserSecret"
                    rules={[{ required: true, message: '请输入客户密钥!' }]}
                >
                    <Input allowClear />
                </Form.Item>
                <Form.Item
                    label="备注"
                    name="remark"
                    rules={[{ required: false, message: '请输入备注!' }]}
                >
                    <Input.TextArea allowClear role='2' />
                </Form.Item>
            </Form>
        </Modal>
        {/* 绑定公众号 */}
        <Modal
            visible={showWx}
            title={<div>绑定公众号</div>}
            width={580}
            maskClosable={false}
            onCancel={() => {
                setShowWx(false)
            }}
            onOk={bind}
            confirmLoading={add_relation?.loading}
        >
            <Transfer
                dataSource={wxList}
                showSearch
                listStyle={{
                    width: 250,
                    height: 300,
                }}
                operations={['添加', '移除']}
                targetKeys={allWx}
                onChange={wxSelect}
                filterOption={(inputValue, option) => {
                    let reg = /[^\u4E00-\u9FA5]/
                    if (!reg.test(inputValue)) {
                        if (option['wechatAccountName']?.includes(inputValue)) {
                            return true
                        }
                        return false
                    } else {
                        return true
                    }
                }}
                render={item => <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
                    {item?.wechatAccountName || item?.wechatAccountId}
                    {
                        allWx.some((i: any) => i === item.id) && <span
                            onClick={(e) => {
                                e.stopPropagation()
                                setDwx(dWx === item?.id ? 0 : item?.id)
                            }} >
                        </span>
                    }
                </div>
                }
            />

        </Modal>
        {/* 设置默认上报源 */}
        <Modal
            visible={showUp}
            title={<div>选择上报源</div>}
            width={580}
            maskClosable={false}
            onCancel={() => {
                setShowUp(false)
            }}
            onOk={setY}
            confirmLoading={add_relation?.loading}
        >
            <Table
                bordered
                columns={upConfig(handelGetActionSet)}
                dataSource={get_actionSet?.data}
                pagination={false}
                loading={get_actionSet?.loading}

                rowSelection={{
                    type: 'radio',
                    selectedRowKeys: [userActionSetId],
                    onSelect: (record) => {
                        setUserActionSetId(record?.userActionSetId)
                    }
                }}
                rowKey={(record) => {
                    return record?.userActionSetId
                }} />
        </Modal>
    </div>
}
export default userManage