import { CloseOutlined, SearchOutlined } from "@ant-design/icons"
import { Button, Checkbox, Input, message, Modal, Spin } from "antd"
import React, { useCallback, useEffect, useState } from "react"
import './index.less'
import { ReactComponent as DrawStem } from '@/assets/drawStem.svg'
import { SortableContainer, SortableElement, SortableHandle } from "react-sortable-hoc";
import arrayMove from "array-move";
import { useModel } from "umi"

const DragHandle = SortableHandle(() => <DrawStem className='draw' />);
const SortableItem = SortableElement(({ item, del }: any) => {
    return <li className='liDraw'>
        <div className='lileft'><DragHandle /><div>{item.index_name}</div></div>
        {item.db_name !== 'pos_type' && <div className="clear" onClick={() => { del() }}><CloseOutlined /></div>}
    </li>
});
/** 外层 */
const SortableList = SortableContainer(({ children }: { children: any }) => (<ul className='selectedList'>{children}</ul>));

interface IndexListProps {
    index_name: string,
    index_description: string,
    db_name: string,
    for_pos_type: string,
    for_ad_level: string,
    is_default: number,
    format_type: string,
    support_crowd: number,
    name_desc: string
}

interface DataProps {
    index_classify_name: string,
    indexList: IndexListProps[]
}

/**
 * 自定义列
 */
type customProps = {
    visible?: boolean,
    onChange?: () => void,
    onClose?: () => void,
    unames?: {
        MP?: any,
        ADQ?: any,
        id: number
    }[]
}
function CustomListModel(props: customProps) {
    const { visible, onChange, onClose, unames } = props

    const { getAdsTableConfig, getUserConfig, updateUserConfig } = useModel('useLaunch.useAdAuthorize')
    // dataA 总数据
    // 数据开始
    const [dataA, setDataA] = useState<DataProps[]>([])
    const [data, setData] = useState<DataProps[]>([])
    const [search, setSearch] = useState<string>('')  // 搜索字段
    const [selectData, setSelectData] = useState<IndexListProps[]>([])
    const [serverData, setServerData] = useState<IndexListProps[]>([])
    // 数据结束

    // 获取数据
    useEffect(() => {
        getList(false)
        getUserList()
    }, [])

    // 获取所有配置信息
    const getList = (update: boolean) => {
        getAdsTableConfig.run({ update }).then((res: any) => {
            if (res?.data) {
                setDataA(() => JSON.parse(res?.data))
                setData(() => JSON.parse(res?.data))
            }
        })
    }
    // 获取个人配置
    const getUserList = () => {
        getUserConfig.run().then((res: any) => {
            if (res?.data) {
                setSelectData(() => JSON.parse(res?.data))
                setServerData(() => JSON.parse(res?.data))
            } else {
                setSelectData(() => [
                    { index_name: "广告位", index_description: "广告展现的位置。", db_name: "pos_type", for_pos_type: "mp", for_ad_level: "all", is_default: 0, format_type: "", support_crowd: 0, name_desc: "" }
                ])
            }
        })
    }

    // 搜索 过滤
    const searchHandle = useCallback((value: string) => {
        setSearch(value)
        if (search) {
            let newData1: any[] = []
            dataA.forEach((item: DataProps) => {
                let newData = item.indexList.filter((listItem: IndexListProps) => {
                    if (listItem?.index_name?.includes(value)) {
                        return listItem
                    } else {
                        return null
                    }
                })
                if (newData?.length > 0) {
                    newData1.push({ ...item, indexList: newData })
                }
            })
            setData([...newData1])
        } else {
            setData(dataA)
        }
    }, [data, dataA, search])

    // 选中数据
    const selectHandle = useCallback((checked: boolean, data: IndexListProps) => {
        if (checked) {
            setSelectData([...selectData, { ...data }])
        } else {
            let newSelectData = selectData.filter((item: IndexListProps) => {
                if (item.db_name === data.db_name) {
                    return null
                } else {
                    return item
                }
            })
            setSelectData(newSelectData)
        }
    }, [selectData])

    // 每个大项 全选
    const checkAllHandle = useCallback((checked: boolean, value: string) => {
        let oldData = data.find((item: DataProps) => item.index_classify_name === value)
        if (oldData) {
            if (checked) {
                let newSelectData: any[] = selectData
                oldData.indexList.forEach((item: IndexListProps) => {
                    if (selectData.findIndex((selsectItem: IndexListProps) => selsectItem.db_name === item.db_name) === -1) {
                        newSelectData.push(item)
                    }
                })
                console.log(value,newSelectData,oldData)
                setSelectData([...newSelectData])
            } else {
                let newSelectData = selectData.filter((item: IndexListProps) => {
                    if (oldData?.indexList?.some((dataItem: IndexListProps) => dataItem.db_name === 'pos_type' ? false : dataItem?.db_name === item.db_name)) {
                        return null
                    } else {
                        return item
                    }
                })
                setSelectData(newSelectData)
            }
        }

    }, [selectData, data])

    const onSortEnd = ({ oldIndex, newIndex }: { oldIndex: number, newIndex: number }) => {
        setSelectData(arrayMove(selectData, oldIndex, newIndex))
    }
    // 提交
    const onSubmit = useCallback(() => {
        let idList: any[] = []
        unames?.forEach((item: { MP?: any, ADQ?: any, id: number }) => {
            let { MP } = item
            if (MP?.length > 0) {
                let mpIds = MP?.map((m: any) => m?.id)
                idList = idList.concat(mpIds)
            }
        })     
        updateUserConfig.run({idList, tableConfig: JSON.stringify(selectData)}).then((res: any) => {
            if (res?.data) {
                message.success('同步成功')
                onClose && onClose()
            }
        })
    }, [unames, serverData, selectData])

    return <Modal
        title={null}
        footer={null}
        visible={visible}
        width={960}
        className='customListModel'
        onCancel={() => { onClose && onClose() }}
    >
        <div className='content'>
            <div className='left'>
                <div className='leftSearch'>
                    <Input size="small" placeholder="输入关键词，搜索数据指标" onChange={(e) => { searchHandle(e.target.value) }} value={search} prefix={<SearchOutlined style={{ color: '#a3a3a3', fontSize: 18 }} />} allowClear bordered={false} />
                </div>

                <div className="dataList">
                    <Spin spinning={getAdsTableConfig.loading}>
                        {data?.map((item: DataProps, index: number) => {
                            return <dl key={index}>
                                <dt>
                                    <Checkbox onChange={(e) => { checkAllHandle(e.target.checked, item.index_classify_name) }} className='checkbox'>{item.index_classify_name}</Checkbox>
                                </dt>
                                {item.indexList?.map((listItem: IndexListProps, listIndex: number) => {
                                    return <dd key={item.index_classify_name + listIndex}>
                                        <Checkbox onChange={(e) => { selectHandle(e.target.checked, listItem) }} disabled={listItem.db_name === 'pos_type'} checked={selectData.some((selectItem: { db_name: string }) => selectItem.db_name === listItem.db_name)} className='checkbox'>{listItem.index_name}</Checkbox>
                                    </dd>
                                })}
                            </dl>
                        })}
                    </Spin>
                </div>
            </div>
            <div className='right'>
                <div className='rightTitle'>
                    <div className="rightTitleLeft">已选<span>{selectData?.length}</span>项</div>
                </div>
                <SortableList axis='y' onSortEnd={onSortEnd} useDragHandle>
                    {selectData.map((item: IndexListProps, index: number) => <SortableItem key={'li' + index} index={index} item={item} del={() => { selectHandle(false, item) }} />)}
                </SortableList>
                <div className='rightOperate'>
                    <Button type='link' loading={getAdsTableConfig.loading} onClick={() => { getList(true) }}>刷新</Button>
                    <div>
                        <Button onClick={() => { onClose && onClose() }}>取消</Button>
                        <Button type='primary' className='confirm' loading={updateUserConfig.loading} onClick={() => { onSubmit() }}>确认</Button>
                    </div>
                </div>
            </div>
        </div>
    </Modal>
}

export default React.memo(CustomListModel)