
import HocError from '@/Hoc/HocError'
import { Button, Card, Form, Input, message, Modal, Radio, Select, Space, Table, Tag ,Tabs} from 'antd'
import React, { useCallback, useEffect, useState } from 'react'
import { columnsMp, columnsAdq } from './tableConfig'
import LaunchRefresh from './launchRefresh'
import { useModel } from 'umi'
import AdLogin from '../components/adLogin'
import { getCookie, setCookie } from '@/utils/cry'
import { CloudDownloadOutlined, EyeOutlined, QuestionCircleOutlined } from '@ant-design/icons'


/** 投放管理 */
const AdAuthorize: React.FC = () => {
    const [form] = Form.useForm();
    const [refreshShow, setRefreshShow] = useState<boolean>(false) // 刷新账户弹窗控制
    const [channel, setChannel] = useState<string>('MP') // 选择渠道
    const [paging, setPaging] = useState<{ pageSize: number, pageNum: number, withChannel: boolean, uname?: string, selectServer?: number }>({ pageSize: 20, pageNum: 1, withChannel: true }) // 用户表格参数
    const { allOfLoginUser, adsChannelAccountAdq1, adsChannelAccountMp1, mpSc, adqSc, loginAd } = useModel('useLaunch.useAdAuthorize')
    const userId = useModel('@@initialState',model=>model.initialState?.currentUser?.userId as string)
    const [authData, setAuthData] = useState<{ base64: string, code: string }>({ base64: '', code: '' })
    const [lock,setLock] = useState(false)
    const [errShow,setErrShow]=useState(false)
    /** 查询 */
    const submitForm = useCallback((values: any) => {
        setPaging({ ...paging, ...values, pageNum: 1 })
    }, [paging])
    /** 重置 */
    const onReset = useCallback(() => {
        form.resetFields();
    }, [])


    /**  */
    const onAuthorize = () => {
        // setWarrant(true)
        setRefreshShow(true)
    }

    useEffect(() => {
        // 获取服务商列表
        allOfLoginUser.run()
    }, [])

    /** 获取列表 */
    useEffect(() => {
        if (channel === 'MP') {
            adsChannelAccountMp1.run({ ...paging })
        } else {
            adsChannelAccountAdq1.run({ ...paging })
        }
    }, [channel, paging])

    /**收藏*/
    const collect = useCallback((arg: { id: any, c: boolean, name: 'adq' | 'mp' }) => {
        let { id, c, name } = arg
        if (name === 'mp') {
            mpSc.run({ accountId: id, collect: c }).then((res) => {
                adsChannelAccountMp1.refresh()
            })
        } else {
            adqSc.run({ accountId: id, collect: c }).then((res) => {
                adsChannelAccountAdq1.refresh()
            })
        }
    }, [adsChannelAccountMp1, adsChannelAccountAdq1])

    /**验证授权*/
    const checkLogin = useCallback((fn: () => void) => {
        let isLogin = getCookie('mpLogin'+userId) || getCookie(userId)
        if (!isLogin) {
            let hide = message.warning('验证授权状态中,成功授权后请重新点击....', 0)
            loginAd.run({ scanCode: 'wx' }).then((res: any) => {
                if (res?.code === 1003 && res?.data?.base64) {
                    // setIsUpdataAcc(false)
                    setAuthData(res?.data)
                    // setBacse64(res?.data?.base64, res?.data?.code)
                } else if (res?.code === 500) {
                    console.log('接口出错')
                } else if (res?.code === 200) {
                    console.log('已授权3', res)
                    setCookie('mpLogin'+userId, 'true', 1)
                    fn()
                }
                hide()
            })
        } else {
            fn()
        }
    }, [])
    /**帮助跳转页面 */
    const help = useCallback(() => {
        window.open('https://shimo.im/docs/xvHKKtJgXXkrhRTy')
    }, [])
    const plugin=useCallback(()=>{
        window.open('http://test.zanxiangnet.com/aaplugin/插件.zip')
    },[])
    return <Card
        title={<Space wrap>
            <Radio.Group value={channel} onChange={(e) => { setChannel(e.target.value); setPaging({ pageSize: 20, pageNum: 1, withChannel: true }) }}>
                <Radio.Button value="MP">MP</Radio.Button>
                {/* <Radio.Button value="ADQ">ADQ</Radio.Button> */}
            </Radio.Group>
            <Form
                layout="inline"
                form={form}
                onFinish={submitForm}
            >
                <Form.Item label="服务商" name="channelId">
                    <Select style={{ width: 180 }} placeholder="选择服务商" allowClear>
                        {allOfLoginUser?.data?.data?.map((item: { id: number, accountName: string }) => <Select.Option value={item?.id} key={item?.id}>{item?.accountName}</Select.Option>)}
                    </Select>
                </Form.Item>
                <Form.Item label="广告主名称" name="uname">
                    <Input placeholder="输入广告主" />
                </Form.Item>
                <Form.Item>
                    <Space>
                        <Button type="primary" htmlType="submit">查询</Button>
                        <Button onClick={onReset}>重置</Button>
                    </Space>
                </Form.Item>
            </Form>
        </Space>}
        extra={<Space>
            <Button onClick={plugin} ><CloudDownloadOutlined />插件下载</Button>
            <Button onClick={()=>{setLock(true)}} ><EyeOutlined />插件安装演示</Button>
            <Button onClick={help} >帮助<QuestionCircleOutlined /></Button>
            {/* <Button onClick={()=>{setErrShow(true)}} type="primary" danger>错误信息帮助<QuestionCircleOutlined /></Button> */}
            <Button type="primary" onClick={() => { checkLogin(onAuthorize) }}>授权/刷新账户</Button>
        </Space>}
    >
        {refreshShow && <LaunchRefresh show={refreshShow} onClose={() => { setRefreshShow(false) }}></LaunchRefresh>}
        {
            channel === "MP" ? <Table dataSource={adsChannelAccountMp1?.data?.data?.records} loading={adsChannelAccountMp1?.loading} columns={columnsMp(collect)} size="small" bordered
                pagination={{
                    position: ['bottomRight'],
                    total: adsChannelAccountMp1?.data?.data?.total,//总共多少条数据,服务器给,设置后分页自动计算页数
                    showTotal: (total) => <Tag color="cyan">总共{total}数据</Tag>,
                    showSizeChanger: true,
                    showLessItems: true,
                    defaultCurrent: 1,
                    defaultPageSize: 20,//默认初始的每页条数
                    current: paging?.pageNum || 1,
                    pageSize: paging?.pageSize || 20,
                    onChange: (page, pageSize) => { setPaging({ ...paging, pageNum: page, pageSize: pageSize as number }) }
                }}
                rowKey={(row) => row.id}
            /> :
                <Table dataSource={adsChannelAccountAdq1?.data?.data?.records} loading={adsChannelAccountAdq1?.loading} columns={columnsAdq(collect)} size="small" bordered
                    pagination={{
                        position: ['bottomRight'],
                        total: adsChannelAccountAdq1?.data?.data?.total,//总共多少条数据,服务器给,设置后分页自动计算页数
                        showTotal: (total) => <Tag color="cyan">总共{total}数据</Tag>,
                        showSizeChanger: true,
                        showLessItems: true,
                        defaultCurrent: 1,
                        defaultPageSize: 20,//默认初始的每页条数
                        current: paging?.pageNum || 1,
                        pageSize: paging?.pageSize || 20,
                        onChange: (page, pageSize) => { setPaging({ ...paging, pageNum: page, pageSize: pageSize as number }) }
                    }}
                    rowKey={(row) => row.id}
                />
        }
        {/* 授权登录 */}
        <AdLogin onClose={() => { setAuthData({ base64: '', code: '' }) }} value={authData} onChange={() => { setAuthData({ base64: '', code: '' }) }} />
        {/* 插件安装演示弹窗 */}
        {
            lock && <Modal
                    visible={lock}
                    onCancel={()=>{setLock(false)}}
                    width={'80%'}
                    title={<><h3>插件演示<span style={{color:'red',fontSize:14}}>(注:一定要开启无痕模式)</span></h3></>}
                    footer={null}
                >
                    <Tabs defaultActiveKey={'1'}>
                        <Tabs.TabPane tab='首次安装' key={'1'}>
                        <video src='https://zx-oss-dev.oss-cn-hangzhou.aliyuncs.com/file/C6B091FEDB8C461898F2F0297ADFF864.mp4' style={{width:'100%'}} controls/>
                        </Tabs.TabPane>
                        <Tabs.TabPane tab='版本更新' key={'2'}>
                        <video src='https://zx-oss-dev.oss-cn-hangzhou.aliyuncs.com/file/078AA816C9DE4498B78CEC0854F29530.mp4' style={{width:'100%'}} controls/>
                        </Tabs.TabPane>
                        <Tabs.TabPane tab='开启无痕' key={'3'}>
                        <video src='https://zx-oss-dev.oss-cn-hangzhou.aliyuncs.com/file/82954CAE8F634CD48C8596CBFBF21AC5.mp4' style={{width:'100%'}} controls/>
                        </Tabs.TabPane>
                    </Tabs>
                    
            </Modal>
        }
        {/* 错误信息帮助 */}
        {
            errShow && <Modal
            visible={errShow}
            onCancel={()=>{setErrShow(false)}}
            width={'60%'}
            title={<><h3>任务错误信息帮助</h3></>}
            footer={null}
        >
            <div>

            </div>
            
    </Modal>
        }
    </Card>
}

export default HocError(AdAuthorize)