import { CheckOutlined } from "@ant-design/icons";
import { Button, Checkbox, Input, Modal, Radio, Space, Spin, Table, Tag, Tooltip, message } from "antd";
import { CheckboxValueType } from "antd/es/checkbox/Group";
import React, { useCallback, useEffect, useReducer, useState } from "react";
import { useModel } from "umi";
import './index.less'
import { columnsMp, columnsAdq } from './tableConfigAd'
import AdLogin from '../components/adLogin'
import CustomListModel from './customListModel'

interface State {
    unames: {
        MP?: any,
        ADQ?: any,
        id: number
    }[]
}

interface Action {
    type: 'init' | 'unames',
    params?: any
}

function reducer(state: State, action: Action) {
    let { type, params } = action
    switch (type) {
        case 'unames':
            const newState = { ...state, unames: [...params.unames] }
            return newState
        case 'init':
            return {
                unames: []
            }
        default:
            return state
    }
}



type Props = {
    show?: boolean
    onClose?: () => void,
    onChange?: () => void
}
export default function LaunchRefresh(props: Props) {
    const initState = {
        unames: []
    }
    const { show = false, onClose, onChange } = props
    const [state, dispatch] = useReducer(reducer, initState)
    const [checkAll, setCheckAll] = useState<boolean>(false);   // 全选
    const [checkedList, setCheckedList] = useState<CheckboxValueType[]>([]);
    const [indeterminate, setIndeterminate] = useState(false);  // 没全选
    const [ispList, setIspList] = useState<any[]>([]);  // 服务商列表
    const [selectServer, setSelectServer] = useState<number>(0) // 点击选中的服务商
    const [channel, setChannel] = useState<string>('MP') // 选择渠道
    const [isUpdataAcc, setIsUpdataAcc] = useState<boolean>(false)  // 是否是更新账号密码
    const [paging, setPaging] = useState<{ pageSize: number, pageNum: number, uname?: string }>({ pageSize: 20, pageNum: 1 }) // 用户表格参数
    const [authData, setAuthData] = useState<{ base64: string, code: string }>({ base64: '', code: '' })
    const [tabConfigShow, setTabConfigShow] = useState<boolean>(false)

    const { updateChannelInfo, allOfLoginUser, adsChannelAccountAdq, adsChannelAccountMp, getUserInfo, mpSc, adqSc } = useModel('useLaunch.useAdAuthorize')

    useEffect(() => {
        if (show) {
            allOfLoginUser.run().then((res: any) => {
                setIspList(() => res?.data)
                if (res?.data?.length > 0) {
                    setSelectServer(() => res?.data[0]?.id)
                }
            })
            getUser()
        }
    }, [show])

    /** 获取用户更新状态 */
    const getUser = useCallback(() => {
        getUserInfo.run()
    }, [])

    useEffect(() => {
        return () => {
            dispatch({ type: 'unames', params: { unames: [] } })
        }
    }, [])

    useEffect(() => {
        if (selectServer > 0) {
            if (channel === 'MP') {
                adsChannelAccountMp.run({ ...paging, channelId: selectServer })
            } else {
                adsChannelAccountAdq.run({ ...paging, channelId: selectServer })
            }
        }
    }, [channel, selectServer, paging])

    const checkboxOnChange = useCallback((list: CheckboxValueType[]) => {
        setCheckedList(list);
        setIndeterminate(!!list.length && list.length < ispList.length);
        setCheckAll(list.length === ispList.length);
    }, [ispList])

    const onCheckAllChange = (e: any) => {
        if (e.target.checked) {
            setCheckedList(ispList?.map((item: any) => item?.id))
        } else {
            setCheckedList([])
        }
        setIndeterminate(false);
        setCheckAll(e.target.checked);
    };

    const onSearch = (value: string) => {
        setPaging({ ...paging, uname: value, pageNum: 1 })
    }

    /** 设置账号密码 */
    const setBacse64 = useCallback((base64: string, code: string) => {
        setAuthData({ base64, code })
    }, [authData])


    /** 全部更新 */
    // const refreshAllHandle = useCallback(() => {
    //     updateChannelInfo.run({ updateName: 'all' }).then((res: any) => {
    //         if (res?.code === 1003 && !res?.data?.base64) {
    //             setWarrant(true)
    //             setIsUpdataAcc(false)
    //         } else if (res?.code === 1003 && res?.data?.base64) {
    //             setBacse64(res?.data?.base64, res?.data?.code)
    //         }
    //     })
    // }, [warrant, isUpdataAcc])

    // console.log('unames[selectServer][channel]', unames);
    /** 更新人群包 */
    const refreshOrientPackage = useCallback(() => {
        let channels: number[] = []
        let channelMpAccount: any = {}
        let channelAdqAccount: any = {}
        state?.unames?.forEach((item: { id: number, MP: any[], ADQ: any[] }) => {
            let { id, MP, ADQ } = item
            if (MP?.length > 0 || ADQ?.length > 0) {
                channels.push(id)
                let mpIds = MP?.map((m: any) => m?.id)
                let adqIds = ADQ?.map((a: any) => a?.id)
                if (mpIds?.length > 0) {
                    channelMpAccount[id] = mpIds
                }
                if (adqIds?.length > 0) {
                    channelAdqAccount[id] = adqIds
                }
            }
        })
        // dispatch({ type: 'unames', params: { unames: [] } })
        updateChannelInfo.run({ updateName: 'crowd_package', channels, channelMpAccount, channelAdqAccount }).then((res: any) => {
            if (res?.code === 1003 && res?.data?.base64) {
                setBacse64(res?.data?.base64, res?.data?.code)
                setIsUpdataAcc(false)
            } else if (res?.code === 200) {
                message.success('正在刷新，可关闭当前窗口，刷新完成会钉钉通知')
                dispatch({ type: 'unames', params: { unames: [] } })
            }
        })

    }, [state?.unames, isUpdataAcc, authData])

    /** 刷新服务商 */
    const refreshServerISP = useCallback(() => {
        updateChannelInfo.run({ updateName: 'channel' }).then((res: any) => {
            if (res?.code === 1003 && res?.data?.base64) {
                setIsUpdataAcc(false)
                setBacse64(res?.data?.base64, res?.data?.code)
            } else if (res?.code === 200) {
                message.success('正在刷新，可关闭当前窗口，刷新完成会钉钉通知')
            }
            getUserInfo.refresh()
        })
    }, [isUpdataAcc, authData])
    /** 同步公众号列表 */
    const refreshAccount = useCallback(() => {
        updateChannelInfo.run({ updateName: 'user', channels: checkedList }).then((res: any) => {
            if (res?.code === 1003 && res?.data?.base64) {
                setBacse64(res?.data?.base64, res?.data?.code)
                setIsUpdataAcc(false)
            } else if (res?.code === 200) {
                message.success('正在刷新，可关闭当前窗口，刷新完成会钉钉通知')
            }
        })
    }, [checkedList, isUpdataAcc, authData, authData])

    /** 更新账号密码 */
    const refreshAccPwd = useCallback(() => {
        setIsUpdataAcc(true)
        setBacse64("", "更新账号密码")
    }, [isUpdataAcc])
    /**收藏*/
    const collect = useCallback((arg: { id: any, c: boolean, name: 'adq' | 'mp' }) => {
        let { id, c, name } = arg
        if (name === 'mp') {
            mpSc.run({ accountId: id, collect: c }).then((res) => {
                adsChannelAccountMp.refresh()
            })
        } else {
            adqSc.run({ accountId: id, collect: c }).then((res) => {
                adsChannelAccountAdq.refresh()
            })
        }
    }, [adsChannelAccountMp, adsChannelAccountAdq])
    return <div>
        {/* 广告后台字段配置 */}
        {tabConfigShow && <CustomListModel unames={state?.unames} visible={tabConfigShow} onClose={() => { setTabConfigShow(false) }} />}
        {/* 授权登录 */}
        <AdLogin isUpdataAcc={isUpdataAcc} value={authData} onClose={() => { setAuthData({ base64: '', code: '' }) }} onChange={() => { setAuthData({ base64: '', code: '' }); message.success('正在刷新，可关闭当前窗口，刷新完成会钉钉通知') }} />
        <Modal
            title='授权/刷新账户'
            visible={show}
            onCancel={() => { onClose && onClose() }}
            footer={null}
            maskClosable
            width={1000}
            destroyOnClose
            className="launchRefresh"
        >
            <Space className="refBts">
                {/* <Tooltip placement="topLeft" color="#fff" title={<div className="refreshNotice">
                    <p><CheckOutlined /> 已刷新</p>
                    <p>上次刷新 2021/07/20</p>
                </div>}
                >
                    <Button type="primary" onClick={refreshAllHandle} loading={updateChannelInfo?.loading}>全部更新</Button>
                </Tooltip> */}
                <Tooltip placement="topLeft" color="#fff" title={<div className="refreshNotice">
                    <p><CheckOutlined /> 已刷新</p>
                    <p>上次刷新 {getUserInfo?.data?.data?.lastUpdateDataTime}</p>
                </div>}
                >
                    <Button type="primary" onClick={refreshServerISP} loading={updateChannelInfo?.loading}>刷新服务商列表</Button>
                </Tooltip>
                <Button type="primary" disabled={checkedList.length === 0} onClick={refreshAccount} loading={updateChannelInfo?.loading}>同步公众号列表</Button>
                <Button type="primary" disabled={!state?.unames?.some((item: any) => item?.MP?.length > 0 || item?.ADQ?.length > 0)} onClick={refreshOrientPackage} loading={updateChannelInfo?.loading}>更新人群包/商品</Button>
                {/* <Button type="primary" onClick={refreshAccPwd}>更新账号密码</Button> */}
                <Button type="primary" onClick={()=>{ setTabConfigShow(true) }} disabled={!state?.unames?.some((item: any) => item?.MP?.length > 0 || item?.ADQ?.length > 0)}>同步自定义列</Button>
            </Space>
            <div className="refContent">
                <div className="left">
                    <Spin spinning={allOfLoginUser?.loading}>
                        <h4>服务商账户</h4>
                        <Checkbox indeterminate={indeterminate} onChange={onCheckAllChange} checked={checkAll} style={{ margin: '10px 0 5px' }}>全选</Checkbox>
                        <Checkbox.Group style={{ width: '100%' }} value={checkedList} onChange={checkboxOnChange}>
                            {ispList?.length > 0 && ispList.map((item: any, index: number) => {
                                return <div className={`isp ${item?.id === selectServer ? 'selectServer' : ''}`} key={item?.id} onClick={() => { setSelectServer(item?.id) }}>
                                    <Checkbox value={item?.id}></Checkbox> <span>{item?.accountName}</span> {(state?.unames?.find((it: any) => it?.id === item?.id)?.MP?.length > 0 || state?.unames?.find((it: any) => it?.id === item?.id)?.ADQ?.length > 0) && <CheckOutlined />}
                                </div>
                            })}
                        </Checkbox.Group>
                    </Spin>


                </div>
                <div className="right">
                    <Space direction="vertical" style={{ width: '100%' }}>
                        <Space>
                            <Radio.Group value={channel} onChange={(e) => { setChannel(e.target.value); setPaging({ pageSize: 20, pageNum: 1 }) }}>
                                <Radio.Button value="MP">MP {state?.unames?.find((it: any) => it?.id === selectServer)?.MP?.length > 0 && <CheckOutlined />}</Radio.Button>
                                {/* <Radio.Button value="ADQ">ADQ {state?.unames?.find((it: any) => it?.id === selectServer)?.ADQ?.length > 0 && <CheckOutlined />}</Radio.Button> */}
                            </Radio.Group>
                            <Input.Search placeholder="请输入广告主名称" onSearch={onSearch} style={{ width: 200 }} allowClear />
                        </Space>
                        {
                            channel === "MP" ? <Table dataSource={adsChannelAccountMp?.data?.data?.records} scroll={{ x: 660, y: 300 }} loading={adsChannelAccountMp?.loading} columns={columnsMp(collect)} size="small" bordered pagination={{
                                position: ['bottomLeft'],
                                total: adsChannelAccountMp?.data?.data?.total,//总共多少条数据,服务器给,设置后分页自动计算页数
                                showTotal: (total) => <Tag color="cyan">总共{total}数据</Tag>,
                                showSizeChanger: true,
                                showLessItems: true,
                                defaultCurrent: 1,
                                defaultPageSize: 20,//默认初始的每页条数
                                current: paging?.pageNum || 1,
                                pageSize: paging?.pageSize || 20,
                                onChange: (page, pageSize) => { setPaging({ ...paging, pageNum: page, pageSize: pageSize as number }) }
                            }}
                                rowKey={(row) => row.id}
                                rowSelection={{
                                    selectedRowKeys: state?.unames?.find((item: any) => item?.id === selectServer)?.[channel]?.map((item: any) => item.id),
                                    onChange: (selectedRowKeys, selectedRows) => {
                                        let index = state?.unames?.findIndex((item: any) => item?.id === selectServer)
                                        let data = state?.unames
                                        let ch: any = {}
                                        ch[channel] = selectedRows
                                        ch.id = selectServer
                                        if (index !== -1) {
                                            data[index] = { ...ch }
                                        } else {
                                            data?.push({ ...ch })
                                        }
                                        dispatch({ type: 'unames', params: { unames: [...data] } })
                                    }
                                }} /> :
                                <Table dataSource={adsChannelAccountAdq?.data?.data?.records} scroll={{ x: 660, y: 300 }} loading={adsChannelAccountAdq?.loading} columns={columnsAdq(collect)} size="small" bordered pagination={{
                                    position: ['bottomLeft'],
                                    total: adsChannelAccountAdq?.data?.data?.total,//总共多少条数据,服务器给,设置后分页自动计算页数
                                    showTotal: (total) => <Tag color="cyan">总共{total}数据</Tag>,
                                    showSizeChanger: true,
                                    showLessItems: true,
                                    defaultCurrent: 1,
                                    defaultPageSize: 20,//默认初始的每页条数
                                    current: paging?.pageNum || 1,
                                    pageSize: paging?.pageSize || 20,
                                    onChange: (page, pageSize) => { setPaging({ ...paging, pageNum: page, pageSize: pageSize as number }) }
                                }}
                                    rowKey={(row) => row.id}
                                    rowSelection={{
                                        selectedRowKeys: state?.unames?.find((item: any) => item?.id === selectServer)?.[channel]?.map((item: any) => item.id),
                                        onChange: (selectedRowKeys, selectedRows) => {
                                            let index = state?.unames?.findIndex((item: any) => item?.id === selectServer)
                                            let select = state?.unames?.find((item: any) => item?.id === selectServer)
                                            let data = state?.unames
                                            let ch: any = {}
                                            ch[channel] = selectedRows
                                            ch.id = selectServer
                                            if (index !== -1) {
                                                data[index] = { ...select, ...ch }
                                            } else {
                                                data?.push({ ...ch })
                                            }
                                            dispatch({ type: 'unames', params: { unames: [...data] } })
                                        }
                                    }} />
                        }

                    </Space>
                </div>
            </div>
        </Modal>
    </div>
}