import React, { useCallback, useEffect, useMemo, useState } from 'react'
import { Button, Card, Descriptions, Drawer, message, Row, Tabs } from 'antd'
import Form from '@/components/Formitem'
import { FormConfig } from '@/components/Formitem/type'
import { useRequest } from 'umi';
import { allBook, switchBook, logBook, getBookAll } from '@/services/operating/book';
const { TabPane } = Tabs;
interface Props {
    name: string,
    visible: boolean,
    fnc: () => void,
    mpid: string,
    fnlist: any,
    platformInfo?: {
        id: string,
        platformName: string,
        remark: string,
        bookName: string,
        platformPassword: string,
        platformAccount: string,
        vipAccounts: {
            id: number,
            periodId: string,
            account: string,
            mpName: string,
            periodInfo: {
                period: string
            }
        }[]
    }
}

let DarwerPage = React.memo((props: Props) => {
    let { name, visible, fnc, mpid, platformInfo, fnlist } = props
    const [arr, setArr] = useState<{ value: string, text: string }[]>([])//处理后的select数组
    const [loding, setLoding] = useState<boolean>(false)//加载状态
    const [books, setBooks] = useState<any[]>([])//加载状态
    const allData = useRequest(() => allBook())//全部列表
    const [pSubmit, setPSubmit] = useState<() => Promise<any>>()//切书城切书
    const [submit, setSubmit] = useState<() => Promise<any>>()//切书
    const callback = useCallback((fnc: () => Promise<any>) => setSubmit(fnc), [])
    const callbackP = useCallback((fnc: () => Promise<any>) => setPSubmit(fnc), [])
    const switchData = useRequest((params: { mpId: string, operType: string, remark: string, newBookName?: string, newPlatformId?: string } | any) => switchBook(params), { manual: true })
    const logData = useRequest((params: { mpId: string }) => logBook(params), { manual: true })
    const allbookData = useRequest(() => getBookAll(), { manual: true })
    const [value, setValue] = useState<string>('')
    const qsArr = useMemo(() => {
        let arr: any = []
        if (allData?.data && value) {
            allData?.data?.forEach((data: { id: number, vipAccounts: any[] }) => {
                if (value === data.id.toString()) {
                    console.log(value, data.id)
                    data?.vipAccounts?.forEach((item: { account: string, periodId: string, id: number, mpName: string, periodInfo: { id: number, period: string } }) => {
                        arr.push({
                            text: item?.mpName ? item?.periodInfo?.period + '--' + item?.mpName : item?.periodInfo?.period,
                            value: item.id
                        })
                    })
                }
            })
        }
        return arr
    }, [value, allData?.data])
    useEffect(() => {
        if (platformInfo?.id) {
            setValue(platformInfo?.id?.toString())
        }
    }, [platformInfo?.id])
    useEffect(() => {
        allbookData.run().then(res => {
            console.log(1111,res)
            res = res?.map((item: any) => {
                item.value = item.bookName
                item.text = item.bookName
                return item
            })
            setBooks(res)
        })
    }, [])
    const shuqi = useMemo(() => {
        if (platformInfo?.vipAccounts) {
            return {
                text: platformInfo?.vipAccounts[0]?.mpName ? platformInfo?.vipAccounts[0]?.periodInfo?.period + '--' + platformInfo?.vipAccounts[0]?.mpName : platformInfo?.vipAccounts[0]?.periodInfo?.period,
                id: platformInfo?.vipAccounts[0]?.id
            }
        }
        return { text: '', id: '' }
    }, [platformInfo])
    const platformConfig: FormConfig[] = [
        {
            label: '当前书城名称',
            tag: 'input',
            name: 'platformName',
            width: 200,
            disabled: true,
            defaultValue: ''
        },
        {
            label: '当前期数',
            tag: 'input',
            name: 'newPlatformId3',
            children: arr,
            width: 200,
            disabled: true,
        },
        {
            label: '当前对接书籍',
            tag: 'input',
            name: 'bookName',
            width: 200,
            disabled: true,
            defaultValue: ''
        },
        {
            label: '当前书城账号',
            tag: 'input',
            name: 'platformAccount',
            width: 200,
            disabled: true,
            defaultValue: ''
        },
        {
            label: '当前书城密码',
            tag: 'input',
            name: 'platformPassword',
            width: 200,
            disabled: true,
            defaultValue: ''
        },
        {
            label: '切换书城账号',
            tag: 'input',
            name: 'newAccount',
            width: 200,
            required: true,
            defaultValue: ''
        },
        {
            label: '切换书城密码',
            tag: 'input',
            name: 'newPassword',
            width: 200,
            required: true,
            defaultValue: ''
        },
        {
            label: '切换书城',
            tag: 'select',
            name: 'newPlatformId',
            children: arr,
            width: 200,
            required: true,
            change: true,
            callback: (value: any) => { setValue(value) }
        },
        {
            label: '期数',
            tag: 'select',
            name: 'newPlatformId1',
            children: qsArr,
            width: 200,
            required: true,
        },
        {
            label: '切换书籍',
            tag: 'select',
            name: 'newBookName',
            width: 200,
            children: books,
            required: true,
        },
        {
            label: '备注',
            tag: 'TextArea',
            name: 'remark',
            width: 400,
            placeholder: '请输入不少于十个字的备注',
            required: true,
            rows: 5,
            Rule: { min: 10, type: 'string' }
        }
    ]
    const userConfig: FormConfig[] = [
        {
            label: '当前书城',
            tag: 'input',
            name: 'platformName',
            children: arr,
            width: 200,
            disabled: true,
            defaultValue: ''
        },
        {
            label: '当前书城账号',
            tag: 'input',
            name: 'platformAccount',
            width: 200,
            disabled: true,
            defaultValue: ''
        },
        {
            label: '当前书城密码',
            tag: 'input',
            name: 'platformPassword',
            width: 200,
            disabled: true,
            defaultValue: ''
        },
        {
            label: '切换书城账号',
            tag: 'input',
            name: 'newAccount',
            width: 200,
            required: true,
            defaultValue: ''
        },
        {
            label: '切换书城密码',
            tag: 'input',
            name: 'newPassword',
            width: 200,
            required: true,
            defaultValue: ''
        },
        {
            label: '备注',
            tag: 'TextArea',
            name: 'remark',
            width: 400,
            placeholder: '请输入不少于十个字的备注',
            required: true,
            rows: 5,
            Rule: { min: 10, type: 'string' }
        }
    ]
    const bookConfig: FormConfig[] = [
        {
            label: '当前书城',
            tag: 'input',
            name: 'platformName',
            children: arr,
            width: 200,
            disabled: true,
            defaultValue: ''
        },
        {
            label: '当前期数',
            tag: 'input',
            name: 'newPlatformId3',
            children: arr,
            width: 200,
            disabled: true,
        },
        {
            label: '当前书籍',
            tag: 'input',
            name: 'bookName',
            children: arr,
            width: 200,
            disabled: true,
            defaultValue: ''
        },
        {
            label: '期数',
            tag: 'select',
            name: 'newPlatformId1',
            children: qsArr,
            width: 200,
            required: true,
        },
        {
            label: '需要切换书名',
            tag: 'select',
            name: 'newBookName',
            children: books,
            width: 200,
            required: true,
        },
        {
            label: '备注',
            tag: 'TextArea',
            name: 'remark',
            width: 400,
            placeholder: '请输入不少于十个字的备注',
            required: true,
            rows: 5,
            Rule: { min: 10, type: 'string' }
        }
    ]
    //书城列表数据处理
    useEffect(() => {
        let a: { value: string, text: string }[] = []
        allData?.data?.map((item: { id: string, platformName: string, remark: string }) => {
            a.push({ value: item.id.toString(), text: item.platformName })
        })
        setArr(a)
    }, [allData.data])
    //切书城
    let handleSubmit = useCallback(() => {
        (submit as () => Promise<any>)().then((value: { newPlatformId1: string, remark: string, newBookName: string, newAccount: string, newPassword: string }) => {
            if (value) {
                let { newPlatformId1, remark, newBookName, newAccount, newPassword } = value
                setLoding(true);
                switchData.run({ mpId: mpid, operType: '10', newPlatformId: newPlatformId1, remark, newBookName, newAccount, newPassword }).then((res) => {
                    setLoding(false);
                    if (res) {
                        message.success('切换成功！')
                        fnlist.refresh()
                        logData.refresh()
                        fnc()
                    }
                }).catch(() => {
                    setLoding(false);
                })
            }
        })
    }, [submit, fnlist, logData])
    //切书
    let handlePSubmit = useCallback(() => {
        (pSubmit as () => Promise<any>)().then((value: { newPlatformId1: string, remark: string, newBookName: string }) => {
            if (value) {
                let { newPlatformId1, remark, newBookName } = value
                setLoding(true);
                switchData.run({ mpId: mpid, operType: '1', newPlatformId: newPlatformId1, remark, newBookName }).then((res) => {
                    message.success('切换成功！')
                    setLoding(false);
                    fnlist.refresh()
                    logData.refresh()
                    fnc()
                }).catch(() => {
                    setLoding(false);
                })
            }
        })
    }, [pSubmit, fnlist, logData])
    //密码
    let handleUserSubmit = useCallback(() => {
        (pSubmit as () => Promise<any>)().then((value: { newAccount: string, remark: string, newPassword: string }) => {
            if (value) {
                let { newAccount, remark, newPassword } = value
                setLoding(true);
                switchData.run({ mpId: mpid, operType: '11', newAccount, remark, newPassword }).then((res) => {
                    message.success('切换成功！')
                    setLoding(false);
                    fnlist.refresh()
                    logData.refresh()
                    fnc()
                }).catch(() => {
                    setLoding(false);
                })
            }
        })
    }, [pSubmit, fnlist, logData])
    useEffect(() => {
        logData?.run({ mpId: mpid })
    }, [mpid])
    return (
        <Drawer
            destroyOnClose={true}
            width={600}
            placement='right'
            visible={visible}
            title={`当前公众号:${name}`}
            onClose={fnc}
        >
            <Tabs type="card">
                <TabPane tab="切书城/切书/切账号" key="1">
                    {
                        arr.length > 0 && <Form
                            formConfig={platformConfig}
                            flow='column'
                            getFormSubmit={callback}
                            defaultProps={{
                                newPlatformId3: shuqi?.text,
                                platformName: platformInfo?.platformName,
                                bookName: platformInfo?.bookName,
                                platformPassword: platformInfo?.platformPassword,
                                platformAccount: platformInfo?.platformAccount
                            }}
                        />
                    }
                    <Row justify='center'>
                        <Button type='primary' onClick={handleSubmit} loading={loding}>保存</Button>
                    </Row>
                </TabPane>
                <TabPane tab="切书" key="2">
                    {
                        arr.length > 0 && <Form
                            formConfig={bookConfig}
                            flow="column"
                            getFormSubmit={callbackP}
                            defaultProps={{
                                newPlatformId3: shuqi?.text,
                                platformName: platformInfo?.platformName,
                                bookName: platformInfo?.bookName,
                                newPlatformId1: shuqi?.id,
                                platformPassword: platformInfo?.platformPassword,
                                platformAccount: platformInfo?.platformAccount
                            }} />
                    }

                    <Row justify='center'>
                        <Button type='primary' onClick={handlePSubmit} loading={loding}>保存</Button>
                    </Row>
                </TabPane>
                <TabPane tab="切账号" key="4">
                    {
                        arr.length > 0 && <Form
                            formConfig={userConfig}
                            flow="column"
                            getFormSubmit={callbackP}
                            defaultProps={{
                                newPlatformId3: shuqi?.text,
                                platformName: platformInfo?.platformName,
                                bookName: platformInfo?.bookName,
                                newPlatformId1: shuqi?.id,
                                platformPassword: platformInfo?.platformPassword,
                                platformAccount: platformInfo?.platformAccount
                            }} />
                    }

                    <Row justify='center'>
                        <Button type='primary' onClick={handleUserSubmit} loading={loding}>保存</Button>
                    </Row>
                </TabPane>
                <TabPane tab="操作日志" key="3">
                    <Tabs defaultActiveKey="1" tabPosition={'top'} >
                        {
                            logData?.data?.map((item: any) => {
                                let newqishu: string = ''
                                let oldqishu: string = ''
                                item?.newPlatformInfo?.vipAccounts?.forEach((vip: { id: number, account: string, mpName: string, periodInfo: { period: string } }) => {
                                    if (vip.id === item?.newPlatformId) {
                                        newqishu = vip?.mpName ? vip?.periodInfo?.period + '--' + vip?.mpName : vip?.periodInfo?.period
                                    }
                                })
                                item?.oldPlatformInfo?.vipAccounts?.forEach((vip: { id: number, account: string, mpName: string, periodInfo: { period: string } }) => {
                                    if (vip.id === item?.oldPlatformId) {
                                        oldqishu = vip?.mpName ? vip?.periodInfo?.period + '--' + vip?.mpName : vip?.periodInfo?.period
                                    }
                                })
                                return <TabPane tab={item.createTime.replace('T', ' ')} key={item.createTime} >
                                    <h1>{item?.operType === 1 ? '切书日志' : item?.operType === 11 ? '切账号日志' : '切书城日志'}</h1>
                                    <Card>
                                        <Descriptions title="切换前" bordered column={1} >
                                            <Descriptions.Item label="书城名称">{item?.oldPlatformInfo?.platformName}</Descriptions.Item>
                                            <Descriptions.Item label="期数">{oldqishu}</Descriptions.Item>
                                            {item?.operType !== 1 && <>
                                                <Descriptions.Item label="书城账号">{item?.oldAccount}</Descriptions.Item>
                                                <Descriptions.Item label="书城密码">{item?.oldPassword}</Descriptions.Item>
                                            </>}
                                            {
                                                item?.operType !== 11 && <>
                                                    <Descriptions.Item label="书籍名称" >{item?.oldBookName}</Descriptions.Item>
                                                    {item?.operType === 10 && <Descriptions.Item label="书城备注" >{item?.oldPlatformInfo?.remark}</Descriptions.Item>}
                                                </>
                                            }
                                        </Descriptions>
                                    </Card>
                                    <Card>
                                        <Descriptions title="切换后" bordered column={1}>
                                            <Descriptions.Item label="书城名称">{item?.newPlatformInfo?.platformName}</Descriptions.Item>
                                            <Descriptions.Item label="期数">{newqishu}</Descriptions.Item>
                                            {
                                                item?.operType !== 1 && <>
                                                    <Descriptions.Item label="书城账号">{item?.newAccount}</Descriptions.Item>
                                                    <Descriptions.Item label="书城密码">{item?.newPassword}</Descriptions.Item>
                                                </>
                                            }
                                            {
                                                item?.operType !== 11 && <>
                                                    <Descriptions.Item label="书籍名称">{item?.newBookName}</Descriptions.Item>
                                                    {item?.operType === 10 && <Descriptions.Item label="书城备注">{item?.newPlatformInfo?.platformName}</Descriptions.Item>}
                                                </>
                                            }
                                        </Descriptions>
                                    </Card>
                                    {
                                        item?.operType !== 10 && <Card>
                                            <Descriptions title={item?.operType === 1 ? '切书' : item?.operType === 11 ? '切账号' : ''} bordered column={1}>
                                                <Descriptions.Item label="备注">{item?.remark}</Descriptions.Item>
                                            </Descriptions>
                                        </Card>
                                    }
                                    <Card>
                                        <Descriptions title="操作账号" bordered column={1}>
                                            <Descriptions.Item label="名称" >{item?.operUserInfo?.nickname}</Descriptions.Item>
                                            <Descriptions.Item label="手机" >{item?.operUserInfo?.phone}</Descriptions.Item>
                                            <Descriptions.Item label="email" >{item?.operUserInfo?.email}</Descriptions.Item>
                                        </Descriptions>
                                    </Card>
                                </TabPane>
                            })
                        }
                    </Tabs>
                </TabPane>
            </Tabs>
        </Drawer>
    )
})

export default DarwerPage