import React, { useEffect, useState, useCallback } from 'react'
import { editSubmit } from '@/services/operating/book';
import { Modal, message, Form, Input } from 'antd'
import { useRequest } from 'umi';
interface Props {
    name: string,
    visible: boolean,
    fnc: () => void,
    mpid: string,
    fnlist: any,
    platformInfo?: { id: string, platformName: string, remark: string }
}

let EditModal = React.memo((props: Props) => {
    let { name, visible, fnc, mpid, fnlist } = props
    const [data, setData] = useState<{secret: string, account: string, password: string, managePhone: string, managePhoneNo: string}>({
        secret: '',
        account: '',
        password: '',
        managePhone: '',
        managePhoneNo: ''
    })
    const edRequest = useRequest((params: { mpId: string, account: string, managePhone: string, managePhoneNo: string, password: string, secret: string }) => editSubmit(params), { manual: true })

    useEffect(() => {
        fnlist?.data?.records?.forEach((item: any)=>{
            if(item.id === mpid){
                setData({
                    secret: item?.secret ? item?.secret : '',
                    account: item?.account ? item?.account : '',
                    password: item?.password ? item?.password : '',
                    managePhone: item?.managePhone ? item?.managePhone : '',
                    managePhoneNo: item?.managePhoneNo ? item?.managePhoneNo : ''
                })
            }
        })
    }, [fnlist])

    let handleSubmit = useCallback(() => {
        edRequest.run({ mpId: mpid, ...data }).then((res) => {
            if(res){
                message.success('设置成功！')
                fnlist.refresh()
                fnc()
            }
        })
    }, [data])
    return (
        <Modal
            title={`${name}`}
            visible={visible}
            onOk={handleSubmit}
            onCancel={fnc}
            okText='保存'
            confirmLoading= {edRequest.loading}
        >
            <Form layout="vertical">
                <Form.Item label="公众号secret">
                    <Input value={data.secret} onChange={e=>setData({...data, secret: e.target.value})}/>
                </Form.Item>
                <Form.Item label="公众号账号">
                    <Input value={data.account} onChange={e=>setData({...data, account: e.target.value})}/>
                </Form.Item>
                <Form.Item label="公众号密码">
                    <Input type="password" style={{display:'none',width:'0',height:'0'}}/>
                    <Input.Password autoComplete={'off'} value={data.password} onChange={e=>setData({...data, password: e.target.value})}/>
                </Form.Item>
                <Form.Item label="手机号">
                    <Input maxLength={11} value={data.managePhone} onChange={e=>setData({...data, managePhone: e.target.value})}/>
                </Form.Item>
                <Form.Item label="手机号编号">
                    <Input value={data.managePhoneNo} onChange={e=>setData({...data, managePhoneNo: e.target.value})}/>
                </Form.Item>
            </Form>
           
        </Modal>
    )
})

export default EditModal