import { Col, DatePicker, Input, message, Modal, Row, Select, Space, Button, Popconfirm } from 'antd'
import React, { useCallback, useEffect, useState } from 'react'
import { useAjax } from "@/Hook/useAjax";
import { allBook, businessGroup, getBookAll, getPeriodAll, lins, listByPlatform } from '@/services/operating/book';
import { ReadOutlined } from '@ant-design/icons';
import styles from './index.less'
import moment from 'moment';
import { verify } from '@/services/operating/account';
import e from '@umijs/server/node_modules/@types/express';
const { Option } = Select;
/**临时切书弹窗*/
function LinsModal(arg: { oldPlatformId?: any, mpId: any, list: any, oldPeriodId: any, oldPlatformAccountId: any, oldBookId: any, oldPutStatus: any, oldPutChannel: any, oldBusinessGroupId: any, oldRechargeTemplate: any }) {
    const { oldPlatformId, mpId, list, oldPeriodId, oldPlatformAccountId, oldBookId, oldPutStatus, oldPutChannel, oldBusinessGroupId, oldRechargeTemplate } = arg
    const linsQ = useAjax((params) => lins(params))//全部列表
    const verifys = useAjax((params) => verify(params))//切书前验证
    const [visible, setVisible] = useState<boolean>(false)
    const [arr, setArr] = useState<{ value: string, text: string }[]>([])//处理后的select数组
    const [platformId, setPlatformId] = useState<any>(oldPlatformId)//选中的书城
    const [periodId, setPeriodId] = useState<any>(oldPeriodId)//选中期数
    const [platformAccountId, setPlatformAccountId] = useState<any>(oldPlatformAccountId)//选中账号
    const [bookId, setBookId] = useState<any>(oldBookId)//选中书
    const [remark, setRemark] = useState<string>('')//描述
    const allData = useAjax(() => allBook())//获取全部小说平台
    const periodAll = useAjax(() => getPeriodAll())//获取全部期数
    const platformAll = useAjax((platformId: number) => listByPlatform(platformId))//获取全部期数
    const bookAll = useAjax(() => getBookAll())//获取书籍
    const [beginTime, setBeginTime] = useState<any>(moment(new Date()).format('YYYY-MM-DD'))
    const [businessGroupId, setBusinessGroupId] = useState<any>(oldBusinessGroupId)
    const [putStatus, setPutStatus] = useState<any>(oldPutStatus)
    const [rechargeTemplate, setRechargeTemplate] = useState<any>(oldRechargeTemplate)
    const [putChannel, setPutChannel] = useState<any>(oldPutChannel)
    const businessGroupALL = useAjax(() => businessGroup())//项目组
    const [pvisible, setPvisible] = useState(false)
    //书城列表数据处理
    useEffect(() => {
        if (visible) {
            // 获取全部小说平台
            allData.run().then((res: any) => {
                let a: { value: string, text: string }[] = []
                res?.map((item: { id: string, platformName: string, remark: string }) => {
                    a.push({ value: item.id.toString(), text: item.platformName })
                })
                setArr(() => a)
            })
            // 获取全部期数
            periodAll.run()
            //获取书籍
            bookAll.run()
            businessGroupALL.run()
        }
    }, [visible])
    // 获取书城账号列表
    useEffect(() => {
        if (platformId && visible) {
            platformAll.run(platformId)
        }
    }, [platformId, visible])
    useEffect(() => {
        if (oldPlatformId) {
            setPlatformId(JSON.stringify(oldPlatformId))
        }
    }, [oldPlatformId])
    const yz = useCallback(() => {
        if (beginTime) {
            verifys.run({ resourceId: mpId, beginTime }).then(res => {
                if (res) {
                    submit()
                } else {
                    setPvisible(true)
                }
            })

        } else {
            message.error('请选择日期！')
        }
    }, [platformId, mpId, periodId, platformAccountId, remark, bookId, beginTime, businessGroupId, putStatus, rechargeTemplate, putChannel])
    const submit = useCallback(() => {
        linsQ.run({ platformId, resourceId: mpId, periodId, platformAccountId, bookId, remark, beginTime, businessGroupId, putStatus, rechargeTemplate, putChannel }).then((res) => {
            if (res) {
                list.refresh()
                setVisible(false)
                message.success('切换成功！')
                setBeginTime(moment(new Date()).format('YYYY-MM-DD'))
            }
        })
    }, [platformId, mpId, periodId, platformAccountId, remark, bookId, beginTime, businessGroupId, putStatus, rechargeTemplate, putChannel])
    return <>
        <span onClick={() => { setVisible(!visible) }} style={{ cursor: 'pointer' }}>
            <ReadOutlined style={{ color: '#2db7f5' }} />
        </span>
        <Modal
            visible={visible}
            // onCancel={() => { setVisible(false) }}
            // onOk={submit}
            width={350}
            title={'切书切平台'}
            maskClosable={false}
            footer={<div>
                <Popconfirm title='会覆盖上一条，是否确定？' visible={pvisible} onCancel={() => { setPvisible(false) }} onConfirm={()=>{
                    setPvisible(false)
                    submit()
                }}>
                    <Button type={'primary'} onClick={yz}>确定</Button>
                </Popconfirm>
                <Button onClick={() => { setVisible(false) }}>取消</Button>
            </div>}
        >
            <Row gutter={[10, 10]} className={styles.edit_book}>
                <Col>
                    <Space>
                        <label><span style={{ color: 'red' }}>*</span>日期:</label>
                        <DatePicker
                            value={beginTime ? moment(beginTime) : undefined}
                            onChange={(date, dateString) => {
                                setBeginTime(dateString)
                            }} />
                    </Space>
                </Col>
                <Col>
                    <Space>
                        <label>期数:</label>
                        <Select
                            style={{ width: 200 }} value={periodId}
                            onChange={(value: any,) => { setPeriodId(value) }}
                            showSearch
                            filterOption={(input, option: any) =>
                                option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                            }
                        >
                            {
                                periodAll?.data?.map((item: any) => {
                                    return <Option value={item?.id} key={item?.id}>{item?.period}</Option>
                                })
                            }
                        </Select>
                    </Space>
                </Col>
                <Col>
                    <Space>
                        <label>书城: </label>
                        <Select style={{ width: 200 }} value={platformId} onChange={(value: any,) => { setPlatformId(value) }}
                            showSearch
                            filterOption={(input, option: any) =>
                                option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                            }
                        >
                            {
                                arr.map((item) => {
                                    return <Option value={item?.value} key={item?.value}>{item?.text}</Option>
                                })
                            }
                        </Select>
                    </Space>
                </Col>
                <Col>
                    <Space>
                        <label>账号:</label>
                        <Select style={{ width: 200 }} value={platformAccountId} onChange={(value: any,) => { setPlatformAccountId(value) }} disabled={!platformId}
                            showSearch
                            filterOption={(input, option: any) =>
                                option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                            }
                        >
                            {
                                platformAll?.data?.map((item: any) => {
                                    return <Option value={item?.id} key={item?.id}>{item?.account}</Option>
                                })
                            }
                        </Select>
                    </Space>
                </Col>
                <Col>
                    <Space>
                        <label>书籍:</label>
                        <Select style={{ width: 200 }} value={bookId} onChange={(value: any,) => { setBookId(value) }}
                            showSearch
                            filterOption={(input, option: any) =>
                                option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                            }
                        >
                            {
                                bookAll?.data?.map((item: any) => {
                                    return <Option value={item?.id} key={item?.id}>{item?.bookName}</Option>
                                })
                            }
                        </Select>
                    </Space>
                </Col>
                <Col>
                    <Space>
                        <label>项目组:</label>
                        <Select
                            allowClear
                            onChange={(value) => {
                                setBusinessGroupId(value)
                            }}
                            value={businessGroupId}
                            style={{ width: 200 }}
                            showSearch
                            filterOption={(input, option: any) =>
                                option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                            }
                        >
                            {
                                businessGroupALL?.data?.map((item: any) => {
                                    return <Select.Option value={item?.id}>{item?.businessGroupName}</Select.Option>
                                })
                            }
                        </Select>
                    </Space>
                </Col>
                <Col>
                    <Space>
                        <label>投放状态:</label>
                        <Select
                            allowClear
                            onChange={(value) => {
                                setPutStatus(value)
                            }}
                            value={putStatus}
                            style={{ width: 200 }}
                        >
                            <Select.Option value='wait'>待投放</Select.Option>
                            <Select.Option value='ing'>投放中</Select.Option>
                            <Select.Option value='stop'>停投</Select.Option>
                            <Select.Option value='destroy'>已注销</Select.Option>
                        </Select>
                    </Space>
                </Col>
                <Col>
                    <Space>
                        <label>投放渠道:</label>
                        <Select
                            allowClear
                            onChange={(value) => {
                                setPutChannel(value)
                            }}
                            value={putChannel}
                            style={{ width: 200 }}
                        >
                            <Select.Option value='MP'>MP</Select.Option>
                            <Select.Option value='GDT'>GDT</Select.Option>
                            <Select.Option value='头条'>头条</Select.Option>
                            <Select.Option value='企微'>企微</Select.Option>
                        </Select>
                    </Space>
                </Col>
                <Col>
                    <Space>
                        <label>充值模板:</label>
                        <Input
                            placeholder='请输入充值模板'
                            value={rechargeTemplate}
                            allowClear
                            onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                                let value = e.target.value
                                setRechargeTemplate(value)
                            }}
                        />
                    </Space>
                </Col>
                <Col>
                    <Space>
                        <label>描述:</label>
                        <Input.TextArea style={{ width: 208, marginLeft: -8 }} onChange={(e) => {
                            setRemark(e.target.value)
                        }} />
                    </Space>
                </Col>
            </Row>
        </Modal>
    </>
}

export default LinsModal