import React, { useEffect, useState, useCallback } from 'react'
import { getUserAll, switchPitcher } from '@/services/operating/book';
import { Drawer, message, Popconfirm, Spin, Tooltip } from 'antd'
import { useRequest, useModel } from 'umi';
import { ExclamationCircleOutlined } from '@ant-design/icons'
import style from './index.less'

interface Props {
    name: string,
    visible: boolean,
    fnc: () => void,
    mpid: string,
    fnlist: any,
    platformInfo?: { id: string, platformName: string, remark: string }
}

let DarwerPage = React.memo((props: Props) => {
    let { name, visible, fnc, mpid, fnlist } = props
    const getAllUser = useRequest(() => getUserAll())
    const setSwitchP = useRequest((params: { mpId: string, userId: string }) => switchPitcher(params), { manual: true })
    const { currentUser }: any = useModel('@@initialState', model => ({ currentUser: model.initialState?.currentUser }))
    const [putUserId, setPutUserId] = useState<string>('')
    const [hoverItem, setHoverItem] = useState<any | {}>({})
    const [isPitcher, setIsPitcher] = useState<boolean>(false)
    const { getAllOfMember, getDataList } = useModel('useOperating.useWxGroupList')

    const setupPitcher = (userid: string) => {
        setSwitchP.run({ mpId: mpid, userId: userid }).then((res) => {
            if(res){
                message.success('设置成功！')
                fnlist.refresh()
                getAllOfMember.refresh()
                getDataList.refresh()
            }
        }).catch(() => {
        })
    }
    useEffect(() => {
        fnlist?.data?.records?.forEach((item: any)=>{
            if(item.id === mpid){
                setPutUserId(item.putUserId)
            }
        })
    }, [fnlist])

    /**
     * list鼠标移入
     */
    let hoverIn = useCallback((item: any) => {
        setHoverItem(item)
    }, [])
    /**
    * list鼠标移出
    */
    let hoverOut = useCallback(() => {
        setHoverItem({})
    }, [])

    useEffect(() => {
        getAllUser?.data?.forEach((item: any)=>{
            if(item.userId === putUserId){
                setIsPitcher(true)
            }
        })
    }, [getAllUser, putUserId, fnlist])
    return (
        <Drawer
            destroyOnClose={true}
            width={250}
            placement='right'
            visible={visible}
            title={`当前公众号:${name}`}
            onClose={fnc}
        >
            {
                getAllUser?.loading ? <Spin size="small" /> : 
                <div className={style.darwerPage}>
                    { !isPitcher ? 
                        <div className={style.not_deploy}>
                            <Tooltip title='点击下方人员可配置投手'>
                                <ExclamationCircleOutlined className={style.ts_icon}/>
                            </Tooltip>
                            当前还没有配置投手
                        </div> :
                        <div className={style.a_deploy}>
                            <Tooltip title='点击下方人员其他人员可切换投手'>
                                <ExclamationCircleOutlined className={style.ts_icon}/>
                            </Tooltip>
                            标注<span style={{color: 'red'}}>*</span>为当前公众号投手
                        </div>    
                    }
                    {
                        getAllUser?.data?.map((ele: any) => {
                            return ele.userId != currentUser.userId ? ele.userId == putUserId ? <div className={`${style.item} ${style.desc_item}`} key={ele.userId}>{ele.userId == putUserId && <span style={{color: 'red'}}>*</span>} {ele?.nickName}</div> :
                                <Popconfirm title="确定要设置？" okText="是" cancelText="否" onConfirm={()=>setupPitcher(ele.userId)} key={ele.userId}>
                                    <div className={style.item} style={{backgroundColor: hoverItem.userId === ele.userId ? '#efefef' : ''}} onMouseEnter={() => hoverIn(ele)} onMouseLeave={hoverOut}>{ele?.nickName}</div>
                                </Popconfirm>  : ''
                        })
                    }
                </div>
            }
        </Drawer>
    )
})

export default DarwerPage