import { useAjax } from "@/Hook/useAjax"
import {  getAllUser, modify2 } from "@/services/operating/account"
import { allBook, businessGroup, getBookAll, getPeriodAll, listByPlatform } from "@/services/operating/book"
import { Col, DatePicker, Input, message, Modal, Row, Select, Space } from "antd"
import moment from "moment"
import React, { useCallback, useEffect, useState } from "react"
const { Option } = Select;
import styles from './index.less'

function EditBook(props:{editData: any, list: any,hide:any}) {
    let {editData,list,hide} = props
    const { beginTime, endTime, id, putStatus, putChannel, remark, rechargeTemplate, platformId, periodId, bookId, platformAccountId, businessGroupId,operUserId,putUserId } = editData
    const edit = useAjax((params) => modify2(params))
    const [arr, setArr] = useState<{ value: string, text: string }[]>([])//处理后的select数组
    const allData = useAjax(() => allBook())//获取全部小说平台
    const periodAll = useAjax(() => getPeriodAll())//获取全部期数
    const platformAll = useAjax((platformId: number) => listByPlatform(platformId))//获取全部期数
    const bookAll = useAjax(() => getBookAll())//获取书籍
    const businessGroupALL = useAjax(() => businessGroup())//项目组
    const allUsers = useAjax(() => getAllUser())//获取所有用户
    const [oldPlatformId,setOldPlatformId]=useState<any>(platformId)//上次的书城
    const [state, setState] = useState<any>({
        beginTime,//开始时间
        endTime,//结束时间
        putChannel,//渠道
        putStatus,//状态
        remark,//备注
        rechargeTemplate,//模板
        platformId,//书城
        periodId,//期数
        bookId,//书籍
        platformAccountId,//账号
        businessGroupId,//项目组
        operUserId,//运营
        putUserId//投手
    })
    //书城列表数据处理
    useEffect(() => {
            businessGroupALL.run()
            allUsers.run()
            // 获取全部小说平台
            allData.run().then((res: any) => {
                let a: { value: string, text: string }[] = []
                res?.map((item: { id: string, platformName: string, remark: string }) => {
                    a.push({ value: item.id.toString(), text: item.platformName })
                })
                setArr(() => a)
            })
            // 获取全部期数
            periodAll.run()
            //获取书籍
            bookAll.run()
    }, [])
    // 获取书城账号列表
    useEffect(() => {
        if (state?.platformId) {
            platformAll.run(state?.platformId)
        }
    }, [state?.platformId])
    // 切换书城
    useEffect(()=>{
        if(state?.platformId != oldPlatformId){
            setState({...state,platformAccountId:''})//清空账号选项
            setOldPlatformId(state?.platformId)//替换上次书城为本次选项
        }
    },[oldPlatformId,state])
    const submit = useCallback(() => {
        if (state.beginTime) {
            edit.run({ changeRecordId: id, ...state }).then((res) => {
                if (res) {
                    list.refresh()
                    message.success('切换成功！')
                    setState({})
                    hide()
                }
            })
        } else {
            message.error('请选择日期！')
        }
    }, [state, id])
    return <Modal
        onCancel={() => {hide()}}
        width={350}
        title={'编辑'}
        onOk={submit}
        visible={true}
        maskClosable={false}
    >
        <Row gutter={[10, 10]} className={styles.edit_book}>
            <Col>
                <Space>
                    <label><span style={{ color: 'red' }}>*</span>开始时间:</label>
                    <DatePicker
                        value={state?.beginTime ? moment(state?.beginTime): undefined}
                        onChange={(date, dateString) => {
                            setState({ ...state, beginTime: dateString ?moment(dateString).format('YYYY-MM-DD')  : '' })
                        }} />
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>结束时间:</label>
                    <DatePicker
                        value={state?.endTime ? moment(state?.endTime) : undefined}
                        onChange={(date, dateString) => {
                            setState({ ...state, endTime:dateString ? moment(dateString).format('YYYY-MM-DD')  : ''  })
                        }} />
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>项目组:</label>
                    <Select
                        allowClear
                        onChange={(value) => {
                            setState({ ...state, businessGroupId: value })
                        }}
                        value={state?.businessGroupId}
                        style={{ width: 200 }}
                        showSearch
                        filterOption={(input, option: any) =>
                            option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                        }
                    >
                        {
                            businessGroupALL?.data?.map((item: any) => {
                                return <Select.Option value={item?.id}>{item?.businessGroupName}</Select.Option>
                            })
                        }
                    </Select>
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>运营:</label>
                    <Select
                        allowClear
                        onChange={(value) => {
                            setState({ ...state, operUserId: value })
                        }}
                        value={state?.operUserId}
                        style={{ width: 200 }}
                        showSearch
                        filterOption={(input, option: any) =>
                            option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                        }
                    >
                        {
                            allUsers?.data?.map((item: any) => {
                                return <Select.Option value={item?.userId}>{item?.nickname}</Select.Option>
                            })
                        }
                    </Select>
                </Space>
            </Col>
             <Col>
                <Space>
                    <label>投手:</label>
                    <Select
                        allowClear
                        onChange={(value) => {
                            setState({ ...state, putUserId: value })
                        }}
                        value={state?.putUserId}
                        style={{ width: 200 }}
                        showSearch
                        filterOption={(input, option: any) =>
                            option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                        }
                    >
                        {
                            allUsers?.data?.map((item: any) => {
                                return <Select.Option value={item?.userId}>{item?.nickname}</Select.Option>
                            })
                        }
                    </Select>
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>期数:</label>
                    <Select
                        style={{ width: 200 }} value={state?.periodId}
                        onChange={(value: any,) => {
                            setState({ ...state, periodId: value })
                        }}
                        showSearch
                        filterOption={(input, option: any) =>
                            option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                        }
                    >
                        {
                            periodAll?.data?.map((item: any) => {
                                return <Option value={item?.id} key={item?.id}>{item?.period}</Option>
                            })
                        }
                    </Select>
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>书城: </label>
                    <Select style={{ width: 200 }} value={state?.platformId?.toString()} onChange={(value: any,) => {
                        setState({ ...state, platformId: value })
                    }}
                        showSearch
                        filterOption={(input, option: any) =>
                            option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                        }
                    >
                        {
                            arr.map((item) => {
                                return <Option value={item?.value} key={item?.value}>{item?.text}</Option>
                            })
                        }
                    </Select>
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>账号:</label>
                    <Select style={{ width: 200 }}
                        value={state?.platformAccountId}
                        onChange={(value: any,) => {
                            setState({ ...state, platformAccountId: value })
                        }}
                        disabled={!state?.platformId}
                        showSearch
                        filterOption={(input, option: any) =>
                            option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                        }
                    >
                        {
                            platformAll?.data?.map((item: any) => {
                                return <Option value={item?.id} key={item?.id}>{item?.account}</Option>
                            })
                        }
                    </Select>
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>书籍:</label>
                    <Select style={{ width: 200 }} value={state?.bookId} onChange={(value: any,) => {
                        setState({ ...state, bookId: value })
                    }}
                        showSearch
                        filterOption={(input, option: any) =>
                            option?.children?.toLowerCase()?.indexOf(input?.toLowerCase()) >= 0
                        }
                    >
                        {
                            bookAll?.data?.map((item: any) => {
                                return <Option value={item?.id} key={item?.id}>{item?.bookName}</Option>
                            })
                        }
                    </Select>
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>投放状态:</label>
                    <Select
                        allowClear
                        onChange={(value) => {
                            setState({ ...state, putStatus: value })
                        }}
                        value={state?.putStatus}
                        style={{ width: 200 }}
                    >
                        <Select.Option value='wait'>待投放</Select.Option>
                        <Select.Option value='ing'>投放中</Select.Option>
                        <Select.Option value='stop'>停投</Select.Option>
                        <Select.Option value='destroy'>已注销</Select.Option>
                    </Select>
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>投放渠道:</label>
                    <Select
                        allowClear
                        onChange={(value) => {
                            setState({ ...state, putChannel: value })
                        }}
                        value={state?.putChannel}
                        style={{ width: 200 }}
                    >
                        <Select.Option value='MP'>MP</Select.Option>
                        <Select.Option value='GDT'>GDT</Select.Option>
                        <Select.Option value='头条'>头条</Select.Option>
                        <Select.Option value='企微'>企微</Select.Option>
                    </Select>
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>充值模板:</label>
                    <Input
                        placeholder='请输入充值模板'
                        value={state?.rechargeTemplate}
                        allowClear
                        onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                            let value = e.target.value
                            setState({ ...state, rechargeTemplate: value })
                        }}
                    />
                </Space>
            </Col>
            <Col>
                <Space>
                    <label>备注:</label>
                    <Input.TextArea
                        style={{ width: 208, marginLeft: -8 }}
                        value={state?.remark}
                        onChange={(e) => {
                            setState({ ...state, remark: e?.target?.value })
                        }} />
                </Space>
            </Col>
        </Row>
    </Modal>
}

export default EditBook