import React, { useCallback, useEffect, useState } from 'react'
import HeaderForm from '@/components/Formitem'
import { headerConfig } from './headerConfig'
import { Button, Card, Modal, Result } from 'antd'
import Tables from '@/components/Tables'
import { tablesConfig } from './tablesConfig'
import { useModel, useRequest } from 'umi'
import { getAccount, postList, Postlist } from '@/services/operating/account'
import GroupWxTabs from '@/components/GroupWxTabs'
import { useAjax } from '@/Hook/useAjax'
import HocError from '@/Hoc/HocError'

function Account() {
    const [pageNum, setPageNum] = useState(1)
    const [pageSize, setPageSize] = useState(10)
    const { userId } = useModel('useOperating.useUser', model => ({ userId: model.state.selectdUserId }))
    const [visible, setVisible] = useState<boolean>(false)//成功失败弹窗
    const [query, setQuery] = useState<{ groupId: string, platformId: string, nickName: string, principalName: string }>({
        groupId: '',
        platformId: '',
        nickName: '',
        principalName: ''
    })
    /**
     * 获取二维码
    */
    const codeData = useAjax((params: any) => getAccount(params))
    /**
     * 获取list列表
     */
    const listData = useRequest((params?: Postlist) => postList(params), {
        manual: true,
        formatResult: (res: any) => res.data,
        cacheKey: 'list',
    })

    /**头部搜索数据 */
    const headerSubmit = useCallback((v: any, key: string) => {
        query[key] = v[key] || ''
        setQuery(query)
        let data: { groupId?: string, platformId?: string, nickName?: string, principalName?: string } = {}
        if (query.groupId != "") {
            data.groupId = query.groupId
        }
        if (query.platformId != "") {
            data.platformId = query.platformId
        }
        if (query.nickName != "") {
            data.nickName = query.nickName
        }
        if (query.principalName != "") {
            data.principalName = query.principalName
        }
        listData.run({ ...data, pageNum, pageSize, userId })
    }, [userId])
    /**
     * 打开链接扫码
    */
    const open = useCallback((mpId: string) => {
        codeData.run({ params: 'http://mp.zanxiangnet.com/#/operatePage/account/wxCode', mpId }).then((res: any) => {
            if (res) {
                window.open(res)
            }
        })
    }, [])
    /**
     * 分页操作
     */
    let pageChange = useCallback((page: number, pageSize?: number) => {
        listData.run({ pageNum: page, pageSize: pageSize, ...query, userId })
        setPageNum(page)
        setPageSize(pageSize as number)
    }, [userId, query])
    let sizeChange = useCallback((current: number, size?: number) => {
        listData.run({ pageNum: current, pageSize: size, ...query, userId })
        setPageNum(current)
        setPageSize(size as number)
    }, [userId, query])
    /**
     * 副作用执行
     */
    useEffect(() => {
        listData.run({ pageNum: '1', pageSize: '10', userId })
    }, [userId])
    /**监听code页面消息 */
    let codeMsg = useCallback((e: any) => {
        console.log('e.key===>', e.key)
        if (e.key === 'code') {
            if (e.newValue === 'ok') {
                console.log('isOk')
                setVisible(true)
            } else {
                console.log('err')
                setVisible(true)
            }
        }
    }, [listData])
    useEffect(() => {
        window.addEventListener('storage', codeMsg)
        return () => {
            window.removeEventListener('storage', codeMsg)
        }
    }, [])
    return <>
        <Card>
            <HeaderForm flow='row' formConfig={headerConfig(headerSubmit)} submit={headerSubmit} />
            <GroupWxTabs>
                <Tables
                    columns={tablesConfig(listData, open)}
                    dataSource={listData?.data?.records}
                    total={listData?.data?.total}
                    pageChange={pageChange}
                    sizeChange={sizeChange}
                    current={listData?.data?.current}
                    pageSize={listData?.data?.size}
                    rowClassName='authStatus'
                    scroll={{ x: 2000 }}
                    size={'small'}
                />
            </GroupWxTabs>
        </Card>
        {visible && <Modal
            closable={false}
            visible={visible}
            destroyOnClose
            footer={false}
        >
            {
                localStorage.getItem('code') === 'ok' ? <Result
                    status="success"
                    title="绑定公众号成功!"
                    extra={[
                        <Button type="primary" key="console" onClick={
                            () => {
                                setVisible(false)
                                localStorage.removeItem('code')
                                location.reload()
                            }
                        }>确定</Button>
                    ]}
                /> : <Result
                    status="error"
                    title="绑定公众号失败!"
                    subTitle={localStorage.getItem('errMsg') || ''}
                    extra={[
                        // <Button type="primary" key="console" onClick={
                        //     () => {
                        //         setVisible(false)
                        //         open()
                        //     }
                        // }>重新去绑定</Button>,
                        <Button key="console" onClick={
                            () => {
                                setVisible(false)
                                localStorage.removeItem('code')
                                localStorage.removeItem('errMsg')
                            }
                        }>确定</Button>
                    ]}
                />
            }
        </Modal>}
    </>

}

export default HocError(Account)