import React, { useCallback, useEffect, useReducer, useRef, useState } from 'react'
import { ColumnProps, ColumnsType } from 'antd/lib/table'
import { Row, Col, Tooltip, Popconfirm, Popover, Button, Avatar, Input, Badge, Space, Table, Divider, Image, Drawer, Tag,  message } from 'antd'
import { DeleteOutlined, UsergroupAddOutlined, QuestionCircleOutlined, EditOutlined, PlusCircleOutlined, ReloadOutlined, ReadOutlined,  WechatOutlined, CopyOutlined, QrcodeOutlined } from '@ant-design/icons'
import { useModel, useRequest } from 'umi'
import { del, putWx } from '@/services/operating/account'
import style from './index.less'
// import Pitcher from './Pitcher'

import useCopy from '@/Hook/useCopy'
import Modal from 'antd/lib/modal/Modal'
import DatePickePage from '@/components/DatePicker'
import LinsModal from './Lins'
import { useAjax } from '@/Hook/useAjax'
import { businessGroup, resourceChangeRecord } from '@/services/operating/book'
import EditBook from './editBook'
// import { bookImg } from '@/pages/public'

/**
 * 分组
*/
interface List {
    id: string,
    operUserId: string,
    groupName: string,
    remark: string
}
/**
 * 分组
*/
function GroupPopover(props: { data: any, fncList: any }) {
    const [isAdd, setIsAdd] = useState<boolean>(false)
    const [ckItem, setCkItem] = useState<List | {}>({})
    const [hoverItem, setHoverItem] = useState<List | {}>({})
    const { groupAdd, groupEdit, groupDel, groupConfig } = useModel('useOperating.useAccount')
    const { groupList } = useModel('useOperating.useWxGroupList', model => ({ groupList: model.getDataList }))
    const inputRef: { current: any } = useRef(null)
    const input1Ref: { current: any } = useRef(null)
    /**
     * 新增分组
     */
    let add = useCallback(() => {
        setIsAdd(true)
    }, [])
    /**
     * @param v 保存分组
     */
    let save = useCallback((v: string, e?: React.ChangeEvent<HTMLInputElement> | React.MouseEvent<HTMLElement, MouseEvent> | React.KeyboardEvent<HTMLInputElement>) => {
        e?.stopPropagation()
        if ((ckItem as List).id) {//存在代表编辑
            if (v) {//编辑名称
                groupEdit.run({ groupId: (ckItem as List).id, groupName: v }).then(() => {
                    groupList.run()//重新获取列表
                    props.fncList.refresh()
                })
            }
        } else {
            if (v) {//新增分组
                groupAdd.run({ groupName: v }).then(() => {
                    groupList.run()//重新获取列表
                    props.fncList.refresh()
                })
            }
        }
        setCkItem({})
        setIsAdd(false)
    }, [ckItem])
    /**
     * 删除分组
     */
    let del = useCallback((item: List, e?: React.MouseEvent<HTMLElement, MouseEvent>) => {
        e?.stopPropagation()
        groupDel.run({ groupId: item.id }).then(() => {
            groupList.run()
        })
    }, [])
    /**
     * 编辑分组
     */
    let edit = useCallback((e: React.MouseEvent<HTMLSpanElement, MouseEvent>, item: List) => {
        e.stopPropagation()
        setCkItem(item)
    }, [])
    /**
     * list鼠标移入
     */
    let hoverIn = useCallback((item: List) => {
        setHoverItem(item)
    }, [])
    /**
    * list鼠标移出
    */
    let hoverOut = useCallback(() => {
        setHoverItem({})
    }, [])
    /**
     * 修改所属分组
     */
    let clickGroup = useCallback((item: List) => {
        groupConfig.run({ groupId: item.id, mpAccountId: props.data.id }).then(() => {
            groupList.run();
            props.fncList.refresh()
        })
    }, [])
    useEffect(() => {
        if (inputRef?.current) {
            inputRef.current.focus()
        }
    }, [isAdd])
    useEffect(() => {
        if (input1Ref?.current) {
            input1Ref.current.focus()
        }
    }, [ckItem])
    let cursor = { cursor: 'pointer' }
    let content = <div className={style.group_popover} >
        <Row justify='space-between' gutter={[0, 10]} className={style.group_popover_header}>
            <Col >移动至</Col>
            <Col style={{ color: '#108ee9', ...cursor }} onClick={add}><PlusCircleOutlined />&nbsp;新增</Col>
        </Row>
        {
            isAdd && <Row gutter={[0, 10]}>
                <Col>
                    <Input.Search
                        placeholder="请输入组名"
                        enterButton="保存"
                        onSearch={save}
                        ref={inputRef}
                        onBlur={() => setIsAdd(false)}
                    />
                </Col>
            </Row>
        }
        {
            groupList?.data?.map((item: List) => {
                return <Row justify='space-between' gutter={[0, 10]} key={item.id} className={style.list} onMouseEnter={() => hoverIn(item)} onMouseLeave={hoverOut} onClick={() => clickGroup(item)}>
                    {
                        (ckItem as List).id === item.id ? <Col>
                            <Input.Search
                                placeholder="请输入组名"
                                enterButton="保存"
                                onSearch={save}
                                onClick={e => e.stopPropagation()}
                                ref={input1Ref}
                                onBlur={() => setCkItem({})}
                            />
                        </Col> :
                            <>
                                <Col >
                                    {
                                        props.data.groupId === item.id && <span style={{ color: "red" }}>*</span>
                                    }
                                    {item.groupName}
                                </Col>
                                <Col>
                                    {
                                        ((hoverItem as List).id === item.id && (hoverItem as List).id !== '0') && <Row gutter={[10, 0]} className={style.group_action}>
                                            <Col>
                                                <Tooltip title='修改名称'>
                                                    <EditOutlined style={{ color: '#f90', ...cursor }} onClick={(e: React.MouseEvent<HTMLSpanElement, MouseEvent>) => edit(e, item)} />
                                                </Tooltip>
                                            </Col>
                                            <Col>
                                                <Tooltip title='删除' placement="bottom">
                                                    <Popconfirm
                                                        title={
                                                            <p>
                                                                确定要删除<span style={{ color: 'red' }}>{item.groupName}</span>分组吗？
                                                                <br />
                                                                删除后该分组下的公众号将移动到“未分组”中
                                                            </p>
                                                        }
                                                        onConfirm={(e?: React.MouseEvent<HTMLElement, MouseEvent>) => del(item, e)}
                                                        onCancel={(e) => e?.stopPropagation()}
                                                        okText="是"
                                                        cancelText="否"
                                                    >
                                                        <DeleteOutlined style={{ color: 'red' }} onClick={e => e.stopPropagation()} />
                                                    </Popconfirm>
                                                </Tooltip>
                                            </Col>
                                        </Row>
                                    }
                                </Col>
                            </>
                    }

                </Row >
            })
        }
    </div >
    return <Popover content={content} trigger="click" overlayClassName={style.group}>
        <Tooltip title='分组' >
            <Button size='small' style={{ borderColor: 'orange' }}><UsergroupAddOutlined style={{ color: 'orange' }} /></Button>
        </Tooltip>
    </Popover>
}
/**
 * 发送信息
 * */
// function MsgPopover() {
//     let content = <>
//         <Row gutter={[1, 5]}><Link to='/'>高级群发</Link></Row>
//         <Row gutter={[1, 5]}><Link to='/'>模板消息</Link></Row>
//         <Row gutter={[1, 5]}><Link to='/'>客服消息</Link></Row>
//     </>
//     return <Popover content={content} trigger="focus" placement="bottom">
//         <Button size='small' style={{ borderColor: 'orange' }}>
//             <Tooltip title='发送消息'>
//                 <SendOutlined style={{ color: 'orange' }} />
//             </Tooltip>
//         </Button>
//     </Popover>
// }
/**
 *  公众号信息展示
 */
let Gz = React.memo((props: { img: string, name: string, userName: string, authStatus: number, appid: string, verifyTypeInfo: any }) => {
    const { copy } = useCopy()
    return <>
        <Row gutter={[5, 0]} >
            <Col>
                <Avatar src={props.img} size='large' shape='square' style={{ width: 65, height: 65 }} />
            </Col>
            <Col style={{ display: 'flex', flexFlow: 'column', justifyContent: 'space-between' }}>
                <Row><strong style={{ fontSize: 15 }}>{props.name}{props?.authStatus === 1 ? <span style={{ color: 'red' }}>（未授权）</span> : ''}</strong></Row>
                <Row>
                    <Space>
                        原始id:
                        <span style={{ color: '#888', fontSize: '13px' }}>
                            {props.userName ? props.userName : '--'}
                        </span>
                        {
                            props.userName && <a>
                                <CopyOutlined onClick={() => { copy(props?.userName) }} />
                            </a>
                        }
                    </Space>
                </Row>
                <Row>
                    <Space>
                        appId: <span style={{ color: '#888', fontSize: '13px' }}>
                            {props.appid ? props?.verifyTypeInfo == -1 ? <del>{props.appid}</del> : props.appid : '--'}
                        </span>
                        {
                            props.appid && <a>
                                <CopyOutlined onClick={() => { copy(props?.appid) }} />
                            </a>
                        }
                    </Space>
                </Row>
            </Col>
        </Row>
    </>
})


// 公众号信息编辑reducer
interface State {
    gzhxxVisible?: boolean,
    administratorCard?: string,//管理员身份证号码
    administratorName?: string,//管理员名称
    administratorWechat?: string,//管理员微信号
    legalCard?: string,//法人身份证
    legalName?: string,//法人姓名
    legalWechat?: string,//法人手机号
    authTime?: string,//认证时间
    authTimeout?: string,//认证到期时间
    businessGroupId?: string,//项目组
    putStatus?: string,//投放状态
    putChannel?: string,//投放渠道
    rechargeTemplate?: string,//充值模板
}
interface Action {
    type: 'addData' | 'init',
    params?: State
}
const initGzhxx: State = {
    gzhxxVisible: false,
    administratorCard: '',
    administratorName: '',
    administratorWechat: '',
    legalCard: '',
    legalName: '',
    legalWechat: '',
    authTime: '',
    authTimeout: '',
    businessGroupId: '',
    putStatus: '',
    putChannel: '',
    rechargeTemplate: '',
}

function reducer(state: State, action: Action) {
    let { type, params } = action
    switch (type) {
        case 'addData':
            let obj: any = {}
            Object.keys(params as State).forEach((key: string) => {
                obj[key] = (params as State)[key]
            })
            return { ...state, ...obj }
        case 'init':
            return { ...initGzhxx }
        default:
            return { ...state }
    }

}
/**
 * 操作渲染
 */
const Action = React.memo((props: { data: any, fncList: any }) => {
    const [state, gzhxxDispacth] = useReducer(reducer, initGzhxx)
    const { currentUser }: any = useModel('@@initialState', model => ({ currentUser: model.initialState?.currentUser }))
    const { userId } = useModel('useOperating.useUser', model => ({ userId: model.state.selectdUserId }))
    const { editStatus, perfectInformation } = useModel('useOperating.useAccount', model => ({ editStatus: model.editStatus, perfectInformation: model.perfectInformation }))
    const [visible, setVisible] = useState<boolean>(false)
    const [radio, setRadio] = useState<1 | 2 | 3>(props?.data?.approveStatus || 1)
    const resourceList = useAjax((params) => resourceChangeRecord(params))
    const businessGroupALL = useAjax((paams) => businessGroup())
    const [editData, setEditData] = useState<any>(null)
    const delLog = useAjax((changeRecordId) => del(changeRecordId))//删除日志
    // 获取记录列表
    let showModel = useCallback(() => {
        setVisible(!visible)
        handleResourceList({ pageNum: 1, pageSize: 10 })
    }, [visible])
    let handleResourceList = (params?: any) => {
        resourceList.run({ ...params, resourceId: props?.data?.id })
    }
    useEffect(() => {
        if (state.gzhxxVisible) {
            businessGroupALL.run()
        }

    }, [state.gzhxxVisible])
    let [qsCodeShow, setQsCodeShow] = useState<boolean>(false)
    /**
     * 同步微信
     */
    const weChat = useRequest((params: { id: string }) => putWx(params), {
        manual: true,
        formatResult: (res) => res.data,
        cacheKey: 'weChat',
    })
    /**
     * 同步操作
     */
    let handleweChat = () => {
        weChat.run({ id: props.data.id }).then(() => {
            props.fncList.refresh()
        })
    }
    /**切换公众号状态 */
    let handleStatus = () => {
        editStatus.run({ mpId: props.data.id, status: radio }).then((res: any) => {
            if (res) {
                props.fncList.refresh()
            }
        })
    }
    /**修改公众号信息*/
    let handleGzhxx = () => {
        let { gzhxxVisible, ...params } = state
        perfectInformation.run({ ...params, mpId: props.data.id }).then((res) => {
            if (res) {
                gzhxxDispacth({ type: 'init' })
                props.fncList.refresh()
            }
        })
    }
    /**编辑切书日志*/
    let handleEditShow = useCallback((obj: any) => {
        setEditData(obj)
    }, [])
    /**删除日志*/
    let handleDelLog = useCallback((id: number) => {
        delLog.run(id).then(res => {
            if(res){
                message.success('删除成功！')
                resourceList.refresh()
            }
        })
    }, [resourceList])
    let resource_columns: any = [
        {
            title: '开始时间',
            dataIndex: 'beginTime',
            key: 'beginTime',
            width: 200,
            align: 'center',
            render: (a: any) => {
                return a || '/'
            }
        },
        {
            title: '结束时间',
            dataIndex: 'endTime',
            key: 'endTime',
            width: 200,
            align: 'center',
            render: (a: any) => {
                return a || '/'
            }
        },
        {
            title: '公众号名称',
            dataIndex: 'resourceName',
            key: 'resourceName',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return b?.resourceInfo?.resourceName || '/'
            }
        },
        {
            title: '项目组',
            dataIndex: 'businessGroupName',
            key: 'businessGroupName',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return b?.businessGroupInfo?.businessGroupName || '/'
            }
        },
        {
            title: '运营',
            dataIndex: 'operUserInfo?.nickname',
            key: 'operUserInfo?.nickname',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return b?.operUserInfo?.nickname || '/'
            }
        },
        {
            title: '投手',
            dataIndex: 'putUserInfo.nickname',
            key: 'putUserInfo.nickname',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return b?.putUserInfo?.nickname || '/'
            }
        },
        {
            title: '期数',
            dataIndex: 'period',
            key: 'period',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return b?.periodInfo?.period || '/'
            }
        },
        {
            title: '当前书城',
            dataIndex: 'platformName',
            key: 'platformName',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return b?.platformInfo?.platformName || '/'
            }
        },
        {
            title: '书城VIP账号',
            dataIndex: 'account',
            key: 'account',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return b?.platformAccountInfo?.account || '/'
            }
        },
        {
            title: '当前书籍',
            dataIndex: 'bookName',
            key: 'bookName',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return b?.bookInfo?.bookName || '/'
            }
        },
        {
            title: '投放状态',
            dataIndex: 'putStatus',
            key: 'putStatus',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                let state = {
                    wait: '待投放',
                    ing: '投放中',
                    stop: '停投',
                    destroy: '已注销'
                }
                let status = {
                    wait: 'error',
                    ing: 'processing',
                    stop: 'warning',
                    destroy: 'default'
                }
                return <Badge status={status[a] as 'error' | 'processing' | 'warning' | 'default'} text={state[a]} />
            }
        },
        {
            title: '投放渠道',
            dataIndex: 'putChannel',
            key: 'putChannel',
            width: 200,
            align: 'center',
            render: (a: any) => {
                return a || '/'
            }
        },
        {
            title: '充值模板',
            dataIndex: 'rechargeTemplate',
            key: 'rechargeTemplate',
            width: 200,
            align: 'center',
            render: (a: any) => {
                return a || '/'
            }
        },
        {
            title: '操作人',
            dataIndex: 'nickname',
            key: 'nickname',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return b?.createUser?.nickname || '/'
            }
        },
        {
            title: '备注',
            dataIndex: 'remark',
            key: 'remark',
            width: 200,
            align: 'center',
            render: (a: any) => {
                return a || '/'
            }
        },
        {
            title: '操作',
            dataIndex: 'action',
            key: 'action',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                return <Space>
                    <a onClick={() => { handleEditShow(b) }}>编辑</a>
                    <Popconfirm
                        title={'确定删除本条记录?'}
                        onConfirm={()=>{handleDelLog(b?.id)}}
                        okText="Yes"
                        cancelText="No"
                    >
                        <a >删除</a>
                    </Popconfirm>
                </Space>
            }
        },
    ]
    return <Row gutter={[5, 5]} justify='center'>
        <Col>
            <Tooltip title='公众号信息完善'>
                <Button size='small'
                    style={{ borderColor: '#d12e3c' }}
                    onClick={() => {
                        gzhxxDispacth({
                            type: 'addData',
                            params: {
                                gzhxxVisible: true,
                                legalCard: props?.data?.legalCard || '',
                                legalName: props?.data?.legalName || '',
                                legalWechat: props?.data?.legalWechat || '',
                                administratorCard: props?.data?.administratorCard || '',
                                administratorName: props?.data?.administratorName || '',
                                administratorWechat: props?.data?.administratorWechat || '',
                                authTime: props?.data?.authTime || '',
                                authTimeout: props?.data?.authTimeout || '',
                                businessGroupId: props?.data?.resourceInfo?.businessGroupId || '',
                                putStatus: props?.data?.resourceInfo?.putStatus || '',
                                putChannel: props?.data?.resourceInfo?.putChannel || '',
                                rechargeTemplate: props?.data?.resourceInfo?.rechargeTemplate || '',
                            }
                        })
                    }}
                >
                    <EditOutlined style={{ color: '#d12e3c' }} />
                </Button>
                <Modal
                    visible={state.gzhxxVisible}
                    onOk={handleGzhxx}
                    onCancel={() => {
                        gzhxxDispacth({ type: 'init' })
                    }}
                    title='公众号信息完善'
                    okText='保存'
                    cancelText='取消'
                >
                    <Divider orientation='left'>法人信息</Divider>
                    <Row gutter={[20, 20]}>
                        <Col span={12}>
                            <label>法人</label>
                            <Input
                                placeholder='请输入法人姓名'
                                value={state.legalName}
                                onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                                    let value = e.target.value
                                    gzhxxDispacth({ type: 'addData', params: { legalName: value } })
                                }}
                            />
                        </Col>
                        <Col span={12}>
                            <label>法人身份证</label>
                            <Input
                                placeholder='请输入法人身份证'
                                value={state.legalCard}
                                onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                                    let value = e.target.value
                                    gzhxxDispacth({ type: 'addData', params: { legalCard: value } })
                                }}
                            />
                        </Col>
                        <Col span={12}>
                            <label>法人微信</label>
                            <Input
                                placeholder='请输入法人微信'
                                value={state.legalWechat}
                                onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                                    let value = e.target.value
                                    gzhxxDispacth({ type: 'addData', params: { legalWechat: value } })
                                }}
                            />
                        </Col>
                    </Row>
                    <Divider orientation='left'>管理员信息</Divider>
                    <Row gutter={[20, 20]}>
                        <Col span={12}>
                            <label>管理员姓名</label>
                            <Input
                                placeholder='请输入管理员姓名'
                                value={state.administratorName}
                                onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                                    let value = e.target.value
                                    gzhxxDispacth({ type: 'addData', params: { administratorName: value } })
                                }}
                            />
                        </Col>
                        <Col span={12}>
                            <label>管理员身份证</label>
                            <Input
                                placeholder='请输入管理员身份证'
                                value={state.administratorCard}
                                onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                                    let value = e.target.value
                                    gzhxxDispacth({ type: 'addData', params: { administratorCard: value } })
                                }}
                            />
                        </Col>
                        <Col span={12}>
                            <label>管理员微信</label>
                            <Input
                                placeholder='请输入管理员微信'
                                value={state.administratorWechat}
                                onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                                    let value = e.target.value
                                    gzhxxDispacth({ type: 'addData', params: { administratorWechat: value } })
                                }}
                            />
                        </Col>
                    </Row>
                    <Divider orientation='left'>认证信息</Divider>
                    <Row gutter={[20, 20]}>
                        <Col span={12} style={{ display: 'flex', flexFlow: 'column' }}>
                            <label>认证时间</label>
                            <DatePickePage
                                placeholder='请输入认证时间'
                                model='DatePicker'
                                date={state?.authTime}
                                DatePickerChange={(moment: any, formatString: string | string[]) => {
                                    gzhxxDispacth({ type: 'addData', params: { authTime: formatString as string } })
                                }}
                                isDisabledDate={false}
                            />
                        </Col>
                        <Col span={12} style={{ display: 'flex', flexFlow: 'column' }}>
                            <label>认证到期时间</label>
                            <DatePickePage
                                placeholder='请输入认证到期时间'
                                model='DatePicker'
                                date={state?.authTimeout}
                                DatePickerChange={(moment: any, formatString: string | string[]) => {
                                    gzhxxDispacth({ type: 'addData', params: { authTimeout: formatString as string } })
                                }}
                                isDisabledDate={false}
                            />
                        </Col>
                    </Row>
                    
                </Modal>
            </Tooltip>
        </Col>
        {/* <Col>
            <Tooltip title='账号状态'>
                <Popconfirm
                    title={

                        <Radio.Group onChange={(e: RadioChangeEvent) => { setRadio(e.target.value) }} value={radio}>
                            <Radio value={1}>投放中</Radio>
                            <Radio value={2}>停投</Radio>
                            <Radio value={3}>已注销</Radio>
                        </Radio.Group>
                    }
                    onConfirm={handleStatus}
                    okText="Yes"
                    cancelText="No"
                    icon={null}
                >
                    <Button size='small' style={{ borderColor: '#722ed1' }} >
                        <SwapOutlined style={{ color: '#722ed1' }} />
                    </Button>
                </Popconfirm>
            </Tooltip>
        </Col> */}
        {/* <Col >
        <Access accessible={(access as any).account_add} fallback={null}>
        <Tooltip title='切书管理'>
            <Button size='small' style={{ borderColor: '#2db7f5' }} onClick={showModel}>
                <ReadOutlined style={{ color: '#2db7f5' }} />
            </Button>
        </Tooltip>
        </Access>
        {visible && <DarwerPage
                name={props.data.nickName}
                visible={visible}
                fnc={showModel}
                mpid={props.data.id}
                platformInfo={{
                    bookName: props?.data?.bookName,
                    ...props?.data?.platformInfo,
                    platformAccount: props?.data?.platformAccount,
                    platformPassword: props?.data?.platformPassword,
                }}
                fnlist={props.fncList} />}
        </Col> */}
        {
            currentUser.userId == userId && <Col >
                {/* <Access accessible={(access as any).account_fz} fallback={null}> */}
                <GroupPopover data={props.data} fncList={props.fncList} />
                {/* </Access> */}
            </Col>
        }
        {/* 切书记录 */}
        <Col>
            <Tooltip title='切书记录'>
                <Button size='small' style={{ borderColor: '#2db7f5' }} onClick={showModel}>
                    <ReadOutlined style={{ color: '#2db7f5' }} />
                </Button>
            </Tooltip>
            {visible && <Drawer
                destroyOnClose={true}
                height={600}
                placement='top'
                visible={visible}
                title={`当前公众号:${props?.data?.nickName}`}
                onClose={showModel}
            >
                <Table
                    size='small'
                    columns={resource_columns}
                    dataSource={resourceList?.data?.records || []}
                    pagination={{
                        current: resourceList?.data?.current,
                        pageSize: resourceList?.data?.size,
                        total: resourceList?.data?.total,
                        showSizeChanger: true,
                        pageSizeOptions: ['10', '20', '50', '70', '100'],
                        showTotal: (total) => <Tag color="cyan">总共{total}数据</Tag>,
                        onChange: (page, pageSize) => {
                            handleResourceList({ pageNum: page, pageSize, })
                        }
                    }}
                />
                {
                    editData && <EditBook editData={editData} list={resourceList} hide={() => { handleEditShow(null) }} />
                }
            </Drawer>}
        </Col>
        {/* 同步 */}
        <Col>
            <Tooltip title='同步微信'>
                <Button style={{ borderColor: '#87d068' }} size='small' onClick={handleweChat}>
                    <ReloadOutlined style={{ color: '#87d068' }} />
                </Button>
            </Tooltip>
        </Col>
        <Col>
            <Tooltip title='公众号二维码'>
                <Button style={{ borderColor: '#8B572A' }} size='small' onClick={() => { setQsCodeShow(true) }}>
                    <QrcodeOutlined style={{ color: '#8B572A' }} />
                </Button>
            </Tooltip>
            {(qsCodeShow && props?.data?.qrcodeUrl) && <Modal title={props?.data?.nickName} visible={qsCodeShow} onCancel={() => { setQsCodeShow(false) }} footer={null} width={250}>
                <Image
                    width={204}
                    height={204}
                    src={props.data.qrcodeUrl}
                />
            </Modal>}
        </Col>
    </Row >
})

// let Title = <Tooltip title="48小时内互动（包括粉丝发送消息给公众号、 点击自定义菜单、关注公众号、 扫描二维码、 支付成功、用户维权等，阅读公众号文章不算互动） 的粉丝数。">互动粉丝数<QuestionCircleOutlined /></Tooltip>
/**
 * Column配置
 */
export let tablesConfig: (
    listData: any, open: (mpId: string) => void
) => ColumnProps<ColumnsType>[] = (listData, open) => {
    const { copy } = useCopy()
    return [
        {
            title: '公众号',
            dataIndex: 'alias',
            key: 'alias',
            align: 'center',
            width: 350,
            fixed: 'left',
            render: (a: any, b: any) => <Gz userName={b.userName} name={b.nickName} img={b.headImg || localStorage?.bookImg} authStatus={b?.authStatus} appid={b?.appid} verifyTypeInfo={b?.verifyTypeInfo} />
        },
        {
            title: '粉丝数',
            dataIndex: 'fansCount',
            key: 'fansCount',
            align: 'center',
            width: 100,
            sorter: (a: any, b: any) => {
                return a?.fansCount - b?.fansCount
            },
            defaultSortOrder: 'descend'
        },
        {
            title: <span>运营信息</span>,
            dataIndex: 'isOperUser',
            key: 'isOperUser',
            align: 'center',
            width: 180,
            render: (a: any, b: any) => {
                return <>
                    {
                        b?.operUserInfo ? <>
                            <div>{b?.operUserInfo?.nickName}</div>
                            <div>{b?.operUserInfo?.phone}</div>
                        </> : <span style={{ color: 'red' }}>未配置</span>
                    }
                </>
            }
        },
        {
            title: '投手信息',
            dataIndex: 'putUserInfo',
            key: 'putUserInfo',
            align: 'center',
            width: 150,
            render: (a: any, b: any) => {
                return <>
                    {
                        b?.putUserInfo && Object.keys(b?.putUserInfo).length > 0 ? <>
                            <div>{b?.putUserInfo?.nickName}</div>
                            <div>{b?.putUserInfo?.phone}</div>
                        </> : <span style={{ color: 'red' }}>未配置</span>
                    }
                </>
            }
        },
        {
            title: '当前书城',
            dataIndex: 'platformInfo',
            key: 'platformInfo',
            width: 200,
            align: 'center',
            render: (a: any, b: any) => {
                let { resourceInfo: { platformAccountInfo, platformInfo, bookInfo, periodInfo } } = b
                return <div style={{ display: 'flex', flexFlow: 'column' }}>
                    <span>
                        <Space>
                            {
                                platformInfo?.platformName ? <a href={platformInfo?.vipLink?.search(/http[s]?:\/\//) === -1 ? 'http://' + platformInfo?.vipLink : platformInfo?.vipLink} target='_blank'>{platformInfo?.platformName}</a> : '无'
                            }
                            <LinsModal
                                oldPlatformId={platformInfo?.id}//书城ID
                                mpId={b?.resourceId}//resourceId
                                list={listData}
                                oldPeriodId={periodInfo?.id}//期数ID
                                oldPlatformAccountId={platformAccountInfo?.id}//账号ID
                                oldBookId={bookInfo?.id}//书ID
                                oldBusinessGroupId={b?.resourceInfo?.businessGroupId}
                                oldPutChannel={b?.resourceInfo?.putChannel}
                                oldPutStatus={b?.resourceInfo?.putStatus}
                                oldRechargeTemplate={b?.resourceInfo?.rechargeTemplate}
                            // remark={}//描述
                            />
                        </Space>
                    </span>
                    <span>账号：{platformAccountInfo?.account || `无`} {
                        platformAccountInfo?.account && <a>
                            <CopyOutlined onClick={() => { copy(platformAccountInfo?.account) }} />
                        </a>
                    }</span>
                    <span>密码：{platformAccountInfo?.password || `无`}{
                        platformAccountInfo?.password && <a>
                            <CopyOutlined onClick={() => { copy(platformAccountInfo?.password) }} />
                        </a>
                    }</span>

                </div>
            }
        },
        {
            title: '所属期数',
            dataIndex: 'qs',
            key: 'qs',
            width: 150,
            align: 'center',
            render: (a: any, b: any) => {
                let { resourceInfo: { periodInfo } } = b
                return periodInfo?.period || '无'
            }
        },
        {
            title: '当前书籍',
            dataIndex: 'bookName',
            key: 'bookName',
            width: 150,
            align: 'center',
            render: (a: string, b: any) => {
                let { resourceInfo: { bookInfo } } = b
                return bookInfo?.bookName || '无'
            }
        },
        {
            title: <span>投放状态</span>,
            dataIndex: 'approveStatus',
            key: 'approveStatus',
            align: 'center',
            width: 150,
            render: (a: any, b: any) => {
                let state = {
                    wait: '待投放',
                    ing: '投放中',
                    stop: '停投',
                    destroy: '已注销'
                }
                let status = {
                    wait: 'error',
                    ing: 'processing',
                    stop: 'warning',
                    destroy: 'default'
                }
                let { resourceInfo: { putStatus } } = b
                return <Badge status={status[putStatus] as 'error' | 'processing' | 'warning' | 'default'} text={state[putStatus]} />
            }
        },
        {
            title: '项目组',
            dataIndex: 'groupInfo',
            key: 'groupInfo',
            align: 'center',
            width: 150,
            render: (a: any, b: any) => {
                return b?.resourceInfo?.businessGroupInfo?.businessGroupName
            }
        },
        {
            title: '投放渠道',
            dataIndex: 'groupInfo',
            key: 'groupInfo',
            align: 'center',
            width: 150,
            render: (a: any, b: any) => {
                return b?.resourceInfo?.putChannel
            }
        },
        {
            title: '充值模板',
            dataIndex: 'groupInfo',
            key: 'groupInfo',
            align: 'center',
            width: 150,
            render: (a: any, b: any) => {
                return b?.resourceInfo?.rechargeTemplate
            }
        },
        {
            title: '公众号账号/密码',
            dataIndex: 'platformAccount',
            key: 'platformAccount',
            width: 200,
            align: 'center',
            render: (a: string, b: any) => {
                return <div style={{ display: 'flex', flexFlow: 'column' }}>
                    <span>账号：{b?.account || `无`} {
                        b?.account && <a>
                            <CopyOutlined onClick={() => { copy(b?.account) }} />
                        </a>
                    }</span>
                    <span>密码：{b?.password || `无`}{
                        b?.password && <a>
                            <CopyOutlined onClick={() => { copy(b?.password) }} />
                        </a>
                    }</span>
                </div>
            }
        },
        {
            title: <span>公众号管理者<Tooltip title="管理者指此公众号在微信平台的真实管理员！"><QuestionCircleOutlined style={{ color: 'red', marginLeft: 5 }} /></Tooltip></span>,
            dataIndex: 'admin',
            key: 'admin',
            width: 200,
            align: 'center',
            render: (a: string, b: any) => <div style={{ display: 'flex', flexFlow: 'column' }}>
                <span>姓名：{b?.administratorName || `无`}</span>
                <span>手机号：{b?.managePhone || `无`}</span>
                <span>编号：{b?.managePhoneNo || `无`}</span>
            </div>
        },
        {
            title: '公司主体',
            dataIndex: 'principalName',
            key: 'principalName',
            align: 'center',
            width: 180,
            render: (a: any, b: any) => {
                return b?.principalName
            }
        },

        {
            title: '认证有效期截止',
            dataIndex: 'authTimeout',
            key: 'authTimeout',
            align: 'center',
            width: 150,
            render: (a: string) => {
                return a
            }
        },
        {
            title: '所属分组',
            dataIndex: 'groupInfo',
            key: 'groupInfo',
            align: 'center',
            width: 150,
            render: (a: any, b: any) => {
                return b?.groupInfo?.groupName
            }
        },

        {
            title: '操作',
            key: 'cz',
            fixed: 'right',
            width: 150,
            align: 'center',
            render: (a: any, b: any) => {
                if (b.authStatus === 0) {
                    return <Action data={b} fncList={listData} />
                }
                if (b.authStatus === 1) {
                    return <Tooltip title='授权'>
                        <Button size='small' style={{ borderColor: '#1cac2f' }} onClick={() => {
                            open(b.id)
                        }}>
                            <WechatOutlined style={{ color: '#1cac2f' }} />
                        </Button>
                    </Tooltip>
                }
                return null
            }
        }
    ]
}
