import { DatePicker, Form, Input, Modal, Select } from "antd";
import moment from "moment";
import React, { useEffect, useState } from "react";
import { useModel } from "umi";


interface Props {
    value?: any,
    handleType?: 'addGDT' | 'addKYY' | 'editGDT' | 'editKYY'
    type?: string,
    visible?: boolean,
    onChange?: () => void,
    onClose?: () => void
}
function AddAccount(props: Props) {
    const { value = {}, handleType = 'addGDT', type = '1', visible = false, onChange, onClose } = props
    const { getResource, addGdtAccount, editGdtAccount, addQuickAppAccount, editQuickAppAccount } = useModel('useOperating.useAccountyyb')
    const { userId } = useModel('useOperating.useUser', model => ({ userId: model.state.selectdUserId }))
    const [titel, setTitle] = useState<string>('新增账号')
    const [form] = Form.useForm()

    useEffect(() => {
        switch (handleType) {
            case 'addGDT':
                setTitle('新增账号')
                break
            case 'addKYY':
                setTitle('新增账号')
                break
            case 'editGDT':
                setTitle('修改账号')
                break
            case 'editKYY':
                setTitle('修改账号')
                break
        }
    }, [])
    // 确认
    const handleOk = async () => {
        form.submit()
        let data = await form.validateFields()
        let { resourceNames, ...newData } = data
        let proms = { ...newData, beginTime: moment(data.beginTime).format('YYYY-MM-DD'), userId }
        switch (handleType) {
            case 'addGDT':
                addGdtAccount.run(proms).then(res => {
                    if (res) {
                        onChange && onChange()
                    }
                })
                break
            case 'addKYY':
                addQuickAppAccount.run(proms).then(res => {
                    if (res) {
                        onChange && onChange()
                    }
                })
                break
            case 'editGDT':
                proms = { ...newData, userId, gdtAccountId: value.gdtAccountId }
                editGdtAccount.run(proms).then(res => {
                    if (res) {
                        onChange && onChange()
                    }
                })
                break
            case 'editKYY':
                proms = { ...newData, userId, accountId: value.accountId }
                editQuickAppAccount.run(proms).then(res => {
                    if (res) {
                        onChange && onChange()
                    }
                })
                break
        }
    }

    // 搜索资源
    const handleSearch = (value: string) => {
        getResource.run({ resourceName: value, resourceType: type === '1' ? 0 : 10 })
    }

    return <Modal title={titel} visible={visible} onOk={handleOk} onCancel={() => { onClose && onClose() }} confirmLoading={addGdtAccount.loading || editGdtAccount.loading || addQuickAppAccount.loading}>
        <Form
            name="basic"
            form={form}
            labelCol={{ span: 5 }}
            wrapperCol={{ span: 19 }}
            autoComplete="off"
            initialValues={{ ...value }}
        >
            {handleType === 'addGDT' ? <Form.Item label="账号ID" name="accountIds" rules={[{ type: 'string', required: true, message: '请输入账号!' }]}>
                <Input.TextArea autoSize placeholder="请输入账号ID（id1,id2,id3）" />
            </Form.Item> : handleType === 'editGDT' ? <Form.Item label="账号ID" name="accountId" rules={[{ type: 'string', required: true, message: '请输入账号!' }]}>
                <Input placeholder="请输入账号ID" />
            </Form.Item> : handleType === 'addKYY' || handleType === 'editKYY' ? <>
                {handleType === 'addKYY' ? <Form.Item label="账号ID" name="advertiserIds" rules={[{ type: 'string', required: true, message: '请输入账号ID!' }]}>
                    <Input.TextArea autoSize placeholder="请输入账号ID（id1,id2,id3）" />
                </Form.Item> : <Form.Item label="账号ID" name="advertiserId" rules={[{ type: 'string', required: true, message: '请输入账号ID!' }]}>
                    <Input.TextArea autoSize placeholder="请输入账号ID" />
                </Form.Item>}
                <Form.Item label="总账号名称" name="accountName" rules={[{ type: 'string', required: true, message: '请输入总账号名称!' }]}>
                    <Input placeholder="请输入总账号名称" />
                </Form.Item>
                <Form.Item label="总账号" name="account" rules={[{ type: 'string', required: true, message: '请输入总账号!' }]}>
                    <Input placeholder="请输入总账号" />
                </Form.Item>
                <Form.Item label="总账号密码" name="accountPassword" rules={[{ type: 'string', required: true, message: '请输入总账号密码!' }]}>
                    <Input placeholder="请输入总账号密码" />
                </Form.Item>
            </> : null}
            {(handleType === 'editGDT' || handleType === 'editKYY') && <Form.Item label="当前投放信息" name="resourceNames">
                <Input.TextArea autoSize disabled />
            </Form.Item>}
            {(handleType === 'addGDT' || handleType === 'addKYY') && <>
                <Form.Item label="投放信息" name="putResourceId" rules={[{ type: 'number', required: true, message: '请选择投放信息!' }]}>
                    <Select
                        showSearch
                        placeholder="选择投放信息"
                        defaultActiveFirstOption={false}
                        showArrow={false}
                        filterOption={false}
                        onSearch={handleSearch}
                        notFoundContent={null}
                    >
                        {getResource?.data?.map((item: { id: number, resourceName: string }) => <Select.Option key={item.id} value={item.id}>{item.resourceName}</Select.Option>)}
                    </Select>

                </Form.Item>
                <Form.Item label="开始时间" name="beginTime" rules={[{ type: 'object' as const, required: true, message: '请选择时间!' }]}>
                    <DatePicker />
                </Form.Item>
            </>}
        </Form>
    </Modal>
}

export default React.memo(AddAccount)