import GroupYybTabs from "@/components/GroupWxTabs/yyb"
import Tables from '@/components/Tables'
import { Button, Input, Popconfirm, Select, Space, Tabs } from "antd"
import React, { useCallback, useEffect, useState } from "react"
import { useModel } from "umi"
import { columns, columnsKyy } from "./tablesConfig"
import { gdtAccountProps, QuickAppAccout } from '@/services/operating/accountyyb'
import { DeleteOutlined, PlusOutlined, SwapOutlined } from "@ant-design/icons"
import AddAccount from "./addAccount"
import CheckAccount from "./checkAccount"
import ChangeRecord from "./changeRecord"

function Accountyyb() {

    const { getGdtAccount, delGdtAccount, getQuickAppAccount, delQuickAppAccount, getResourceOfUser } = useModel('useOperating.useAccountyyb')
    const { userId } = useModel('useOperating.useUser', model => ({ userId: model.state.selectdUserIdYyb }))
    const [actionKey, setActionKye] = useState('1')
    const [queryPlatformGdt, setQueryPlatformGdt] = useState<gdtAccountProps>({ pageNum: 1, pageSize: 10, userId })  // 获取GDT参数
    const [addShow, setAddShow] = useState<boolean>(false)
    const [checkAccShow, setCheckAccShow] = useState<boolean>(false)
    const [data, setData] = useState<{
        putResourceId?: number | undefined,
        beginTime?: string | undefined,
        gdtAccountId?: number,
        accountIds?: string,
        accountId?: string,
        gdtAccountIds?: string,
        resourceNames?: string,
        advertiserId?: string,
        accountName?: string,
        account?: string,
        accountPassword?: string,
        quickAppAccountIds?: string
    } | undefined>(undefined)
    const [handleType, setHandleType] = useState<'addGDT' | 'addKYY' | 'editGDT' | 'editKYY'>('addGDT')
    const [selectAccData, setSelectAccData] = useState<any[]>([])
    const [queryPlatformKyy, setQueryPlatformKyy] = useState<QuickAppAccout>({ pageNum: 1, pageSize: 10, userId })  // 获取KYY参数
    const [crShow, setCrShow] = useState<boolean>(false) // 变更记录控制
    const [crData, setCrData] = useState<{ name: string, id: number } | null>(null)

    // 切换key换接口数据
    useEffect(() => {
        if(userId) {
            getList()
        }
    }, [actionKey, queryPlatformGdt, queryPlatformKyy, userId])

    // 获取投放信息
    useEffect(() => {
        if (userId) {
            getResourceOfUser.run({ userId, resourceType: actionKey === '1' ? 0 : 10 })
        }
    }, [actionKey, userId])

    // 获取数据
    const getList = () => {
        if (actionKey === '1') {//广点通
            getGdtAccount.run({ ...queryPlatformGdt, userId })
        } else {//应用宝
            getQuickAppAccount.run({ ...queryPlatformKyy, userId })
        }
    }

    // 分页
    const pageChange = useCallback((page: string | number, pageSize?: string | number) => {
        if (actionKey === '1') { //广点通
            setQueryPlatformGdt({ ...queryPlatformGdt, pageNum: page as number, pageSize: pageSize as number })
        } else { //快应用
            setQueryPlatformKyy({ ...queryPlatformKyy, pageNum: page as number, pageSize: pageSize as number })
        }
    }, [queryPlatformGdt, queryPlatformKyy, actionKey])

    // 删除账号
    const delAccount = (id: number[]) => {
        if (actionKey === '1') {//广点通
            delGdtAccount.run({ gdtAccountIds: id.toString() }).then(res => {
                if (res) {
                    getGdtAccount.refresh()
                    setSelectAccData([])
                }
            })
        } else {//应用宝
            delQuickAppAccount.run({ quickAppAccountIds: id.toString() }).then(res => {
                if (res) {
                    getQuickAppAccount.refresh()
                    setSelectAccData([])
                }
            })
        }
    }

    // 编辑账号
    const editAccountHandle = (value: any) => {
        if (actionKey === '1') {//广点通
            setHandleType('editGDT')
            setData({ gdtAccountId: value.id, accountId: value.accountId, resourceNames: value?.putResourceInfo?.resourceName })
        } else {//应用宝
            setHandleType('editKYY')
            setData({ accountId: value.id, resourceNames: value?.putResourceInfo?.resourceName, advertiserId: value.advertiserId, accountName: value.accountName, account: value.account, accountPassword: value.accountPassword })
        }
        setAddShow(true);
    }

    // 切号
    const checkGdtAccountHandle = (value: any[]) => {
        if (actionKey === '1') {//广点通
            let ids = value?.map((item: any) => item.id)
            setData({ resourceNames: value?.map((item: any) => item?.putResourceInfo?.resourceName).toString(), accountIds: value?.map((item: any) => item.accountId).toString(), gdtAccountIds: ids.toString(), putResourceId: undefined, beginTime: undefined })
        } else {//应用宝
            let ids = value?.map((item: any) => item.id)
            setData({ resourceNames: value?.map((item: any) => item?.putResourceInfo?.resourceName).toString(), accountIds: value?.map((item: any) => item.account).toString(), quickAppAccountIds: ids.toString(), putResourceId: undefined, beginTime: undefined })
        }
        setCheckAccShow(true);
    }

    // 变更记录
    const changeRecord = (name: string, id: number) => {
        setCrData({ name, id })
        setCrShow(true)
    }

    return <div>
        {/* 新增 */}
        {addShow && <AddAccount type={actionKey} handleType={handleType} value={data} visible={addShow} onChange={() => { getList(); setAddShow(false) }} onClose={() => { setAddShow(false) }} />}
        {/* 切号 */}
        {checkAccShow && <CheckAccount type={actionKey} value={data} visible={checkAccShow} onChange={() => { getList(); setCheckAccShow(false); setSelectAccData([]) }} onClose={() => { setCheckAccShow(false) }} />}
        {/* 变更记录 */}
        {crShow && <ChangeRecord visible={crShow} type={actionKey} data={crData} onClose={() => { setCrShow(false); setCrData(null) }} />}

        <Space>
            {actionKey === '1' ? <>
                <Input placeholder="输入账号搜索" value={queryPlatformGdt.accountIds} allowClear onChange={(e) => { setQueryPlatformGdt({ ...queryPlatformGdt, accountIds: e.target.value }) }} />
            </> :
                <>
                    <Input placeholder="输入账号ID搜索" value={queryPlatformKyy.advertiserIds} allowClear onChange={(e) => { setQueryPlatformKyy({ ...queryPlatformKyy, advertiserIds: e.target.value }) }} />
                    <Input placeholder="输入总账号搜索" value={queryPlatformKyy.account} allowClear onChange={(e) => { setQueryPlatformKyy({ ...queryPlatformKyy, account: e.target.value }) }} />
                </>
            }
            <Select placeholder="选择投放信息" showSearch filterOption={(input, option) =>
                option?.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
            } style={{ width: 150 }} allowClear value={actionKey === '1' ? queryPlatformGdt?.putResourceId : queryPlatformKyy?.putResourceId} onChange={(e) => {
                if (actionKey === '1') {
                    setQueryPlatformGdt({ ...queryPlatformGdt, putResourceId: e })
                } else {
                    setQueryPlatformKyy({ ...queryPlatformKyy, putResourceId: e })
                }
            }}>
                {getResourceOfUser?.data?.map((item: { id: number, resourceName: string }) => <Select.Option value={item.id} key={item.id}>{item.resourceName}</Select.Option>)}
            </Select>
            <Button type="primary" onClick={() => { getList() }}>搜索</Button>
        </Space>
        <Tabs activeKey={actionKey} onChange={(activeKey) => { setActionKye(activeKey); setSelectAccData([]) }}>
            <Tabs.TabPane tab="广点通" key="1" >
                <GroupYybTabs
                    isShowCount={false}
                    allowClear={false}
                    name="账号管理"
                    tabBarExtraContent={{
                        right: <Space>
                            {selectAccData.length > 0 && <>
                                <Popconfirm
                                    title="确定删除?"
                                    onConfirm={() => { delAccount(selectAccData?.map(item => item.id)) }}
                                    okText="Yes"
                                    cancelText="No"
                                >
                                    <Button danger icon={<DeleteOutlined />}>批量删除</Button>
                                </Popconfirm>
                                <Button type="primary" ghost icon={<SwapOutlined />} onClick={() => { checkGdtAccountHandle(selectAccData) }}>批量切号</Button>
                                <Button type="primary" onClick={() => { setSelectAccData([]) }}>取消勾选</Button>
                            </>}
                            <Button type="primary" icon={<PlusOutlined />} onClick={() => { setAddShow(true); setData(undefined); setHandleType(actionKey === '1' ? 'addGDT' : 'addKYY') }}>新增</Button>
                        </Space>
                    }}
                >
                    <Tables
                        columns={columns(editAccountHandle, delAccount, checkGdtAccountHandle, changeRecord)}
                        dataSource={getGdtAccount?.data?.records}
                        total={getGdtAccount?.data?.total}
                        loading={getGdtAccount?.loading}
                        pageChange={pageChange}
                        sizeChange={pageChange}
                        bordered
                        current={getGdtAccount?.data?.current}
                        pageSize={getGdtAccount?.data?.size}
                        rowClassName='authStatus'
                        size={'small'}
                        scroll={{ x: 1100 }}
                        rowSelection={{
                            selectedRowKeys: selectAccData?.map((item: any) => item.id?.toString()),
                            onSelect: (record: { id: number, mpName: string }, selected: boolean) => {
                                if (selected) {
                                    selectAccData.push({ ...record })
                                    setSelectAccData([...selectAccData])
                                } else {
                                    let newSelectAccData = selectAccData.filter((item: { id: number }) => item.id !== record.id)
                                    setSelectAccData([...newSelectAccData])
                                }
                            },
                            onSelectAll: (selected: boolean, selectedRows: { id: number }[], changeRows: { id: number }[]) => {
                                if (selected) {
                                    let newSelectAccData = [...selectAccData]
                                    changeRows.forEach((item: { id: number }) => {
                                        let index = newSelectAccData.findIndex((ite: { id: number }) => ite.id === item.id)
                                        if (index === -1) {
                                            newSelectAccData.push({ ...item })
                                        }
                                    })
                                    setSelectAccData([...newSelectAccData])
                                } else {
                                    let newSelectAccData = selectAccData.filter((item: { id: number }) => {
                                        let index = changeRows.findIndex((ite: { id: number }) => ite.id === item.id)
                                        if (index !== -1) {
                                            return false
                                        } else {
                                            return true
                                        }
                                    })
                                    setSelectAccData([...newSelectAccData])
                                }
                            }
                        }}
                    />
                </GroupYybTabs>
            </Tabs.TabPane>
            <Tabs.TabPane tab="快应用" key="2">
                <GroupYybTabs
                    isShowCount={false}
                    allowClear={false}
                    name="账号管理"
                    tabBarExtraContent={{
                        right: <Space>
                            {selectAccData.length > 0 && <>
                                <Popconfirm
                                    title="确定删除?"
                                    onConfirm={() => { delAccount(selectAccData?.map(item => item.id)) }}
                                    okText="Yes"
                                    cancelText="No"
                                >
                                    <Button danger icon={<DeleteOutlined />} loading={delQuickAppAccount.loading}>批量删除</Button>
                                </Popconfirm>
                                <Button type="primary" ghost icon={<SwapOutlined />} onClick={() => { checkGdtAccountHandle(selectAccData) }}>批量切号</Button>
                                <Button type="primary" onClick={() => { setSelectAccData([]) }}>取消勾选</Button>
                            </>}
                            <Button type="primary" icon={<PlusOutlined />} onClick={() => { setAddShow(true); setData(undefined); setHandleType(actionKey === '1' ? 'addGDT' : 'addKYY') }}>新增</Button>
                        </Space>
                    }}
                >
                    <Tables
                        columns={columnsKyy(editAccountHandle, delAccount, checkGdtAccountHandle, changeRecord)}
                        dataSource={getQuickAppAccount?.data?.records}
                        total={getQuickAppAccount?.data?.total}
                        loading={getQuickAppAccount?.loading}
                        pageChange={pageChange}
                        sizeChange={pageChange}
                        bordered
                        current={getQuickAppAccount?.data?.current}
                        pageSize={getQuickAppAccount?.data?.size}
                        rowClassName='authStatus'
                        size={'small'}
                        scroll={{ x: 1550 }}
                        rowSelection={{
                            selectedRowKeys: selectAccData?.map((item: any) => item.id?.toString()),
                            onSelect: (record: { id: number, mpName: string }, selected: boolean) => {
                                if (selected) {
                                    selectAccData.push({ ...record })
                                    setSelectAccData([...selectAccData])
                                } else {
                                    let newSelectAccData = selectAccData.filter((item: { id: number }) => item.id !== record.id)
                                    setSelectAccData([...newSelectAccData])
                                }
                            },
                            onSelectAll: (selected: boolean, selectedRows: { id: number }[], changeRows: { id: number }[]) => {
                                if (selected) {
                                    let newSelectAccData = [...selectAccData]
                                    changeRows.forEach((item: { id: number }) => {
                                        let index = newSelectAccData.findIndex((ite: { id: number }) => ite.id === item.id)
                                        if (index === -1) {
                                            newSelectAccData.push({ ...item })
                                        }
                                    })
                                    setSelectAccData([...newSelectAccData])
                                } else {
                                    let newSelectAccData = selectAccData.filter((item: { id: number }) => {
                                        let index = changeRows.findIndex((ite: { id: number }) => ite.id === item.id)
                                        if (index !== -1) {
                                            return false
                                        } else {
                                            return true
                                        }
                                    })
                                    setSelectAccData([...newSelectAccData])
                                }
                            }
                        }}
                    />
                </GroupYybTabs>
            </Tabs.TabPane>
        </Tabs>
    </div>
}
export default Accountyyb