import React, { useCallback, useEffect, useMemo, useState } from 'react'
import GroupWxTabs from '@/components/GroupWxTabs/wx'
import { useModel } from 'umi'
import { Button, Card, Input, message, Radio, Select, Space, Tabs } from 'antd'
import { useAjax } from '@/Hook/useAjax'
import { autoLink, creatNormalLink, normalLink } from '@/services/operating/link'
import Tables from '@/components/Tables'
import columns from './tableConfig'
import Modal from 'antd/lib/modal/Modal'
import style from './index.less'
let linkArr = ["免费（自动）", "分类（自动）", "排行榜（自动）", "继续阅读", "联系客服", "分站首页", "小说搜索", "阅读历史", "个人中心", "充值", "签到", "排行榜（男生）", "排行榜（女生）", "排行榜（出版）", "分类（男生）", "分类（女生）", "分类（出版）", "免费（男生）", "免费（女生）", "免费（出版）"]
const platforms = [
    {
        platformName: '花生',
        list: [
            { name: '花生常用链接', link_type: -1 },
            { name: '花生平台活动', link_type: -2 },
            { name: '花生推广链接', link_type: 1 },
            { name: '花生自定义活动', link_type: 2 },
            { name: '花生赠币活动', link_type: 3 }
        ]
    },
    {
        platformName: '阅文',
        list: [
            { name: '阅文常用链接', link_type: -1 },
            { name: '阅文推广链接', link_type: 1 },
            { name: '阅文常规活动链接', link_type: 4 },
            { name: '阅文模板充值活动链接', link_type: 5 },
            { name: '阅文模模板直赠活动链接', link_type: 6 },
            { name: '阅文模板消耗活动连接', link_type: 7 },
        ]
    },
    {
        platformName: '阳光',
        list: [
            { name: '阳光常用链接', link_type: -1 },
            { name: '阳光累计充值活动', link_type: -3 },
            { name: '阳光推广链接', link_type: 1 },
            { name: '阳光自定义活动', link_type: 2 },
            { name: '阳光赠币活动', link_type: 3 },
        ]
    },
    {
        platformName: '文鼎',
        list: [
            { name: '文鼎常用链接', link_type: -1 },
            { name: '文鼎平台活动', link_type: -2 },
            { name: '文鼎推广链接', link_type: 1 },
            { name: '文鼎自定义活动', link_type: 2 },
            { name: '文鼎赠币活动', link_type: 3 },
        ]
    },
    {
        platformName: '掌中云',
        list: [
            { name: '掌中云常用链接', link_type: -1 },
            { name: '掌中云平台活动', link_type: -2 },
            { name: '掌中云推广链接', link_type: 1 },
            { name: '掌中云自定义活动', link_type: 2 },
            { name: '掌中云送书卷活动', link_type: 8 },
        ]
    },
]
let pageTypeIds = [
    '',
    '个人中心',
    '免费专区',
    '阅读记录',
    '充值页面',
    '继续阅读',
    '签到送礼',
    'VIP充值',
    '书城首页',
    '榜单',
    '书库(男频)',
    '书库(女频)',
    '书币抽奖'
]
function Links() {
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const [platformName, setPlatformName] = useState<string>('花生')//平台名称
    const [data, setData] = useState<any>()//数据
    const [activeKey, setActiveKey] = useState<string>('花生常用链接_-1')//选中的平台类型
    const [user, setUser] = useState<string>('')//平台账号
    const [password, setPassword] = useState<string>('')//平台密码
    const [pupshow, setPupShow] = useState<boolean>(false)//平台弹窗
    const [vip, setVip] = useState<number>(1)
    const getAutoLink = useAjax((props) => autoLink(props))//获取推广连接
    const getNormalLink = useAjax((props) => normalLink(props))//获取常用链接
    const postNormalLink = useAjax((props) => creatNormalLink(props))//
    const [activityTitle, setActivity_title] = useState<string>('')//链接名称
    const [activityName, setActivity_name] = useState<string>('')//活动名称
    const [spreadType, setSpread_type] = useState<string>('')//链接类型
    // const [creatLinkType, setCreatLinkType] = useState<string>('花生Link')
    const [apiKey, setApiKey] = useState<string>('')//apikey
    const [apiSecret, setApiSecret] = useState<string>('')//apiSecret
    const [remark, setRemark] = useState<string>('')//备注
    const [pageTypeId, setPageTypeId] = useState<number>(1)//入口


    let list = useMemo(() => {
        let arr: any[] = []
        platforms.forEach((item) => {
            if (item.platformName === platformName) {
                arr = item.list
            }
        })
        return arr
    }, [platformName])
    useEffect(() => {
        setActiveKey(`${platformName}常用链接_-1`)//切换平台默认选中平台常用链接
    }, [platformName])
    useEffect(() => {
        setActivity_name('')
        setActivity_title('')
    }, [activeKey])
    //切换链接类型获取对应数据
    useEffect(() => {
        pageChange()
    }, [activeKey, platformName, actionWX])
    //翻页
    const pageChange = useCallback((pageNum?: number, pageSize?: number) => {
        let linkType = Number(activeKey.split('_')[1])
        let ajax = linkType > 0 ? getAutoLink : getNormalLink
        // getNormalLink.run()
        setData(null)
        ajax.run({ pageSize: pageSize || 20, pageNum: pageNum || 1, platformName, linkType: Math?.abs(linkType), mpId: actionWX?.id }).then((res) => {
            if (res?.records && Array.isArray(res?.records) && res?.records.length > 0) {
                setData(res)
            }
        })
    }, [activeKey, platformName, actionWX])
    const PuphandleOk = useCallback(() => {
        if (platformName === '掌中云' && activeKey.includes('掌中云常用链接_-1')) {
            let linkType = Math.abs(Number(activeKey.split('_')[1]))
            let obj: any = {
                account:apiKey,
                password:apiSecret,
                apiKey,
                apiSecret,
                mpId: actionWX?.id,
                linkType,
                vip: !!vip,
                platformName,
                publicName:actionWX?.nickName,
                spreadType,
                pageTypeId,
                remark
            }
            postNormalLink.run(obj).then((res) => {
                console.log(res)
            })
            setPupShow(false)
        } else if (password && user) {
            let linkType = Math.abs(Number(activeKey.split('_')[1]))
            let obj: any = {
                account: user,
                linkType,
                mpId: actionWX?.id,
                password,
                platformName,
                vip: !!vip
            }
            if (platformName === '文鼎') {
                obj = {
                    ...obj,
                    activityTitle,
                    activityName,
                    spreadType
                }
            }
            postNormalLink.run(obj).then((res) => {
                console.log(res)
            })
            setPupShow(false)
        } else {
            message.warning('请填写账号密码')
        }
    }, [password, user, activeKey, platformName, vip, actionWX, activityTitle, activityName, spreadType, apiKey, apiSecret, remark, pageTypeId])
    let tabData = data?.records[0]?.links || data?.records || []
    return <div>
        <GroupWxTabs>
            <Card
                style={{ width: '100%' }}
                title={actionWX?.nickName}
                // extra={<a href="#">More</a>}
                tabList={platforms.map((item) => {
                    return { key: item.platformName, tab: item.platformName }
                })}
                size='small'
                tabProps={{ size: 'small', type: "card" }}
                activeTabKey={platformName}
                onTabChange={(key: string) => {
                    setPlatformName(key)
                }}
            >
                <Tabs
                    onChange={(activeKey: string) => { setActiveKey(activeKey) }}
                    activeKey={activeKey}
                    tabBarExtraContent={
                        <Space>
                            {Number(activeKey.split('_')[1]) < 0 ? <Button type='primary' onClick={() => { setPupShow(true) }}>{Math.abs(Number(activeKey.split('_')[1])) === 1 ? '获取常用链接' : '获取平台活动'}</Button> : null}
                            {/* {Number(activeKey.split('_')[1]) < 0 ? <Button type='primary' >更新列表</Button> : null} */}
                        </Space>
                    }
                >
                    {
                        list.map((item: { name: string, link_type: number }, index: number) => {
                            return <Tabs.TabPane tab={item.name} key={item.name + '_' + item.link_type}>
                                <Tables
                                    columns={columns({ name: activeKey.split('_')[0], isOk: !!data?.records[0]?.links })}
                                    dataSource={tabData.map((item: any, index: number) => { return { id: index + 1, ...item } })}
                                    total={data?.total}
                                    pageChange={pageChange}
                                    sizeChange={pageChange}
                                    size="small"
                                    bordered
                                    loading={false}
                                    rowClassName={(data: any) => {
                                        if (data['createStatus'] === -2 || data['createStatus'] === -1) {
                                            return 'table_row_red'
                                        }
                                        return ''
                                    }}
                                    scroll={{ x: 2000 }}
                                />
                            </Tabs.TabPane>
                        })
                    }
                </Tabs>
                <Modal
                    visible={pupshow}
                    title='平台信息'
                    onOk={PuphandleOk}
                    onCancel={() => { setPupShow(false) }}
                >
                    {(!activeKey.includes('掌中云常用链接_-1')) && <><div className={style.from}>
                        <span>账号：</span>
                        <Input
                            placeholder='平台账号'
                            style={{ width: 300 }}
                            allowClear
                            onChange={(event: React.ChangeEvent<HTMLInputElement>) => { setUser(event.target.value) }}
                        />
                    </div>
                        <div className={style.from}>
                            <span>密码：</span>
                            <Input
                                placeholder='平台密码'
                                style={{ width: 300 }}
                                allowClear
                                onChange={(event: React.ChangeEvent<HTMLInputElement>) => { setPassword(event.target.value) }}
                            />
                        </div>
                        <div className={style.from}>
                            <div >
                                <span>VIP：</span>
                                <Radio.Group onChange={(e) => { setVip(e.target.value) }} value={vip}>
                                    <Radio value={1}>是</Radio>
                                    <Radio value={0}>否</Radio>
                                </Radio.Group>
                            </div>
                        </div></>}
                    {
                        platformName === '文鼎' && <>
                            {
                                Math.abs(Number(activeKey.split('_')[1])) === 2 && <>
                                    <div className={style.from}>
                                        <span>链接名称：</span>
                                        <Input
                                            placeholder='链接名称'
                                            style={{ width: 300 }}
                                            allowClear
                                            value={activityTitle}
                                            onChange={(event: React.ChangeEvent<HTMLInputElement>) => { setActivity_title(event.target.value) }}
                                        />
                                    </div>
                                    <div className={style.from}>
                                        <span>活动名称：</span>
                                        <Input
                                            placeholder='请填写平台存在的活动名称，名称一致'
                                            style={{ width: 300 }}
                                            allowClear
                                            value={activityName}
                                            onChange={(event: React.ChangeEvent<HTMLInputElement>) => { setActivity_name(event.target.value) }}
                                        />
                                    </div>
                                    <div className={style.from}>
                                        <span>链接类型：</span>
                                        <Select style={{ width: 300 }} value={spreadType} onChange={(value: string) => { setSpread_type(value) }}>
                                            <Select.Option value={'外推'}>外推</Select.Option>
                                            <Select.Option value={'内推'}>内推</Select.Option>
                                        </Select>
                                    </div>
                                </>
                            }
                            {
                                Math.abs(Number(activeKey.split('_')[1])) === 1 && <>
                                    <div className={style.from}>
                                        <span>链接名称：</span>
                                        <Select style={{ width: 300 }} value={activityName} onChange={(value: string) => { setActivity_name(value) }}>
                                            {
                                                linkArr?.map((name: string) => {
                                                    return <Select.Option value={name} key={name}>{name}</Select.Option>
                                                })
                                            }
                                        </Select>
                                    </div>
                                    <div className={style.from}>
                                        <span>活动名称：</span>
                                        <Input
                                            placeholder='活动名称'
                                            style={{ width: 300 }}
                                            allowClear
                                            value={activityTitle}
                                            onChange={(event: React.ChangeEvent<HTMLInputElement>) => { setActivity_title(event.target.value) }}
                                        />
                                    </div>
                                    <div className={style.from}>
                                        <span>链接类型：</span>
                                        <Select style={{ width: 300 }} value={spreadType} onChange={(value: string) => { setSpread_type(value) }}>
                                            <Select.Option value={'外推'}>外推</Select.Option>
                                            <Select.Option value={'内推'}>内推</Select.Option>
                                        </Select>
                                    </div>
                                </>
                            }
                        </>
                    }
                    {
                        (platformName === '掌中云' && activeKey.includes('掌中云常用链接_-1')) && <>
                            <div className={style.from}>
                                <span>apiKey：</span>
                                <Input
                                    placeholder='apiKey'
                                    style={{ width: 300 }}
                                    allowClear
                                    onChange={(event: React.ChangeEvent<HTMLInputElement>) => { setApiKey(event.target.value) }}
                                />
                            </div>
                            <div className={style.from}>
                                <span>apiSecret：</span>
                                <Input
                                    placeholder='apiSecret'
                                    style={{ width: 300 }}
                                    allowClear
                                    onChange={(event: React.ChangeEvent<HTMLInputElement>) => { setApiSecret(event.target.value) }}
                                />
                            </div>
                            <div className={style.from}>
                                <span>入口：</span>
                                <Select style={{ width: 300 }} value={pageTypeId} onChange={(value: any) => { setPageTypeId(value) }}>
                                    {
                                        pageTypeIds?.map((name: string, index: number) => {
                                            if (index !== 0) {
                                                return <Select.Option value={index}>{name}</Select.Option>
                                            }
                                            return null
                                        })
                                    }
                                </Select>
                            </div>
                            <div className={style.from}>
                                <span>链接类型：</span>
                                <Select style={{ width: 300 }} value={spreadType} onChange={(value: string) => { setSpread_type(value) }}>
                                    <Select.Option value={'外推'}>外推</Select.Option>
                                    <Select.Option value={'内推'}>内推</Select.Option>
                                </Select>
                            </div>
                            <div className={style.from}>
                                <span>备注：</span>
                                <Input.TextArea
                                    placeholder='备注'
                                    allowClear
                                    onChange={(e: React.ChangeEvent<HTMLTextAreaElement>) => { setRemark(e.target.value) }}
                                />
                            </div>
                            <div className={style.from}>
                                <div >
                                    <span>VIP：</span>
                                    <Radio.Group onChange={(e) => { setVip(e.target.value) }} value={vip}>
                                        <Radio value={1}>是</Radio>
                                        <Radio value={0}>否</Radio>
                                    </Radio.Group>
                                </div>
                            </div>

                        </>
                    }
                </Modal>
            </Card>
        </GroupWxTabs>
    </div >
}
export default Links