import React from "react"
import { Row, Col, Popconfirm, Badge, Select } from "antd"
import { DeleteOutlined, FormOutlined } from "@ant-design/icons"
let columns = (edit: (value: any) => void, del: (id: number) => void, showDrawer: (bookId: number) => void, access: any, setData: (bookId: number, value: any, type: '1' | "2") => void, bookify: any[]) => [
    {
        title: '书名',
        dataIndex: 'bookName',
        key: 'bookName',
        align: 'center',
        render: (a: any, b: any) => {
            return <span style={{ fontSize: "12px" }}>{a}</span>
        }
    },
    {
        title: '作者',
        dataIndex: 'author',
        key: 'author',
        align: 'center',
        render: (a: any, b: any) => {
            return <span style={{ fontSize: "12px" }}>{a || "<空>"}</span>
        }
    },
    {
        title: '主角',
        dataIndex: 'protagonist',
        key: 'protagonist',
        align: 'center',
        render: (a: any, b: any) => {
            return <span style={{ fontSize: "12px" }}>{a}</span>
        }
    },
    {
        title: '平台',
        dataIndex: 'platformInfo',
        key: 'platformInfo',
        align: 'center',
        render: (a: any, b: any) => {
            return <>
                {
                    a?.platformName && <span style={{ fontSize: "12px" }}>{a.platformName}</span>
                }
            </>
        }
    },


    {
        title: '频道',
        dataIndex: 'channel',
        key: 'channel',
        align: 'center',
        render: (a: any, b: any) => {
            return <Select value={a} style={{ width: 90 }} onChange={(e) => { setData(b?.id, e ? e : null, '1') }} size="small" allowClear placeholder="选择频道">
                <Select.Option value="男频">男频</Select.Option>
                <Select.Option value="女频">女频</Select.Option>
                <Select.Option value="男女通投">男女通投</Select.Option>
            </Select>
        }
    },
    {
        title: '分类',
        dataIndex: 'bookTypeInfo',
        key: 'bookTypeInfo',
        align: 'center',
        render: (a: any, b: any) => {
            return <Select value={a?.id} style={{ width: 100 }} onChange={(e) => { setData(b?.id, e ? e : null, '2') }} size="small" allowClear placeholder="选择分类">
                {bookify?.map((item: any) => <Select.Option value={item?.id} key={item?.id}>{item?.text}</Select.Option>)}
            </Select>
        }
    },
    {
        title: '来源',
        dataIndex: 'source',
        key: 'source',
        align: 'center',
        render: (a: any, b: any) => {
            return <span style={{ fontSize: "12px" }}>{a}</span>
        }
    },
    {
        title: '字数(万字)',
        dataIndex: 'wordCount',
        key: 'wordCount',
        align: 'center',
        render: (a: any, b: any) => {
            return <>
                {
                    a && <span style={{ fontSize: "12px" }}>{a}万字</span>
                }
            </>
        }
    },
    {
        title: '当前卡点(首日ROI)',
        dataIndex: 'ratios',
        key: 'ratios',
        align: 'center',
        width: 150,
        render: (a: any, b: any) => {
            return <>
                {
                    a?.length > 0 && <span style={{ fontSize: "12px" }}>{Number(a[0].nodePrice) + "%"}</span>
                }
            </>
        }
    },
    {
        title: '当前倍率',
        dataIndex: 'ratios',
        key: 'ratios',
        align: 'center',
        render: (a: any, b: any) => {
            return <>
                {
                    a?.length > 0 && <span style={{ fontSize: "12px" }}>{a[0].ratio}</span>
                }
            </>
        }
    },
    {
        title: '当前投放渠道',
        dataIndex: 'ratios',
        key: 'ratios',
        align: 'center',
        render: (a: any, b: any) => {
            return <>
                {
                    a?.length > 0 && <span style={{ fontSize: "12px" }}>{a[0].type === 'corp' ? '企业微信' : a[0].type === 'BYTEDANCE' ? '快应用' : a[0].type}</span>
                }
            </>
        }
    },
    {
        title: '状态',
        dataIndex: 'status',
        key: 'status',
        align: 'center',
        render: (a: any, b: any) => {
            return <span style={{ fontSize: "12px" }}>
                {
                    a == '排期' ? <span><Badge color="pink" />排期</span> : a == '测书' ? <span><Badge status="processing" />测书</span> : a == '等数据' ? <span><Badge status="warning" />等数据</span> : a == '投手独家中' ? <span><Badge color="lime" />投手独家中</span> : a == '公司独家中' ? <span><Badge color="volcano" />公司独家中</span> : a == '弃书' ? <span><Badge status="error" />弃书</span> : <span><Badge status="success" />开放可投</span>
                }
            </span>
        }
    },
    {
        title: '备注',
        dataIndex: 'remark',
        key: 'remark',
        align: 'center',
        render: (a: any, b: any) => {
            return <span style={{ fontSize: "12px" }}>{a}</span>
        }
    },
    {
        title: '操作',
        dataIndex: 'cz',
        key: 'cz',
        align: 'center',
        width: 200,
        render: (a: string, b: any) => (
            <Row justify='center' gutter={[10, 0]}>
                {
                    access['书籍卡点'] && <Col><a onClick={() => showDrawer(b.id)} style={{ fontSize: "12px" }}><FormOutlined /> 书籍卡点</a></Col>
                }
                <Col><a onClick={() => edit(b)} style={{ fontSize: "12px" }}><FormOutlined /> 编辑</a></Col>
                {
                    access['删除书籍'] && <Col>
                        <Popconfirm
                            title={`是否要删除?`}
                            onConfirm={() => del(b.id)}
                            okText="是"
                            cancelText="否"
                        >
                            <a style={{ color: "red", fontSize: "12px" }}><DeleteOutlined /> 删除</a>
                        </Popconfirm>
                    </Col>
                }
            </Row>
        )
    }
]

export default columns