import React, { useCallback, useEffect, useState } from "react";
import { Modal, message, Space, Input, Select } from 'antd'
import { getPeriodListApi, PeriodList, getPeriodAll, editVipBookApi, delVipBookApi } from '@/services/operating/book'
import { useRequest } from "umi";
import columns from './periodsTableConfig'
import Tables from "@/components/Tables";
import HeaderForm from '@/components/Formitem'
import vipFormConfig from './vipFormConfig'

interface Props {
    data: any,
    show?: boolean,
    onClose?: () => void
}

function Periods(props: Props) {
    let { data, show = false, onClose } = props
    const getPeriodList = useRequest((params: any) => getPeriodListApi(params), { manual: true })//vip平台新增
    const getPeriodAllReq = useRequest(() => getPeriodAll(), { manual: true })//获取期数
    const editVipBook = useRequest((params: any) => editVipBookApi(params), { manual: true })//vip平台编辑
    const delVipBook = useRequest((platformId: number) => delVipBookApi(platformId), { manual: true })//vip平台删除

    const [paramsList, setParamsList] = useState<PeriodList>({ platformId: 0, pageNum: 1, pageSize: 20 }) // 列表参数
    const [title, setTitle] = useState<string>("") // 弹窗名称
    const [viptitle, setVipTitle] = useState<string>('添加')//model标题
    const [vipVisible, setVipVisible] = useState(false)//弹窗
    const [sectData, setSectData] = useState<any[]>([])
    const [defaultVipProps, setDefaultVipProps] = useState<{
        platformId: string,
        periodId: string,
        account: string,
        password: string,
        principalName: string,
        bankName: string,
        bankAccount: string,
        link: string,
        formulaDivided: string,
        remark: string,
        accountId: string
    } | {}>({})//vip默认值
    const [vipSubmit, setVipSubmit] = useState<() => Promise<any>>()//存放vipformsubmit
    const [btnVipLoding, setBtnVipLoding] = useState<boolean>(false)//vip按钮loding
    const vipCallack = useCallback((fnc: () => Promise<any>) => { setVipSubmit(fnc) }, [])//vipform回调映射submit

    useEffect(() => {
        setParamsList({ ...paramsList, platformId: data?.id })
        setTitle(data.platformName)
        getPeriodAllReq.run().then(res => {
            let da = res?.map((item: any) => {
                item.text = item.period
                item.value = item.id + ""
                return item
            })
            setSectData(da)
        })
    }, [data])

    // 获取数据
    useEffect(() => {
        if (paramsList?.platformId !== 0) {
            getPeriodList.run(paramsList)
        }
    }, [paramsList])

    /**分页 */
    let pageChange = useCallback((page: string | number, pageSize?: string | number) => {
        setParamsList({ ...paramsList, pageNum: page as number, pageSize: pageSize as number })
    }, [paramsList])

    /**vip隐藏 */
    let hideVipModal = useCallback(() => {
        setDefaultVipProps({})//清空默认值
        setVipTitle('')
        setVipVisible(false)//关闭弹窗
    }, [])

    /** vip弹窗确定 */
    let handleVipOk = useCallback(() => {
        (vipSubmit as () => Promise<any>)().then(res => {
            if (res) {
                setBtnVipLoding(true);
                let accountId = (defaultVipProps as {
                    platformId: string,
                    periodId: string,
                    account: string,
                    password: string,
                    principalName: string,
                    bankName: string,
                    bankAccount: string,
                    link: string,
                    formulaDivided: string,
                    remark: string,
                    accountId: string
                }).accountId
                if (accountId) {
                    res.platformId = data?.id
                    editVipBook.run({ ...res, accountId: accountId }).then(r => {
                        setBtnVipLoding(false)
                        getPeriodList.refresh()
                        hideVipModal()
                        message.success('编辑成功', 2)
                    })
                }
            }

        })
    }, [vipSubmit, data, btnVipLoding, getPeriodList])
    /** vip编辑 */
    let vipEdit = useCallback((props: any) => {
        let { id } = props
        setDefaultVipProps({ ...props, accountId: id })
        setVipTitle('编辑')
        setVipVisible(true)
    }, [])
    /** vip删除 */
    let vipDel = useCallback((id: number) => {
        delVipBook.run(id).then(res => {
            getPeriodList.refresh()
            message.success('删除成功', 2)
        })
    }, [getPeriodList])
    return <>
        <Modal
            title={title}
            visible={show}
            okText={<></>}
            cancelText="取消"
            onCancel={() => { onClose && onClose() }}
            destroyOnClose={true}
            width={1214}
        >
            <Space wrap style={{ marginBottom: 10 }}>
                <Input.Search allowClear placeholder="请输入账号搜索" onSearch={(e) => { setParamsList({ ...paramsList, account: e }) }} style={{ width: 180 }} />
                <Input.Search allowClear placeholder="请输入开户名搜索" onSearch={(e) => { setParamsList({ ...paramsList, principalName: e }) }} style={{ width: 180 }} />
                <Select allowClear style={{ width: 180 }} showSearch filterOption={(input, option: any) =>
                    option.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
                } onChange={(e: number) => { setParamsList({ ...paramsList, periodId: e }) }} placeholder="请选择期数">
                    {sectData?.map((item: { text: string, value: string }) => <Select.Option key={item.value} value={item.value}>{item.text}</Select.Option>)}
                </Select>
                <Select allowClear style={{ width: 120 }} onChange={(e: number) => { setParamsList({ ...paramsList, status: e }) }} placeholder="状态">
                    <Select.Option value={0}>信息待完善</Select.Option>
                    <Select.Option value={1}>拉取中</Select.Option>
                </Select>
            </Space>
            <Tables
                columns={columns(vipEdit, vipDel)}
                bordered
                dataSource={getPeriodList?.data?.records}
                className="components-table-demo-nested"
                size="small"
                pagination={false}
                loading={getPeriodList?.loading}
                total={getPeriodList?.data?.total}
                pageChange={pageChange}
                sizeChange={pageChange}
                scroll={{ x: 1150, y: 500 }}
            />
        </Modal>

        <Modal
            title={`${viptitle}VIP平台`}
            visible={vipVisible}
            okText="确认"
            cancelText="取消"
            onCancel={hideVipModal}
            onOk={handleVipOk}
            confirmLoading={btnVipLoding}
            destroyOnClose={true}
            width={640}
        >
            <HeaderForm formConfig={vipFormConfig(sectData)} flow='row' getFormSubmit={vipCallack} defaultProps={defaultVipProps} labelCol={{ span: 24 }} ew />
        </Modal>
    </>
}

export default React.memo(Periods)