import React, { useCallback, useEffect, useState } from 'react'
import Tables from '@/components/Tables'
import HeaderForm from '@/components/Formitem'
import { Card, Modal, message } from 'antd'
import columns from './tableConfig'
import config from './headerConfig'
import formConfig from './formConfig'
import { addBooktype, deleteBooktype, editBooktype, getBooktypeList } from '@/services/operating/book'
import { useAjax } from '@/Hook/useAjax'

/**
 * 分类管理
 */
const BookIfy: React.FC = () => {
    const [visible, setVisible] = useState(false)//弹窗
    const [title, setTitle] = useState<string>('')//model标题
    const [defaultProps, setDefaultProps] = useState< {id: number, name: string} | {}>({})//默认值
    const [submit, setSubmit] = useState<() => Promise<any>>()//存放formsubmit
    const callack = useCallback((fnc: () => Promise<any>) => { setSubmit(fnc) }, [])//form回调映射submit
    const [btnLoding, setBtnLoding] = useState<boolean>(false)//按钮loding
    const addType = useAjax((params: {name: string}) => addBooktype(params))//添加请求
    const delData = useAjax((id: number) => deleteBooktype(id))//删除请求
    const editData = useAjax((params: {id: number, name: string}) => editBooktype(params))//编辑请求
    const getBookify = useAjax(() => getBooktypeList())//搜索列表

    /**显示 */
    let showModal = useCallback(() => {
        setTitle('添加')//设置标题
        setVisible(true)//开启弹窗
    }, [])
    /**隐藏 */
    let hideModal = useCallback(() => {
        setDefaultProps({})//清空默认值
        setTitle('')//清空标题
        setVisible(false)//关闭弹窗
    }, [])
    
    /**新增请求 */
    let handleOk = useCallback(() => {
        (submit as () => Promise<any>)().then(res => {
            if (res) {
                setBtnLoding(true);
                let id = (defaultProps as {id: number, name: string}).id
                if (id) {
                    editData.run({...res, id}).then(r => {
                        setBtnLoding(false)
                        getBookify.run()
                        hideModal()
                        message.success('编辑成功', 2)
                    })
                } else {
                    addType.run(res).then(res => {
                        setBtnLoding(false)
                        getBookify.run()
                        hideModal()
                        message.success('添加成功', 2)
                    })
                }
            }

        })
    }, [submit, btnLoding])
    
    
    /**编辑 */
    let edit = useCallback((props: { id: number, name: string }) => {
        setDefaultProps(props)
        setTitle('编辑')
        setVisible(true)
    }, [])
    
    /**删除 */
    let del = useCallback((id: number) => {
        delData.run(id).then(res => {
            if(res){
                getBookify.run()
                message.success('删除成功', 2)
            }
        })
    }, [])
    
    useEffect(() => {
        getBookify.run()
    }, [])
    return <Card>
        <HeaderForm formConfig={config(showModal)} flow='row' />
        <Tables
            columns={columns(edit, del)}
            dataSource={getBookify?.data}
            pagination={false}
            size="small"
            loading={getBookify?.loading}
        />
        <Modal
            title={`${title}分类`}
            visible={visible}
            okText="确认"
            cancelText="取消"
            onCancel={hideModal}
            onOk={handleOk}
            confirmLoading={btnLoding}
            destroyOnClose={true}
            width={450}
        >
            <HeaderForm formConfig={formConfig()} flow='row' getFormSubmit={callack} defaultProps={defaultProps} labelCol={{span:24}} ew/>
        </Modal>

    </Card>
}

export default BookIfy