import { Button, message, Modal, Select, Space, Tag } from 'antd'
import { SizeType } from 'antd/lib/config-provider/SizeContext'
import React, { useCallback, useEffect, useMemo, useState } from 'react'
import { useModel } from 'umi'
import style from './index.less'
type Props = {
    type: 'Advanced' | 'Aservice' | 'Atemplate' | 'Interact', //Advanced=群发，Aservice=客服，Atemplate=模板，Interact=立即/延迟
    isExamine?: boolean,//是否是审查
    strategyId: any,//任务ID
    id: number | any[],//公众号ID
    size?: SizeType,
    wxs?: any[],//公众号列表
    buttonType?: "link" | "text" | "ghost" | "default" | "primary" | "dashed" | undefined,
    setYlVisible: (v: any) => void,
    ylVisible: boolean
}
function Page(props: Props) {
    let { id, type, strategyId, isExamine = false, wxs, setYlVisible, ylVisible } = props
    const [value, setValue] = useState<string>('')//微信号名称
    const { searchFans } = useModel('useOperating.useFans', model => ({ searchFans: model.searchFans }))
    const {
        lookAdvanced,//群发
        lookAservice,//客服
        lookAtemplate,//模板
        lookInteract,//立即/延迟
        state
    } = useModel('useOperating.useExamine')
    const actionWX = useModel('useOperating.useWxGroupList', model => model.state.actionWX)//普通预览默认选中ID使用
    const [names, setNames] = useState<{ id: number, nickname: string, headimgurl: string }[]>([])
    const [mpId, setMpId] = useState<number>(Number(isExamine ? id && Array.isArray(id) ? id[0] : id || state.mpId : actionWX.id))
    /**按不同模块返回对应模块的预览接口*/
    let ajax = useMemo(() => {
        switch (type) {
            case 'Advanced':
                return lookAdvanced
            case 'Aservice':
                return lookAservice
            case 'Atemplate':
                return lookAtemplate
            case 'Interact':
                return lookInteract
        }
    }, [type])
    /**存放昵称 */
    const PreviewChange = useCallback((value: string, option: any) => {
        setValue(value)
        if (value) {
            let arr = value.split('_')
            localStorage.setItem('fans', JSON.stringify({ id: arr[1], nickname: arr[0] }))
        }

    }, [])
    /**查询*/
    const onSearch = useCallback((val: string) => {
        if (val) {
            searchFans.run({ mpId, nickname: val })
        }
    }, [mpId])
    useEffect(() => {
        let data = searchFans.data
        if (data?.length > 0) {
            setNames(data?.map((item: any) => { return { id: item?.id, nickname: item?.nickname, headimgurl: item?.headimgurl } }))
            data.forEach((item: any) => {
                if (item.nickname === value?.split('_')[0]) {
                    setValue(item.nickname + '_' + item.id)
                }
            })
        }else{
            setNames([])
        }
    }, [searchFans.data])
    /**预览数据 */
    const handlePreview = useCallback(() => {
        if (!value) {
            message.error('请输入预览粉丝昵称')
            return
        }
        let fansId = value?.split('_')[1]
        ajax.run({ strategyId, fansId, mpId }).then(res => {
            if (res) {
                message.success('预览成功！')
                setYlVisible(false)
            }
        })
    }, [strategyId, ajax, value, mpId])
    /**清空昵称 */
    useEffect(() => {
        let fans = localStorage.getItem('fans') ? JSON.parse(localStorage.getItem('fans') as string) : ''
        if (fans && mpId) {
            searchFans.run({ mpId, nickname: fans?.nickname })
        }
    }, [mpId, ylVisible])
    console.log(wxs)
    return <>
        <Modal
            width={500}
            visible={ylVisible}
            title="发送手机预览"
            onCancel={() => setYlVisible(false)}
            okText='发送预览'
            destroyOnClose
            footer={<Space>
                <Button onClick={() => setYlVisible(false)}>取消</Button>
                <Button type='primary' onClick={handlePreview} loading={false}>发送预览</Button>
            </Space>}
        >
            {//type === 'Aservice' &&
                 <>
                    <Space style={{ flexFlow: 'row wrap' }}>
                        {
                            wxs?.map((i) => {
                                return <div key={i.id} className={i.id === mpId ? style.action : style.wx} onClick={() => {
                                    setMpId(Number(i.id))
                                }}>
                                    <img src={i.headImg} style={{ width: 20, marginRight: 5 }} />
                                    <span>{i.nickName}</span>
                                </div>
                            })
                        }
                    </Space>
                </>
            }
            <Select
                showSearch
                style={{ margin: '10px 0', width: '100%' }}
                placeholder="请输入微信号名称自动模糊搜索匹配"
                optionFilterProp="children"
                onChange={PreviewChange}
                onSearch={onSearch}
                allowClear={true}
            >
                {
                    names?.map((item: { id: number, nickname: string, headimgurl: string }) => {
                        return <Select.Option key={item.id} value={item.nickname + '_' + item.id}>
                            <img src={item?.headimgurl} alt="" style={{ width: 20 }} />&nbsp;{item?.nickname}
                        </Select.Option>
                    })
                }
            </Select>
            <Tag color='warning'>预览功能仅用于公众号查看文章效果，不适用于公众传播，预览链接会在短期内失效</Tag>
        </Modal>
    </>
}

export default Page