import { Button, Input, Modal, Space, message } from 'antd'
import React, { useCallback, useMemo, useState } from 'react'
import { useModel } from 'umi'
type Props = {
    type: 'Advanced' | 'Aservice' | 'Atemplate' | 'Interact', //Advanced=群发，Aservice=客服，Atemplate=模板，Interact=立即/延迟
    strategyId: any,//任务ID
    defaultValue?: { checkStatus: number, checkRemark: string }
}
function Review(props: Props) {
    const { type, strategyId, defaultValue } = props
    const {
        putReviewAdvanced,//群发
        advancedList,
        putReviewAservice,//客服
        aserviceList,
        putReviewAtemplate,//模板
        atemplateList,
        putReviewInteract,//立即/延迟
        interactList,
    } = useModel('useOperating.useExamine')
    const [state, setState] = useState({ checkStatus: defaultValue?.checkStatus || 100, checkRemark: defaultValue?.checkRemark || '', })
    const [visible, setVisible] = useState(false)
    /**按不同模块返回对应模块的审查接口*/
    let ajax = useMemo(() => {
        switch (type) {
            case 'Advanced':
                return putReviewAdvanced
            case 'Aservice':
                return putReviewAservice
            case 'Atemplate':
                return putReviewAtemplate
            case 'Interact':
                return putReviewInteract
        }
    }, [type])
    /**刷新对应列表*/ 
    let get = useMemo(()=>{
        switch (type) {
            case 'Advanced':
                return advancedList
            case 'Aservice':
                return aserviceList
            case 'Atemplate':
                return atemplateList
            case 'Interact':
                return interactList
        }
    },[type])
    /**显示隐藏审核弹窗*/
    const showChange = useCallback(() => {
        setVisible(!visible)
    }, [visible])
    /**发送审核*/
    const submit = useCallback((checkStatus: number) => {
        let param = {...state, checkStatus}
        if (param.checkStatus === -1 && !param.checkRemark) {
            message.warning('请填写描述！！')
            return
        }
        if (param.checkStatus === 100) {
            param = { ...param, checkRemark: '' }
        }
        ajax.run({ strategyId, ...param }).then(res => {
            if (res) {
                setVisible(false)
                get.refresh()
            }
        })
    }, [state, ajax, get,strategyId])
    /***/
    return <>
        {/* <Button onClick={() => { setVisible(true) }} size='small' loading={ajax?.loading}>审核</Button> */}
        
        <Space>
            <Button onClick={() => { submit(100) }} size='small' loading={ajax?.loading} type="primary">审核通过</Button>
            <Button onClick={() => { setVisible(true) }} size='small' loading={ajax?.loading} danger>审核失败</Button>
        </Space>
        <Modal
            visible={visible}
            onOk={()=>{submit(-1)}}
            onCancel={showChange}
            title={'审查'}
        >
            <div>
                <Space style={{ display: 'flex', alignItems: 'start' }}>
                    <label style={{ letterSpacing: 2 }}>审查描述:</label>
                    <Input.TextArea
                        style={{ width: 350 }}
                        onChange={(event: React.ChangeEvent<HTMLTextAreaElement>) => { setState({ ...state, checkRemark: event.target.value }) }}
                        value={state.checkRemark}
                    />
                </Space>
            </div>
        </Modal>
    </>
}
export default Review