import React, { useCallback, useEffect, useState } from 'react'
import { useVirtualList } from 'ahooks'
import { useModel } from 'umi'
import style from './index.less'
import { Button, Select, Space, Tooltip } from 'antd'
import { SwapOutlined } from '@ant-design/icons'
import { SelectValue } from 'antd/es/select'

interface Props {
    /**table内容区*/
    children?: JSX.Element,
    /**顶部搜索条件*/
    header?: JSX.Element,
    /**是否支持不选择公众号返回全部公众号数据 默认true 支持*/
    userAll?: boolean
}
function UesrList(props: Props) {
    let { userAll = true } = props
    const { dispatch, state } = useModel('useOperating.useExamine')
    const { userList } = state
    const [listShow, setListShow] = useState<boolean>(true)
    /**当前选中*/
    const [action, setAction] = useState<number>(userAll ? -1 : 0)
    /**虚拟列表*/
    let { list, containerProps, wrapperProps, scrollTo } = useVirtualList(userList as any[], {
        overscan: 10,
        itemHeight: 35,
    });
    /**左侧列表缩进事件*/
    const listChange = useCallback(() => {
        setListShow(!listShow)
    }, [listShow])
    /**选中公众号*/
    const actionChange = useCallback((mpId: any) => {
        dispatch({ type: 'set', params: { mpId } })
    }, [])
    /**初始选中公众号*/
    useEffect(() => {
        if (!userAll && Array.isArray(userList) && userList?.length > 0) {
            dispatch({ type: 'set', params: { mpId: userList[0].id } })
        }
    }, [userAll])
    console.log('userAll----->', userAll)
    return <div className={style.box}>
        {/* 顶部 */}
        <div className={style.top}>
            <div className={style.selectAll }>
            {/* <div className={userAll ? style.selectAll : style.select}> */}
                {
                    userAll ? <Tooltip title='显示全部公众号数据（数字代表全部的公众号个数）' ><Button onClick={() => {
                        setAction(-1)//设置选中关于css展示
                        actionChange('')//设置选中的公众号ID
                    }}>ALL<strong style={{color:'red'}}>({userList?.length})</strong></Button></Tooltip>: <Tooltip title='数字代表全部的公众号个数' ><Button><strong style={{color:'red'}}>({userList?.length})</strong></Button></Tooltip>
                }
                <Select
                    showSearch
                    placeholder="公众号筛选"
                    optionFilterProp="children"
                    onSelect={(v, o) => {
                        scrollTo(Number(v))//跳转到指定位置
                        setAction(Number(v))//设置选中关于css展示
                        actionChange(o?.id)//设置选中的公众号ID
                    }}
                    onChange={(value: SelectValue) => {
                        if (value === undefined) {
                            actionChange('')//清空
                            setAction(Number(-1))//清空选中
                        }
                    }}
                    value={action === -1 ? undefined : action}
                    allowClear={userAll}
                    style={{ width: '100%' }}
                    options={userList?.map((item, index) => ({
                        value: index,
                        label: <Space>
                            <img src={item?.headImg} style={{ width: 20 }} />
                            <span>{item?.nickName}</span>
                        </Space>,
                        id: item.id,
                        title: item?.nickName
                    }))}
                    filterOption={(input: string, option: any) => {
                        let str = JSON.stringify(option.title)
                        return str.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                    }
                />
                {/* 左侧列表展开开关 */}
                <Tooltip title='显示/隐藏公众号列表' ><Button onClick={listChange}><SwapOutlined /></Button></Tooltip>
            </div>
            {props?.header}
        </div>
        {/* 内容 */}
        <div className={style.content}>
            {/* 左侧列表 */}
            <div {...containerProps} style={{ overflow: 'auto' }} className={listShow ? style.list : style.listHide}>
                <div {...wrapperProps}>
                    {list?.map((ele) => (
                        <div
                            style={{
                                height: 35,
                                display: 'flex',
                                alignItems: 'center',
                                marginBottom: 0,
                                paddingLeft: 30,
                                cursor: 'pointer',
                            }}
                            onClick={() => {
                                setAction(ele.index)//设置选中关于css展示
                                actionChange(ele?.data?.id)//设置选中的公众号ID
                            }}
                            className={action == ele.index ? style.action : null}
                            key={ele.index}
                        >
                            <Space>
                                {ele?.data?.headImg && <img src={ele?.data?.headImg} />}
                                <span>{ele?.data?.nickName}</span>
                            </Space>
                        </div>
                    ))}
                </div>
            </div>
            {/* 右侧 */}
            <div className={style.table}>
                {props.children}
            </div>
        </div>
    </div>
}

export default UesrList