import { Drawer, Input, Select, Space } from "antd"
import { SelectValue } from "antd/es/select"
import React, { useCallback, useEffect, useReducer, useState } from "react"
import { useModel } from "umi"
import UesrList from "../components/userList"
import Tables from '@/components/Tables'
import { columns } from './tableConfig'
import WxDetailsBox from "@/components/WxDetailsBox"
import { expandedRowRender } from "./sonTableConfig"
import AddModal from "../../news/advanced/components/addModal"
const { Option } = Select
interface Params {
    checkStatus?: 0 | 100 | -1 | null | any,//审查状态
    executionStatus?: any,//执行状态
    name?: string,//任务名称
    pageSize?: number,//每页展示条数
    pageNum?: number//页数
}
type State = {
    visible: boolean,//弹窗开启与否
    defaultData: any,//编辑填数据
    theEditer: any,//当前查看数据栏
    del: boolean,//删除开启
    drawerVis: boolean,//日志弹窗
    logsData: any[],//日志数据
}
export type Action = {
    type: 'show' | 'setDefaultData' | 'theEditer' | 'del' | 'drawerVis' | 'logsData',
    params?: any
}
function reducer(state: State, action: Action) {
    let { type, params } = action
    let { defaultData } = state
    switch (type) {
        case 'show':
            return { ...state, visible: !state.visible }
        case 'setDefaultData':
            if (params?.defaultData) {
                return { ...state, defaultData: { ...defaultData, ...params.defaultData } }
            }
            return { ...state, defaultData: params.defaultData }
        case 'theEditer':
            return { ...state, theEditer: params.theEditer }
        case 'del':
            return { ...state, del: params.del }
        case 'drawerVis':
            return { ...state, drawerVis: params.drawerVis }
        case 'logsData':
            return { ...state, logsData: params.logsData }
        default:
            return state;
    }
}
function Page() {
    /**============================================================变量============================================================*/
    const [bState, dispatch] = useReducer(reducer, { visible: false, defaultData: null, theEditer: null, del: false, drawerVis: false, logsData: [] })
    const { logsData, drawerVis, visible, defaultData } = bState
    const [params, setParams] = useState<Params>({ checkStatus: 0, name: '', executionStatus: 0, pageSize: 20, pageNum: 1 })
    const { state, advancedList } = useModel('useOperating.useExamine')
    const { addDispath, show, catlog, getDetail } = useModel('useOperating.useNews', model => ({
        addDispath: model.dispatch,
        show: model.state.visible,
        catlog: model.catlog,
        getDetail: model.getDetail,
    }))
    const { getWXInfo } = useModel('useOperating.useMaterialContent', model => ({ getWXInfo: model.getWXInfo }))
    /**============================================================事件============================================================*/
    /**任务名称操作*/
    const taskChange = useCallback((event: React.ChangeEvent<HTMLInputElement>) => {
        let value = event.target.value
        setParams({ ...params, name: value })
    }, [params])
    /**审查状态操作*/
    const eStatusChange = useCallback((value: SelectValue) => {
        setParams({ ...params, checkStatus: value })
    }, [params])
    /**执行状态操作*/
    const pStatusChange = useCallback((value: SelectValue) => {
        setParams({ ...params, executionStatus: value })
    }, [params])
    /**搜索值改变重新请求列表*/
    useEffect(() => {
        advancedList.run({ ...params, mpId: state.mpId })
    }, [params, state.mpId])
    //高级群发分页
    const pageSize = useCallback((page: number, pageSize?: number) => {
        // setParams({ ...params, pageNum: page, pageSize })
        advancedList.run({ ...params, mpId: state.mpId, pageNum: page, pageSize })
    }, [params, state.mpId])
    // 执行日志打开
    const journalHandle = useCallback((strategyId: number) => {
        dispatch({ type: 'drawerVis', params: { drawerVis: true } })
        catlog.run(strategyId).then((data) => {
            dispatch({ type: 'logsData', params: { logsData: data } })
        })
    }, [])
    //编辑详情打开时查询详情信息插入数据
    const showModal = useCallback((data: any, type: number) => {
        getDetail.run(data.id).then((res) => {
            let { mediaInfo, msgType, mediaId, triggerType, weekDay } = res
            let newtriggerType = triggerType === 3 ? 4 : triggerType === 2 && weekDay ? 3 : triggerType
            if (data.msgType === 'text') {
                let theEdit = { textContent: mediaInfo?.textContent?.replace(/href/ig, '_href').split('<br/>'), msgType }
                dispatch({ type: 'setDefaultData', params: { defaultData: { ...res, theEdit, triggerType: newtriggerType } } })
                switch (type) {
                    case 1:
                        dispatch({ type: 'show' })
                        break;
                    default:
                        addDispath({ type: 'show' })
                        break;
                }
            } else {
                let { name, url, title, videoTitle, videoDescription } = mediaInfo
                let theEdit = {
                    url: url,
                    title: name || title,
                    msgType,
                    mediaId,
                    content: mediaInfo,//NEWS使用
                }
                if (msgType === 'mpvideo') {
                    theEdit['title'] = videoTitle
                    theEdit['videoTitle'] = videoTitle
                    theEdit['videoDescription'] = videoDescription
                }
                if (msgType === 'mpnews' || msgType === 'image') {
                    dispatch({ type: 'setDefaultData', params: { defaultData: { ...res, theEdit, triggerType: newtriggerType } } })
                    switch (type) {
                        case 1:
                            dispatch({ type: 'show' })
                            break;
                        default:
                            addDispath({ type: 'show' })
                            break;
                    }
                } else {
                    dispatch({ type: 'setDefaultData', params: { defaultData: { ...res, theEdit, triggerType: newtriggerType } } })
                    switch (type) {
                        case 1:
                            dispatch({ type: 'show' })
                            break;
                        default:
                            addDispath({ type: 'show' })
                            break;
                    }
                }
            }
        })
    }, [dispatch, addDispath])
     /**============================================================JSX============================================================*/
    return <UesrList
        //顶部搜索条件
        header={
            <Space>
                <Select onChange={eStatusChange} style={{ width: 180 }} value={params.checkStatus} placeholder='审查状态' allowClear>
                    <Select.Option value={0} >待审查</Select.Option>
                    <Select.Option value={100}>审查成功</Select.Option>
                    <Select.Option value={-1}>审查有问题</Select.Option>
                </Select>
                <Select onChange={pStatusChange} style={{ width: 180 }} value={params.executionStatus} placeholder='执行状态' allowClear >
                    <Option value={0}>创建未执行</Option>
                    <Option value={1}>执行中</Option>
                    <Option value={2}>已完成</Option>
                    <Option value={-1}>已停止</Option>
                </Select>
                <Input onChange={taskChange} style={{ width: 180 }} placeholder='任务名称搜索' allowClear />
            </Space>
        }
    >
        <div>
            {/* table */}
            <Tables
                dataSource={advancedList?.data?.records || []}
                columns={columns({ show: showModal, getWXInfo, journalHandle, })}
                total={advancedList?.data?.total}
                current={advancedList?.data?.current}
                pageChange={pageSize}
                sizeChange={pageSize}
                size={'small'}
            />
            {/* 详情 */}
            <Drawer
                title="内容详情"
                placement="right"
                width={400}
                closable={false}
                onClose={() => {
                    dispatch({ type: 'show' })
                    dispatch({ type: 'del', params: { del: false } })
                    dispatch({ type: 'setDefaultData', params: { defaultData: null } })
                }}
                visible={visible}
                destroyOnClose
            >
                <WxDetailsBox data={{ ...defaultData?.theEdit, mpStrategyDeletes: defaultData?.mpStrategyDeletes, id: defaultData?.id }} del={false} newsDispatch={dispatch} />
            </Drawer>
            {/* 执行日志 */}
            <Drawer
                title="执行日志"
                placement='top'
                onClose={() => dispatch({ type: 'drawerVis', params: { drawerVis: false } })}
                visible={drawerVis}
                height='450'
            >
                <Tables
                    dataSource={logsData}
                    columns={expandedRowRender()}
                    size='small'
                />
            </Drawer>
            {/* 编辑 */}
            {show && <AddModal defaultData={defaultData} AdvancedDispatch={dispatch} isReview={true} />}
        </div>
    </UesrList>
}
export default Page