import { Button, Drawer, Input, Row, Select, Space } from "antd"
import { SelectValue } from "antd/es/select"
import React, { useCallback, useEffect, useReducer, useState } from "react"
import { useModel } from "umi"
import UesrList from "../components/userList"
import Tables from '@/components/Tables'
import { columns } from './tableConfig'
import { daysColumns } from "./daysTableConfig"
import { SearchOutlined } from "@ant-design/icons"
import AddModal from "../../news/aservice/components/addModal"
const { Option } = Select
interface Params {
    checkStatus?: 0 | 100 | -1 | null | any,//审查状态
    status?: any,//执行状态
    taskName?: string,//任务名称
    pageSize?: number,//每页展示条数
    pageNum?: number//页数
}
type State = {
    defaultData: any,//编辑填数据
    theEditer: any,//当前查看数据栏
}
export type Action = {
    type: 'setDefaultData' | 'theEditer' | 'logsData',
    params?: any
}
function reducer(state: State, action: Action) {
    let { type, params } = action
    let { defaultData } = state
    switch (type) {
        case 'setDefaultData':
            if (params?.defaultData) {
                return { ...state, defaultData: { ...defaultData, ...params.defaultData } }
            }
            return { ...state, defaultData: params.defaultData }
        case 'theEditer':
            return { ...state, theEditer: params.theEditer }
        case 'logsData':
            return { ...state, logsData: params.logsData }
        default:
            return state;
    }
}
function Page() {
    /**============================================================变量============================================================*/
    const [bState, dispatch] = useReducer(reducer, { defaultData: null, theEditer: null})
    const { defaultData } = bState
    const [params, setParams] = useState<Params>({ checkStatus: 0, taskName: '', status: 1, pageSize: 20, pageNum: 1 })
    const [drawerVis, setDrawerVis] = useState<boolean>(false)
    const [daysId, setDaysId] = useState<number>(0)
    const [daysMps, setDaysMps] = useState<any[]>([])
    const [select, setSelect] = useState<string>()
    const { state, aserviceList } = useModel('useOperating.useExamine')
    const { addDispath, show, daysMsg, detailKefuMsgStrategy } = useModel('useOperating.useAservice', model => ({
        addDispath: model.dispatch,
        show: model.state.visible,
        daysMsg: model.daysKefuMsgStrategy,
        detailKefuMsgStrategy: model.detailKefuMsgStrategy,
    }))
    const { getWXInfo } = useModel('useOperating.useMaterialContent', model => ({ getWXInfo: model.getWXInfo }))
    const { filterWxs } = useModel('useOperating.useWxGroupList', model => ({ filterWxs: model.state.filterWxs }))
    const { userId } = useModel('useOperating.useUser', model => ({ userId: model.state.selectdUserId }))
    /**============================================================事件============================================================*/
    /**任务名称操作*/
    const taskChange = useCallback((event: React.ChangeEvent<HTMLInputElement>) => {
        let value = event.target.value
        setParams({ ...params, taskName: value })
    }, [params])
    /**审查状态操作*/
    const eStatusChange = useCallback((value: SelectValue) => {
        setParams({ ...params, checkStatus: value !== undefined ? Number(value) : '' })
    }, [params])
    /**执行状态操作*/
    const pStatusChange = useCallback((value: SelectValue) => {
        setParams({ ...params, status: value !== undefined ? Number(value) : '' })
    }, [params])
    /**搜索值改变重新请求列表*/
    useEffect(() => {
        aserviceList.run({ ...params, mpId: state.mpId })
    }, [params, state.mpId])
    //分页
    const pageSize = useCallback((page: number, pageSize?: number) => {
        // setParams({ ...params, pageNum: page, pageSize })
        aserviceList.run({ ...params, mpId: state.mpId, pageNum: page, pageSize })
    }, [params, state.mpId])
    //日志选择框
    const selectChange = useCallback((value: string, option: any) => {
        setSelect(value)
    }, [daysMps])
    //日志分页
    const daysPageSize = useCallback((page: number, pageSize?: number) => {
        daysMsg.run({ strategyId: daysId, pageNum: page, pageSize: pageSize, belongUserId: userId })
    }, [daysId, userId])
    // 日志查询指定公众号
    const searchJournal = useCallback(() => {
        let query: { strategyId: number, pageNum: number, pageSize: number, belongUserId: number, mpId?: string } = { strategyId: daysId, pageNum: 1, pageSize: 20, mpId: select, belongUserId: userId }
        if (!select) {
            query = { strategyId: daysId, pageNum: 1, pageSize: 20, belongUserId: userId }
        }
        daysMsg.run(query)
    }, [select, daysId, userId])
    // 执行日志打开
    const journalHandle = useCallback((strategyId: number, mpIds: number[]) => {
        let arr: any = []
        filterWxs.forEach((wx: any) => {
            if (mpIds.some((id) => id === wx.id)) {
                arr.push(wx)
            }
        })
        setDaysMps(arr)
        setDaysId(strategyId)
        setDrawerVis(true)
        daysMsg.run({ strategyId, pageNum: 1, pageSize: 20, belongUserId: userId })
    }, [userId])
    //编辑详情打开时查询详情信息插入数据
    //编辑详情打开时查询详情信息插入数据
    const showModal = useCallback((data: any, isCopy?: boolean) => {
        let { id, islook } = data
        detailKefuMsgStrategy.run({ strategyId: id, belongUserId: userId }).then((res: any) => {
            if (res) {
                let data = JSON.parse(JSON.stringify(res))
                let mpIds: any[] = filterWxs.filter((wx: { id: number }) => {
                    if (data.mpIds.some((id: number) => id === wx.id)) {
                        return wx
                    }
                    return null
                })
                if (data?.weekDay) {
                    data.triggerType = 3
                }
                data.mpIds = mpIds
                data.fans = data.fansAll ? 1 : 0
                let { msgContents } = data
                let newMsgContents = msgContents ? JSON.parse(JSON.stringify(msgContents)) : []
                data['msgContents'] = newMsgContents?.map((item: { textContent: any, msgType: string, newsList: any[], platformMediaInfo: any }) => {
                    if (item.msgType === 'news') {
                        let reg = new RegExp(' ', "g") // 
                        let newsList = item?.newsList?.map((nl: { newsTitle: string }) => {
                            return { ...nl, newsTitle: nl?.newsTitle.replace(reg, '&nbsp;') }
                        })
                        item['newsList'] = newsList
                    }
                    if (item.msgType === 'miniprogrampage') {
                        item['imageUrl'] = item?.platformMediaInfo?.url
                    }
                    return item
                })
                data['islook'] = !!islook
                addDispath({ type: 'initData', params: { ...data, id: isCopy ? 0 : data.id, visible: true } })
                dispatch({ type: 'setDefaultData', params: { defaultData: { ...data, id: isCopy ? 0 : data.id } } })
            }
        })
    }, [dispatch, addDispath, filterWxs, userId])

    /**============================================================JSX============================================================*/
    return <UesrList
        //顶部搜索条件
        header={
            <Space>
                <Select onChange={eStatusChange} style={{ width: 180 }} value={params.checkStatus} placeholder='审查状态' allowClear>
                    <Select.Option value={0} >待审查</Select.Option>
                    <Select.Option value={100}>审查成功</Select.Option>
                    <Select.Option value={-1}>审查有问题</Select.Option>
                </Select>
                <Select onChange={pStatusChange} style={{ width: 180 }} value={params.status} placeholder='执行状态' allowClear >
                    <Option value={0}>未执行</Option>
                    <Option value={1}>执行中</Option>
                    <Option value={2}>任务完成</Option>
                    <Option value={3}>任务终止</Option>
                </Select>
                <Input onChange={taskChange} style={{ width: 180 }} placeholder='任务名称搜索' allowClear />
            </Space>
        }
    >
        <div>
            {/* table */}
            <Tables
                dataSource={aserviceList?.data?.records || []}
                columns={columns({ show: showModal, getWXInfo, journalHandle, filterWxs })}
                total={aserviceList?.data?.total}
                current={aserviceList?.data?.current}
                pageChange={pageSize}
                sizeChange={pageSize}
                size={'small'}
            />
            {/* 执行日志 */}
            <Drawer
                title="执行日志"
                placement='top'
                onClose={() => setDrawerVis(false)}
                visible={drawerVis}
                height='450'
            >
                <Space direction="vertical">
                    <Row>
                        <Select style={{ width: '200px' }} value={select} onChange={selectChange} showArrow allowClear={true}>
                            {
                                daysMps.map((option: any) => {
                                    return <Option key={option.id} value={option.id}>{option?.nickName}</Option>
                                })
                            }
                        </Select>
                        <Button icon={<SearchOutlined />} onClick={searchJournal}>搜索</Button>
                    </Row>
                    {
                        <Tables
                            dataSource={daysMsg?.data?.records || []}
                            columns={daysColumns()} scroll={{ y: 180 }}
                            total={daysMsg?.data?.total}
                            current={daysMsg?.data?.current}
                            pageChange={daysPageSize}
                            sizeChange={daysPageSize}
                            loading={daysMsg?.loading}
                        />
                    }

                </Space>
            </Drawer>
            {/* 编辑 */}
            {show && <AddModal defaultData={defaultData} AdvancedDispatch={dispatch} isReview={true}/>}
        </div>
    </UesrList>
}
export default Page