import { Badge, Button, Space, Tag, Tooltip } from 'antd'
import React from 'react'
import { bgColor } from '@/utils/color'
import Review from '../components/review'
import Look from '../components/look'

let sex = ['未知', '男', '女']

type Props = {
    journalHandle: (id: number, mpIds: number[]) => void,
    filterWxs: any[],
    show: any,
    getWXInfo: any
}

export const columns = (props: Props) => {
    const { journalHandle, filterWxs, show, getWXInfo, } = props
    return [
        {
            title: '消息名称',
            dataIndex: 'taskName',
            key: 'taskName',
            align: 'center',
        },
        {
            title: '创建人',
            dataIndex: 'createUser',
            key: 'createUser',
            align: 'center',
            render: (a: any) => {
                return a.nickName
            }
        },
        {
            title: '公众号',
            dataIndex: 'mpInfoList',
            key: 'mpInfoList',
            align: 'center',
            render: (a: any[], b: { headImg: string }) => {
                return <div style={{ display: 'flex', flexFlow: 'column' }}>
                    {
                        a?.map((wx: { headImg: string, nickName: string, id: number }, index: number) => {
                            if (index < 5) {
                                return <span key={wx.id}><img src={wx?.headImg || localStorage.bookImg} style={{ width: 25, marginBottom: 8 }} /> <span style={{ marginLeft: 10 }}>{wx.nickName}</span></span>
                            }
                            return null
                        })
                    }
                    {
                        a.length > 5 && <span>...共{a.length}个公众号</span>
                    }
                </div>
            }
        },
        {
            title: '发送方式',
            dataIndex: 'triggerType',
            key: 'triggerType',
            align: 'center',
            render: (a: number, b: { time: string, sendTime: string, weekDay: number, fansFilterSex: number }) => {
                let type = ['立即发送', '特定时间']
                let weekType = ['', '周一', '周二', '周三', '周四', '周五', '周六', '周日']
                let msg = ''
                let sj = ''
                if (type[a]) {
                    msg = type[a]
                    if (a === 1) {
                        sj = b?.sendTime
                    }
                } else {
                    if (b?.weekDay) {
                        msg = '每周'
                        sj = weekType[b?.weekDay] + b?.time
                    } else {
                        msg = '每日'
                        sj = b?.time
                    }
                }

                return <div style={{ display: 'flex', flexFlow: 'column ' }}>
                    <span>{msg}</span>
                    {sj && <span>{sj}</span>}
                </div>

            }
        },
        {
            title: '发送对象',
            dataIndex: 'fansAll',
            key: 'fansAll',
            align: 'center',
            render: (a: string, b: { time: string, sendTime: string, weekDay: number, fansFilterSex: number, fansFilterTags: any[], fansFilterTagType: number }) => {
                if (a) {
                    return '全部粉丝'
                } else {
                    return <div style={{ display: 'flex', flexFlow: 'column ' }}>
                        <span>性别：{b?.fansFilterSex !== null ? sex[b?.fansFilterSex] : '全部'}</span>
                        {/* <span>类型：{fansTagType[b?.tagType]}</span> */}
                        <div>
                            {
                                b?.fansFilterTagType === 0 ? '类型：并集' : b?.fansFilterTagType === 1 ? '类型：交集' : b?.fansFilterTagType === 2 ? '类型：取反' : ''
                            }
                        </div>
                        {
                            b?.fansFilterTags?.length > 0 && <div>
                                标签：{
                                    b?.fansFilterTags?.map((item: any, index: number) => {
                                        return <Tag key={item.id} color={item?.id ? bgColor[item?.id] : ''} style={{ marginBottom: 8 }}>{item.name}</Tag>
                                    })
                                }
                            </div>
                        }


                    </div>

                }
            }
        },
        {
            title: '运行状态',
            dataIndex: 'executionStatus',
            key: 'executionStatus',
            align: 'center',
            render: (a: number, b: any) => {
                return <span>
                    {b.executionStatus === 0 ? <Badge status="error" text='执行失败请点击强制启动' /> : b.executionStatus === 1 ? <Badge status="processing" text='执行中' /> : b.executionStatus === 2 ? <Badge status="success" text='任务完成' /> : <Badge status="error" text='任务终止' />}
                </span>
            }
        },
        {
            title: '审核状态',
            dataIndex: 'checkStatus',
            key: 'checkStatus',
            align: 'center',
            render: (a: number, b: any) => {
                return <span>
                    {b.checkStatus === 0 ? <Badge status="warning" text='待审查' /> : b.checkStatus === 100 ? <Badge status="success" text='通过' /> : <Tooltip title={`未通过原因：${b?.checkRemark ? b?.checkRemark : ''}`}>
                        <Badge status="error" text="未通过" />
                    </Tooltip>}
                </span>
            }
        },
        {
            title: '操作',
            key: 'action',
            dataIndex: 'action',
            align: 'center',
            render: (a: any, data: any) => {
                return <div onClick={(e: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
                    e.preventDefault()
                    e.stopPropagation()
                }}>
                    <Space>
                        <Button onClick={() => {
                            journalHandle(data.id, data.mpIds)
                        }} size='small'>执行日志</Button>
                        {//只有在未发送是出现
                            < Button onClick={() => {
                                show(data)
                            }} size='small' loading={getWXInfo?.loading}>查看</Button>
                        }
                        {/* 预览 */}
                        <Look type='Aservice' strategyId={data.id} id={data.mpIds} isExamine={true} wxs={data.mpInfoList}/>
                        {/* 审查 */}
                        <Review type='Aservice' strategyId={data.id} defaultValue={{ checkStatus: data.checkStatus, checkRemark: data.checkRemark }} />
                    </Space>
                </div >
            }
        }
    ]
}