import { Drawer, Input, Select, Space } from "antd"
import { SelectValue } from "antd/es/select"
import React, { useCallback, useEffect, useState } from "react"
import { useModel } from "umi"
import UesrList from "../components/userList"
import Tables from '@/components/Tables'
import { columns } from './tableConfig'
import WxDetailsBox from "@/components/WxDetailsBox"
import { daysColumns } from "./sonTableConfig"
import AddModal from "../../news/atemplate/components/addModal"
const { Option } = Select
interface Params {
    checkStatus?: 0 | 1 | 2 | -1 | null | any,//审查状态
    executionStatus?: any,//执行状态
    taskName?: string,//任务名称
    pageSize?: number,//每页展示条数
    pageNum?: number//页数
}
function Page() {
    /**============================================================变量============================================================*/
    const [params, setParams] = useState<Params>({ checkStatus: 0, taskName: '', executionStatus: 1, pageSize: 20, pageNum: 1 })
    const { state, atemplateList } = useModel('useOperating.useExamine')
    const [daysMsg, setDaysMsg] = useState<any[]>([])  // 日志
    const [temVisible, setTemVisible] = useState<boolean>(false)   // 新增模板消息弹窗
    const [temData, setTemData] = useState<{ title: string, dataTem: string }>({ title: "", dataTem: "" }) // 保存查看数据
    const [addVisible, setAddVisible] = useState<boolean>(false)   // 详情弹窗控制
    const [detailsData, setDetailsData] = useState<any>({})  // 保存详情数据
    const [drawerVis, setDrawerVis] = useState<boolean>(false) // 执行日志弹窗控制
    const { getWXInfo } = useModel('useOperating.useMaterialContent', model => ({ getWXInfo: model.getWXInfo }))
    /**============================================================事件============================================================*/
    /**任务名称操作*/
    const taskChange = useCallback((event: React.ChangeEvent<HTMLInputElement>) => {
        let value = event.target.value
        setParams({ ...params, taskName: value })
    }, [params])
    /**审查状态操作*/
    const eStatusChange = useCallback((value: SelectValue) => {
        setParams({ ...params, checkStatus: value !== undefined ? Number(value) : '' })
    }, [params])
    /**执行状态操作*/
    const pStatusChange = useCallback((value: SelectValue) => {
        setParams({ ...params, executionStatus: value !== undefined ? Number(value) : '' })
    }, [params])
    /**搜索值改变重新请求列表*/
    useEffect(() => {
        atemplateList.run({ ...params, mpId: state.mpId })
    }, [params, state.mpId])
    //高级群发分页
    const pageSize = useCallback((page: number, pageSize?: number) => {
        // setParams({ ...params, pageNum: page, pageSize })
        atemplateList.run({ ...params, mpId: state.mpId, pageNum: page, pageSize })
    }, [params, state.mpId])
    // 执行日志打开
    const journalHandle = useCallback((value: any) => {
        setDrawerVis(true)
        setDaysMsg(value?.executionLogs)
    }, [daysMsg, drawerVis])
    //编辑详情打开时查询详情信息插入数据
    const seeHandle = useCallback((tem: string, contentFields: any[], title: string) => {
        let newDataTem: string = tem
        contentFields.forEach((item: any) => {
            let reg = new RegExp("{{" + item.field + ".DATA}}", "ig")
            if (item) {
                newDataTem = newDataTem.replace(reg, `<span style="color:${item?.color ? item?.color : '#000'}">${item.value}</span>`)
            }
        });
        setTemData({ title, dataTem: newDataTem })
        setTemVisible(true)
    }, [temData])
    /** 详情 */
    const show = useCallback((data: any) => {
        setDetailsData(data)
        setAddVisible(true)
    }, [addVisible, detailsData])
    /**============================================================JSX============================================================*/
    return <UesrList
        //顶部搜索条件
        header={
            <Space>
                <Select onChange={eStatusChange} style={{ width: 180 }} value={params.checkStatus} placeholder='审查状态' allowClear>
                    <Select.Option value={0} >待审查</Select.Option>
                    <Select.Option value={100}>审查成功</Select.Option>
                    <Select.Option value={-1}>审查有问题</Select.Option>
                </Select>
                <Select onChange={pStatusChange} style={{ width: 180 }} value={params.executionStatus} placeholder='执行状态' allowClear>
                    <Option value={0}>创建未执行</Option>
                    <Option value={1}>执行中</Option>
                    <Option value={2}>任务完成</Option>
                    <Option value={-1}>任务终止</Option>
                </Select>
                <Input onChange={taskChange} style={{ width: 180 }} placeholder='模板消息名称搜索' allowClear />
            </Space>
        }
    >
        <div>
            {/* table */}
            <Tables
                dataSource={atemplateList?.data?.records || []}
                columns={columns({ seeHandle, show, getWXInfo, journalHandle, })}
                total={atemplateList?.data?.total}
                current={atemplateList?.data?.current}
                pageChange={pageSize}
                sizeChange={pageSize}
                size={'small'}
            />

            <Drawer
                title="查看模板消息内容"
                placement='right'
                onClose={() => setTemVisible(false)}
                visible={temVisible}
                width='380'
            >
                <WxDetailsBox data={{ msgType: 'tem', data: temData }}></WxDetailsBox>
            </Drawer>

            {/* 执行日志 */}
            <Drawer
                title="执行日志"
                placement='top'
                onClose={() => { setDrawerVis(false) }}
                visible={drawerVis}
                height='450'
            >
                <Tables
                    dataSource={daysMsg}
                    columns={daysColumns()}
                    size='small'
                />
            </Drawer>
            {/* 编辑 */}
            {addVisible && <AddModal defaultData={detailsData} visible={addVisible} onHide={() => { setAddVisible(false); setDetailsData({}) }} isModify={false}></AddModal>}
        </div>
    </UesrList>
}
export default Page