import { Badge, Button, Space, Tag, Tooltip } from 'antd'
import React from 'react'

import { bgColor } from '@/utils/color'
import Review from '../components/review'
import Look from '../components/look'
type Props = {
    getWXInfo: any,
    show: (data: any) => void,
    seeHandle: (tem: string, contentFields: any[], title: string) => void,
    journalHandle: (value: any) => void,
}
let sex = ['未知', '男', '女']
export const columns = (props: Props) => {
    const { getWXInfo, seeHandle, show, journalHandle } = props

    return [
        {
            title: '模板消息名称',
            dataIndex: 'taskName',
            key: 'taskName',
            align: 'center',
            width: 200,
        },
        {
            title: '模板名称',
            dataIndex: 'templateMsgInfo',
            key: 'templateMsgInfo',
            align: 'center',
            width: 220,
            render: (a: any, b: any) => {
                return <span>{a?.title}</span>
            }
        },
        {
            title: '发送对象',
            dataIndex: 'fansAll',
            key: 'fansAll',
            align: 'center',
            width: 220,
            render: (a: string, b: { time: string, sendTime: string, weekDay: number, fansFilterSex: number, fansFilterTags: any[], fansFilterTagType: number }) => {
                if (a) {
                    return '全部粉丝'
                } else {
                    return <div style={{ display: 'flex', flexFlow: 'column ' }}>
                        <span>性别：{b?.fansFilterSex !== null ? sex[b?.fansFilterSex] : '全部'}</span>
                        {/* <span>类型：{fansTagType[b?.tagType]}</span> */}
                        <div>
                            {
                                b?.fansFilterTagType === 0 ? '类型：并集' : b?.fansFilterTagType === 1 ? '类型：交集' : b?.fansFilterTagType === 2 ? '类型：取反' : ''
                            }
                        </div>
                        {
                            b?.fansFilterTags?.length > 0 && <div>
                                标签：{
                                    b?.fansFilterTags?.map((item: any, index: number) => {
                                        return <Tag key={item.id} color={item?.id ? bgColor[item?.id] : ''} style={{ marginBottom: 8 }}>{item.name}</Tag>
                                    })
                                }
                            </div>
                        }


                    </div>

                }
            }
        },
        {
            title: '发送方式',
            dataIndex: 'triggerType',
            key: 'triggerType',
            align: 'center',
            width: 250,
            render: (a: number, b: any) => {
                let type = ['立即发送', '特定时间']
                let msg = ''
                let sj = ''
                let time = b?.resDelayHours || b?.resDelayMinutes || b?.resDelaySecond
                if (type[a]) {
                    msg = type[a]
                    if (a === 1) {
                        sj = b?.sendTime
                    }
                }

                return <div style={{ display: 'flex', flexFlow: 'column ' }}>
                    {
                        a === 3 ? <>
                            <span>关注延迟指定时间</span>
                            <span>{time ? `${b?.resDelayHours ? b?.resDelayHours + '小时' : ''} ${b?.resDelayMinutes ? b?.resDelayMinutes + '分' : ''}${b?.resDelaySecond}秒` : '立即发送'}</span>
                        </> : <>
                                <span>{msg}</span>
                                {sj && <span>{sj}</span>}
                            </>
                    }
                </div>

            }
        },
        {
            title: '运行状态',
            dataIndex: 'executionStatus',
            key: 'executionStatus',
            align: 'center',
            width: 100,
            render: (a: number, b: any) => {
                return <span>
                    {b.executionStatus === 0 ? <Badge status="warning" text='创建未执行' /> : b.executionStatus === 1 ? <Badge status="processing" text='执行中' /> : b.executionStatus === 2 ? <Badge status="success" text='任务完成' /> : <Badge status="error" text='任务终止' />}
                </span>
            }
        },
        {
            title: '启动状态',
            dataIndex: 'enabled',
            key: 'enabled',
            align: 'center',
            width: 100,
            render: (a: any, b: any) => {
                return <span>{a ? <Tag color="#87d068">启动</Tag> : <Tag color="#f50">暂停</Tag>}</span>
            }
        },
        {
            title: '审核状态',
            dataIndex: 'checkStatus',
            key: 'checkStatus',
            align: 'center',
            width: 120,
            render: (a: number, b: any) => {
                return <span>
                    {b.checkStatus === 0 ? <Badge status="warning" text='待审查' /> : b.checkStatus === 100 ? <Badge status="success" text='通过' /> : <Tooltip title={`未通过原因：${b?.checkRemark ? b?.checkRemark : ''}`}>
                        <Badge status="error" text="未通过" />
                    </Tooltip>}
                </span>
            }
        },
        {
            title: '操作',
            key: 'action',
            dataIndex: 'action',
            align: 'center',
            render: (a: any, data: any) => {
                return <div onClick={(e: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
                    e.preventDefault()
                    e.stopPropagation()
                }}>
                    <Space>
                        <Button onClick={() => {
                            journalHandle(data)
                        }} size='small'>执行日志</Button>
                        <Button onClick={() => {
                            seeHandle(data?.templateMsgInfo?.template?.content, data?.contentFields, data?.templateMsgInfo?.title)
                        }} size='small' loading={getWXInfo?.loading}>查看</Button>
                        < Button onClick={() => {
                            show(data)
                        }} size='small' loading={getWXInfo?.loading}>详情</Button>
                        {/* 预览 */}
                        <Look type='Atemplate' strategyId={data.id} id={data.mpId} isExamine={true} wxs={[data?.mpInfo]}/>
                        {/* 审查 */}
                        <Review type='Atemplate' strategyId={data.id} defaultValue={{ checkStatus: data.checkStatus, checkRemark: data.checkRemark }} />
                    </Space>
                </div >
            }
        }
    ]
}

