import { Select, Space } from "antd"
import { SelectValue } from "antd/es/select"
import React, { useCallback, useEffect, useState } from "react"
import { useModel } from "umi"
import UesrList from "../components/userList"
import Tables from '@/components/Tables'
import { columns } from './tableConfig'
import PushModal from "../../interact/components/pushModal"
const { Option } = Select
interface Params {
    checkStatus?: 0 | 1 | 2 | -1 | null | any,//审查状态
    eventType?: any,//执行状态
    pageSize?: number,//每页展示条数
    pageNum?: number//页数
}
function Page() {
    /**============================================================变量============================================================*/
    const [params, setParams] = useState<Params>({ checkStatus: 0, eventType: '', pageSize: 20, pageNum: 1 })
    const { state, interactList } = useModel('useOperating.useExamine')
    const { getWXInfo } = useModel('useOperating.useMaterialContent', model => ({ getWXInfo: model.getWXInfo }))
    const { searchDetail } = useModel('useOperating.useInteract')
    const { initData } = useModel('useOperating.useInteract')
    const [data, setData] = useState<any>(null)//footer编辑数据
    const [visible, setVisible] = useState<boolean>(false)
    /**============================================================事件============================================================*/
    /**审查状态操作*/
    const eStatusChange = useCallback((value: SelectValue) => {
        setParams({ ...params, checkStatus: value !== undefined ? Number(value) : '' })
    }, [params])
    /**执行状态操作*/
    const pStatusChange = useCallback((value: SelectValue) => {
        setParams({ ...params, eventType: value !== undefined ? Number(value) : '' })
    }, [params])
    /**搜索值改变重新请求列表*/
    useEffect(() => {
        interactList.run({ ...params, mpId: state.mpId })
    }, [params, state.mpId])
    //高级群发分页
    const pageSize = useCallback((page: number, pageSize?: number) => {
        // setParams({ ...params, pageNum: page, pageSize })
        interactList.run({ ...params, mpId: state.mpId, pageNum: page, pageSize })
    }, [params, state.mpId])
    /** 详情 */
    const show = useCallback((id: number) => {
        let web = { video: 3, news: 5, music: 2, image: 1, text: 4, miniprogrampage: 6, voice: 2 }
        searchDetail.run({ strategyId: id }).then(res => {
            let msgContents: any[] = []
            /**编辑将数据处理存入model */
            res?.msgContents?.forEach((item: any, index: number) => {
                if (item.webType === 4) {
                    msgContents.push({ ...item, textContent: item.textContent.replace(/href/ig, '_href').split('<br    />'), indexId: index + 1, webType: 4 })
                } else {
                    let reg = new RegExp(' ', "g")
                    let data = item?.newsList?.map((item: { newsTitle: string }) => {
                        return { ...item, newsTitle: item?.newsTitle.replace(reg, '&nbsp;') }
                    })
                    if (item.webType === 6) {
                        msgContents.push({ ...item, newsList: data, indexId: index + 1, webType: web[item.msgType], imageUrl: item?.platformMediaInfo?.url })
                    } else {
                        msgContents.push({ ...item, newsList: data, indexId: index + 1, webType: web[item.msgType] })
                    }
                }
            })
            let data = { ...res, msgContents }
            if (data?.id) {//假如存在证明编辑把数据存放给footer组件用
                setData(data)
                initData({ data: { ...data, delId: [] } })
            }
            if (visible) {
                initData({ data: { msgContents: [], textKey: '', resDelayTime: 0, strategyDesc: '', msgStrategy: 0, eventType: 0, delId: [], id: '' } })
                setData(null)
            }
            localStorage.setItem('collapsed', visible ? '0' : '1')
            setVisible(!visible)
        })
    }, [visible])
    /**============================================================JSX============================================================*/
    return <UesrList
        //顶部搜索条件
        header={
            <Space>
                <Select onChange={eStatusChange} style={{ width: 180 }} value={params.checkStatus} placeholder='审查状态' allowClear>
                    <Select.Option value={0} >待审查</Select.Option>
                    <Select.Option value={100}>审查成功</Select.Option>
                    <Select.Option value={-1}>审查有问题</Select.Option>
                </Select>
                <Select onChange={pStatusChange} style={{ width: 180 }} placeholder='执行状态' allowClear>
                    <Option value="0">关注公众号</Option>
                    <Option value="1">扫码</Option>
                    <Option value="10">消息回复</Option>
                    <Option value="11">关键字</Option>
                    <Option value="20">菜单点击</Option>
                </Select>
            </Space>
        }
    >
        <div>
            {/* table */}
            <Tables
                dataSource={interactList?.data?.records || []}
                columns={columns({ show, getWXInfo })}
                total={interactList?.data?.total}
                current={interactList?.data?.current}
                loading={interactList?.loading}
                pageChange={pageSize}
                sizeChange={pageSize}
                size={'small'}
            />
            {visible && <PushModal visible={visible} onClose={() => { setVisible(false); localStorage.setItem('collapsed', visible ? '0' : '1') }} data={data} type={1} isModify={false} />}
        </div>
    </UesrList>
}
export default Page