import { Badge, Button, Space, Switch, Tooltip } from 'antd'
import React from 'react'

import Review from '../components/review'
import Look from '../components/look'
type Props = {
    getWXInfo: any,
    show: (id: number) => void,
}
export const columns = (props: Props) => {
    const { getWXInfo, show } = props
    return [
        {
            title: '消息名称',
            align: 'center',
            dataIndex: 'strategyDesc',
            key: 'strategyDesc',
        },
        {
            title: '互动类型',
            align: 'center',
            dataIndex: 'eventType',
            key: 'eventType',
            render: (a: any, b: any) => {
                return <span>{b.eventType === 0 ? `关注回复` : b.eventType === 1 ? `扫码` : b.eventType === 10 ? `消息回复` : b.eventType === 20 ? `菜单点击` : `关键词`}</span>
            }
        },
        {
            title: '延迟时间',
            align: 'center',
            dataIndex: 'resDelayTime',
            key: 'resDelayTime',
            render: (a: any, b: any) => {
                let time = b?.resDelayHours || b?.resDelayMinutes || b?.resDelaySecond
                return <span>{time ? `${b?.resDelayHours ? b?.resDelayHours + '小时' : ''} ${b?.resDelayMinutes ? b?.resDelayMinutes + '分' : ''}${b?.resDelaySecond}秒` : '立即发送'}</span>
            }
        },
        {
            title: '关键词',
            align: 'center',
            dataIndex: 'textKey',
            key: 'textKey',
            render: (a: any, b: any) => {
                return <span>{b.textKey ? b.textKey : `--`}</span>
            }
        },
        {
            title: '状态',
            align: 'center',
            key: 'enabled',
            dataIndex: 'enabled',
            render: (a: any, b: any) => {
                return <Switch checkedChildren="开启" unCheckedChildren="关闭" disabled={true} checked={b?.enabled} />
            }
        },
        {
            title: '审核状态',
            dataIndex: 'checkStatus',
            key: 'checkStatus',
            align: 'center',
            render: (a: number, b: any) => {
                return <span>
                    {b.checkStatus === 0 ? <Badge status="warning" text='待审查' /> : b.checkStatus === 100 ? <Badge status="success" text='通过' /> : <Tooltip title={`未通过原因：${b?.checkRemark ? b?.checkRemark : ''}`}>
                        <Badge status="error" text="未通过" />
                    </Tooltip>}
                </span>
            }
        },
        {
            title: '操作',
            key: 'action',
            dataIndex: 'action',
            align: 'center',
            render: (a: any, data: any) => {
                return <div onClick={(e: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
                    e.preventDefault()
                    e.stopPropagation()
                }}>
                    <Space>
                        <Button onClick={() => {
                            show(data?.id)
                        }} size='small' loading={getWXInfo?.loading}>详情</Button>
                        {/* 预览 */}
                        <Look type='Interact' strategyId={data.id} id={data.mpId} isExamine={true} />
                        {/* 审查 */}
                        <Review type='Interact' strategyId={data.id} defaultValue={{ checkStatus: data.checkStatus, checkRemark: data.checkRemark }} />
                    </Space>
                </div >
            }
        }
    ]
}

