import Tables from '@/components/Tables'
import { Avatar, Button, Card, Col, DatePicker, Descriptions, Drawer, Input, message, Radio, Row, Select, Space, Tag, InputNumber, Checkbox, Switch } from 'antd'
import React, { useCallback, useEffect, useState } from 'react'
import columns from './tableConfig'
import orderColumns from './orderTableConfig'
import ActionModal from '@/components/ActionModal'
import style from './index.less'
import { request, useModel } from 'umi'
import { RadioChangeEvent } from 'antd/lib/radio'
import Modal from 'antd/lib/modal/Modal'
import { EditOutlined } from '@ant-design/icons'
import ModalTag from './modalTag'
import { bgColor } from '@/utils/color'
import TagSelect from '@/components/TagSelect'
import moment from 'moment'
import NoFoundPage from '@/pages/empty'
import { scene } from '@/utils/dictionary'
import HocError from '@/Hoc/HocError'
import UpImg from '@/components/UpImg'
const { RangePicker } = DatePicker;

type QuerysInit = {
    subscribeBeginTime: string | undefined,//关注起始时间
    subscribeEndTime: string | undefined,//关注截止时间
    rechargeCountMin: number | undefined,//最低充值次数
    rechargeCountMax: number | undefined,//最大充值次数
    rechargeTimeMin: number | undefined,//上次充值时间（最小 n天内）
    rechargeTimeMax: number | undefined,//上次充值时间（最大 n天内）
    rechargeMin: number | undefined,//最低充值金额
    rechargeMax: number | undefined,//最大充值金额
    activeTimeMin: number | undefined,//上次活跃时间距今小
    activeTimeMax: number | undefined,//上次活跃时间距今大
    osTypes: string[]
}
type PackageForm = {
    adAccountId: number,
    userPackageName: string,
    userPackageDescription: string,
    cooperated: boolean
}
let packageFormInit = {
    adAccountId: -1,
    userPackageName: '',
    userPackageDescription: '',
    cooperated: false
}
let querysInit = {
    subscribeBeginTime: undefined,//关注起始时间
    subscribeEndTime: undefined,//关注截止时间
    rechargeCountMin: undefined,//最低充值次数
    rechargeCountMax: undefined,//最大充值次数
    rechargeTimeMin: undefined,//上次充值时间（最小 n天内）
    rechargeTimeMax: undefined,//上次充值时间（最大 n天内）
    rechargeMin: undefined,//最低充值金额
    rechargeMax: undefined,//最大充值金额
    activeTimeMin: undefined,//上次活跃时间距今小
    activeTimeMax: undefined,//上次活跃时间距今大
    osTypes: []//系统
}


function List() {
    const { state, getDataList } = useModel('useOperating.useWxGroupList')
    const { fileUrl } = useModel('useOperating.useBdMedia')
    const { get, fansList, fansSyncAll, fansRemark, getFansStatOnline, getFansOrderList, syncAllBooks, is_boundAdAccount, create_adUserPackage } = useModel('useOperating.useFans',
        model => ({ get: model.get, fansList: model.fansList, fansSyncAll: model.fansSyncAll, fansRemark: model.fansRemark, getFansStatOnline: model.getFansStatOnline, getFansOrderList: model.getFansOrderList, syncAllBooks: model.syncAllBooks, create_adUserPackage: model.create_adUserPackage, is_boundAdAccount: model.is_boundAdAccount })
    )
    const [visible, setVisible] = useState<boolean>(false)//显示隐藏
    const [remark, setRemark] = useState<string>('')//备注
    const [sex, setSex] = useState<string>('all')//性别
    const [tags, setTags] = useState<number[]>([])//搜索标签列表
    const [tagType, setTagType] = useState<0 | 2 | 1>(0)//搜索标签类型
    const [selectedRowKeys, setSelectedRowKeys] = useState<any[]>([])//选中的tableRow
    const [detailShow, setDetailShow] = useState<boolean>(false)//显示详情弹窗
    const [detailData, setDetailData] = useState<any>(null)//详情数据
    const [editRemark, setEditRemark] = useState<boolean>(false)//详情编辑
    const [editName, setEditName] = useState<boolean>(false)//编辑名称
    const [remarkStr, setRemarkStr] = useState<string>('')//详情编辑INPUT输入
    const [nameStr, setNameStr] = useState<string>('')//详情编辑INPUT输入
    const [ref, setRef] = useState<any>(null)//input焦点获取
    const [fansId, setFansId] = useState<string>('')//备注
    const [isShow, setIsShow] = useState<boolean>(false) //tagModal弹窗
    const [isAll, setIsAll] = useState<boolean>(false) //是否全部打标签
    const [subscribe, setSubscribe] = useState<number>(1)
    const [fansStat, setFansStat] = useState<any[]>([])
    const [platformId, setPlatformId] = useState<number>()
    const [orderVisible, setOrderVisible] = useState<boolean>(false)  // 订单弹窗控制
    const [openId, setOpenId] = useState<string>('')//openID搜
    const [fileData, setFileData] = useState<any>(null)//图片信息
    const [querys, setQuerys] = useState<QuerysInit>(querysInit)//新增搜索条件
    const [packageForm, setPackageForm] = useState<PackageForm>(packageFormInit)
    const [packagePup, setPackagePup] = useState<boolean>(false)//创建人群包弹窗
    const [orderQuery, setOrderQuery] = useState<{ queryDate: string, platformId: number, mpId: string, openId: string, pageNum: number, pageSize: number, orderStatus?: 0 | 1 | 2 | -1 }>({ queryDate: moment().format("YYYY-MM"), platformId: 0, mpId: "", openId: '', pageNum: 1, pageSize: 20 })
    //性别
    const changeSex = useCallback((e: RadioChangeEvent) => {
        let value = e.target.value
        setSex(value)
    }, [])
    //公众号
    const openWx = useCallback(() => {
        setVisible(true)
    }, [])
    const hideWx = useCallback(() => {
        setVisible(false)
    }, [])
    const handelWx = useCallback(() => {
        openWx()
    }, [])
    //备注
    const handelremark = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let value = e.target.value
        setRemark(value)
    }, [])
    // openId
    const handelOpenId = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let value = e.target.value
        setOpenId(value)
    }, [])
    //标签
    const selectTags = useCallback((obj: { tagType: 0 | 2 | 1, tagIds: any[] }) => {
        setTags(obj.tagIds)
        setTagType(obj.tagType)
    }, [])

    //重置
    const initSelect = useCallback(() => {
        setRemark('')
        setSex('all')
        setTags([])
        setQuerys(querysInit)
    }, [])
    //搜索
    const selectSubmit = useCallback((id?: any) => {
        let mpId: string | number
        if (typeof id === 'number') {
            mpId = id
        } else {
            mpId = state.actionWX.id
        }
        let params = { sex: sex === 'all' ? '' : sex, nickname: remark, tagIds: tags, pageSize: 20, pageNum: 1, mpId: mpId, tagType, subscribe: subscribe == 2 ? '' : !!subscribe }
        fansList.run({ ...params, openId, ...querys })
    }, [remark, sex, tags, state.actionWX, tagType, subscribe, openId, querys])

    //公众号切换搜索
    useEffect(() => {
        setPlatformId(() => 0)
        if (state.actionWX) {
            fansList.run({ mpId: state.actionWX.id, pageSize: 20, pageNum: 1, subscribe: !!subscribe })
            getFansStatOnline.run(state.actionWX.id).then((res: any) => {
                let data: any[] = [
                    {
                        label: '粉丝所在书城',
                        value: null,
                        key: 'platformInfo'
                    },
                    {
                        label: '粉丝总数',
                        value: 0,
                        key: 'fansCount'
                    },
                    {
                        label: '今日关注粉丝数',
                        value: 0,
                        key: 'subFansCountToday'
                    },
                    {
                        label: '今日取关粉丝数',
                        value: 0,
                        key: 'unSubFansCountToday'
                    },
                    {
                        label: '总计充值次数',
                        value: 0,
                        key: 'rechargeTotal'
                    },
                    {
                        label: '充值成功次数总数',
                        value: 0,
                        key: 'rechargeSuccessTotal'
                    },
                    {
                        label: '总计充值金额',
                        value: 0,
                        key: 'rechargeMoneyTotal'
                    },
                    {
                        label: 'VIP粉丝总数',
                        value: 0,
                        key: 'vipFansCount'
                    },
                    {
                        label: '书币总计',
                        value: 0,
                        key: 'bookCoinRemainingTotal'
                    },
                    {
                        label: '安卓粉丝占比',
                        value: '0%',
                        key: 'androidFansRatio'
                    },
                    {
                        label: 'IOS粉丝占比',
                        value: '0%',
                        key: 'iosFansRatio'
                    }
                ]
                for (const key in res) {
                    if (Object.prototype.hasOwnProperty.call(res, key)) {
                        const element = res[key];
                        if (key === 'platformInfo') {
                            if (element) {
                                setPlatformId(() => element.id)
                            } else {
                                setPlatformId(() => 0)
                            }
                            data[0] = {
                                label: '粉丝所在书城',
                                value: element?.platformName,
                                key
                            }
                        } else if (key === 'fansCount') {
                            data[1] = {
                                label: '粉丝总数',
                                value: element || 0,
                                key
                            }
                        } else if (key === 'subFansCountToday') {
                            data[2] = {
                                label: '今日关注粉丝数',
                                value: element || 0,
                                key
                            }
                        } else if (key === 'unSubFansCountToday') {
                            data[3] = {
                                label: '今日取关粉丝数',
                                value: element || 0,
                                key
                            }
                        } else if (key === 'rechargeTotal') {
                            data[4] = {
                                label: '总计充值次数',
                                value: element || 0,
                                key
                            }
                        } else if (key === 'rechargeSuccessTotal') {
                            data[5] = {
                                label: '充值成功次数总数',
                                value: element || 0,
                                key
                            }
                        } else if (key === 'rechargeMoneyTotal') {
                            data[6] = {
                                label: '总计充值金额',
                                value: element ? element / 100 : 0,
                                key
                            }
                        } else if (key === 'vipFansCount') {
                            data[7] = {
                                label: 'VIP粉丝总数',
                                value: element || 0,
                                key
                            }
                        } else if (key === 'bookCoinRemainingTotal') {
                            data[8] = {
                                label: '书币总计',
                                value: element || 0,
                                key
                            }
                        }
                    }
                }
                data[9] = {
                    label: '安卓粉丝占比',
                    value: (res?.fansCount && res?.androidFansCount) ? (res?.androidFansCount / res?.fansCount * 100).toFixed(2) + '%' : '0%',
                    key: 'androidFansRatio'
                }
                data[10] = {
                    label: 'IOS粉丝占比',
                    value: (res?.fansCount && res?.iosFansCount) ? (res?.iosFansCount / res?.fansCount * 100).toFixed(2) + '%' : '0%',
                    key: 'iosFansRatio'
                }
                setFansStat(data)
            })
        }
    }, [state.actionWX])
    //首次默认选中公众号第一组第一个
    useEffect(() => {
        getDataList.refresh()
    }, [])
    //获取标签
    useEffect(() => {
        if (state.actionWX) {
            get.run({ mpId: state.actionWX.id })
        }
    }, [state.actionWX])
    //table多选
    const rowSelection = useCallback((key) => {
        setSelectedRowKeys(key)
    }, [])
    //行点击处理
    const rowClick = useCallback((item: { id: number, subscribe?: boolean }) => {
        let key = item.id
        if (!item.subscribe) {
            return
        }
        let keys: number[] = [...selectedRowKeys]
        if (keys.every((k: number) => k !== key)) {
            keys.push(key)
        } else {
            keys = keys.filter((k: number) => k !== key)
        }
        setSelectedRowKeys(keys)
    }, [selectedRowKeys])
    //详情
    const detail = useCallback((value: any) => {
        setNameStr(value?.nickname)
        setRemarkStr(value?.remark)
        setFileData({ file: null, fileUrl: value?.headimgurl })
        setDetailData(value)
        setFansId(value?.id)
        showDetail()
    }, [])
    //显示详情
    const showDetail = useCallback(() => {
        setDetailShow(true)
    }, [])
    //隐藏详情
    const hideDetail = useCallback(() => {
        setDetailShow(false)
        setDetailData(null)
    }, [])
    //修改备注刷新数据
    useEffect(() => {
        if (fansList?.data?.records && detailData) {
            fansList?.data?.records.forEach((item: any) => {
                if (item.id === detailData.id) {
                    setDetailData(item)
                }
            })
        }
    }, [fansList, detailData])
    //编辑备注
    const handeleditRemark = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let value = e.target.value
        setRemarkStr(value)
    }, [])
    const handeleditName = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let value = e.target.value
        setNameStr(value)
    }, [])
    const onBlur = useCallback(() => {
        setEditRemark(false)
        setEditName(false)
    }, [])
    const edit = useCallback(() => {
        if (remarkStr && nameStr) {
            let { file } = fileData
            if (file) {
                /**修改文件名以用户设置的文件title命名*/
                let formData = new FormData();
                /**向阿里云请求上传地址*/
                fileUrl.run({ type: file.type }).then((res1: { [x: string]: string | Blob; ossUrl?: any }) => {
                    Object.keys(res1).forEach((key: string) => {
                        if (key !== 'url') {
                            formData.append(key, res1[key])
                        }
                    })
                    formData.append('file', file)
                    /**向阿里云返回的上传地址上传文件*/
                    request(res1?.ossUrl, { method: 'post', body: formData }).then((res2: { code: number, data: { url: string } }) => {
                        if (res2.code === 200) {
                            message.success('上传成功')
                            if (res2) {
                                /**取到返回的文件地址向后端发送具体数据*/
                                if (res2?.data?.url) {
                                    fansRemark.run({ fansId, mpId: state.actionWX.id, remark: remarkStr, nickname: nameStr, headimgurl: res2?.data?.url }).then((res) => {
                                        if (res) {
                                            message.success('修改成功')
                                            fansList.refresh()
                                            setNameStr('')
                                            setRemarkStr('')
                                            setFileData(null)
                                            setDetailShow(false)
                                        }
                                    })
                                }
                            }
                        } else {
                            message.error('上传失败！')
                        }
                    })
                })
            } else {
                fansRemark.run({ fansId, mpId: state.actionWX.id, remark: remarkStr, nickname: nameStr }).then((res) => {
                    if (res) {
                        message.success('修改成功')
                        fansList.refresh()
                        setNameStr('')
                        setRemarkStr('')
                        setFileData(null)
                        setDetailShow(false)
                    }
                })
            }
        }
        if (!remarkStr) {
            message.error('修改时备注必填！')
        }
    }, [remarkStr, nameStr, fansId, state, fileData])
    //同步粉丝
    const sync = useCallback(() => {
        fansSyncAll.run({ mpId: state.actionWX.id }).then(() => {
            fansList.refresh()
        })
    }, [state.actionWX, fansList])
    // 同步书城信息
    const syncBooks = useCallback(() => {
        syncAllBooks.run({ mpId: state.actionWX.id, platformId }).then(() => {
            fansList.refresh()
        })
    }, [state.actionWX, fansList, platformId])
    //获取焦点
    useEffect(() => {
        if (ref) {
            ref.focus()
        }
    }, [ref])
    //打标签
    const onTag = useCallback(() => {
        if (selectedRowKeys.length === 0) {
            message.error('请先勾选选择粉丝')
            return
        }
        handelTagModal()
        setIsAll(false)
    }, [selectedRowKeys])
    //一键打标签
    const onTags = useCallback(() => {
        handelTagModal()
        setIsAll(true)
        if (fansList?.data?.records) {//筛选出所有粉丝id选中
            let tags: any[] = []
            fansList?.data?.records?.forEach((fans: { id: number, subscribe: boolean }) => {
                if (fans?.subscribe) {
                    tags.push(fans.id)
                }
            })
            setSelectedRowKeys(tags)
        }

    }, [fansList?.data?.records])
    //关闭标签弹窗
    const handelTagModal = useCallback(() => {
        setIsShow(!isShow)
    }, [isShow])
    //分页
    const pageSize = useCallback((page: number, pageSize?: number) => {
        fansList.run({ mpId: state.actionWX.id, pageSize: pageSize, pageNum: page, sex: sex === 'all' ? '' : sex, nickname: remark, tagIds: tags, tagType, subscribe: subscribe == 2 ? '' : !!subscribe })
    }, [state, remark, sex, tags, state.actionWX, tagType, subscribe])
    //分页
    const pageOrderSize = useCallback((page: number, pageSize?: number) => {
        setOrderQuery({ ...orderQuery, pageSize: pageSize as number, pageNum: page })
    }, [orderQuery])

    // 订单数据
    const orderHandle = useCallback((props: any) => {
        setOrderQuery({ ...orderQuery, openId: props?.openId, mpId: props?.mpId, platformId: props?.platformFansInfo?.platformId })
        setOrderVisible(true)
    }, [orderQuery, orderVisible])
    // 处理去除小数
    const formatter = useCallback((value) => {
        return value ? Math.floor(value).toString() : ''
    }, [])
    // 设置querys
    const changeQuerys = useCallback((value, event) => {
        if (event !== 'subscribeBeginTime' && event !== 'osTypes' && event !== 'rechargeMin' && event !== 'rechargeMax') {
            value = Number(formatter(value))
        }
        switch (event) {
            case 'subscribeBeginTime'://关注起始时间
                setQuerys({ ...querys, subscribeBeginTime: value[0], subscribeEndTime: value[1] })
                break;
            case 'rechargeCountMin'://最低充值次数
                setQuerys({ ...querys, rechargeCountMin: value === 0 ? null : value })
                // setQuerys({ ...querys, rechargeCountMin: value })
                break;
            case 'rechargeCountMax'://最大充值次数
                setQuerys({ ...querys, rechargeCountMax: value === 0 ? null : value })
                break;
            case 'rechargeTimeMin'://上次充值时间（最小 n天内）
                setQuerys({ ...querys, rechargeTimeMin: value === 0 ? null : value })
                break;
            case 'rechargeTimeMax'://上次充值时间（最大 n天内）
                setQuerys({ ...querys, rechargeTimeMax: value === 0 ? null : value })
                break;
            case 'rechargeMin'://最低充值金额
                setQuerys({ ...querys, rechargeMin: value === 0 ? null : value })
                break;
            case 'rechargeMax'://最大充值金额
                setQuerys({ ...querys, rechargeMax: value === 0 ? null : value })
                break;
            case 'activeTimeMin'://上次活跃时间距今小
                setQuerys({ ...querys, activeTimeMin: value === 0 ? null : value })
                break;
            case 'activeTimeMax'://上次活跃时间距今大
                setQuerys({ ...querys, activeTimeMax: value === 0 ? null : value })
                break;
            case 'osTypes':
                setQuerys({ ...querys, osTypes: value })
                break;
            default:
                break;
        }
    }, [querys])
    // 设置创建人群包参数
    const changgePackageForm = useCallback((value, event) => {
        switch (event) {
            case 'userPackageName':
                setPackageForm({ ...packageForm, userPackageName: value })
                break;
            case 'userPackageDescription':
                setPackageForm({ ...packageForm, userPackageDescription: value })
                break;
            case 'cooperated':
                setPackageForm({ ...packageForm, cooperated: value })
                break;
            default:
                break;
        }
    }, [packageForm])
    // 创建人群包验证
    const testPackage = useCallback(() => {
        is_boundAdAccount.run(state.actionWX.id).then(res => {
            if (res) {
                setPackagePup(true)
                setPackageForm({ ...packageForm, adAccountId: res })
            }
        })
    }, [state.actionWX, packageForm])
    // 创建人群包
    const creactPackage = useCallback(() => {
        let params = { sex: sex === 'all' ? '' : sex, nickname: remark, tagIds: tags, pageSize: 20, pageNum: 1, mpId: state.actionWX.id, tagType, subscribe: subscribe == 2 ? '' : !!subscribe }
        create_adUserPackage.run({ ...packageForm, mpId: state.actionWX.id, fansFilterDTO: { ...params, openId, ...querys } }).then((res) => {
            console.log(res)
            if (res) {
                setPackagePup(false)
                setPackageForm(packageFormInit)
            }
        })
    }, [remark, sex, tags, state.actionWX, tagType, subscribe, openId, querys, packageForm])
    useEffect(() => {
        if (orderQuery.platformId) {
            let props = { ...orderQuery }
            props.queryDate = props.queryDate + '-01'
            getFansOrderList.run(props)
        }
    }, [orderQuery])
    return <>
        {
            state?.actionWX && <>
                <Card title="粉丝统计信息" style={{ marginBottom: 10 }}>
                    <Row gutter={[16, 16]} className={style.box} >
                        {
                            fansStat.map((item: any) => {
                                return <Col key={item.key} className={style.box_col} flex={1}>
                                    <b>{item.label}</b>
                                    <strong>{item.value}</strong>
                                </Col>
                            })
                        }
                    </Row>
                </Card>
                <Drawer
                    title="订单数据"
                    placement='top'
                    closable={false}
                    onClose={() => { setOrderVisible(false) }}
                    visible={orderVisible}
                    height={600}
                >
                    <Space style={{ marginBottom: 10 }}>
                        <DatePicker onChange={(value: moment.Moment | null, dateString: string) => { setOrderQuery({ ...orderQuery, queryDate: moment(value).format("YYYY-MM") }) }} picker="month" value={moment(orderQuery.queryDate)} />
                        <Select value={orderQuery.orderStatus || undefined} style={{ width: 150 }} onChange={(e: 0 | 2 | 1 | -1 | undefined) => { setOrderQuery({ ...orderQuery, orderStatus: e }) }} placeholder="选择订单状态" allowClear>
                            <Select.Option value={0}>等待付款</Select.Option>
                            <Select.Option value={1}>支付失败</Select.Option>
                            <Select.Option value={2}>支付成功</Select.Option>
                            <Select.Option value={-1}>未知</Select.Option>
                        </Select>
                    </Space>
                    <Tables
                        columns={orderColumns()}
                        dataSource={getFansOrderList?.data?.records || []}
                        onRow={{ onClick: (item: { id: number }) => { rowClick(item) } }}
                        total={getFansOrderList?.data?.total}
                        current={getFansOrderList?.data?.current}
                        pageChange={pageOrderSize}
                        sizeChange={pageOrderSize}
                        scroll={{ x: 1000, y: 450 }}
                        size='small'
                    />
                </Drawer>
            </>
        }
        {
            state?.actionWX ? <div className={style.fans_list}>
                <Card
                    title='粉丝筛选'
                    headStyle={{ textAlign: 'center' }}
                    style={{ padding: 0 }}
                >
                    <div className={style.select_btn}>
                        <Button type='primary' onClick={selectSubmit}>搜索</Button>
                        <Button onClick={initSelect}>重置</Button>
                    </div>
                    <div className={style.fans_select}>
                        {/* 公众号 */}
                        <div >
                            <label>选择公众号：</label>
                            <div onClick={handelWx}>
                                <Avatar shape='square' src={state?.actionWX?.headImg || localStorage?.bookImg} className={style.img} />
                                <span>{state?.actionWX?.nickName}</span>
                            </div>
                            <ActionModal visible={visible} hideWx={hideWx} />
                        </div>
                        {/* 粉丝状态*/}
                        <div>
                            <label>粉丝状态：</label>
                            <Select value={subscribe} onChange={(v: number) => {
                                setSubscribe(v)
                            }}>
                                <Select.Option value={1}>已关注</Select.Option>
                                <Select.Option value={0}>未关注</Select.Option>
                                <Select.Option value={2}>全部</Select.Option>
                            </Select>
                        </div>
                        {/* 关注时间*/}
                        <div>
                            <label>关注时间：</label>
                            <RangePicker
                                value={[querys.subscribeBeginTime ? moment(querys.subscribeBeginTime) : null, querys.subscribeEndTime ? moment(querys.subscribeEndTime) : null]}
                                className={style.rangepicker}
                                onChange={(mom, value) => { changeQuerys(value, 'subscribeBeginTime') }}
                            />
                        </div>
                        {/* 充值次数*/}
                        <div>
                            <label>充值次数：</label>
                            <div >
                                <InputNumber
                                    min={0}
                                    max={1000}
                                    value={querys.rechargeCountMin}
                                    onChange={(value) => { changeQuerys(value, 'rechargeCountMin') }}
                                    style={{ width: '45%' }}
                                    placeholder='最小次数'
                                    formatter={formatter}

                                />
                                ~
                                <InputNumber
                                    min={0}
                                    max={1000}
                                    value={querys.rechargeCountMax}
                                    onChange={(value) => { changeQuerys(value, 'rechargeCountMax') }}
                                    style={{ width: '45%'  }}
                                    placeholder='最大次数'
                                    formatter={formatter} />
                            </div>
                        </div>
                        {/*充值金额*/}
                        <div>
                            <label>充值金额：</label>
                            <div>
                                <InputNumber
                                    min={0}
                                    value={querys.rechargeMin}
                                    max={1000}
                                    onChange={(value) => { changeQuerys(value, 'rechargeMin') }}
                                    style={{ width: '45%' }}
                                    placeholder='最低充值金额'
                                />
                                ~
                                <InputNumber
                                    min={0}
                                    max={1000}
                                    value={querys.rechargeMax}
                                    onChange={(value) => { changeQuerys(value, 'rechargeMax') }}
                                    style={{ width: '45%' }}
                                    placeholder='最大充值金额'
                                />
                            </div>
                        </div>
                        {/*上次充值时间*/}
                        <div>
                            <label>上次充值时间：</label>
                            <div>
                                <InputNumber
                                    min={0}
                                    max={1000}
                                    value={querys.rechargeTimeMin}
                                    onChange={(value) => { changeQuerys(value, 'rechargeTimeMin') }}
                                    style={{ width: '45%' }}
                                    placeholder='最少n天内'
                                    formatter={formatter}
                                />
                                ~
                                <InputNumber
                                    min={0}
                                    max={1000}
                                    value={querys.rechargeTimeMax}
                                    onChange={(value) => { changeQuerys(value, 'rechargeTimeMax') }}
                                    style={{ width: '45%'  }}
                                    placeholder='最大n天内'
                                    formatter={formatter}
                                />
                            </div>
                        </div>
                        {/* 活跃时间*/}
                        <div>
                            <label>上次至今活跃时间：</label>
                            <div>
                                <InputNumber
                                    min={0}
                                    max={1000}
                                    value={querys.activeTimeMin}
                                    onChange={(value) => { changeQuerys(value, 'activeTimeMin') }}
                                    style={{ width: '45%' }}
                                    placeholder='最少n天内'
                                    formatter={formatter} />
                                ~
                                <InputNumber
                                    min={0}
                                    max={1000}
                                    value={querys.activeTimeMax}
                                    onChange={(value) => { changeQuerys(value, 'activeTimeMax') }}
                                    style={{ width: '45%'  }}
                                    placeholder='最大n天内'

                                    formatter={formatter} />
                            </div>
                        </div>
                        {/**系统 */}
                        <div>
                            <label>操作系统：</label>
                            <div>
                                <Checkbox.Group value={querys.osTypes} onChange={(value) => { changeQuerys(value, 'osTypes') }}>
                                    <Checkbox value='0'>未知</Checkbox>
                                    <Checkbox value='1'>安卓</Checkbox>
                                    <Checkbox value='2'>IOS</Checkbox>
                                </Checkbox.Group>
                            </div>
                        </div>

                        {/* 备注*/}
                        <div>
                            <label>昵称或备注：</label>
                            <Input placeholder='请输入粉丝昵称或备注' onChange={handelremark} value={remark} />
                        </div>
                        {/* openID*/}
                        <div>
                            <label>openId：</label>
                            <Input placeholder='请输入openId搜索' onChange={handelOpenId} value={openId} />
                        </div>
                        {/* 性别*/}
                        <div>
                            <label>性别：</label>
                            <Radio.Group defaultValue="all" buttonStyle="solid" onChange={changeSex} value={sex}>
                                <Radio.Button value="all">全部</Radio.Button>
                                <Radio.Button value="1">男</Radio.Button>
                                <Radio.Button value="2">女</Radio.Button>
                                <Radio.Button value="0">未知</Radio.Button>
                            </Radio.Group>
                        </div>
                        <div style={{ marginTop: 15 }}>
                            <TagSelect
                                change={selectTags}
                                value={{
                                    sex: 'all',
                                    tagIds: tags,
                                    tagType
                                }}
                            />
                        </div>
                    </div>
                    {/* <div className={style.select_btn}>
                        <Button type='primary' onClick={selectSubmit}>搜索</Button>
                        <Button onClick={initSelect}>重置</Button>
                    </div> */}
                </Card>
                <Card
                    title={<span>粉丝管理列表<span style={{ fontSize: 12, color: '#999' }}>(不可选粉丝为已取关粉丝)</span></span>}
                >
                    <div className={style.tables_btn}>
                        <Space>
                            {/* <Button onClick={testPackage} loading={is_boundAdAccount?.loading} type='primary'>创建人群包</Button> */}
                            <Button onClick={onTags}>一键标签</Button>
                            <Button onClick={onTag}>打标签<span style={{ color: '#999' }}>{`(${selectedRowKeys.length}/${fansList?.data?.total || 0})`}</span></Button>
                            <Button type='primary' onClick={sync} loading={fansSyncAll.loading}>同步粉丝</Button>
                            {platformId ? <Button type='primary' onClick={syncBooks} loading={syncAllBooks.loading}>同步书城信息</Button> : <></>}
                        </Space>
                        {isShow && <ModalTag fansKeys={selectedRowKeys} onCancel={handelTagModal} visible={isShow} isAll={isAll} />}
                    </div>
                    <Tables
                        columns={columns(detail, orderHandle)}
                        dataSource={fansList?.data?.records || []}
                        rowSelection={{
                            selectedRowKeys, onChange: rowSelection, getCheckboxProps: (record: { subscribe: boolean }) => {
                                return {
                                    disabled: !record?.subscribe
                                }
                            }
                        }}
                        onRow={{ onClick: (item: { id: number }) => { rowClick(item) } }}
                        rowClassName='subscribe'
                        total={fansList?.data?.total}
                        current={fansList?.data?.current}
                        pageChange={pageSize}
                        sizeChange={pageSize}
                        scroll={{ x: 1000 }}
                        size='small'
                    />
                </Card>
                <Modal
                    visible={packagePup}
                    width={300}
                    title='人群包创建'
                    onCancel={() => { setPackagePup(false) }}
                    onOk={creactPackage}
                >
                    <Row gutter={[10, 20]}>
                        <Col>
                            <Row>
                                <Col span={8}><label style={{ fontWeight: 700 }}>人群包名：</label></Col>
                                <Col span={16}><Input placeholder='人群包名'
                                    value={packageForm.userPackageName}
                                    onChange={(e) => {
                                        let v = e.target.value
                                        changgePackageForm(v, 'userPackageName')
                                    }}
                                /></Col>
                            </Row>
                        </Col>
                        <Col>
                            <Row>
                                <Col span={8}> <label style={{ fontWeight: 700 }}>人群描述：</label></Col>
                                <Col span={16}><Input.TextArea placeholder='人群描述'
                                    value={packageForm.userPackageDescription}
                                    onChange={(e) => {
                                        let v = e.target.value
                                        changgePackageForm(v, 'userPackageDescription')
                                    }}
                                /></Col>
                            </Row>
                        </Col>
                        <Col>
                            <Row>
                                <Col flex={10}><label style={{ fontWeight: 700 }}>是否深度合作：</label></Col>
                                <Col flex={14}><Switch checkedChildren="是" unCheckedChildren="否"
                                    checked={packageForm.cooperated}
                                    onChange={(v) => {
                                        changgePackageForm(v, 'cooperated')
                                    }}
                                /></Col>
                            </Row>
                        </Col>
                    </Row>
                </Modal>
                <Modal
                    visible={detailShow}
                    width={500}
                    footer={<div>
                        <Button type='primary' onClick={edit} loading={fileUrl?.loading || fansRemark?.loading}>确定</Button>
                    </div>}
                    title='粉丝详情'
                    onCancel={hideDetail}
                >
                    {
                        detailData && <Card
                            title={
                                <Row gutter={[5, 0]} >
                                    <Col>
                                        <Avatar src={fileData?.fileUrl} size='large' shape='square' />
                                        <UpImg callbakc={setFileData} />
                                    </Col>
                                    <Col style={{ display: "flex", alignItems: 'center' }}>
                                        {
                                            editName ? <Input allowClear maxLength={10} onBlur={onBlur} onChange={handeleditName} ref={ref => setRef(ref)} defaultValue={nameStr} />
                                                :
                                                <Button type='text' size='small' onClick={() => { setEditName(true) }} disabled={!detailData?.subscribe}>
                                                    {nameStr}< EditOutlined />
                                                </Button>
                                        }
                                    </Col>
                                </Row>
                            }
                        >
                            <Descriptions column={1} layout='horizontal'>
                                <Descriptions.Item label={<span className={style.detail_label}>备注</span>}>
                                    {
                                        editRemark ? <Input allowClear maxLength={10} onBlur={onBlur} onChange={handeleditRemark} ref={ref => setRef(ref)} defaultValue={remarkStr} />
                                            :
                                            <Button type='text' size='small' onClick={() => { setEditRemark(true) }} disabled={!detailData?.subscribe}>
                                                {remarkStr}< EditOutlined />
                                            </Button>
                                    }
                                </Descriptions.Item>
                                <Descriptions.Item label={<span className={style.detail_label}>性别</span>}>{['未知', '男', '女'][detailData.sex]}</Descriptions.Item>
                                <Descriptions.Item label={<span className={style.detail_label}>地域</span>}>{detailData.country + '-' + detailData.province + '-' + detailData.city}</Descriptions.Item>
                                <Descriptions.Item label={<span className={style.detail_label}>渠道来源</span>}>{scene[detailData?.subscribeScene]}</Descriptions.Item>
                                <Descriptions.Item label={<span className={style.detail_label}>关注时间</span>}>{moment(detailData?.subscribeTime).format('YYYY-MM-DD hh:mm:ss')}</Descriptions.Item>
                                <Descriptions.Item label={<span className={style.detail_label}>上次活跃</span>}>暂无</Descriptions.Item>
                                <Descriptions.Item label={<span className={style.detail_label}>订阅状态</span>}>{detailData?.subscribe ? '已关注' : '已取关'}</Descriptions.Item>
                                <Descriptions.Item label={<span className={style.detail_label}>标签</span>}>{
                                    Array.isArray(detailData.tags) && detailData.tags.map((item: any) => {
                                        return <Tag key={item.id} color={detailData?.subscribe ? bgColor[item.id] : ''} style={{ marginBottom: 8 }}>{item.name}</Tag>
                                    })
                                }</Descriptions.Item>
                            </Descriptions>
                        </Card>
                    }
                </Modal>
            </div> : <NoFoundPage />
        }
    </>
}

export default HocError(List)