import { Button, Checkbox, Col, Input, Modal, Row } from 'antd'
import React, { useCallback, useEffect, useMemo, useState } from 'react'
import { useModel } from 'umi'

type Props = {
    onCancel: () => void,
    visible: boolean,
    fansKeys: any[],
    isAll: boolean
}
const ModalTag = React.memo((props: Props) => {
    const { get, add, fansList, fansTag } = useModel('useOperating.useFans', model => ({ get: model.get, add: model.add, fansList: model.fansList, fansTag: model.fansTag }))//标签数据
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const [keys, setKeys] = useState<any[]>([])//选中的标签
    const [publicTags, setPublicTags] = useState<any[]>([])//当前选中的粉丝公有标签
    const [isAdd, setIsAdd] = useState<boolean>(false)//
    const [str, setStr] = useState<string>('')//标签输入
    //处理标签
    const options = useMemo(() => {
        if (get?.data) {
            return get?.data.map((item: any) => {
                return { label: item.name, value: item.id }
            })
        }
        return []
    }, [get.data])
    //标签选择
    const onChange = useCallback((keys: any) => {
        setKeys(keys)
    }, [])
    //新建
    const onAdd = useCallback(() => {
        setIsAdd(true)
    }, [])
    const addSubmit = useCallback(() => {
        if (str) {
            add.run({ name: str, mpId: actionWX?.id }).then(() => {
                get.refresh()
            })
        }
        setIsAdd(false)
    }, [str, actionWX])
    const addChanage = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let value = e.target.value
        setStr(value)
    }, [])
    //确定
    const submit = useCallback(() => {
        //哪些粉丝打标签
        let fansId = props.fansKeys
        //对比选中的标签中是否少了公有标签代表删除标签
        let delTag: any[] = []
        publicTags?.forEach((tag: number) => {
            if (!keys.some((key: number) => key === tag)) {
                delTag.push(tag)
            }
        })
        fansTag.run({ fansIds: fansId, addTagIds: keys, removeTagIds: delTag, appId: actionWX?.id }).then(() => {
            props.onCancel()
            fansList.refresh()
        })
    }, [keys, props.fansKeys, props.isAll, fansList, publicTags, actionWX])
    //取消
    const cancel = useCallback(() => {
        setKeys([])
        setPublicTags([])
        props.onCancel()
    }, [props])
    //处理单个或多个fans打标签
    useEffect(() => {
        let allTags: any[] = []
        let publicAll: any[] = []
        fansList?.data?.records?.forEach((fans: { id: number, tags: any[] }) => {
            if (props?.fansKeys.some((key) => key === fans.id)) {//当前的fans是否存在于选中的fans列表中
                if (props?.fansKeys?.length === 1 && fans?.id === props?.fansKeys[0]) {//选中一个粉丝的时候
                    fans?.tags?.forEach((tag: { id: number }) => {
                        publicAll.push(tag.id)
                    })
                }
                if (props?.fansKeys?.length > 1) {//选中多个粉丝的时候取共有标签
                    //取出所选粉丝标签
                    props?.fansKeys.forEach((key: number) => {
                        if (fans?.id === key) {
                            fans?.tags?.forEach((tag: { id: number }) => {
                                allTags.push(tag.id)
                            })
                        }
                    })
                    //查找当前粉丝标签集合中哪些标签总数量等于粉丝个数代表所有粉丝都拥有这个标签并保留
                    options?.forEach((option: { value: number }) => {
                        let regexp = new RegExp(`\\b${option?.value}\\b`, 'g')
                        let strLen: number | undefined = allTags.toString().match(regexp)?.length
                        let keyLen = props?.fansKeys?.length
                        let isOk = strLen === keyLen
                        if (isOk) {
                            publicAll.push(option.value)
                        }
                    })
                }
            }
        })
        setKeys(publicAll)
        setPublicTags(publicAll)
    }, [options, props?.fansKeys])
    return <Modal
        visible={props.visible}
        title={<span>{props.isAll ? '为筛选出的所有粉丝增加标签' : '为选中的粉丝打上标签'}</span>}
        width={700}
        onOk={submit}
        confirmLoading={fansTag?.loading}
        onCancel={cancel}
        destroyOnClose
    >
        <Row gutter={[10, 20]} style={{ flexFlow: 'column' }}>
            <Col>
                <Checkbox.Group
                    options={options}
                    onChange={onChange}
                    value={keys}
                />
            </Col>
            <Col>
                {isAdd ? <Input.Search enterButton="新建" style={{ width: 200 }} maxLength={8} onSearch={addSubmit} onChange={addChanage} loading={add?.loading}/> : <Button type='primary' onClick={onAdd} loading={add?.loading}>新增标签</Button>}
            </Col>
        </Row>
    </Modal>
})

export default ModalTag