import { Row, Col, Tag, Avatar, Badge } from "antd"
import React from 'react'
import { bgColor } from '@/utils/color'
import moment from "moment"
let Gz = React.memo((props: { img: string, name: string, id: string, openId: string }) => {
    return <>
        <Row gutter={[5, 0]} style={{ flexFlow: 'row nowrap' }}>
            <Col>
                <Avatar src={props.img} size='large' shape='square' />
            </Col>
            <Col style={{ display: 'flex', flexFlow: 'column', alignItems: 'flex-start' }}>
                <span>{props.name || '--'}</span>
                <span style={{ color: '#888', fontSize: '13px' }}>{props?.openId}</span>
            </Col>
        </Row>
    </>
})
const columns = (detail: (props: any) => void, orderHandle: (props: any) => void) => {
    return [
        {
            title: '粉丝',
            dataIndex: 'id',
            key: 'id',
            align: 'center',
            width: 300,
            render: (a: any, b: any) => <Gz id={b.alias} name={b.nickname} img={b.headimgurl} openId={b?.openId} />
        },
        {
            title: '性别',
            dataIndex: 'sex',
            key: 'sex',
            align: 'center',
            width: 80,
            render: (a: string) => {
                return <span>{['未知', '男', '女'][a]}</span>
            }
        },
        {
            title: '粉丝状态',
            dataIndex: 'subscribe',
            key: 'subscribe',
            align: 'center',
            width: 140,
            defaultSortOrder: 'descend',
            sorter: (a: any, b: any) => {
                return a.subscribe - b.subscribe
            },
            render: (a: string) => {
                return <span>{a ? <Badge status="processing" text='关注中' /> : <Badge status="default" text='已取关' color='red' style={{ color: 'red' }} />}</span>
            }
        },
        {
            title: '关注时间',
            dataIndex: 'subscribeTime',
            key: 'subscribeTime',
            align: 'center',
            width: 160,
            render: (a: string) => {
                return <span>{moment(a).format('YYYY-MM-DD HH:mm:ss')}</span>
            }
        },
        {
            title: '标签',
            dataIndex: 'tags',
            key: 'tags',
            align: 'center',
            width: 180,
            render: (tags: any[], b: { subscribe: boolean }) => {
                let arr = Array.isArray(tags) ? tags : []
                return arr.map((item) => {
                    return <Tag key={item.id} color={b?.subscribe ? bgColor[item?.id] : ''} style={{ marginBottom: 8 }}>{item.name}</Tag>
                })
            }
        },
        {
            title: '首充金额',
            dataIndex: 'platformFansInfo',
            key: 'firstRechargeMoney',
            align: 'center',
            width: 60,
            render: (a: any, b: any) => {
                return <span>{a?.firstRechargeMoney || 0}</span>
            }
        },
        {
            title: '手机系统',
            dataIndex: 'platformFansInfo',
            key: 'operSys',
            align: 'center',
            width: 60,
            render: (a: any, b: any) => {
                return <span>{a?.operSys === 1 ? '安卓' : a?.operSys === 2 ? 'IOS' : '未知'}</span>
            }
        },
        {
            title: '充值次数',
            dataIndex: 'platformFansInfo',
            key: 'rechargeCount',
            align: 'center',
            width: 60,
            render: (a: any, b: any) => {
                return <span>{a?.rechargeCount || 0}</span>
            }
        },
        {
            title: '充值金额（元）',
            dataIndex: 'platformFansInfo',
            key: 'rechargeMoney',
            align: 'center',
            width: 90,
            render: (a: any, b: any) => {
                return <span>{a / 100 || 0}</span>
            }
        },
        {
            title: '充值成功次数',
            dataIndex: 'platformFansInfo',
            key: 'rechargeSuccessCount',
            align: 'center',
            width: 100,
            render: (a: any, b: any) => {
                return <span>{a?.rechargeSuccessCount || 0}</span>
            }
        },
        {
            title: '最近支付时间',
            dataIndex: 'platformFansInfo',
            key: 'lastRechargeSuccessTime',
            align: 'center',
            width: 160,
            render: (a: any, b: any) => {
                return <span>{a?.lastRechargeSuccessTime}</span>
            }
        },
        {
            title: '最近一次充值时间',
            dataIndex: 'platformFansInfo',
            key: 'lastRechargeTime',
            align: 'center',
            width: 160,
            render: (a: any, b: any) => {
                return <span>{a?.lastRechargeTime}</span>
            }
        },
        // {
        //     title: '同步状态',
        //     dataIndex: 'platformFansInfo',
        //     key: 'syncStatus',
        //     align: 'center',
        //     render: (a: any, b: any) => {
        //         return <span>{a?.syncStatus || 0}</span>
        //     }
        // },
        {
            title: '操作',
            dataIndex: 'cz',
            key: 'cz',
            align: 'center',
            width: 160,
            render: (a: string, b: { id: string, mpId: string, name: string, subscribe: boolean, platformFansInfo: any }) => (
                <Row justify='center' gutter={[10, 0]}>
                    <Col><a onClick={() => detail(b)} style={b.subscribe ? {} : { color: '#999' }}>详情</a></Col>
                    {b?.platformFansInfo && <Col><a onClick={() => orderHandle(b)} style={b.subscribe ? {} : { color: '#999' }}>订单数据</a></Col>}
                </Row>
            )
        }
    ]
}
export default columns