import React, { useCallback, useEffect, useState } from 'react'
import GzhMenu from '@/components/gzhMenu'
import { Button, Card, Input, Space } from 'antd'
import Tables from '@/components/Tables'
import columns from './tableConfig'
import style from './index.less'
import { PlusCircleOutlined } from '@ant-design/icons'
import { useModel } from 'umi'
import { Modal } from 'antd'
import NoFoundPage from '@/pages/empty'
import HocError from '@/Hoc/HocError'
function Tag() {
    const { selectTag, addTag, visible, isVisible, editTag, delTag, tagSyncAll } = useModel('useOperating.useFans', model => ({
        selectTag: model.select,
        addTag: model.add,
        editTag: model.edit,
        delTag: model.del,
        visible: model.visible,
        isVisible: model.state.visible,
        tagSyncAll: model.tagSyncAll
    }))
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const [tagName, setTagName] = useState<string>('')
    const [editId, setEditId] = useState<string>('')
    //新建输入事件
    const handelChange = useCallback((event: React.ChangeEvent<HTMLInputElement>) => {
        let name = event.target.value
        setTagName(name)
    }, [])
    //编辑弹窗
    const edit = useCallback((params: { id: string, mpId: string, name: string }) => {
        setEditId(params.id)
        setTagName(params.name)
        visible()
    }, [])
    //弹窗
    const showModal = useCallback(() => {
        setTagName('')//清空输入框
        setEditId('')//清空编辑ID
        visible()
    }, [actionWX])
    //删除
    const del = useCallback((params: { tagId: string }) => {
        delTag.run(params).then(() => {
            selectTag.refresh()
            console.log(1)
        })
    }, [selectTag])
    //翻页
    const pageChange = useCallback((pageNum, pageSize) => {
        selectTag.run({ mpId: actionWX.id, pageNum, pageSize })
    }, [actionWX])
    //发送数据
    const submit = useCallback(() => {
        let ajax = editId ? editTag : addTag
        let ajaxParams = editId ? { name: tagName, tagId: editId } : { name: tagName, mpId: actionWX.id }
        ajax.run(ajaxParams).then(() => {
            selectTag.refresh()
            showModal()
        })
    }, [tagName, actionWX, editId])
    // 同步标签
    const syncAllTagHandle = useCallback(() => {
        tagSyncAll.run(actionWX.id).then(res => {
            console.log(res)
            if(res) {
                selectTag.refresh()
            }
        })
    },[actionWX])
    //首次获取列表
    useEffect(() => {
        if (actionWX) {
            selectTag.run({ mpId: actionWX.id, pageNum: 1, pageSize: 20 })
        }
    }, [actionWX])
    return <>
        {
            actionWX ? <div className={style.body}>
                <div className={style.fans_tag}>
                    <GzhMenu h={600}/>
                    <Card
                        title='标签管理'
                    >
                        <div className={style.fans_tag_header}>
                            <Space>
                                <Button type='primary' onClick={visible}><PlusCircleOutlined />新建标签</Button>
                                <Button type='primary' onClick={syncAllTagHandle}>同步标签</Button>
                            </Space>
                        </div>
                        <Tables columns={columns(edit, del)} dataSource={selectTag?.data?.records || []} total={selectTag?.data?.total} pageChange={pageChange} />

                    </Card>
                </div>
                <Modal
                    visible={isVisible}
                    onCancel={showModal}
                    title={editId ? '编辑标签' : '新增标签'}
                    onOk={submit}
                    okText='确定'
                    cancelText='取消'
                    width={400}
                    confirmLoading={addTag?.loading || editTag?.loading}
                >
                    <Input placeholder='请输入标签名称（不得超过8个字符）' maxLength={6} onChange={handelChange} allowClear value={tagName} />
                </Modal>
            </div> : <NoFoundPage />
        }
    </>
}

export default HocError(Tag)