import FansSelect from '@/components/FansSelect'
import { Col, Input, message, Radio, Row, Select, Space, Tooltip } from 'antd'
import { RadioChangeEvent } from 'antd/lib/radio'
import { isArray } from 'lodash'
import { stringify } from 'qs'
import React, { useCallback, useEffect, useState } from 'react'
import { useModel } from 'umi'
import style from './footer.less'
const { Option } = Select;

/**
 * type  默认 0  延迟消息 1  自动回复 2
 * isTextKey 是否是关键字回复
 */

const Footer = React.memo((props: { data: any, type?: number, isTextKey?: boolean, cpName?: string }) => {
    const { type = 0, isTextKey = false, cpName } = props
    const { catFans } = useModel('useOperating.useFans')
    const [radio, setRadio] = useState<number>(1)//推送时间选择
    const [tiem, setTiem] = useState<string>('')//时间设置
    const [tjradio, setTjRadio] = useState<number>(0)//触发条件
    const [fsradio, setFsRadio] = useState<number>(0)//发送顺序
    const [key, setKey] = useState<string>('')//关键字
    const [desc, setDesc] = useState<string>('')//任务名称
    const [select, setSelect] = useState<string[]>([])  //菜单切换
    const [keyword, setKeyword] = useState<number>(1)  //关键字半匹配 全匹配
    const [menus, setMenus] = useState<{ key: string, menuId: number, name: string, ruleClientPlatformType: number }[]>([])
    const [fansNum, setFansNum] = useState<number>(0)
    // const [fansType, setFansType] = useState<any>(1)
    useEffect(() => {
        if (type === 2) {
            setRadio(0)
        }
    }, [type])
    useEffect(() => {
        if (isTextKey) {
            setTjRadio(11)
            setEventType(11)
        }
    }, [isTextKey])

    useEffect(() => {
        if (tjradio == 20) {
            // 请求
            getMenuList.run({ mpId: actionWX.id }).then(res => {
                if (isArray(res)) {
                    setMenus(res)
                }
            })
        }
    }, [tjradio])

    const { setTextKey, setMenuKeys, setTime, setStrategyDesc, setMsgStrategy, setTextKeyStrategy, setEventType, setFans, setFansType, getMenuList, state } = useModel('useOperating.useInteract')
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    //推送时间选择
    const radioChange = useCallback((e: RadioChangeEvent) => {
        let value = e.target.value
        // if (value === 0 && state.msgContents.length > 1) {
        //     message.error('立即发送只能插入一条内容，请删除多余内容')
        //     return
        // }
        setRadio(value)
        switch (value) {
            case 1:
                setTime({ resDelayHours: Number(tiem) })
                break;
            case 2:
                setTime({ resDelayMinutes: Number(tiem) })
                break;
            case 3:
                setTime({ resDelaySecond: Number(tiem) })
                break;
        }
    }, [tiem, state])
    //触发条件
    const tjradioChange = useCallback((e: RadioChangeEvent) => {
        let value = e.target.value
        if (value !== 10) {
            setKey('')
        }
        setEventType(value)
        setTjRadio(value)
    }, [])
    ///发送顺序
    const fsradioChange = useCallback((e: RadioChangeEvent) => {
        let value = e.target.value
        setMsgStrategy(value)
        setFsRadio(value)
    }, [])
    //时间设置
    const tiemInput = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let value = e.target.value
        if (/^[0-9]*$/.test(value)) {
            if (value === '0' && state.msgContents.length > 1) {
                message.error('立即发送只能插入一条内容，请删除多余内容')
                return
            }
            setTiem(value)
            switch (radio) {
                case 1:
                    setTime({ resDelayHours: Number(value) })
                    break;
                case 2:
                    setTime({ resDelayMinutes: Number(value) })
                    break;
                case 3:
                    setTime({ resDelaySecond: Number(value) })
                    break;
            }
        }
    }, [radio, state])
    //setKey
    const handelKey = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let value = e.target.value
        setKey(value)
        setTextKey(value)
    }, [])
    //策略描述
    const handelDesc = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let value = e.target.value
        setDesc(value)
        setStrategyDesc(value)
    }, [])
    // 半匹配 全匹配 切换
    const handleKeyWord = useCallback((value: number, option: any) => {
        setKeyword(value);
        setTextKeyStrategy(value);
    }, [])
    //编辑回填数据
    useEffect(() => {
        if (props.data) {
            const { textKey, strategyDesc, resDelayHours, resDelayMinutes, resDelaySecond, msgStrategy, eventType, menuKeys, textKeyStrategy, fansAll } = props.data
            // setRadio(resDelayHours ? 1 : resDelayMinutes ? 2 : 3)
            // setTiem(resDelayHours || resDelayMinutes || resDelaySecond)
            setTjRadio(eventType ? eventType : 0)
            setFsRadio(msgStrategy)
            setDesc(strategyDesc)
            setKey(textKey)
            setSelect(menuKeys)
            setMenuKeys(menuKeys)
            setKeyword(textKeyStrategy || 0);
            setTextKeyStrategy(textKeyStrategy || 0);
            setFansType(fansAll ? 1 : 0)
        }
        return () => {
            setRadio(1)
            setTiem('')
            setTjRadio(0)
            setFsRadio(0)
            setDesc('')
            setKey('')
        }
    }, [props.data])

    useEffect(() => {
        return () => {
            setRadio(1)
            setTiem('')
            setTjRadio(0)
            setFsRadio(0)
            setDesc('')
            setKey('')
        }
    }, [])

    const selectChange = useCallback((value: string[], option: any) => {
        // let value = e.target.value
        // console.log(value)
        setSelect(value)
        setMenuKeys(value)
    }, [])

    /** 获取筛选粉丝数量*/
    useEffect(() => {
        if (actionWX) {
            if (!state?.fansType && state?.fansSelectValue && Object.values(state?.fansSelectValue).some((value: any) => {
                return (value !== '' && JSON.stringify(value) !== '[]')
            })) {
                if (state?.fansSelectValue && state?.fansType === 0) {
                    catFans.run({ mpId: actionWX?.id, fansAll: false, ...state?.fansSelectValue }).then((res) => {
                        setFansNum(res)
                    })
                }
            } else {
                if (state?.fansType === 1) {
                    catFans.run({ mpId: actionWX?.id, fansAll: true }).then((res) => {
                        setFansNum(res)
                    })
                }
            }
        }
    }, [state?.fansSelectValue, actionWX, state?.fansType])

    console.log('fansSelectValue', state)
    return <div className={style.footer}>
        <Row gutter={[10, 20]}>
            <Col span={24}>
                <label>消息名称：</label>
                <Input style={{ width: 300 }} onChange={handelDesc} value={desc} placeholder='选填，用于自己识别' />
            </Col>
            <Col span={24}>
                <label > 延迟时间：</label>
                <Space>
                    {/* {
                        radio !== 0 && <Input style={{ width: 100 }} onChange={tiemInput} value={tiem} size='small' />
                    } */}
                    {
                        type !== 1 && <Radio.Group onChange={radioChange} value={radio}>
                            <Radio value={0}>立即发送</Radio>
                        </Radio.Group>
                    }
                    {
                        type !== 2 && <div>
                            <Input
                                addonAfter="时"
                                style={{ width: 75 }}
                                size='small'
                                value={state?.resDelayHours}
                                onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
                                    let v = Number(event.target.value)
                                    if (isNaN(v)) {
                                        message.error('请输入数字')
                                        return
                                    } else {
                                        setTime({ resDelayHours: v })
                                    }
                                }}
                            />
                            <Input
                                addonAfter="分"
                                style={{ width: 75 }}
                                size='small'
                                value={state?.resDelayMinutes}
                                onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
                                    let v = Number(event.target.value)
                                    if (isNaN(v)) {
                                        message.error('请输入数字')
                                        return
                                    } else {
                                        setTime({ resDelayMinutes: v })
                                    }
                                }}
                            />
                            <Input
                                addonAfter="秒"
                                style={{ width: 75 }}
                                size='small'
                                value={state?.resDelaySecond}
                                onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
                                    let v = Number(event.target.value)
                                    if (isNaN(v)) {
                                        message.error('请输入数字')
                                        return
                                    } else {
                                        setTime({ resDelaySecond: v })
                                    }
                                }}
                            />
                        </div>
                    }
                </Space>
            </Col>
            <Col span={24}>
                <label > 互动类型：</label>
                <Space>
                    <Radio.Group onChange={tjradioChange} value={tjradio}>
                        {
                            !isTextKey && <>
                                <Radio value={0}>关注</Radio>
                                <Radio value={1}>扫码</Radio>
                                <Radio value={10}>消息</Radio>
                                <Radio value={20}>菜单点击</Radio>
                            </>
                        }
                        <Radio value={11}>关键词</Radio>
                        {tjradio === 11 && <span>
                            <Input addonBefore={'关键词'}
                                style={{ width: 200 }}
                                size='small'
                                onChange={handelKey}
                                value={key}
                            />
                            <span style={{ marginLeft: '10px' }}></span>
                            <Select value={keyword} style={{ width: 100 }} onChange={handleKeyWord} size='small'>
                                <Option value={1}>半匹配</Option>
                                <Option value={0}>全匹配</Option>
                            </Select>
                        </span>
                        }
                        {
                            tjradio === 20 && <Select style={{ width: '250px' }} value={select} onChange={selectChange} loading={getMenuList.loading} mode="multiple" showArrow>
                                {
                                    menus.map((option: any, index: number) => {
                                        return <Option key={option.key + index} value={option.key}>{option.ruleClientPlatformType === 1 ? 'IOS：' : option.ruleClientPlatformType === 2 ? "Android：" : "默认："}{option?.name}</Option>
                                    })
                                }
                            </Select>
                        }
                    </Radio.Group>
                </Space>
            </Col>
            <Col span={24}>
                <label > 回复方式：</label>
                <Space>
                    <Radio.Group onChange={fsradioChange} value={fsradio}>
                        <Radio value={0}>全部推送</Radio>
                        <Radio value={1}>随机回复一条</Radio>
                    </Radio.Group>
                </Space>
            </Col>
            {cpName === 'push' && <Col span={24}>
                <label > 触发条件：</label>
                <Radio.Group onChange={(e) => {
                    let value = e.target.value
                    setFansType(value)
                }} value={state?.fansType} style={{ marginBottom: 20 }}>
                    {/* disabled={actionWX?.serviceTypeInfo !== 2 || triggerType === 4} */}
                    <Radio value={0} >按条件筛选粉丝</Radio>
                    <Radio value={1}>全部粉丝<span>符合条件约<i>{fansNum || 0}</i> 人（如与实际粉丝数差别大，请同步粉丝）</span></Radio>
                </Radio.Group>
                {state?.fansType === 0 && <FansSelect callback={setFans} openConfig={{ activeTime: false }} defaultValue={
                    {
                        fansFilterOsType: props.data?.fansFilterOsType || [],//操作系统
                        fansFilterMember: props.data?.fansFilterMember || '',//是否是会员
                        fansFilterSex: props.data?.fansFilterSex || [],//粉丝性别
                        fansFilterSubscribeTimeType: props.data?.fansFilterSubscribeTimeType || '',//关注时间
                        fansFilterSubscribeTimeBegin: props.data?.fansFilterSubscribeTimeBegin || '',//关注起始时间
                        fansFilterSubscribeTimeEnd: props.data?.fansFilterSubscribeTimeEnd || '',//关注截至时间
                        fansFilterRechargeCountMin: props.data?.fansFilterRechargeCountMin || null,//充值次数（最少）
                        fansFilterRechargeCountMax: props.data?.fansFilterRechargeCountMax || null,//充值次数（最多）
                        fansFilterRechargeTimeMin: props.data?.fansFilterRechargeTimeMin || null,//上次充值时间（最少 n天内）
                        fansFilterRechargeTimeMax: props.data?.fansFilterRechargeTimeMax || null,//上次充值时间（最大 n天内）
                        fansFilterRechargeMin: props.data?.fansFilterRechargeMin || '',//最低充值金额
                        fansFilterRechargeMax: props.data?.fansFilterRechargeMax || '',//最大充值金额
                        fansFilterCoinCountMin: props.data?.fansFilterCoinCountMin || '',//最低书币余额
                        fansFilterCoinCountMax: props.data?.fansFilterCoinCountMax || '',//最高书币余额
                        fansFilterActiveTimeMin: props.data?.fansFilterActiveTimeMin || '',//上次活跃距今时间（最低）
                        fansFilterActiveTimeMax: props.data?.fansFilterActiveTimeMax || '',//上次活跃距今时间（最高）
                        rechargeType: props.data?.rechargeType || '',//充值情况选项
                        dayType: props.data?.dayType || '',//天数选项
                        countType: props.data?.countType || '',//书币选项
                        timeType: props.data?.timeType || ''//时间选项
                    }
                } />}
            </Col>}
            {/* <Col span={24} style={{ display: 'flex' }}>
                <label > 任务描述：</label>
                <Input.TextArea rows={3} style={{ width: 300 }} onChange={handelDesc} value={desc} />
            </Col> */}
        </Row>
    </div>
})

export default Footer