import PreviewModal from '@/components/MaterialModal/previewModal'
import { Button, Drawer, message, Space } from 'antd'
import React, { useCallback } from 'react'
import { useModel } from 'umi'
import Content from './content'
import Footer from './footer'
import style from './index.less'

/**
 * type  默认 0  延迟消息 1  立即回复 2
 * isTextKey 是否是关键字回复
 */

type Props = {
    visible: boolean,
    onClose: () => void,
    data: any,
    type?: number,
    isTextKey?: boolean,
    isModify?: boolean,  // 是否可以修改
    cpName?: string,
}
const PushModal = (prop: Props) => {
    const { type = 0, isTextKey = false, isModify = true, cpName, ...props } = prop
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const { state, addMsg, searchMsg, editMsg, editMsgIm, searchImMsg } = useModel('useOperating.useInteract', model => ({
        state: model.state,
        addMsg: model.addMsg,
        searchMsg: model.searchMsg,
        editMsg: model.editMsg,
        editMsgIm: model.editMsgIm,
        searchImMsg: model.searchImMsg,
    }))
    const { visible, onClose, data } = props
    const submit = useCallback(() => {
        let { msgContents, data, fansSelectValue, fansType, ...props } = state
        /**检测条件 */
        let isEventType: boolean = !props.eventType //0是关注回复允许插入一个多图文，0取反为true
        let isMoreNews: number = 0 //是否存在多图文,并填入有多少多图文
        msgContents.forEach((item: any) => {
            if (item.webType === 5 && item.newsList.length > 1) {
                isMoreNews += 1
            }
        })
        if (isMoreNews > 0 && !isEventType) {
            message.error('只能在关注回复条件下才能添加多图文素材，请手动删除或更改条件！')
            return
        }
        if (isMoreNews > 1 && isEventType) {
            message.error('只允许添加一条多图文素材，请手动删除多余多图文')
            return
        }

        /**数据解构处理 */
        let newMsgContents: any[] = []
        msgContents.forEach((item: any) => {
            let { webType, indexId, newsList } = item
            switch (webType) {
                case 5:
                    let reg = new RegExp('&nbsp;', "g")
                    let data = newsList?.map((item: { title: string }) => {
                        return { ...item, title: item?.title.replace(reg, ' ') }
                    })
                    newMsgContents.push({ newsList: data, type: 3, msgType: "news", webType: 5, indexId })
                    break;
                case 4:
                    let textContent: string = ''
                    item?.textContent?.forEach((key: string, index: number) => {
                        // if (key !== "") {
                        textContent += index !== item.textContent.length - 1 ? key.replace(/_href/ig, 'href') + `<br/>` : key.replace(/_href/ig, 'href')
                        // }
                    })
                    newMsgContents.push({ msgType: "text", textContent, indexId, webType: 4, type: 2 })
                    break;
                case 3:
                    // if (item.mediaId || item.wxMediaId) {
                    //     newMsgContents.push({ wxMediaId: item.mediaId || item.wxMediaId, type: 0, msgType: "video", indexId, webType: 3 })
                    // }
                    newMsgContents.push(item)
                    break;
                case 2:
                    // if (item.mediaId || item.wxMediaId) {
                    //     newMsgContents.push({ wxMediaId: item.mediaId || item.wxMediaId, type: 0, msgType: "music", indexId, webType: 2 })
                    // }
                    newMsgContents.push(item)
                    break;
                case 1:
                    newMsgContents.push(item)
                    // if (item.mediaId || item.wxMediaId) {
                    //     newMsgContents.push({ wxMediaId: item.mediaId || item.wxMediaId, type: 0, msgType: "image", indexId, webType: 1 })
                    // }
                    break;
                case 6:
                    newMsgContents.push(item)
                    break;
            }
        })
        if (props?.eventType === 11 && props?.textKey == '') {
            message.error('请输入关键字')
            return
        }
        if (props?.eventType === 20 && props?.menuKeys?.length === 0) {
            message.error('请选择菜单')
            return
        }
        if (type === 2) {
            // 立即回复保存
            editMsgIm.run({ msgContents: newMsgContents, ...props, textKey: props?.eventType === 11 ? props?.textKey : '', mpId: actionWX.id, id: props.id }).then((res) => {
                if (res) {
                    searchImMsg.refresh()
                    onClose()
                }
            })
            return
        }
        if (type === 1) {
            let time = props?.resDelayHours || props?.resDelayMinutes || props?.resDelaySecond
            if (!time) {
                message.error('请设置延迟时间')
                return
            }
        }
        console.log('actionWX.id===>', actionWX.id, props.id, newMsgContents, { ...props })
        console.log('state?.fansSelectValue===>', state?.fansSelectValue)
        if (props.id) {
            editMsg.run({ msgContents: newMsgContents, ...props, textKey: !!props?.eventType ? props?.textKey : '', strategyId: props.id, mpId: actionWX.id, ...fansSelectValue, fansAll: !!fansType }).then((res) => {
                if (res) {
                    searchMsg.refresh()
                    onClose()
                }
            })
        } else {
            addMsg.run({ msgContents: newMsgContents, ...props, textKey: !!props?.eventType ? props?.textKey : '', mpId: actionWX.id, ...fansSelectValue, fansAll: !!fansType }).then((res) => {
                if (res) {
                    searchMsg.refresh()
                    onClose()
                }
            })
        }

    }, [state, actionWX.id])

    return <>
        <Drawer
            title={actionWX?.nickName}
            placement="right"
            width={'90%'}
            onClose={onClose}
            visible={visible}
            getContainer={false}
            footer={
                < div className={style.footer} >
                    <Space>
                        {isModify && <Button type='primary' onClick={submit} loading={editMsg?.loading || addMsg?.loading}>保存</Button>}
                        <PreviewModal isYc data={{ mpIds: [actionWX], msgContents: state?.msgContents }} />
                    </Space>
                </div >
            }
        >
            <Content type={1} cpName='push' />
            {visible && <Footer data={data} type={type} isTextKey={isTextKey} cpName={cpName} />}
        </Drawer >
    </>
}

export default PushModal