import React, { useCallback } from 'react'
import Tables from '@/components/Tables'
import { columns, columnsIm } from './tablesCongig'
import { useModel } from 'umi'
import './index.less'

type props = {
    tableData: any[],
    open: (data: any) => void,
    msgType?: string
}

const MsgTable: React.FC<props> = (props) => {
    const { setEnabled, searchMsg, delMsg, searchDetail } = useModel('useOperating.useInteract', model => ({
        setEnabled: model.setEnabled,
        searchMsg: model.searchMsg,
        delMsg: model.delMsg,
        searchDetail: model.searchDetail
    }))

    const { tableData, open, msgType = "" } = props
    // 数据
    const dataCallback = useCallback((item: any) => {
    }, [])
    // 修改
    let web = { video: 3, news: 5, music: 2, image: 1, text: 4, miniprogrampage: 6, voice: 2 }
    const updataCallback = useCallback((item: any) => {
        searchDetail.run({ strategyId: item?.id }).then(res => {
            let msgContents: any[] = []
            /**编辑将数据处理存入model */
            res?.msgContents?.forEach((item: any, index: number) => {
                if (item.webType === 4) {
                    msgContents.push({ ...item, textContent: item.textContent.replace(/href/ig, '_href').split('<br    />'), indexId: index + 1, webType: 4 })
                } else {
                    let reg = new RegExp(' ', "g")
                    let data = item?.newsList?.map((item: { title: string }) => {
                        return { ...item, title: item?.title.replace(reg, '&nbsp;') }
                    })
                    if (item.webType === 6) {
                        msgContents.push({ ...item, newsList: data, indexId: index + 1, webType: web[item.msgType], imageUrl: item?.platformMediaInfo?.url })
                    } else {
                        msgContents.push({ ...item, newsList: data, indexId: index + 1, webType: web[item.msgType] })
                    }
                }
            })
            open({ ...res, msgContents })
        })
        return

    }, [tableData])
    // 状态修改
    const stateCallback = useCallback((item: any) => {
        setEnabled.run({ strategyId: item?.id, enabled: !item?.enabled }).then(() => {
            searchMsg.refresh()
        })
    }, [tableData])
    // 删除
    const delCallback = useCallback((item: any) => {
        delMsg.run({ strategyId: item?.id }).then(() => {
            searchMsg.refresh()
        })
    }, [tableData])
    return <>
        {
            msgType === 'delay' ?
                <Tables
                    columns={columns(dataCallback, updataCallback, stateCallback, delCallback)} 
                    dataSource={tableData}
                    rowClassName={(record: any) => {
                        if (record?.checkStatus === -1) {
                            return 'error'
                        } else {
                            return ""
                        }
                    }}
                />
                :
                <Tables
                    columns={columnsIm(dataCallback, updataCallback, stateCallback, delCallback)} 
                    dataSource={tableData}
                    rowClassName={(record: any) => {
                        if (record?.checkStatus === -1) {
                            return 'error'
                        } else {
                            return ""
                        }
                    }}
                />
        }

    </>
}

export default React.memo(MsgTable)