import { Button, Input, Select, Space, Radio, Upload, message } from 'antd'
import { RadioChangeEvent } from 'antd/lib/radio'
import React, { useCallback, useEffect, useState } from 'react'
import style from './index.less'
import { useModel } from 'umi'
import WxMenu from '@/components/gzhMenu'
import PushModal from '../components/pushModal'
import NoFoundPage from '@/pages/empty'
import MsgTable from '../components/table/tableDelay'
import HocError from '@/Hoc/HocError'
import { DownloadOutlined, UploadOutlined } from '@ant-design/icons'
import { RcCustomRequestOptions } from 'antd/lib/upload/interface'
const { Option } = Select;

/**
 * 延迟消息
 */

function Push() {
    const { actionWX } = useModel('useOperating.useWxGroupList', models => ({ allWx: models.state.allWx, actionWX: models.state.actionWX }))
    const { searchMsg, initData, setDeflault, upLoad } = useModel('useOperating.useInteract', models => ({
        searchMsg: models.searchMsg,
        initData: models.initData,
        setDeflault: models.setDeflault,
        upLoad: models.upLoad
    }))
    const [select, setSelect] = useState<string>('all')
    const [radio, setRadio] = useState<string>('all')
    const [visible, setVisible] = useState<boolean>(false)
    const [data, setData] = useState<any>(null)//footer编辑数据
    const [btnUploadLoding, setBtnUploadLoding] = useState<boolean>(false)//按钮loding
    // const [strategyDesc, setStrategyDesc] = useState<string>('')
    //选择
    const selectChange = useCallback((value: string, option: any) => {
        // let value = e.target.value
        let enabled = radio === 'all' ? {} : radio === '1' ? { enabled: true } : { enabled: false }
        searchMsg.run({ mpId: actionWX?.id, eventType: value === 'all' ? '' : value, ...enabled })
        setSelect(value)
    }, [actionWX, radio, select])
    //输入搜索
    const subStrategyDesc = useCallback((value: string) => {
        let enabled = radio === 'all' ? {} : radio === '1' ? { enabled: true } : { enabled: false }
        searchMsg.run({ mpId: actionWX?.id, eventType: select === 'all' ? '' : select, searchKey: value, ...enabled })
    }, [select, actionWX, radio])
    //新建编辑弹窗
    const onClose = useCallback((data?: any) => {
        console.log(data)
        setDeflault()
        if (data?.id) {//假如存在证明编辑把数据存放给footer组件用
            setData(data)
            let {
                fansFilterOsType,//操作系统
                fansFilterMember,//是否是会员
                fansFilterSex,//粉丝性别
                fansFilterSubscribeTimeType,//关注时间
                fansFilterSubscribeTimeBegin,//关注起始时间
                fansFilterSubscribeTimeEnd,//关注截至时间
                fansFilterRechargeCountMin,//充值次数（最少）
                fansFilterRechargeCountMax,//充值次数（最多）
                fansFilterRechargeTimeMin,//上次充值时间（最少 n天内）
                fansFilterRechargeTimeMax,//上次充值时间（最大 n天内）
                fansFilterRechargeMin,//最低充值金额
                fansFilterRechargeMax,//最大充值金额
                fansFilterCoinCountMin,//最低书币余额
                fansFilterCoinCountMax,//最高书币余额
                fansFilterActiveTimeMin,//上次活跃距今时间（最低）
                fansFilterActiveTimeMax,//上次活跃距今时间（最高）
                rechargeType,//充值情况选项
                dayType,//天数选项
                countType,//书币选项
                timeType,//时间选项
                ...d
            } = data
            initData({ data: { ...d, delId: [] } })
        }
        if (visible) {
            initData({ data: { msgContents: [], textKey: '', resDelayTime: 0, strategyDesc: '', msgStrategy: 0, eventType: 0, delId: [], id: '' } })
            setData(null)
        }
        localStorage.setItem('collapsed', visible ? '0' : '1')
        setVisible(!visible)
    }, [visible])
    //获取当前微信的策略
    useEffect(() => {
        if (actionWX) {
            searchMsg.run({ mpId: actionWX?.id })
        }
    }, [actionWX])

    const options = [
        { label: '全部', value: 'all' },
        { label: '启动', value: '1' },
        { label: '禁用', value: '0' },
    ];

    const radioChange = useCallback((e: RadioChangeEvent) => {
        let value = e.target.value
        setRadio(value)
        let enabled = value === 'all' ? {} : value === '1' ? { enabled: true } : { enabled: false }
        searchMsg.run({ mpId: actionWX?.id, eventType: select === 'all' ? '' : select, ...enabled })
    }, [actionWX, select])

    return <>
        {
            actionWX ? <div className={style.box}>
                <WxMenu h={600} isDisabled={false}/>
                <div style={{ width: '100%' }}>
                    <div className={style.header}>
                        <div>
                            <Space>
                                <Radio.Group options={options} onChange={radioChange} value={radio} optionType="button" />
                                <Select style={{ width: '150px' }} value={select} onChange={selectChange}>
                                    <Option value="all">显示全部</Option>
                                    <Option value="0">关注公众号</Option>
                                    <Option value="1">扫码</Option>
                                    <Option value="10">消息回复</Option>
                                    <Option value="11">关键字</Option>
                                    <Option value="20">菜单点击</Option>
                                </Select>
                                <Input.Search
                                    onSearch={subStrategyDesc}
                                    style={{ width: 200 }}
                                    enterButton
                                    placeholder='规则名称/关键字'
                                />

                            </Space>
                        </div>
                        <Space>
                            <Button ><DownloadOutlined /><a href={`http://oss.zanxiangnet.com/zx-system/file/excel/延时消息导入模板.xlsx`}>导出模板</a></Button>
                            <Upload
                                accept="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet, application/vnd.ms-excel"
                                action=""
                                listType="text"
                                onChange={() => { }}
                                multiple={true}
                                showUploadList={false}
                                customRequest={(options: RcCustomRequestOptions) => {
                                    setBtnUploadLoding(true)
                                    let formData = new FormData();
                                    formData.append("file", options.file);
                                    upLoad.run({ data: formData }).then(res => {
                                        if (res) {
                                            searchMsg.refresh()
                                            message.success('创建完成！')
                                            setBtnUploadLoding(false)
                                        }

                                    }).catch(() => {
                                        setBtnUploadLoding(false)
                                    })
                                }}
                            ><Button type='primary' icon={<UploadOutlined />} loading={btnUploadLoding}>批量创建</Button></Upload>
                            <Button type='primary' onClick={onClose}>新建推送</Button>
                        </Space>
                    </div>
                    <div >
                        {
                            <div style={{ padding: '10px 0 0 10px' }}><MsgTable tableData={searchMsg?.data} open={onClose} msgType='delay'></MsgTable></div>
                        }

                    </div>
                    <PushModal visible={visible} onClose={onClose} data={data} type={1} cpName='push' />
                </div>
            </div> : <NoFoundPage />
        }
    </>
}

export default HocError(Push)