import { DeleteOutlined, EditOutlined, PieChartOutlined, WechatFilled } from '@ant-design/icons'
import { Avatar, Card, Popconfirm, Switch, Tooltip } from 'antd'
import React, { useCallback } from 'react'
import { useModel } from 'umi'
import style from './wxbox.less'
const colors = { '0': '#ff5722', '10': '#cddc39', '20': '#ffc107' }
const WxBox = React.memo((props: { data: any, open: (data: any) => void }) => {
    const { setEnabled, searchMsg, delMsg } = useModel('useOperating.useInteract', model => ({ setEnabled: model.setEnabled, searchMsg: model.searchMsg, delMsg: model.delMsg }))
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const { data, open } = props
    /**开关*/
    const switchChange = useCallback((e: boolean) => {
        setEnabled.run({ strategyId: data?.id, enabled: e }).then(() => {
            searchMsg.refresh()
        })
    }, [data])
    /**删除*/
    const del = useCallback(() => {
        delMsg.run({ strategyId: data?.id }).then(() => {
            searchMsg.refresh()
        })
    }, [data])
    let web = { video: 3, news: 5, music: 2, image: 1, text: 4 }
    const Edit = () => {
        let msgContents: any[] = []
        /**编辑将数据处理存入model */
        data.msgContents.forEach((item: any, index: number) => {
            if (item.webType === 4) {
                msgContents.push({ ...item, textContent: item.textContent.replace(/href/ig, '_href').split('<br    />'), indexId: index + 1, webType: 4 })
            } else {
                msgContents.push({ ...item, indexId: index + 1, webType: web[item.msgType] })
            }
        })
        return <Tooltip title="编辑">
            <EditOutlined onClick={() => { open({ ...data, msgContents }) }} />
        </Tooltip>
    }
    const PieChart = useCallback(() => {
        return <Tooltip title="查看数据">
            <PieChartOutlined />
        </Tooltip>
    }, [])
    const Delete = useCallback(() => {
        return <Tooltip title="删除">
            <Popconfirm
                title={`确定要删除此条规则吗？`}
                onConfirm={del}
                okText="Yes"
                cancelText="No"
            >
                <DeleteOutlined />
            </Popconfirm>
        </Tooltip>
    }, [])
    return <Card
        style={{ width: 300 }}
        hoverable
        title={
            <div className={`${style.header} ${data?.enabled ? '' : style.close}`}>
                <Avatar style={data?.enabled ? { backgroundColor: colors[data?.eventType] } : { backgroundColor: '#c5c5c5' }} icon={actionWX?.headImg ? <img src={actionWX?.headImg} /> : <WechatFilled />} />
                <div style={{ marginLeft: 10 }}>
                    <span >{actionWX?.nickName}</span>
                </div>
            </div>
        }
        extra={<Switch checkedChildren="开启" unCheckedChildren="关闭" onChange={switchChange} checked={data?.enabled} />}
        actions={
            [
                <Edit />,
                <PieChart />,
                <Delete />
            ]
        }
    >
        {
            <div className={style.no_null}>
                <p>推送时间：<span>{data?.resDelayTime === 0 ? `立即推送` : `${data?.resDelayTime}分钟后推送`}</span></p>
                <p>推送方式：<span>{data?.msgStrategy === 0 ? `全部推送` : `随机推送一条`}</span></p>
                <p>触发条件：<span>{data?.eventType === 0 ? `关注回复` : `消息回复`}</span></p>
                {data?.textKey && <p>关键字：<span>{data?.textKey}</span></p>}
                <p>推送内容：<span>{data?.msgContents.length}条信息</span></p>
                <p>备注：<span>{data?.strategyDesc || '无'}</span></p>
            </div>
        }

    </Card >
})

export default WxBox