import { Button, Col, Input, message, Popconfirm, Radio, Row, Space, Switch } from 'antd'
import { RadioChangeEvent } from 'antd/lib/radio'
import React, { useCallback, useEffect, useState } from 'react'
import style from '../push/index.less'
import { useModel } from 'umi'
import WxMenu from '@/components/gzhMenu'
import PushModal from '../components/pushModal'
import NoFoundPage from '@/pages/empty'
import Content from '../components/pushModal/content'
import MsgTable from '../components/table'
import { CheckCircleOutlined, CloseCircleOutlined } from '@ant-design/icons'
import HocError from '@/Hoc/HocError'
import Look from '../../examine/components/look'
/**
 * 自动回复
 */

const Replay: React.FC = () => {
    const { actionWX } = useModel('useOperating.useWxGroupList', models => ({ allWx: models.state.allWx, actionWX: models.state.actionWX }))

    const [radio, setRadio] = useState<number>(0)
    const [visible, setVisible] = useState<boolean>(false)
    const [data, setData] = useState<any>(null)//footer编辑数据
    const { state, initData, setDeflault, setMsgStrategy, setEnabled, searchImMsg, editMsgIm, setEventType } = useModel('useOperating.useInteract', models => ({
        state: models.state,
        initData: models.initData,
        setDeflault: models.setDeflault,
        setMsgStrategy: models.setMsgStrategy,
        setEnabled: models.setEnabled,
        searchImMsg: models.searchImMsg,
        editMsgIm: models.editMsgIm,
        setEventType: models.setEventType
    }))

    const switchChange = useCallback((e: boolean) => {

        if (!('id' in state)) {
            message.error('请至少保存一条内容，再来设置')
            return
        }
        // console.log(state)
        setEnabled.run({ strategyId: state?.id, enabled: e }).then(() => {
            searchImMsg.refresh()
        })
    }, [state])

    //选择
    const radioChange = useCallback((e: RadioChangeEvent) => {
        let value = e.target.value
        setEventType(e.target.value)
        searchImMsg.run({ mpId: actionWX?.id, eventType: value })
        setRadio(value)
    }, [actionWX, radio])
    //输入搜索
    const subStrategyDesc = useCallback((value: string) => {
        // 关键字搜索
        if (value == '') {
            message.error('请输入消息名称/关键字')
            return
        }
        searchImMsg.run({ mpId: actionWX?.id, eventType: radio, searchKey: value })
    }, [radio, actionWX])
    //新建编辑弹窗
    const onClose = useCallback((data?: any) => {
        setDeflault()
        if (data?.id) {//假如存在证明编辑把数据存放给footer组件用
            setData(data)
            initData({ data: { ...data, delId: [] } })
        }
        if (visible) {
            initData({ data: { msgContents: [], textKey: '', resDelayTime: 0, strategyDesc: '', msgStrategy: 0, eventType: 0, delId: [], id: '' } })
            setData(null)
        }
        localStorage.setItem('collapsed', visible ? '0' : '1')
        setVisible(!visible)
    }, [visible])
    //获取当前微信的策略
    useEffect(() => {
        if (actionWX) {
            // searchMsg.run({ mpId: actionWX?.id })
            searchImMsg.mutate([])
            searchImMsg.run({ mpId: actionWX?.id, eventType: radio })
        }
    }, [actionWX])
    ///发送顺序
    const fsradioChange = useCallback((e: RadioChangeEvent) => {
        let value = e.target.value
        setMsgStrategy(value)
    }, [])
    /// 保存
    const msgSubmit = useCallback(() => {
        console.log('submit===>state', state)
        let { msgContents, data, ...props } = state
        /**检测条件 */
        let isEventType: boolean = [0, 1].indexOf(radio) === -1 ? false : true //0是关注回复允许插入一个多图文，0取反为true
        let isMoreNews: number = 0 //是否存在多图文,并填入有多少多图文
        msgContents.forEach((item: any) => {
            if (item.webType === 5 && item.newsList.length > 1) {
                isMoreNews += 1
            }
        })
        if (isMoreNews > 0 && !isEventType) {
            message.error('只能在关注回复和扫码回复条件下才能添加多图文素材，请手动删除或更改条件！')
            return
        }
        if (isMoreNews > 1 && isEventType) {
            message.error('只允许添加一条多图文素材，请手动删除多余多图文')
            return
        }
        /**数据解构处理 */
        let newMsgContents: any[] = []
        msgContents.forEach((item: any) => {
            let { webType, indexId, newsList } = item
            switch (webType) {
                case 5:
                    let reg = new RegExp('&nbsp;', "g")
                    let data = newsList?.map((item: { title: string }) => {
                        return { ...item, title: item?.title.replace(reg, ' ') }
                    })
                    newMsgContents.push({ newsList: data, type: 3, msgType: "news", webType: 5, indexId })
                    break;
                case 4:
                    let textContent: string = ''
                    item?.textContent?.forEach((key: string, index: number) => {
                        // if (key !== "") { 
                        textContent += index !== item.textContent.length - 1 ? key.replace(/_href/ig, 'href') + `<br/>` : key.replace(/_href/ig, 'href')
                        // }
                    })
                    newMsgContents.push({ msgType: "text", textContent, indexId, webType: 4, type: 2 })
                    break;
                case 3:
                    if (item.mediaId || item.wxMediaId) {
                        newMsgContents.push({ wxMediaId: item.mediaId || item.wxMediaId, type: 0, msgType: "video", indexId, webType: 3 })
                    }
                    break;
                case 2:
                    if (item.mediaId || item.wxMediaId) {
                        newMsgContents.push({ wxMediaId: item.mediaId || item.wxMediaId, type: 0, msgType: "music", indexId, webType: 2 })
                    }
                    break;
                case 1:
                    if (item.mediaId || item.wxMediaId) {
                        newMsgContents.push({ wxMediaId: item.mediaId || item.wxMediaId, type: 0, msgType: "image", indexId, webType: 1 })
                    }
                    break;
                case 6:
                    if (!item?.platformMediaId) {
                        item['platformMediaId'] = item.mediaId
                    }
                    newMsgContents.push(item)
                    break;
            }
        })
        editMsgIm.run({ msgContents: newMsgContents, ...props, eventType: radio, textKey: radio === 11 ? props?.textKey : '', mpId: actionWX.id, id: props.id }).then((res) => {
            if (res) {
                searchImMsg.refresh()
                localStorage.setItem('collapsed', '0')
            }

        })

    }, [state])
    return <>
        {
            actionWX ? <div className={style.box}>
                <WxMenu h={600} isDisabled={false}/>
                <div style={{ width: '100%', display: "flex", flexDirection: 'column' }}>
                    <div className={style.header}>
                        <div>
                            <Space>
                                <Radio.Group onChange={radioChange} value={radio}>
                                    <Radio value={0}>关注公众号</Radio>
                                    <Radio value={1}>扫码</Radio>
                                    <Radio value={10}>消息回复</Radio>
                                    <Radio value={11}>关键字</Radio>
                                </Radio.Group>
                                {
                                    radio === 11 && <Input.Search
                                        onSearch={subStrategyDesc}
                                        style={{ width: 200 }}
                                        enterButton
                                        placeholder='规则名称/关键字'
                                    />
                                }
                            </Space>
                        </div>
                        {
                            radio === 11 && <Button type='primary' onClick={onClose}>新建推送</Button>
                        }
                    </div>
                    <div style={{ flex: '1', padding: '10px 0 0 10px', height: '100%', boxSizing: 'border-box' }}>
                        {
                            [0, 1, 10].indexOf(radio) !== -1 ? <div style={{ height: "100%", display: 'flex', flexDirection: 'column' }}>
                                {
                                    <>
                                        <Row align='middle' style={{ padding: '3px 20px', border: "1px solid #ffe58f", backgroundColor: "#fffbe6", marginBottom: '10px', borderRadius: '5px' }}>

                                            {
                                                radio === 0 ? <Col flex="auto">
                                                    <div>1）开启后，新关注的用户将自动收到下列消息；关闭后，将立即对所有用户生效。</div>
                                                    <div>2）可一次性发送多条消息，消息形式有图片、文字、语音、视频、单图文链接、多图文链接（仅限第一条）</div>
                                                </Col> :
                                                    radio === 1 ? <Col flex="auto">
                                                        <div>1）开启后，扫码的用户将自动收到下列消息；关闭后，将立即对所有用户生效。</div>
                                                        <div>2）可一次性发送多条消息，消息形式有图片、文字、语音、视频、单图文链接、多图文链接（仅限第一条）</div>
                                                    </Col> :
                                                        <Col flex="auto">
                                                            <div>{state?.enabled ? <><CheckCircleOutlined style={{ color: 'rgb(82, 196, 26)', marginRight: '5px' }} />您已开启收到消息回复设置，可点击右侧开关，操作关闭</> : <><CloseCircleOutlined style={{ color: 'rgb(245, 34, 45)', marginRight: '5px' }} />您已关闭收到消息回复设置，可点击右侧开关，操作开启</>}</div>
                                                        </Col>
                                            }
                                            <Col flex="100px" style={{ alignItems: 'center' }}>
                                                <Switch defaultChecked onChange={switchChange} checked={state?.enabled} />
                                            </Col>
                                        </Row>
                                        {state?.checkStatus === -1 && <Row align='middle' style={{ padding: '3px 20px', border: "1px solid #f58686", backgroundColor: "#ffdddd", marginBottom: '10px', borderRadius: '5px' }}>
                                            <Col flex="auto" style={{color: '#f95656'}}>
                                                审查未通过：{state?.checkRemark}
                                            </Col>
                                        </Row>}
                                        <Content type={2} myStype={{ backgroundColor: '#FFF' }} data={searchImMsg?.data} myHeight={true} cpName='reply' />

                                        <Row style={{ backgroundColor: '#FFF', marginTop: '10px', padding: '15px' }}>
                                            <Col span={24}>
                                                <label > 回复方式：</label>
                                                <Space>
                                                    <Radio.Group onChange={fsradioChange} value={state?.msgStrategy}>
                                                        <Radio value={0}>全部推送</Radio>
                                                        <Radio value={1}>随机回复一条</Radio>
                                                    </Radio.Group>
                                                </Space>
                                            </Col>
                                            <Col span={24} style={{ marginTop: '10px' }}>
                                                <Space>
                                                    <Button type="primary" onClick={msgSubmit}>保存</Button>
                                                    <Popconfirm
                                                        title="确定要清空?"
                                                        onConfirm={() => { setDeflault() }}
                                                        onCancel={() => { }}
                                                        okText="确定"
                                                        cancelText="取消"
                                                    >
                                                        <Button>清空消息</Button>
                                                    </Popconfirm>
                                                    {/* 预览 */}
                                                    {state?.id && <Look type='Interact' strategyId={state?.id} id={state?.mpId} size="middle" buttonType="primary" />}
                                                </Space>
                                            </Col>
                                        </Row>
                                    </>
                                }

                            </div> : <div>
                                {
                                    <div style={{ padding: '10px 0 0 10px' }}><MsgTable tableData={searchImMsg?.data} open={onClose} msgType='immediately'></MsgTable></div>
                                }
                            </div>
                        }

                    </div>
                    <PushModal visible={visible} onClose={onClose} data={data} type={2} isTextKey={true} />
                </div>
            </div> : <NoFoundPage />
        }
    </>
}

export default HocError(Replay)