import Tables from "@/components/Tables"
import { PlusOutlined } from "@ant-design/icons"
import { Button, Col, DatePicker, Drawer, Form, Input, Modal, Row, Select, Space } from "antd"
import React, { useCallback, useEffect, useState } from "react"
import { useModel } from "umi"
import columnsCr from "./crTableConfig"
import './index.less'
import { insetCutProps, editCutProps } from "@/services/operating/book"
import moment from "moment"

type Props = {
    data?: any,
    visible?: boolean,
    onChange?: () => void,
    onClose?: () => void
}
function ChangeRecord(props: Props) {
    const { data, visible, onChange, onClose } = props
    const { gitCutRecordList, businessGroupALL, getBookALL, getPeriodALL, allBookCity, platformAll, getAllUserList, insertCutRecord, editCutRecord, delCutRecord } = useModel('useOperating.useAccountyyb')

    const [queryPlatform, setQueryPlatform] = useState<any>({ pageNum: 1, pageSize: 10, resourceId: data?.id })  // 获取G参数
    const [title, setTitle] = useState<string>('')
    const [show, setShow] = useState<boolean>(false)
    const [form] = Form.useForm()
    const [platformId, setPlatformId] = useState<number | undefined>(data?.platformId)
    const [addQueryPlatForm, setAddQueryPlatForm] = useState<insetCutProps | editCutProps | null>()

    useEffect(() => {
        getList()
    }, [queryPlatform])

    const getList = () => {
        gitCutRecordList.run(queryPlatform)
    }

    // 获取期数 书 分组
    useEffect(() => {
        console.log('data--->', data)
        getAll()
        platformAll.run(data?.platformId)
    }, [])

    const getAll = () => {
        businessGroupALL.run()
        getBookALL.run()
        getPeriodALL.run()
        allBookCity.run()
        getAllUserList.run()
    }
    // 获取账号
    const getBookAccount = async (platformId: any) => {
        setPlatformId(platformId as any)
        platformAll.run(platformId)
        let dataForm = await form.validateFields()
        form.setFieldsValue({ ...dataForm, platformAccountId: undefined })
    }

    // 分页
    const pageChange = useCallback((page: string | number, pageSize?: string | number) => {
        setQueryPlatform({ ...queryPlatform, pageNum: page as number, pageSize: pageSize as number })
    }, [queryPlatform])

    /** 新增记录 */
    const handleCutRecord = () => {
        setShow(true);
        setTitle('插入起始记录')
        const { id, businessGroupId, putUserId, operUserId, periodId, platformId, platformAccountId, bookId, putStatus, putChannel, rechargeTemplate } = data
        setAddQueryPlatForm({
            beginTime: null,
            resourceId: id,
            businessGroupId,
            operUserId,
            putUserId,
            periodId,
            platformId,
            platformAccountId,
            bookId,
            putStatus,
            putChannel,
            rechargeTemplate
        })
    }

    // 插入修改
    const insertDownHandle = (item: any, type: string) => {
        setShow(true);
        setTitle(`${type}记录`)
        let data1 = {}
        const { beginTime, endTime, id, resourceId, businessGroupId, operUserId, putUserId, periodId, platformId, platformAccountId, bookId, putStatus, putChannel, rechargeTemplate } = item
        if (type === '修改') {
            data1 = { beginTime: moment(beginTime), endTime: endTime ? moment(endTime) : null, id }
        } else {
            data1 = { lastChangeRecordId: id }
        }
        setAddQueryPlatForm({
            ...data1,
            resourceId,
            businessGroupId,
            operUserId,
            putUserId,
            periodId,
            platformId,
            platformAccountId,
            bookId,
            putStatus,
            putChannel,
            rechargeTemplate
        })
    }

    // 删除
    const delCutHandle = (value: any) => {
        delCutRecord.run(value.id).then(res => {
            if (res)
                gitCutRecordList?.refresh()
        })
    }

    // 确定
    const handleOk = async () => {
        form.submit()
        let data1 = await form.validateFields()
        let proms = { ...data1, beginTime: moment(data1.beginTime).format('YYYY-MM-DD') + ' 00:00:00' }
        if (data1.endTime) {
            proms.endTime = moment(data1.endTime).format('YYYY-MM-DD') + ' 00:00:00'
        }
        if (title === '插入起始记录' || title === '向后插入记录') {
            let param = {}
            if (title === '插入起始记录') {
                param = { ...proms, resourceId: data.id }
            } else {
                param = { ...proms, resourceId: addQueryPlatForm?.resourceId, lastChangeRecordId: addQueryPlatForm?.lastChangeRecordId }
            }
            insertCutRecord.run(param).then(res => {
                if (res) {
                    setShow(false)
                    gitCutRecordList?.refresh()
                }
            })
        } else if (title === '修改记录') {
            editCutRecord.run({ ...proms, resourceId: addQueryPlatForm?.resourceId, id: addQueryPlatForm?.id }).then(res => {
                if (res) {
                    setShow(false)
                    gitCutRecordList?.refresh()
                }
            })
        }
    }

    return <div>
        <Drawer title={data?.resourceName} placement="right" width={'85%'} onClose={() => { onClose && onClose() }} visible={visible}>
            <div style={{ marginBottom: 10 }}>
                <Button type="primary" icon={<PlusOutlined />} onClick={() => { handleCutRecord() }}>插入起始记录</Button>
            </div>
            <Tables
                className="changeRecord"
                columns={columnsCr({ insertDownHandle, delCutHandle })}
                dataSource={gitCutRecordList?.data?.records}
                total={gitCutRecordList?.data?.total}
                loading={gitCutRecordList?.loading}
                pageChange={pageChange}
                sizeChange={pageChange}
                current={gitCutRecordList?.data?.current}
                pageSize={gitCutRecordList?.data?.size}
                size={'small'}
                scroll={{ x: 1200 }}
            />
        </Drawer>

        <Modal title={title} visible={show} onOk={handleOk} onCancel={() => { setShow(false); setAddQueryPlatForm(null) }} width={600} confirmLoading={insertCutRecord.loading || editCutRecord.loading}>
            <Form
                name="basic"
                form={form}
                autoComplete="off"
                layout="vertical"
                initialValues={{ ...addQueryPlatForm }}
            >
                <Row gutter={10}>
                    <Col span={8}>
                        <Form.Item label="开始时间" name="beginTime" rules={[{ type: 'object' as const, required: true, message: '请选择开始时间!' }]}>
                            <DatePicker />
                        </Form.Item>
                    </Col>
                    <Col span={8}>
                        <Form.Item label="结束时间" name="endTime">
                            <DatePicker />
                        </Form.Item>
                    </Col>
                    <Col span={8}>
                        <Form.Item label="项目组" name="businessGroupId">
                            <Select placeholder="选择项目组">
                                {businessGroupALL?.data?.map((item: { id: number, businessGroupName: string }) => <Select.Option value={item.id} key={item.id}>{item.businessGroupName}</Select.Option>)}
                            </Select>
                        </Form.Item>
                    </Col>
                </Row>

                <Row gutter={10}>
                    <Col span={8}>
                        <Form.Item label="运营" name="operUserId">
                            <Select placeholder="选择运营">
                                {getAllUserList?.data?.map((item: { userId: number, nickname: string }) => <Select.Option value={item.userId} key={item.userId}>{item.nickname}</Select.Option>)}
                            </Select>
                        </Form.Item>
                    </Col>
                    <Col span={8}>
                        <Form.Item label="投手" name="putUserId">
                            <Select placeholder="选择投手">
                                {getAllUserList?.data?.map((item: { userId: number, nickname: string }) => <Select.Option value={item.userId} key={item.userId}>{item.nickname}</Select.Option>)}
                            </Select>
                        </Form.Item>
                    </Col>
                    <Col span={8}>
                        <Form.Item label="期数" name="periodId">
                            <Select placeholder="选择期数">
                                {getPeriodALL?.data?.map((item: { id: number, period: string }) => <Select.Option value={item.id} key={item.id}>{item.period}</Select.Option>)}
                            </Select>
                        </Form.Item>
                    </Col>
                </Row>

                <Row gutter={10}>
                    <Col span={8}>
                        <Form.Item label="书城" name="platformId">
                            <Select placeholder="选择书城" onChange={(e) => getBookAccount(e as any)}>
                                {allBookCity?.data?.map((item: { id: number, platformName: string }) => <Select.Option value={item.id} key={item.id}>{item.platformName}</Select.Option>)}
                            </Select>
                        </Form.Item>
                    </Col>
                    <Col span={8}>
                        <Form.Item label="账号" name="platformAccountId">
                            <Select placeholder="选择账号" disabled={!platformId}>
                                {platformAll?.data?.map((item: { id: number, account: string }) => <Select.Option value={item.id} key={item.id}>{item.account}</Select.Option>)}
                            </Select>
                        </Form.Item>
                    </Col>
                    <Col span={8}>
                        <Form.Item label="书" name="bookId">
                            <Select placeholder="选择书">
                                {getBookALL?.data?.map((item: { id: number, bookName: string }) => <Select.Option value={item.id} key={item.id}>{item.bookName}</Select.Option>)}
                            </Select>
                        </Form.Item>
                    </Col>
                </Row>

                <Row gutter={10}>
                    <Col span={8}>
                        <Form.Item label="投放状态" name="putStatus">
                            <Select placeholder="选择投放状态">
                                <Select.Option value="wait">待投放</Select.Option>
                                <Select.Option value="ing">投放中</Select.Option>
                                <Select.Option value="stop">停投</Select.Option>
                                <Select.Option value="destroy">账号已注销</Select.Option>
                            </Select>
                        </Form.Item>
                    </Col>
                    <Col span={8}>
                        <Form.Item label="投放渠道" name="putChannel">
                            <Select placeholder="选择投放渠道">
                                <Select.Option value="MP">MP</Select.Option>
                                <Select.Option value="GDT">GDT</Select.Option>
                                <Select.Option value="头条">头条</Select.Option>
                                <Select.Option value="企微">企微</Select.Option>
                            </Select>
                        </Form.Item>
                    </Col>
                    <Col span={8}>
                        <Form.Item label="充值模板" name="rechargeTemplate">
                            <Input placeholder="输入充值模板" />
                        </Form.Item>
                    </Col>
                </Row>
            </Form>
        </Modal>
    </div>
}

export default React.memo(ChangeRecord)