import { Button, Col, Popconfirm, Row, Tag, Tooltip } from "antd"
import React from "react"


const statusTypes = {
    'wait': { label: '待投放', value: 'wait', type: 'warning' },
    'ing': { label: '投放中', value: 'ing', type: 'success' },
    'stop': { label: '停投', value: 'stop', type: 'processing' },
    'destroy': { label: '账号已注销', value: 'destroy', type: 'error' }
}
const columnsCr = (props?: { insertDownHandle: (data: any, type: string) => void, delCutHandle: (data: any) => void }) => {
    return [
        {
            title: '开始时间',
            dataIndex: 'beginTime',
            key: 'beginTime',
            align: 'center',
            width: 100,
            fixed: 'left',
        },
        {
            title: '结束时间',
            dataIndex: 'endTime',
            key: 'endTime',
            align: 'center',
            fixed: 'left',
            width: 100
        },
        {
            title: '资源名称',
            dataIndex: 'resourceName',
            key: 'resourceName',
            width: 100,
            ellipsis: true,
            align: 'center',
            render: (a: any, b: any) => {
                return <span>{b?.resourceInfo.resourceName || '<空>'}</span>
            }
        },
        {
            title: '资源标识',
            dataIndex: 'resourceKey',
            key: 'resourceKey',
            align: 'center',
            width: 100,
            ellipsis: true,
            render: (a: any, b: any) => {
                return <span>{b?.resourceInfo.resourceKey || '<空>'}</span>
            }
        },
        {
            title: '项目组',
            dataIndex: 'businessGroupInfo',
            key: 'businessGroupInfo',
            align: 'center',
            width: 100,
            ellipsis: true,
            render: (a: any) => {
                return <span>{a?.businessGroupName || '<空>'}</span>
            }
        },
        {
            title: '运营',
            dataIndex: 'operUserInfo',
            key: 'operUserInfo',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return a?.nickname ? <Tooltip title={<span>电话：{a?.phone}</span>}>
                    <span>{a?.nickname || '<空>'}</span>
                </Tooltip> : <span>{'<空>'}</span>
            }
        },
        {
            title: '投手',
            dataIndex: 'putUserInfo',
            key: 'putUserInfo',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return a?.nickname ? <Tooltip title={<span>电话：{a?.phone}</span>}>
                    <span>{a?.nickname || '<空>'}</span>
                </Tooltip> : <span>{'<空>'}</span>
            }
        },
        {
            title: '投放状态',
            dataIndex: 'putStatus',
            key: 'putStatus',
            align: 'center',
            width: 80,
            render: (a: any) => {
                return statusTypes[a] && <Tag color={statusTypes[a]?.type}>{statusTypes[a]?.label}</Tag>
            }
        },
        {
            title: '投放渠道',
            dataIndex: 'putChannel',
            key: 'putChannel',
            align: 'center',
            width: 75
        },
        {
            title: '期数',
            dataIndex: 'periodInfo',
            key: 'periodInfo',
            align: 'center',
            width: 100,
            ellipsis: true,
            render: (a: any) => {
                return <span>{a?.period || '<空>'}</span>
            }
        },
        {
            title: '当前书籍',
            dataIndex: 'bookInfo',
            key: 'bookInfo',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return a ? <Tooltip title={<>
                    <div style={{ fontSize: '13px' }}>
                        <strong>来源：</strong>
                        <span>{a?.source}-{a?.author}</span>
                    </div>
                    <div style={{ fontSize: '13px' }}>
                        <strong>信息：</strong>
                        <span>{a?.protagonist}-{a?.channel}</span>
                    </div>
                </>}>
                    <span>{a?.bookName || '<空>'}</span>
                </Tooltip> : <span>{'<空>'}</span>
            }
        },
        {
            title: '书城信息',
            dataIndex: 'platformInfo',
            key: 'platformInfo',
            align: 'center',
            width: 100,
            ellipsis: true,
            render: (a: any) => {
                return <span>{a?.platformName || '<空>'}</span>
            }
        },
        {
            title: '充值模板',
            dataIndex: 'rechargeTemplate',
            key: 'rechargeTemplate',
            align: 'center',
            width: 100,
            ellipsis: true,
            render: (a: any) => {
                return <span>{a || '<空>'}</span>
            }
        },
        {
            title: '账号',
            dataIndex: 'platformAccountInfo',
            key: 'platformAccountInfo',
            align: 'center',
            width: 100,
            ellipsis: true,
            render: (a: any) => {
                return <span>{a?.account || '<空>'}</span>
            }
        },
        {
            title: '操作人',
            dataIndex: 'createUser',
            key: 'createUser',
            align: 'center',
            width: 100,
            ellipsis: true,
            render: (a: any) => {
                return <span>{a?.nickname || '<空>'}</span>
            }
        },
        {
            title: '备注',
            dataIndex: 'remark',
            key: 'remark',
            align: 'center',
            ellipsis: true,
            width: 150
        },
        {
            title: '操作',
            dataIndex: 'cz',
            key: 'cz',
            width: 200,
            fixed: 'right',
            render: (a: string, b: any) => (
                <Row gutter={[10, 0]}>
                    <Col><Button type="link" size="small" style={{ fontSize: 12 }} onClick={() => { props?.insertDownHandle(b, '向后插入') }}>往后插入</Button></Col>
                    <Col><Button type="link" size="small" style={{ fontSize: 12 }} onClick={() => { props?.insertDownHandle(b, '修改') }}>修改</Button></Col>
                    <Col>
                        <Popconfirm
                            title="确定删除?"
                            onConfirm={() => { props?.delCutHandle(b) }}
                            okText="Yes"
                            cancelText="No"
                        >
                            <Button type="link" size="small" style={{ color: 'red', fontSize: 12 }}>删除</Button>
                        </Popconfirm>
                    </Col>
                </Row>
            )
        }
    ]
}

export default columnsCr