import { DatePicker, Form, Input, Modal, Select } from "antd";
import moment from "moment";
import React, { useEffect, useState } from "react";
import { useModel } from "umi";


type Props = {
    data?: any,
    title?: string,
    visible?: boolean,
    onChange?: () => void,
    onClose?: () => void
}
function CutBook(props: Props) {
    const { data, visible, onChange, onClose, title = '切书切平台' } = props
    const { businessGroupALL, getBookALL, getPeriodALL, allBookCity, platformAll, cutBookPlatform } = useModel('useOperating.useAccountyyb')
    const [form] = Form.useForm()
    const [platformId, setPlatformId] = useState<number | undefined>(data?.platformId)

    // 获取期数 书 分组
    useEffect(() => {
        console.log('data--->', data)
        getAll()
        platformAll.run(data?.platformId)
    }, [])

    const handleOk = async () => {
        form.submit()
        let data1 = await form.validateFields()
        let proms = { ...data1, beginTime: moment(data1.beginTime).format('YYYY-MM-DD') + ' 00:00:00' }
        cutBookPlatform.run({ ...proms, resourceId: data.resourceId }).then((res: any) => {
            if (res) {
                onChange && onChange()
            }
        })
    }

    const getAll = () => {
        businessGroupALL.run()
        getBookALL.run()
        getPeriodALL.run()
        allBookCity.run()
    }

    // 获取账号
    const getBookAccount = async (platformId: any) => {
        setPlatformId(platformId as any)
        platformAll.run(platformId)
        let dataForm = await form.validateFields()
        form.setFieldsValue({ ...dataForm, platformAccountId: undefined })
    }

    return <Modal title={title} visible={visible} onOk={handleOk} onCancel={() => { onClose && onClose() }} width={450} confirmLoading={cutBookPlatform.loading}>
        <Form
            name="basic"
            form={form}
            labelCol={{ span: 5 }}
            wrapperCol={{ span: 19 }}
            autoComplete="off"
            initialValues={{ ...data }}
        >
            <Form.Item label="开始时间" name="beginTime" rules={[{ type: 'object' as const, required: true, message: '请选择开始时间!' }]}>
                <DatePicker />
            </Form.Item>
            <Form.Item label="期数" name="periodId">
                <Select placeholder="选择期数">
                    {getPeriodALL?.data?.map((item: { id: number, period: string }) => <Select.Option value={item.id} key={item.id}>{item.period}</Select.Option>)}
                </Select>
            </Form.Item>
            <Form.Item label="书城" name="platformId">
                <Select placeholder="选择书城" onChange={(e) => getBookAccount(e as any)}>
                    {allBookCity?.data?.map((item: { id: number, platformName: string }) => <Select.Option value={item.id} key={item.id}>{item.platformName}</Select.Option>)}
                </Select>
            </Form.Item>
            <Form.Item label="账号" name="platformAccountId">
                <Select placeholder="选择账号" disabled={!platformId}>
                    {platformAll?.data?.map((item: { id: number, account: string }) => <Select.Option value={item.id} key={item.id}>{item.account}</Select.Option>)}
                </Select>
            </Form.Item>
            <Form.Item label="书" name="bookId">
                <Select placeholder="选择书" showSearch filterOption={(input, option) =>
                    (option!.children as unknown as string)?.toLowerCase()?.includes(input.toLowerCase())
                }>
                    {getBookALL?.data?.map((item: { id: number, bookName: string }) => <Select.Option value={item.id} key={item.id}>{item.bookName}</Select.Option>)}
                </Select>
            </Form.Item>
            <Form.Item label="项目组" name="businessGroupId">
                <Select placeholder="选择项目组">
                    {businessGroupALL?.data?.map((item: { id: number, businessGroupName: string }) => <Select.Option value={item.id} key={item.id}>{item.businessGroupName}</Select.Option>)}
                </Select>
            </Form.Item>
            <Form.Item label="投放状态" name="putStatus">
                <Select placeholder="选择投放状态">
                    <Select.Option value="wait">待投放</Select.Option>
                    <Select.Option value="ing">投放中</Select.Option>
                    <Select.Option value="stop">停投</Select.Option>
                    <Select.Option value="destroy">账号已注销</Select.Option>
                </Select>
            </Form.Item>
            <Form.Item label="投放渠道" name="putChannel">
                <Select placeholder="选择投放渠道">
                    <Select.Option value="MP">MP</Select.Option>
                    <Select.Option value="GDT">GDT</Select.Option>
                    <Select.Option value="头条">头条</Select.Option>
                    <Select.Option value="企微">企微</Select.Option>
                </Select>
            </Form.Item>
            <Form.Item label="充值模板" name="rechargeTemplate">
                <Input placeholder="输入充值模板" />
            </Form.Item>
            <Form.Item label="备注" name="remark">
                <Input placeholder="输入备注" />
            </Form.Item>
        </Form>
    </Modal>
}

export default React.memo(CutBook)