import GroupYybTabs from "@/components/GroupWxTabs/yyb"
import Tables from "@/components/Tables"
import React, { useCallback, useEffect, useState } from "react"
import columns from './tableConfig'
import './index.less'
import { useModel } from "umi"
import { KyyListProps } from '@/services/operating/accountyyb'
import CutBook from './cutBook'
import ChangeRecord from "./changeRecord"
import moment from "moment"
import { Button, Input, Select, Space } from "antd"
import { SearchOutlined } from "@ant-design/icons"

function KyyBoxManage() {

    const { getKyyList, getPeriodALL } = useModel('useOperating.useAccountyyb')
    const { userId } = useModel('useOperating.useUser', model => ({ userId: model.state.selectdUserIdYyb }))
    const [queryPlatform, setQueryPlatform] = useState<KyyListProps>({ pageNum: 1, pageSize: 10, userId, resourceType: 10 })  // 获取G参数
    const [cutShow, setCutShow] = useState<boolean>(false)
    const [data, setData] = useState<{
        beginTime: any,
        periodId: number | undefined,
        platformId: number | undefined,
        platformAccountId: number | undefined,
        bookId: number | undefined,
        businessGroupId: number | undefined,
        putStatus: 'wait' | 'ing' | 'stop' | 'destroy',
        putChannel: 'MP' | 'GDT' | '头条' | '企微',
        rechargeTemplate: string | undefined,
        remark: string | undefined,
        resourceId: number | undefined,
    }>({
        beginTime: undefined,
        periodId: undefined,
        platformId: undefined,
        platformAccountId: undefined,
        bookId: undefined,
        businessGroupId: undefined,
        putStatus: 'wait',
        putChannel: 'MP',
        rechargeTemplate: undefined,
        remark: undefined,
        resourceId: undefined
    })
    const [title, setTitle] = useState<string>('切书切平台')
    const [crShow, setCrShow] = useState<boolean>(false) // 变更记录
    const [crData, setCrData] = useState<any>({}) // 变更记录数据

    // 切换key换接口数据
    useEffect(() => {
        getList()
    }, [queryPlatform, userId])
    // 获取数据
    const getList = () => {
        getKyyList.run({ ...queryPlatform, userId })
    }

    useEffect(() => {
        getAll()
    }, [])

    const getAll = () => {
        getPeriodALL.run()
    }

    // 分页
    const pageChange = useCallback((page: string | number, pageSize?: string | number) => {
        setQueryPlatform({ ...queryPlatform, pageNum: page as number, pageSize: pageSize as number })
    }, [queryPlatform])

    // 切书切平台
    const cutBook = (data: any) => {
        setTitle(data?.resourceName + '切书切平台')
        const { periodId, platformId, platformAccountId, bookId, id, businessGroupId, putStatus, putChannel, rechargeTemplate } = data
        setData({ beginTime: moment(), remark: '', periodId, platformId, platformAccountId, bookId, resourceId: id, businessGroupId, putStatus, putChannel, rechargeTemplate })
        setCutShow(true)
    }

    const changeRecord = (data: any) => {
        setCrShow(true)
        setCrData(data)
    }

    // 关闭弹窗
    const closeCutShow = () => {
        setData({
            beginTime: undefined,
            periodId: undefined,
            platformId: undefined,
            platformAccountId: undefined,
            bookId: undefined,
            businessGroupId: undefined,
            putStatus: 'wait',
            putChannel: 'MP',
            rechargeTemplate: undefined,
            remark: undefined,
            resourceId: undefined
        })
        setCutShow(false)
    }

    return <div>
        {cutShow && <CutBook data={data} title={title} visible={cutShow} onChange={() => { closeCutShow(); getKyyList.refresh() }} onClose={() => { closeCutShow() }} />}
        {crShow && <ChangeRecord visible={crShow} data={crData} onChange={() => { }} onClose={() => { setCrShow(false) }} />}

        <Space style={{ marginBottom: 10 }}>
            <Input value={queryPlatform?.resourceName} allowClear onChange={(e) => { setQueryPlatform({ ...queryPlatform, resourceName: e.target.value }) }} placeholder="输入应用包名" />
            <Select placeholder="选择期数" showSearch filterOption={(input, option) =>
                option?.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
            } style={{ width: 150 }} allowClear value={queryPlatform?.periodId} onChange={(e) => setQueryPlatform({ ...queryPlatform, periodId: e })}>
                {getPeriodALL?.data?.map((item: { id: number, period: string }) => <Select.Option value={item.id} key={item.id}>{item.period}</Select.Option>)}
            </Select>
            <Button type="primary" icon={<SearchOutlined />} onClick={getList}>搜索</Button>
        </Space>
        <GroupYybTabs>
            <Tables
                columns={columns({ cutBook, changeRecord })}
                dataSource={getKyyList?.data?.records}
                total={getKyyList?.data?.total}
                loading={getKyyList?.loading}
                pageChange={pageChange}
                sizeChange={pageChange}
                current={getKyyList?.data?.current}
                pageSize={getKyyList?.data?.size}
                rowClassName='authStatus'
                size={'small'}
                scroll={{ x: 1200 }}
            />
        </GroupYybTabs>
    </div>
}

export default KyyBoxManage