import { FileSearchOutlined, SwapOutlined } from "@ant-design/icons"
import { Button, Col, Row, Tag, Tooltip } from "antd"
import React from "react"

const resourceTypes = {
    '0': { label: '公众号', value: 0, type: 'magenta' },
    '1': { label: '小程序', value: 1, type: 'orange' },
    '3': { label: '企业微信', value: 3, type: 'green' },
    '10': { label: '快应用', value: 10, type: 'purple' }
}
const statusTypes = {
    'wait': { label: '待投放', value: 'wait', type: 'warning' },
    'ing': { label: '投放中', value: 'ing', type: 'success' },
    'stop': { label: '停投', value: 'stop', type: 'processing' },
    'destroy': { label: '账号已注销', value: 'destroy', type: 'error' }
}
const columns = (props: { cutBook: (data: any) => void, changeRecord: (data: any) => void }) => {
    return [
        {
            title: '应用包名',
            dataIndex: 'resourceName',
            key: 'resourceName',
            width: 120,
            fixed: 'left',
            ellipsis: true
        },
        {
            title: '项目组',
            dataIndex: 'businessGroupInfo',
            key: 'businessGroupInfo',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return <span>{a?.businessGroupName || '<空>'}</span>
            }
        },
        {
            title: '运营',
            dataIndex: 'operUserInfo',
            key: 'operUserInfo',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return a?.nickname ? <Tooltip title={<span>电话：{a?.phone}</span>}>
                    <span>{a?.nickname || '<空>'}</span>
                </Tooltip> : <span>{'<空>'}</span>
            }
        },
        {
            title: '投手',
            dataIndex: 'putUserInfo',
            key: 'putUserInfo',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return a?.nickname ? <Tooltip title={<span>电话：{a?.phone}</span>}>
                    <span>{a?.nickname || '<空>'}</span>
                </Tooltip> : <span>{'<空>'}</span>
            }
        },
        {
            title: '投放状态',
            dataIndex: 'putStatus',
            key: 'putStatus',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return statusTypes[a] && <Tag color={statusTypes[a]?.type}>{statusTypes[a]?.label}</Tag>
            }
        },
        {
            title: '投放渠道',
            dataIndex: 'putChannel',
            key: 'putChannel',
            align: 'center',
            width: 100
        },
        {
            title: '期数',
            dataIndex: 'periodInfo',
            key: 'periodInfo',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return <span>{a?.period || '<空>'}</span>
            }
        },
        {
            title: '当前书籍',
            dataIndex: 'bookInfo',
            key: 'bookInfo',
            align: 'center',
            width: 100,
            ellipsis: true,
            render: (a: any) => {
                return a ? <Tooltip title={<>
                    <div style={{ fontSize: '13px' }}>
                        <strong>来源：</strong>
                        <span>{ a?.source }-{ a?.author }</span>
                    </div>
                    <div style={{ fontSize: '13px' }}>
                        <strong>信息：</strong>
                        <span>{ a?.protagonist }-{ a?.channel }</span>
                    </div>
                </>}>
                    <span>{a?.bookName || '<空>'}</span>
                </Tooltip> : <span>{'<空>'}</span>
            }
        },
        {
            title: '充值模板',
            dataIndex: 'rechargeTemplate',
            key: 'rechargeTemplate',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return <span>{a || '<空>'}</span>
            }
        },
        {
            title: '书城',
            dataIndex: 'platformInfo',
            key: 'platformInfo',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return <span>{a?.platformName || '<空>'}</span>
            }
        },
        {
            title: '账号',
            dataIndex: 'platformAccountInfo',
            key: 'platformAccountInfo',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return <span>{a?.account || '<空>'}</span>
            }
        },
        {
            title: '创建时间',
            dataIndex: 'createTime',
            key: 'createTime',
            align: 'center',
            width: 150
        },
        {
            title: '操作',
            dataIndex: 'cz',
            key: 'cz',
            width: 250,
            fixed: 'right',
            render: (a: string, b: any) => (
                <Row gutter={[10, 0]}>
                    <Col><Button type="link" size="small" icon={<SwapOutlined />} onClick={() => { props?.cutBook(b) }}>切书切平台</Button></Col>
                    <Col><Button type="link" size="small" icon={<FileSearchOutlined />} onClick={() => { props?.changeRecord(b) }}>变更记录</Button></Col>
                </Row>
            )
        }
    ]
}

export default columns