import React, { useCallback, useEffect, useMemo,  useRef, useState } from 'react'
import { Card, Tabs, Row, Col, Button, Divider, message, Spin } from 'antd'
import { ScbdBox, ScwxBox } from '../ScBox'
import { PlusCircleOutlined, UndoOutlined } from '@ant-design/icons'
import DrawerPage from "@/components/FileBox/components/newsModal"
import { useModel, history } from 'umi'
import style from './index.less'
import Synthetic from '@/components/MaterialModal/synthetic'

function ContentPage() {
    /**群发返回逻辑 */
    let query: any = history.location.query
    const [key, setKey] = useState<string>(query?.key ? '图文素材' : '图片')//tabkey
    const [refreshNum, setRefreshNum] = useState<number>(1) //翻页当前页
    let refM: { current: { onOpen: () => void, onCancel: () => void } } | any = useRef()//获取Modal实例方法
    let refD: { current: { showDrawer: (props?: any) => void } } | any = useRef()//DrawerPage获取实例方法
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const { collapsed } = useModel('@@initialState', model => ({ collapsed: model.initialState?.collapsed }))
    const [columnArr, setColumnArr] = useState<any[]>([])
    const [queryForm, setQueryForm] = useState<{pageNum: number, pageSize: number}>({pageNum: 1, pageSize: 20})

    /**请求 */
    const { actionKey, delData, getData, update, dispatch, allData } = useModel('useOperating.useMaterialContent', model => ({
        actionKey: model.actionKey,
        delData: model.delWxData,
        getData: model.getWeData,
        mediaType: model.state.mediaType,
        update: model.update,
        dispatch: model.dispatch,
        allData: model.state.allData
    }))
    let config: any = {
        '图文素材': 'news',
        '视频': 'video',
        '音频': 'voice',
        '图片': 'image'
    }
    useEffect(() => {
        setTimeout(() => {
            let w = document.getElementsByClassName('ant-layout')[1].clientWidth - 336
            let column = Math.floor(w / (key === '图文素材' ? 330 : 280))
            let arr: any[] = []
            Array(column).fill('').forEach((a, b) => {
                arr.push(b)
            })
            setColumnArr(arr)
        }, 0)
    }, [key, collapsed])
    /**
     * 获取当前类型
     */
    let type = useMemo(() => {
        return config[key]
    }, [key])
    //起始获取数据
    useEffect(() => {
        if(query?.key) {
            setKey(query?.key ? '图文素材' : '图片')
            dispatch({ type: 'initData' })
            setRefreshNum(1)
            if (actionWX?.id) {
                getData.run({ mpId: actionWX.id, mediaType: query?.key ? 'news' : 'image', pageNum: 1, pageSize: 20 }).then((res) => {
                    if (res) {
                        dispatch({ type: 'addData', params: { data: res.records } })
                    }
                })
            }
        }
    }, [actionWX?.id])
    //删除素材
    let delBox = useCallback((id: number, data: any[]) => {
        delData.run(id).then((res) => {
            if (res) {
                let newArr: any = data.filter((item: { id: number }) => item.id !== id)
                dispatch({ type: 'initData', params: { data: newArr } })
            }
        })
    }, [])
    //新增素材
    let add = useCallback(() => {
        key !== '图文素材' ? message.warning('请去本地素材新建并同步!') : refD?.current.showDrawer()
    }, [key])
    //同步最新数据
    let sync = useCallback(() => {
        update.run({ mpId: actionWX?.id, mediaType: type }).then((res) => {
            if (res) {
                getData.run({ mediaType: type, mpId: actionWX.id, pageNum: 1, pageSize: 20 }).then((res) => {
                    if (res) {
                        setRefreshNum(1)
                        dispatch({ type: 'initData', params: { data: res.records } })
                    }
                })
            }
        })
    }, [update, actionWX?.id, type])
    //tabs点击
    let tabChange = useCallback((key: string) => {
        dispatch({ type: 'initData' })
        actionKey(key)
        getData.mutate([])
        setKey(key)
        setRefreshNum(1)
    }, [actionWX])
    useEffect(() => {
        getData.run({ mediaType: type, mpId: actionWX.id, pageNum: 1, pageSize: 20 }).then((res) => {
            if (res) {
                dispatch({ type: 'addData', params: { data: res.records } })
            }
        })
        return () => {
            dispatch({ type: 'initData' })
        }
    }, [type, actionWX?.id])
    //滚动监听
    let onScrollCapture = useCallback((e: any) => {
        if (getData.loading) {
            return
        }
        let isbottom = Math.ceil(e.target.scrollHeight - e.target.scrollTop) === e.target.clientHeight//到底部
        if (isbottom && !getData.loading) {
            let total = getData.data?.total;//总条数
            let dataLength = allData.length;//数据量
            let isType = false
            if (Array.isArray(getData.data?.records)) {
                isType = type == getData.data?.records[0]?.mediaType//是否是正确的数据
            }
            if (total > dataLength) {
                getData.run({ mediaType: type, pageNum: refreshNum + 1, pageSize: 20, mpId: actionWX?.id }).then((res: any) => {
                    if (res) {
                        if (res.records.length > 0) {
                            dispatch({ type: 'addData', params: { data: res.records } })
                            setRefreshNum(refreshNum + 1)
                            message.success('刷新了!', 2)
                        } else {
                            message.error('没有更多数据了!', 2)
                        }

                    }
                })
            } else {
                message.error('没有更多数据了!', 2)
            }
        }
    }, [refreshNum, type, getData, allData, columnArr, actionWX?.id, queryForm])
    return <Card style={{ height: 'calc(100vh - 96px)', width: '100%', overflow: 'hidden' }}>
        <Tabs defaultActiveKey="1" type="card" onChange={tabChange} activeKey={key} className={style.material_tabs}>
            <Tabs.TabPane tab="图文素材" key="图文素材" forceRender>
                <>
                    <Row gutter={[10, 0]} justify='end'>
                        <Col><Button type='primary' onClick={add}><PlusCircleOutlined />新增素材</Button></Col>
                        <Col><Button type='primary' onClick={sync} loading={update?.loading}><UndoOutlined />更新公众号下素材</Button></Col>
                    </Row>
                    <Divider style={{ margin: '12px 0' }} />
                </>
                <Spin spinning={getData.loading} size='large' >
                    <Row style={{ overflowY: 'scroll', height: 'calc(100vh - 270px)', padding: 20, display: 'flex', justifyContent: 'space-evenly' }} id='column' onScrollCapture={onScrollCapture}>
                        {
                            columnArr?.map((n: number) => {
                                return <Col style={{ width: 300 }} key={n}>
                                    {
                                        key === '图文素材' && allData.map((item: any, index: number) => {
                                            if (index % columnArr.length === n) {
                                                return <ScwxBox model={'img'} {...item} showDrawer={refD?.current?.showDrawer} delFnc={delBox} key={item.mediaId + index} />
                                            }
                                            return
                                        })
                                    }
                                </Col>
                            })
                        }
                    </Row>
                </Spin>
                <Synthetic show={() => { refD?.current.showDrawer() }} />
            </Tabs.TabPane>
            {
                ['视频', '音频', '图片'].map((item: string, eq: number) => {
                    let arr: string[] = ['video', 'audio', 'img']
                    return <Tabs.TabPane tab={item} key={item}>
                        <>
                            <Row gutter={[10, 0]} justify='end'>
                                <Col><Button type='primary' onClick={sync} loading={update?.loading}><UndoOutlined />更新公众号下素材</Button></Col>
                            </Row>
                            <Divider style={{ margin: '12px 0' }} />
                        </>
                        <Spin spinning={getData.loading} size='large' >
                            <Row style={{ overflowY: 'scroll', height: 'calc(100vh - 286px)', padding: 20, display: 'flex', justifyContent: 'space-evenly' }} id='column' onScrollCapture={onScrollCapture}>
                                {
                                    columnArr?.map((n: number, index: number) => {
                                        return <Col style={{ width: 250 }} key={Math.random() * 1000}>
                                            {
                                                key === item && allData.map((item: any, index: number) => {
                                                    if (index % columnArr.length === n) {
                                                        return <ScbdBox model={arr[eq]} {...item} open={refM?.current?.onOpen} delFnc={delBox} key={item.mediaId + index} />
                                                    }
                                                    return
                                                })
                                            }
                                        </Col>
                                    })
                                }
                            </Row>
                        </Spin>
                    </Tabs.TabPane >
                })
            }
        </Tabs>
        {/**图文弹窗 */}
        <DrawerPage ref={refD} isWx/>
    </Card >
}

export default ContentPage