import React from 'react'
import { Card, Image, Popconfirm, Spin, Space, message } from 'antd'
import style from './index.less'
import { CopyrightOutlined, DeleteOutlined, EditOutlined, PlusCircleOutlined, SendOutlined, VerticalAlignBottomOutlined } from '@ant-design/icons'
import { useModel, history } from 'umi'
import PreviewModal from '@/components/MaterialModal/previewModal'
import useCopy from '@/Hook/useCopy'
interface Props {
    sysMediaGraphics?: any[],
    appIds: any[],
    name?: string,
    model: 'img' | 'video' | 'audio',
    url: string,
    thumbUrl?: string,
    videoTitle?: string,
    videoDownUrl?: string,
    videoDescription?: string,
    id: number,
    date?: string,
    title: string,
    createTime?: string,
    mediaType: string,
    uploadTime?: string,
    number?: string,
    news?: any,
    appid?: string,
    mediaId?: string,
    allData?: any[],
    classData?: { groupName: string, id: string }[],
    open: (titlename?: string, data?: any) => void,//弹窗回调函数传去数据
    delFnc: (id: number, allData?: any[]) => void,
    // refSync: (param: { id: string, appIds: string[] }) => void,
    showDrawer: (props?: any) => void
}

/**类型转数字*/
const type = {
    news: 'mpnews',
    video: 'mpvideo',
    audio: 'voice',
    img: 'image',
}
export let ScbdBox = React.memo((props: Props) => {
    const { copy } = useCopy()
    const { id, delFnc } = props
    const { allData } = useModel('useOperating.useMaterialContent', model => ({ getWXInfo: model.getWXInfo, allData: model.state.allData }))
    let del = () => {
        delFnc(id, allData)
    }
    let Tags = () => {

        switch (props.model) {
            case 'img':
                return <Image src={props?.url} placeholder />
            case 'video':
                return <video src={props.url} height='130px' controls />
            case 'audio':
                return <audio src={props.url} controls />
            default:
                return <div></div>
                break;
        }
    }
    let Del = () => <Popconfirm
        title="确定要删除吗？"
        onConfirm={del}
        okText="是"
        cancelText="否"
    >
        <DeleteOutlined />
    </Popconfirm>
    let Download = () => {
        return <a href={props?.videoDownUrl} onClick={() => {
            if (!props?.videoDownUrl) {
                message.warning('此视频没有发现下载链接，请点击右上角更新公众号素材后再次尝试下载')
            }
        }}><VerticalAlignBottomOutlined /></a>
    }
    console.log(props)
    return <Card
        hoverable
        className={style.box_card}
        cover={
            <Tags />
        }
        actions={props.model === 'video' ? [
            <PreviewModal data={{ msgType: type[props.model], theEdit: { mediaId: props?.mediaId || '', videoDownUrl: props?.videoDownUrl, videoDescription: props?.videoDescription, videoTitle: props?.videoTitle, mediaType: props?.mediaType, msgType: type[props.model] } }} type='icon' />,
            <Del />,
            <Download />
        ] : [
                <PreviewModal data={{ msgType: type[props.model], theEdit: { mediaId: props?.mediaId || '', url: props?.url, mediaType: props?.mediaType, msgType: type[props.model] } }} type='icon' />,
                <Del />,
            ]}
    >
        <Card.Meta
            style={{ fontSize: 12, padding: 10 }}
            title={props?.videoTitle || props?.name}
            description={<span style={{ display: 'flex', flexFlow: 'column' }}>
                {props?.number && <span onClick={() => { copy(props?.number as string) }}>编号：{props?.number}</span>}
                {props?.createTime && <span>创建：{props?.createTime?.replace(/T|\.000\+0800/ig, ' ')}</span>}
                {props?.uploadTime && <span >更新：{props?.uploadTime?.replace(/T|\.000\+0800/ig, ' ')}</span>}
            </span>}
            className={style.meta}
        />
    </Card>
})


export let ScwxBox = React.memo((props: Props) => {
    const { id, delFnc, mediaId, appid } = props
    const { copy } = useCopy()
    const { drawerDispatch } = useModel('useOperating.useMaterialDrawer', model => ({
        drawerDispatch: model.dispatch,
    }))
    const { addData } = useModel('useOperating.useSynthetic')
    const { getWXInfo, allData } = useModel('useOperating.useMaterialContent', model => ({ getWXInfo: model.getWXInfo, allData: model.state.allData }))
    const { dispatchNews } = useModel('useOperating.useNews', model => ({ dispatchNews: model.dispatch }))
    //删除
    let del = () => {
        delFnc(id, allData)
    }
    //编辑
    let edit = () => {
        getWXInfo.run({ id: props?.id }).then((res) => {
            if (res) {
                if (res?.news) {
                    drawerDispatch({ type: 'actionData', params: { data: { dataArr: res?.news, actionId: 1 } } })
                }
                props?.showDrawer({ isEdit: true, editId: props.mediaId })
                localStorage.setItem('collapsed', '1')
            }
        })
    }
    //群发
    let news = () => {
        getWXInfo.run({ id: props?.id }).then((res) => {
            if (res) {
                if (res?.news) {
                    dispatchNews({ type: 'theEdit', params: { theEdit: { content: { news: res?.news}, mediaId: props.mediaId, msgType: 'mpnews' } } })
                    history.push(`/operatePage/news/advanced?show=true`)
                }
            }
        })
    }
    let Del = () => <Popconfirm
        title="确定要删除吗？"
        onConfirm={del}
        okText="是"
        cancelText="否"
    >
        <DeleteOutlined />
    </Popconfirm>
    let Edit = () => <EditOutlined key="edit" onClick={getWXInfo?.loading ? () => { } : edit} />
    let News = () => <SendOutlined key="news" onClick={news} />
    return <Spin tip='正在请求素材详情，请耐心等待...' spinning={getWXInfo?.loading}>
        <Card
            hoverable
            className={style.box_card}
            bodyStyle={{ padding: 0 }}
            cover={
                (props?.news as any[])?.map((item: any, index: number) => {
                    return <div key={index} className={`${style.img_ScwxBox} ${style.hover_add}`}>
                        <span>{item.title}</span>
                        <Image src={item.thumbMediaUrl} placeholder />
                        <em >
                            <Space>
                                <PlusCircleOutlined onClick={() => {
                                    console.log('item',item)
                                     addData({ ...item, smId: props?.id, mediaId: props?.mediaId, index, smType: '微信' }) }
                                } />
                                <CopyrightOutlined onClick={() => { window.open(item?.url) }} />
                            </Space>
                        </em>
                    </div>
                })
            }
            actions={[
                <Edit />,
                <PreviewModal data={{ msgType: 'mpnews', theEdit: { mediaId: props?.mediaId || '', content: { news: props?.news }, mediaType: props?.mediaType, msgType: 'news', isWx: true } }} type='icon' />,
                <News />,
                <Del />
            ]}
        >
            <Card.Meta
                style={{ fontSize: 12, padding: 10 }}
                // title={props?.title}
                description={<span style={{ display: 'flex', flexFlow: 'column', fontSize: 12 }}>
                    {props?.number && <span onClick={() => { copy(props?.number as string) }}>编号：{props?.number}</span>}
                    {props?.uploadTime && <span >更新：{props?.uploadTime?.replace(/T|\.000\+0800/ig, ' ')}</span>}
                </span>}
                className={style.meta}
            />
        </Card>
    </Spin>
})
