import ActionModal from '@/components/ActionModal'
import WxTextModal from '@/components/MaterialModal/textModal'
import WxDetailsBox from '@/components/WxDetailsBox'
import { PlusOutlined, QuestionCircleFilled } from '@ant-design/icons'
import { Button, Col, DatePicker, Drawer, Input, message, Radio, Row, Space, Tooltip, Switch, Tag, Select, TimePicker, Modal, Checkbox, } from 'antd'
import { RadioChangeEvent } from 'antd/lib/radio'
import React, { useCallback, useEffect, useMemo, useRef, useState } from 'react'
import { useModel, history } from 'umi'
import style from './index.less'
import WxMpnews from '@/components/MaterialModal/wxMpnews'
import moment from 'moment'
import PreviewModal from '@/components/MaterialModal/previewModal'
import { queryObj } from '@/utils/query'
import DrawerPage from '@/components/FileBox/components/newsModal'
import SmMaterialModal from '@/components/MaterialModal/smModalBox'
import FansSelect from '@/components/FansSelect'
import { CheckboxValueType } from 'antd/lib/checkbox/Group'
import MoreModal from '@/components/ActionModal/more'
/**类型转文字*/
const msgConfig = {
    mpnews: '图文',
    text: '文字',
    voice: '语音',
    mpvideo: '视频',
    image: '图片',
    news: '本地图文'
}
/**类型转数字*/
const type = {
    'mpnews': 5,
    'mpvideo': 3,
    'voice': 2,
    'image': 1,
    'text': 4
}
/**类型转派发字段*/
const set = {
    'mpnews': 'graphicVisible',
    'mpvideo': 'msgVisible',
    'voice': 'msgVisible',
    'image': 'msgVisible',
    'text': 'textVisible'
}
type Props = {
    defaultData: any,
    AdvancedDispatch: any,
    /**是否是审查，审查执行审查规则,默认false */
    isReview?: boolean
}
const AddModal = React.memo((props: Props) => {
    const { isReview = false } = props
    const { getActionWX, actionWx, wx } = useModel('useOperating.useWxGroupList', model => ({ getActionWX: model.state.actionWX, actionWx: model.actionWx, wx: model.state.actionWX }))
    const { addMsgGroup, dispatch, state, getMsgGroup, editMsgGroup } = useModel('useOperating.useNews')
    const { catFans } = useModel('useOperating.useFans')
    const [fansNum, setFansNum] = useState<number>(0)
    const [queryShow, setQueryShow] = useState<boolean>(false)
    const { getWXInfo } = useModel('useOperating.useMaterialContent')
    const { get, set: sets } = useModel('useOperating.useBdMedia')
    const [moreVisible, setMoreVisible] = useState<boolean>(false)//批量
    const [mpIds, setMpIds] = useState<any[]>([])//批量
    let refD: { current: { showDrawer: (props?: any) => void } } | any = useRef()//DrawerPage获取实例方法
    const { enabled, triggerType, weekDay, sendTime, actionWX, visible, wxVisible, msgType, theEdit, msgVisible, textVisible, graphicVisible, time, fans, sendIgnoreReprint, mobile, name, mpFansListDto, resDelayHours, resDelayMinutes, resDelaySecond, id } = state
    const [fansSelectValue, setFansSelectValue] = useState<any>(null)
    const { userId }: { userId: any } = useModel('@@initialState', model => ({ userId: model.initialState?.currentUser?.userId }))
    let userIds = [68, 45, 50, 49, 61, 43, 228, 1, 56, 57,154,242]
    const [actionId, setActionId] = useState<number>()
    const [linksSR, setLinksSR] = useState<any>({})
    const [executionType,setExecutionType] = useState<0|1>(0)
    useEffect(() => {
        let query: any = history.location.query
        setQueryShow(!!query.show)
    }, [])
    /**
   * 假如没有选中微信弹窗选择
   * */
    useEffect(() => {
        let isOk = !!props?.defaultData || !!history.location.query?.show
        if (isOk) {
        } else {
            dispatch({ type: 'wxShow', params: { show: true } })
        }
    }, [])
    /**是否开启图文编辑内容按钮 */
    let isShowEditBtn = useMemo(() => {
        console.log(props?.defaultData)
        //逻辑 是编辑关闭 或者 是素材库跳转开启 或者 编辑的素材ID 不等于 新选择的素材ID开启
        return !props?.defaultData && !!history.location.query?.show && props?.defaultData?.localMediaId !== theEdit?.content?.id
    }, [theEdit])
    /**
   * 编辑处理数据
   */
    useEffect(() => {
        let query: any = history.location.query
        history.location.query = {} //拿到query后清空不然会出现bug导致退出编辑新建无法执行下面逻辑
        if (!query.show) {//假如不是从素材过来的就初始化数据
            if (props?.defaultData) {//初始设置选中微信,方便其他依赖组件
                setExecutionType(props?.defaultData?.executionType || 0)
                dispatch({ type: 'initData', params: props?.defaultData })//初始数据
                actionWx({ appid: props?.defaultData?.mpInfo?.appid, id: props?.defaultData?.mpInfo?.id, nickName: props?.defaultData?.mpInfo?.nickName, headImg: props?.defaultData?.mpInfo?.headImg, serviceTypeInfo: props?.defaultData?.mpInfo?.serviceTypeInfo })
            }
        }
    }, [props?.defaultData])

    /**
     * 设置选中微信
     */
    useEffect(() => {
        console.log('getActionWX',getActionWX)
        if (getActionWX) {
            dispatch({ type: 'setActionWX', params: { actionWX: getActionWX } })
        }
    }, [getActionWX])
    /**
    * 消息类型选择
    * */
    const handelMgsType = useCallback((e: RadioChangeEvent) => {
        dispatch({ type: 'msgType', params: { msgType: e.target.value } })
    }, [])
    /**
     * 日期
     * */
    const setDate = useCallback((m: any, date: string) => {
        console.log(date)
        dispatch({ type: 'setDate', params: { sendTime: date } })
    }, [time])
    /**
     * 快捷设置时间
     * */
    const handelSetTime = useCallback((e: RadioChangeEvent) => {
        let type = e.target.value
        if (type === 4) {
            dispatch({ type: 'setFans', params: { fans: 1 } })
        }
        dispatch({ type: 'triggerType', params: { triggerType: type } })
    }, [])
    /**
   * 时分
   * */
    const setTime = useCallback((moment: any, time: string) => {
        dispatch({ type: 'setTime', params: { time } })
    }, [])
    /**
     * 选择微信后台权限
     * */
    const handelWxRules = useCallback((e: RadioChangeEvent) => {
        let v = e.target.value
        dispatch({ type: 'setRules', params: { rules: v } })
    }, [])
    /**
     * 粉丝选择
     * */
    const handelFans = useCallback((e: RadioChangeEvent) => {
        let v = e.target.value
        dispatch({ type: 'setFans', params: { fans: v } })
    }, [])
    /**
     * 粉丝性别
     */
    const handleSex = useCallback((e: CheckboxValueType[]) => {
        dispatch({ type: 'setMpFansListDto', params: { sex: e } })
    }, [])
    /**
     * 任务名称
     */
    const handleName = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let name = e.target.value
        dispatch({ type: 'setName', params: { name } })
    }, [])
    /**
     * 设置手机号
     */
    const handlePhone = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let mobile = e.target.value
        dispatch({ type: 'setPhone', params: { mobile } })
    }, [])
    /**
     * 图文消息被判定为转载时，是否继续群发
     */
    const handleSendIgnoreReprint = useCallback((SwitchChangeEventHandler) => {
        let sendIgnoreReprint = SwitchChangeEventHandler
        dispatch({ type: 'setSendIgnoreReprint', params: { sendIgnoreReprint } })
    }, [])
    /**图文消息编辑回调 */
    const newsCallback = useCallback((data) => {
        dispatch({ type: 'theEdit', params: { theEdit: { content: data, msgType, ...data } } })
    }, [])
    /**图文素材详情获取并存放 */
    const newsDetail = useCallback((data: any) => {
        if (data?.mediaId) {//微信素材
            getWXInfo.run({ id: data?.id, isCon: true }).then(res => {
                console.log(res, 'wx')
                res?.content?.news((item: any, index: number) => {
                    item['menuId'] = index + 1
                })
                dispatch({ type: 'theEdit', params: { theEdit: { content: res, msgType, ...res } } })
            })
        } else {//本地
            get.run(data?.id).then((res) => {
                console.log(res, 'bd')
                res?.content?.news((item: any, index: number) => {
                    item['menuId'] = index + 1
                })
                dispatch({ type: 'theEdit', params: { theEdit: { content: res, msgType, ...res } } })
            })
        }
        dispatch({ type: 'graphicVisible' })
    }, [msgType])
    /**发送消息 */
    const handleSubmit = useCallback(() => {
        let { msgType, theEdit, time, rules, sendIgnoreReprint, mobile, id, name, sendTime, weekDay, triggerType, resDelayHours, resDelayMinutes, resDelaySecond } = state
        let push = id ? editMsgGroup : addMsgGroup
        time = moment(time, 'HH:mm').format('HH:mm')
        if (!theEdit) {
            message.error('请选择素材')
            return
        }
        if (!name) {
            message.error('请输入任务名称')
            return
        }
        if (!sendTime && triggerType === 1) {
            message.error('请选择时间')
            return
        }
        if (actionWX) {
            let textContent = ''
            theEdit?.textContent?.forEach((key: string, index: number) => {
                textContent += `${key.replace(/_href/ig, 'href')}${index !== theEdit?.textContent.length - 1 ? '<br/>' : ''}`
            })
            console.log(theEdit)
            let data: any = {//外层
                name,//策略名称
                msgType,//消息类型
                mobile,//通知手机
                sendIgnoreReprint,
                mpId: actionWX?.id,//公众号本地ID
                // toAll: !!fans,//是否群发所有粉丝
                rules,
                enabled,//开关启停
                expectSend: fansNum,
                msgGroupStrategyContent: theEdit?.content?.news
            }
            //只有当选中了标签或者性别才添加toAll = flase
            if (!fans) {
                data['fansAll'] = false
            } else {
                data['fansAll'] = true//是否群发所有粉丝
            }
            if (theEdit?.content?.news) {//图文
                data['msgGroupStrategyContent'] = {
                    news: theEdit?.content?.news
                }
            }
            if (theEdit?.fileType === 'video' || theEdit?.msgType === 'video' || theEdit?.msgType === 'mpvideo') {//视频
                data['msgGroupStrategyContent'] = {
                    videoDescription: theEdit?.videoDescription,//视频描述
                    videoTitle: theEdit?.videoTitle,//视频标题
                    url: theEdit?.url,//链接
                }
            }
            if (theEdit?.msgType === 'text' || theEdit?.fileType === 'text') {//文本
                data['msgGroupStrategyContent'] = {
                    textContent
                }
            }
            console.log(theEdit, theEdit?.fileType, theEdit?.msgType)
            if (theEdit?.fileType === 'image' || theEdit?.fileType === 'voice' || theEdit?.msgType === 'image' || theEdit?.msgType === 'voice') {//图片或音频
                data['msgGroupStrategyContent'] = {
                    title: theEdit?.title,//标题
                    url: theEdit?.url,//链接
                }
            }
            data['msgGroupStrategyContent'] = {
                ...data?.msgGroupStrategyContent,
                mediaType: theEdit?.fileType || theEdit?.msgType,//类型

            }
            if (theEdit?.mediaId && !theEdit?.content?.news) {
                data['msgGroupStrategyContent'] = {
                    ...data?.msgGroupStrategyContent,
                    wxMediaId: theEdit?.mediaId
                }
            }
            //内容处理
            if (id) {//编辑加上ID
                data['msgGroupStrategyContent'] = {
                    ...data?.msgGroupStrategyContent,
                    msgGroupStrategyId: id,
                }
                data['strategyId'] = id
            }

            //发送时间处理
            switch (triggerType) {//发送方式处理
                case 1:
                    data['triggerType'] = 1
                    data['sendTime'] = sendTime.length === 16 ? sendTime + ':00' : sendTime//特定时间
                    break;
                case 2:
                    data['triggerType'] = 2
                    data['time'] = time//时分
                    break;
                case 3:
                    data['triggerType'] = 2
                    data['weekDay'] = weekDay//周几
                    data['time'] = time//时分
                    break;
                case 4:
                    data['triggerType'] = 3
                    data['resDelayHours'] = resDelayHours
                    data['resDelayMinutes'] = resDelayMinutes
                    data['resDelaySecond'] = resDelaySecond
                    break;
                default:
                    data['triggerType'] = 0
            }
            data = { ...data, ...fansSelectValue,executionType }
            console.log(data?.msgGroupStrategyContent?.news)
            if (!id && mpIds?.length > 1) {//假如是新增那么就批量,并且批量
                mpIds?.forEach((item) => {
                    let newData = JSON.parse(JSON.stringify(data))
                    if (linksSR[item.id]) {
                        newData?.msgGroupStrategyContent?.news?.forEach((i: { contentSourceUrl: string }, index: number) => {
                            if (i.contentSourceUrl !== linksSR[item.id][index]) {
                                i.contentSourceUrl = linksSR[item.id][index]
                            }
                        })
                    }
                    push.run({ ...newData, mpId: item.id }).then((res) => {
                        if (res) {
                            dispatch({ type: 'initData' })//初始数据
                            getMsgGroup.refresh().then((res) => {
                            })
                            props.AdvancedDispatch({ type: 'setDefaultData', params: { defaultData: null } })
                            /**假如存在query.ptah就是从素材而来*/
                            let query: { ptah?: string, key?: string, isPublic?: string, mediaId?: string } = queryObj(history.location.search)
                            if (query?.ptah) {
                                history.push(`${query?.ptah}?key=${query?.key}${query?.isPublic ? '&isPublic=' + query?.isPublic : ''}`)
                            }
                        }
                    })
                })
            } else {
                push.run(data).then((res) => {
                    if (res) {
                        dispatch({ type: 'initData' })//初始数据
                        getMsgGroup.refresh().then((res) => {
                        })
                        props.AdvancedDispatch({ type: 'setDefaultData', params: { defaultData: null } })
                        /**假如存在query.ptah就是从素材而来*/
                        let query: { ptah?: string, key?: string, isPublic?: string, mediaId?: string } = queryObj(history.location.search)
                        if (query?.ptah) {
                            history.push(`${query?.ptah}?key=${query?.key}${query?.isPublic ? '&isPublic=' + query?.isPublic : ''}`)
                        }
                    }
                })
            }
        } else {//发送数据没有微信选中弹窗选择
            dispatch({ type: 'wxShow', params: { show: true } })
        }
    }, [addMsgGroup, state, actionWX, fansNum, fansSelectValue, fans, mpIds, linksSR,executionType])
    /** 获取筛选粉丝数量*/
    useEffect(() => {
        if (actionWX) {
            if (!fans && fansSelectValue && Object.values(fansSelectValue).some((value: any) => {
                return ( value !== '' && JSON.stringify(value) !== '[]')
            })) {
                catFans.run({ mpId: actionWX?.id, fansAll: false, ...fansSelectValue }).then((res) => {
                    setFansNum(res)
                })
            } else {
                catFans.run({ mpId: actionWX?.id, fansAll: true }).then((res) => {
                    setFansNum(res)
                })
            }
        }
    }, [fansSelectValue, actionWX, fans])
    return <div>
        <Drawer
            title={<span><img src={wx?.headImg || localStorage.bookImg} style={{ width: 40 }} /> <span style={{ marginLeft: 10 }}>{wx?.nickName}</span>--群发消息</span>}
            placement="right"
            width='90%'
            onClose={() => {
                dispatch({ type: 'initData' })//初始数据
                props.AdvancedDispatch({ type: 'setDefaultData', params: { defaultData: null } })
                if (!isReview) {
                    history.push('/operatePage/news/advanced')
                }
            }}
            visible={visible}
            destroyOnClose
            footer={
                <div className={style.drawer_footer}>
                    <Space>
                        <Button onClick={() => {
                            dispatch({ type: 'initData' })
                            props.AdvancedDispatch({ type: 'setDefaultData', params: { defaultData: null } })
                            if (!isReview) {
                                history.push('/operatePage/news/advanced')
                            }
                        }
                        } >取消</Button>
                        {!isReview && <Button onClick={handleSubmit} type="primary" loading={editMsgGroup?.loading || addMsgGroup?.loading}>保存</Button>}
                        <PreviewModal data={{ ...state, mpIds: [actionWX] }} />
                    </Space>
                </div>
            }
        >
            <div className={style.box} >
                <div className={style.left}>
                    <Row className={style.left_content}>
                        {moreVisible && <MoreModal
                            visible={moreVisible}
                            hideWx={() => {
                                setMoreVisible(false)
                            }}
                            ok={(arr: any[]) => {
                                setMpIds(arr)
                                setMoreVisible(false)
                                if (arr.length > 0) {
                                    setActionId(arr[0].id)
                                } else {
                                    setActionId(undefined)
                                }
                            }}
                            defaultDtat={mpIds?.length > 0 ? mpIds : [actionWX]}
                            isSelect
                        />}
                        {!id && (userIds?.some(id => id == userId || localStorage.getItem('vip'))) && <Button type='primary' size='middle' onClick={() => {
                            setMoreVisible(true)
                        }}>私人定制</Button>}
                        <Col className={style.left_wx}>
                            <label >选择公众号：</label>
                            {
                                mpIds?.length > 0 ? mpIds?.map((item) => {
                                    return <div key={item.id} onClick={() => { setActionId(item?.id);actionWx(item) }} className={item.id === actionId ? style?.ck : {}}>
                                        <img src={item?.headImg || localStorage.bookImg} style={{ width: 25 }} />
                                        <span style={{ marginLeft: 10 }}>{item?.nickName}</span>
                                    </div>
                                })
                                    : <div onClick={props?.defaultData || queryShow ? () => { } : () => dispatch({ type: 'wxShow', params: { show: true } })}>
                                        <img src={actionWX?.headImg || localStorage.bookImg} style={{ width: 25 }} />
                                        <span style={{ marginLeft: 10 }}>{actionWX?.nickName}</span>
                                    </div>
                            }
                            <ActionModal visible={wxVisible} hideWx={() => dispatch({ type: 'wxShow', params: { show: false } })} />
                        </Col>
                        <Col>
                            <div className={style.name}>
                                <label>任务名称：</label>
                                <Input placeholder='输入20字以内的任务名称' maxLength={20} value={name} onChange={handleName} />
                            </div>
                        </Col>
                        <Col className={style.left_msgType}>
                            <div>
                                <label>消息类型：</label>
                                <Radio.Group onChange={queryShow ? () => { } : handelMgsType} value={msgType} disabled={props?.defaultData}>
                                    <Radio value='mpnews'>图文消息</Radio>
                                    <Radio value='image'>图片消息</Radio>
                                    <Radio value='text'>文字消息</Radio>
                                    <Radio value='voice'>语音消息</Radio>
                                    <Radio value='mpvideo'>视频消息</Radio>
                                </Radio.Group>
                            </div>
                            <div onClick={queryShow || props?.defaultData ? () => { } : () => {
                                dispatch({ type: set[msgType] })
                                if (msgType === 'mpnews') {
                                    console.log(1)
                                    sets({ fileType: 'news' })
                                }
                            }} className={style.span}>
                                {
                                    props?.defaultData ? <strong style={{ color: 'red' }}>编辑状态不允许修改素材!</strong> : <>
                                        {
                                            theEdit?.msgType === msgType ?
                                                <div style={{ display: 'flex', justifyContent: 'center', flexFlow: 'column', alignItems: 'center' }}>
                                                    <span>你已选中一条{msgConfig[msgType]}消息<a>[修改]</a></span>
                                                    <strong style={{ color: 'red' }}>群发消息一旦创建完成，素材将无法编辑修改！</strong>
                                                </div>
                                                :
                                                <div style={{ display: 'flex', justifyContent: 'center', flexFlow: 'column', alignItems: 'center' }}>
                                                    <span> <PlusOutlined style={{ marginRight: 10 }} />请点击选择{msgConfig[msgType]}消息</span>
                                                    <strong style={{ color: 'red' }}>群发消息一旦创建完成，素材将无法编辑修改！</strong>
                                                </div>
                                        }
                                    </>
                                }

                            </div>
                        </Col>
                        <Col className={style.left_fans}>
                            <div>
                                <label>群发粉丝：</label>
                                <Radio.Group onChange={handelFans} value={fans}>
                                    <Radio value={0} disabled={actionWX?.serviceTypeInfo !== 2 || triggerType === 4}>按条件筛选粉丝</Radio>
                                    <Radio value={1}>全部粉丝<span>符合条件约<i>{fansNum || 0}</i> 人（如与实际粉丝数差别大，请同步粉丝）</span></Radio>
                                </Radio.Group>
                            </div>
                            {
                                fans === 0 && <Row>
                                    {/* <Col>
                                        <label>性别：</label>
                                        <Checkbox.Group onChange={handleSex} value={mpFansListDto.sex}>
                                            <Checkbox value="all">全部</Checkbox>
                                            <Checkbox value={1}>男</Checkbox>
                                            <Checkbox value={2}>女</Checkbox>
                                            <Checkbox value={0}>未知</Checkbox>
                                        </Checkbox.Group>
                                    </Col> */}
                                    {/* <Col>
                                        <TagSelect
                                            labelWith={100}
                                            change={(obj: { tagType: number, tagIds: any[] }) => {
                                                dispatch({ type: 'setMpFansListDto', params: { ...obj } })
                                            }}
                                            value={mpFansListDto}
                                        />
                                    </Col> */}
                                    <Col>
                                        <FansSelect callback={setFansSelectValue} defaultValue={props?.defaultData} />
                                    </Col>
                                </Row>
                            }
                        </Col>
                        <Col>
                            <div>
                                <label>微信后台授权：</label>
                                <Radio.Group
                                    onChange={handelWxRules}
                                    value={fans}
                                >
                                    <Radio value={1} disabled={fans === 0}>
                                        <Space>
                                            出现在微信后台已群发消息
                                        <Tooltip
                                                title='可以在微信后台改错别字或者单条删除（删除高危图文可能降低微信审查风险），有订阅号每天1条、服务号每月4条的“发送”限制'
                                            >
                                                <QuestionCircleFilled />
                                            </Tooltip>
                                        </Space>

                                    </Radio>
                                    <Radio value={0} disabled={fans === 1}>
                                        <Space>
                                            不出现在微信后台已群发消息
                                        <Tooltip
                                                title='不可以改错别字或者单条删除，没有发送次数限制，但粉丝有订阅号每天1条、服务号每月4条的“接收”限制'
                                            >
                                                <QuestionCircleFilled />
                                            </Tooltip>
                                        </Space>
                                    </Radio>
                                </Radio.Group>
                            </div>
                        </Col>
                        <Col className={style.left_time}>
                            <div>
                                <label>发送方式：</label>
                                <div>
                                    <Radio.Group onChange={handelSetTime}
                                        value={triggerType}
                                    >
                                        <Radio value={2}>每日</Radio>
                                        <Radio value={3}>每周</Radio>
                                        <Radio value={1}>特定时间</Radio>
                                        <Radio value={4}>关注延迟指定时间<strong style={{ color: 'red' }}>(仅支持全部粉丝)</strong></Radio>
                                    </Radio.Group>
                                </div>
                            </div>
                            <div />
                        </Col>
                        {
                            triggerType !== 0 && <Col className={style.left_time}>
                                <div>
                                    <label>发送时间：</label>
                                    <div>
                                        {triggerType === 3 && <Select
                                            value={weekDay}
                                            onChange={(a: any) => { dispatch({ type: 'setWeekDay', params: { weekDay: a } }) }}
                                            style={{ marginLeft: 8 }}
                                        >
                                            <Select.Option value={1}>周一</Select.Option>
                                            <Select.Option value={2}>周二</Select.Option>
                                            <Select.Option value={3}>周三</Select.Option>
                                            <Select.Option value={4}>周四</Select.Option>
                                            <Select.Option value={5}>周五</Select.Option>
                                            <Select.Option value={6}>周六</Select.Option>
                                            <Select.Option value={7}>周日</Select.Option>
                                        </Select>
                                        }
                                        {(triggerType === 3 || triggerType === 2) && <TimePicker
                                            value={time ? moment(time, 'HH:mm') : undefined}
                                            format={'HH:mm'}
                                            onChange={setTime}
                                            style={{ width: 90, marginLeft: 8 }}
                                        />}
                                        {
                                            triggerType === 1 && < Space >
                                                <DatePicker
                                                    disabledDate={(current) => {
                                                        let tppday = current && current < moment().startOf('day')
                                                        return tppday
                                                    }}
                                                    format={'YYYY-MM-DD HH:mm'}
                                                    disabledTime={(date) => {//禁选时分秒
                                                        let upDate = moment(date).format('YYYY-MM-DD')//选中的年月日
                                                        let upHours = moment(date).format('HH')//选中的时
                                                        let upMinutes = moment(date).format('mm')//选中的分
                                                        let atDate = moment(new Date()).format('YYYY-MM-DD')//今天的年月日
                                                        let atHours = moment(new Date()).format('HH')//现在的时
                                                        let atMinutes = moment(new Date()).format('mm')//现在的分
                                                        // let atSeconds = moment(new Date()).format('ss')//现在的秒
                                                        let range = (num: number, at: string) => {
                                                            if (upDate == atDate) {//假如选中时间的今天
                                                                let arr: number[] = []
                                                                Array(num).fill('').forEach((a, b) => { if (b < Number(at)) { arr.push(b) } })
                                                                return arr
                                                            } else {
                                                                return []
                                                            }
                                                        }
                                                        let minutes = (num: number, at: string) => {
                                                            if (upDate == atDate) {//假如选中时间的今天
                                                                let arr: number[] = []
                                                                if (upHours == atHours) {
                                                                    Array(num).fill('').forEach((a, b) => { if (b < Number(at)) { arr.push(b) } })
                                                                }
                                                                return arr
                                                            } else {
                                                                return []
                                                            }
                                                        }
                                                        return {
                                                            disabledHours: () => range(24, atHours),
                                                            disabledMinutes: () => minutes(60, atMinutes),
                                                            // disabledSeconds: () => minutes(60, atSeconds),
                                                        }
                                                    }}
                                                    showTime
                                                    value={sendTime ? moment(sendTime) : undefined}
                                                    onChange={setDate}
                                                />
                                                {
                                                    moment(sendTime).format('YYYY-MM-DD') === moment(new Date()).format('YYYY-MM-DD') && <strong style={{ color: 'red' }}>*三块钱友情提示：当前特定时间选择日期为今天！选错是要扣分的！</strong>
                                                }
                                            </Space>
                                        }
                                        {//不是订阅号才可以
                                            triggerType === 4 && actionWX?.serviceTypeInfo !== 0 && actionWX?.serviceTypeInfo !== 1 && <div>
                                                <Input
                                                    addonAfter="时"
                                                    style={{ width: 75 }}
                                                    size='small'
                                                    value={resDelayHours}
                                                    onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
                                                        let v = Number(event.target.value)
                                                        if (isNaN(v)) {
                                                            message.error('请输入数字')
                                                            return
                                                        } else {
                                                            dispatch({ type: 'setTime3', params: { resDelayHours: v } })
                                                        }
                                                    }}
                                                />
                                                <Input
                                                    addonAfter="分"
                                                    style={{ width: 75 }}
                                                    size='small'
                                                    value={resDelayMinutes}
                                                    onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
                                                        let v = Number(event.target.value)
                                                        if (isNaN(v)) {
                                                            message.error('请输入数字')
                                                            return
                                                        } else {
                                                            dispatch({ type: 'setTime3', params: { resDelayMinutes: v } })
                                                        }
                                                    }}
                                                />
                                                <Input
                                                    addonAfter="秒"
                                                    style={{ width: 75 }}
                                                    size='small'
                                                    value={resDelaySecond}
                                                    onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
                                                        let v = Number(event.target.value)
                                                        if (isNaN(v)) {
                                                            message.error('请输入数字')
                                                            return
                                                        } else {
                                                            dispatch({ type: 'setTime3', params: { resDelaySecond: v } })
                                                        }
                                                    }}
                                                />
                                            </div>
                                        }
                                    </div>
                                </div>
                                <div />
                            </Col>
                        }
                        <Col className={style.left_phone}>
                            <div>
                                <label>手机号：</label>
                                <Space>
                                    <Input placeholder='选填' value={mobile} onChange={handlePhone} maxLength={11} type='tel' autoComplete='on' />
                                    <Tooltip
                                        title='手机号用于特殊情况下发送失败后接收通知短信。'
                                    >
                                        <QuestionCircleFilled />
                                    </Tooltip>
                                    <Switch checkedChildren="开启" unCheckedChildren="关闭" defaultChecked={sendIgnoreReprint} onChange={handleSendIgnoreReprint} checked={sendIgnoreReprint} />
                                    若有文章判定为转载，继续群发
                                </Space>
                            </div>
                            <div>
                                <Tag color="orange">受微信接口限制，因原创问题停止群发的文章，仍会显示发送成功.</Tag>
                            </div>
                        </Col>
                        <Col>
                            <div style={{ display: 'flex' }}>
                                <label>消息状态：</label>
                                <div>
                                    <Switch
                                        checkedChildren="启用"
                                        unCheckedChildren="暂停"
                                        defaultChecked={!!enabled}
                                        onChange={(checked) => { dispatch({ type: 'setEnabled', params: { enabled: checked } }) }}
                                    />
                                </div>
                            </div>
                            <div />
                        </Col>
                        <Col>
                            <div style={{ display: 'flex' }}>
                                <label>消息模式：</label>
                                <div>
                                    <Radio.Group onChange={(e: RadioChangeEvent)=>{setExecutionType(e.target.value)}}
                                        value={executionType}
                                    >
                                        <Radio value={0}>群发</Radio>
                                        <Radio value={1}>预览</Radio>
                                    </Radio.Group>
                                </div>
                            </div>
                            <div />
                        </Col>
                    </Row>
                </div>
                <div className={style.right}>
                    <WxDetailsBox data={theEdit} isShowEdit={!props?.defaultData} showDrawer={refD?.current?.showDrawer} isShowEditBtn={!props?.defaultData} actionId={actionId} linsFn={setLinksSR} />
                </div>
                {msgConfig[msgType] !== '文字' && msgConfig[msgType] !== '图文' && msgConfig[msgType] && msgVisible && <SmMaterialModal
                    visible={visible}
                    onCancel={() => dispatch({ type: 'msgVisible' })}
                    title={`选择${msgConfig[msgType]}`}
                    onOk={(props: any) => {
                        console.log(props)
                        dispatch({ type: 'theEdit', params: { theEdit: { ...props, msgType } } })
                        dispatch({ type: 'msgVisible' })
                        // handleOk(props, config[key])
                    }}
                    mediaType={type[msgType]}
                    isShowWx={true}
                    isAllData
                    noFile
                />
                }
                {msgConfig[msgType] === '文字' && <WxTextModal
                    visible={textVisible}
                    onCancel={() => dispatch({ type: 'textVisible' })}
                    onOK={(data: any) => {
                        dispatch({ type: 'theEdit', params: { theEdit: { ...data, msgType } } })
                        dispatch({ type: 'textVisible' })
                    }}
                    defaultData={theEdit}
                    fansName={false}
                    hdLink={false}
                />}
                {msgConfig[msgType] === '图文' && graphicVisible && <WxMpnews
                    visible={graphicVisible}
                    onCancel={() => dispatch({ type: 'graphicVisible' })}
                    onOK={(data: any) => {
                        newsDetail(data)
                    }}
                    defaultData={theEdit}
                    wx={actionWX}
                    isNews={true}
                />}
                {/**图文弹窗 */}
                {<DrawerPage ref={refD} isShowWx={true} styleRight={-180} callback={newsCallback} />}
            </div>
        </Drawer>
    </div>
}, (a, b) => {
    if (JSON.stringify(a) === JSON.stringify(b)) {
        return true
    }
    return false
})

export default AddModal