import DatePickePage from '@/components/DatePicker'
import Tables from '@/components/Tables'
import { Button, Drawer, Input, Select, Space } from 'antd'
import React, { useCallback, useEffect, useState } from 'react'
import { columns } from './tableConfig'
import style from './index.less'
import { useModel, history } from 'umi'
import { SelectValue } from 'antd/es/select'
import { useReducer } from 'react'
import WxDetailsBox from '@/components/WxDetailsBox'
import AddModal from './components/addModal'
import { PlusOutlined } from '@ant-design/icons'
const { Option } = Select;
import GroupWxTabs from '@/components/GroupWxTabs/wx'
import NoFoundPage from '@/pages/empty'
import { SearchOutlined } from '@ant-design/icons';
import { expandedRowRender } from './sonTableConfig'
import './table.less'

type State = {
    visible: boolean,//弹窗开启与否
    defaultData: any,//编辑填数据
    theEditer: any,//当前查看数据栏
    del: boolean,//删除开启
    drawerVis: boolean,//日志弹窗
    logsData: any[],//日志数据
}
export type Action = {
    type: 'show' | 'setDefaultData' | 'theEditer' | 'del' | 'drawerVis' | 'logsData',
    params?: any
}
function reducer(state: State, action: Action) {
    let { type, params } = action
    let { defaultData } = state
    switch (type) {
        case 'show':
            return { ...state, visible: !state.visible }
        case 'setDefaultData':
            if (params?.defaultData) {
                return { ...state, defaultData: { ...defaultData, ...params.defaultData } }
            }
            return { ...state, defaultData: params.defaultData }
        case 'theEditer':
            return { ...state, theEditer: params.theEditer }
        case 'del':
            return { ...state, del: params.del }
        case 'drawerVis':
            return { ...state, drawerVis: params.drawerVis }
        case 'logsData':
            return { ...state, logsData: params.logsData }
        default:
            return state;
    }
}
function Advanced() {
    const [state, dispatch] = useReducer(reducer, { visible: false, defaultData: null, theEditer: null, del: false, drawerVis: false, logsData: [] })
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const { visible, defaultData, del, drawerVis, logsData } = state
    const { getMsgGroup, get, addDispath, show, deletes, refresh, catlog, enabledFnc, getDetail, delLog, restart, executionNow } = useModel('useOperating.useNews', model => ({
        getMsgGroup: model.getMsgGroup,
        deletes: model.delMsgGroup,
        get: model.getMsgGroup,
        addDispath: model.dispatch,
        show: model.state.visible,
        refresh: model.refresh,
        stateNews: model.state,
        catlog: model.catlog,
        enabledFnc: model.enabled,
        getDetail: model.getDetail,
        delLog: model.delLog,
        restart: model.restart,
        executionNow: model.executionNow
    }))
    const [data, setData] = useState<{ appName: string; date: string | string[]; state: SelectValue, name: string }>({
        appName: '',
        date: '',
        state: '',
        name: ''
    })
    const { getWXInfo } = useModel('useOperating.useMaterialContent', model => ({ getWXInfo: model.getWXInfo }))

    //编辑详情打开时查询详情信息插入数据
    const showModal = useCallback((data: any, type: number) => {
        getDetail.run(data.id).then((res) => {
            let { mediaInfo, msgType, mediaId, triggerType, weekDay } = res
            let newtriggerType = triggerType === 3 ? 4 : triggerType === 2 && weekDay ? 3 : triggerType
            if (data.msgType === 'text') {
                let theEdit = { textContent: mediaInfo?.textContent?.replace(/href/ig, '_href').split('<br/>'), msgType }
                dispatch({ type: 'setDefaultData', params: { defaultData: { ...res, theEdit, triggerType: newtriggerType } } })
                switch (type) {
                    case 1:
                        dispatch({ type: 'show' })
                        break;
                    case 2:
                        dispatch({ type: 'show' })
                        dispatch({ type: 'del', params: { del: true } })
                        break;
                    default:
                        addDispath({ type: 'show' })
                        break;
                }
            } else {
                let { name, url, title, videoTitle, videoDescription } = mediaInfo
                let theEdit = {
                    url: url,
                    title: name || title,
                    msgType,
                    mediaId,
                    content: mediaInfo,//NEWS使用
                }
                if (msgType === 'mpvideo') {
                    theEdit['title'] = videoTitle
                    theEdit['videoTitle'] = videoTitle
                    theEdit['videoDescription'] = videoDescription
                }
                if (msgType === 'mpnews' || msgType === 'image') {
                    dispatch({ type: 'setDefaultData', params: { defaultData: { ...res, theEdit, triggerType: newtriggerType } } })
                    switch (type) {
                        case 1:
                            dispatch({ type: 'show' })
                            break;
                        case 2:
                            dispatch({ type: 'show' })
                            dispatch({ type: 'del', params: { del: true } })
                            break;
                        default:
                            addDispath({ type: 'show' })
                            break;
                    }
                } else {
                    dispatch({ type: 'setDefaultData', params: { defaultData: { ...res, theEdit, triggerType: newtriggerType } } })
                    switch (type) {
                        case 1:
                            dispatch({ type: 'show' })
                            break;
                        case 2:
                            dispatch({ type: 'show' })
                            dispatch({ type: 'del', params: { del: true } })
                            break;
                        default:
                            addDispath({ type: 'show' })
                            break;
                    }
                }
            }
        })
    }, [getWXInfo, dispatch, addDispath])
    // 搜索
    const search = useCallback(() => {
        const { appName, date, state, name } = data
        let param = {}
        if (appName != "") {
            param['appName'] = appName
        }
        if (date != "") {
            param['date'] = date
        }
        if (state != 'all') {
            param['executionStatus'] = state
        }
        name && (param['name'] = name)
        getMsgGroup.run({ pageSize: 20, pageNum: 1, appId: actionWX?.id, ...param })
    }, [data, actionWX])
    //状态选择
    const handelSelect = useCallback((value: SelectValue) => {
        setData({ ...data, state: value === 'all' ? '' : value })
    }, [getMsgGroup, actionWX])
    //时间搜索
    const DatePickerChange = useCallback((moment: any, date: string | string[]) => {
        setData({ ...data, date })
    }, [getMsgGroup, actionWX])
    //首次加载搜索
    useEffect(() => {
        if (actionWX) {
            getMsgGroup.run({ pageSize: 20, pageNum: 1, appId: actionWX?.id })
        }
    }, [actionWX])
    // 执行日志打开
    const journalHandle = useCallback((strategyId: number) => {
        dispatch({ type: 'drawerVis', params: { drawerVis: true } })
        catlog.run(strategyId).then((data) => {
            dispatch({ type: 'logsData', params: { logsData: data } })
        })
    }, [])//userId
    //删除日志
    const dellogs = useCallback((id: any) => {
        delLog.run(id).then((res) => {
            console.log(res)
        })
    }, [catlog])
    /**开关 */
    const SwitchChange = useCallback((enabled: boolean, strategyId: number) => {
        enabledFnc.run({ strategyId, enabled }).then((data) => {
            getMsgGroup.refresh()
        })
    }, [getMsgGroup])//getKefuMsgStrategy, userId
    //首次加载是否从素材过来
    useEffect(() => {
        let query: any = history.location.query
        if (query?.show) {
            addDispath({ type: 'show' })
        }
    }, [])
    //高级群发分页
    const pageSize = useCallback((page: number, pageSize?: number) => {
        getMsgGroup.run({ appId: actionWX?.id, pageSize: pageSize, pageNum: page })
    }, [actionWX])
    return <>
        {
            actionWX ? <div>
                <div className={style.header}>
                    <Space>
                        <Select style={{ width: 150 }} defaultValue={'all'} onChange={handelSelect}>
                            <Option value={'all'}>全部状态</Option>
                            <Option value={0}>待发送</Option>
                            <Option value={1}>已发送</Option>
                            <Option value={2}>发送成功</Option>
                            <Option value={3}>发送失败</Option>
                        </Select>
                        <DatePickePage model='DatePicker' DatePickerChange={DatePickerChange} isDisabledDate={false} />
                        {/* <Input placeholder='请输入公众号' value={data.appName} onChange={e => setData({ ...data, appName: e.target.value })} allowClear /> */}
                        <Input placeholder='请输入任务名称' value={data.name} onChange={e => setData({ ...data, name: e.target.value })} allowClear />
                        <Button type="primary" size='middle' icon={<SearchOutlined type="primary" />} onClick={search} loading={getMsgGroup.loading}>搜索</Button>
                    </Space>
                    <Button
                        type='primary'
                        onClick={() => {
                            addDispath({ type: 'show' })
                        }}><PlusOutlined />新增群发策略</Button>
                    {show && <AddModal defaultData={defaultData} AdvancedDispatch={dispatch} />}
                </div>
                <GroupWxTabs isDisabled={false}>
                    <Tables
                        className="newsTabls"
                        dataSource={getMsgGroup?.data?.records || []}
                        columns={columns({ del: deletes, show: showModal, get, getWXInfo, refresh, journalHandle, SwitchChange, restart, executionNow })}
                        // expandedRowRender={expandedRowRender}
                        total={getMsgGroup?.data?.total}
                        current={getMsgGroup?.data?.current}
                        pageChange={pageSize}
                        sizeChange={pageSize}
                        scroll={{ x: 1000 }}
                        rowClassName={(record: any) => {
                            if (record?.checkStatus === -1) {
                                return 'error expanded'
                            } else {
                                return "expanded"
                            }
                        }}
                    />
                </GroupWxTabs>
                <Drawer
                    title="内容详情"
                    placement="right"
                    width={400}
                    closable={false}
                    onClose={() => {
                        dispatch({ type: 'show' })
                        dispatch({ type: 'del', params: { del: false } })
                        dispatch({ type: 'setDefaultData', params: { defaultData: null } })
                    }}
                    visible={visible}
                    destroyOnClose
                >
                    <WxDetailsBox data={{ ...defaultData?.theEdit, mpStrategyDeletes: defaultData?.mpStrategyDeletes, id: defaultData?.id }} del={del} newsDispatch={dispatch} />
                </Drawer>
                <Drawer
                    title="执行日志"
                    placement='top'
                    onClose={() => dispatch({ type: 'drawerVis', params: { drawerVis: false } })}
                    visible={drawerVis}
                    height='450'
                >
                    <Tables
                        dataSource={catlog?.data}
                        columns={expandedRowRender({ delLog, dellogs, refresh, catlog })}
                        size='small'
                    />
                </Drawer>
            </div> : <NoFoundPage />
        }
    </>
}

export default Advanced