import { Badge, Button, Popconfirm, Space, Switch, Tag, Tooltip } from 'antd'
import React from 'react'

import { newsTypeStrColor } from '@/utils/dictionary'
import { bgColor } from '@/utils/color'
import Look from '../../examine/components/look'
type Props = {
    getWXInfo: any,
    del: any,
    get: any,
    show: any,
    refresh: any,
    journalHandle: (id: number) => void,
    SwitchChange: any,
    restart: any,
    executionNow: any
}
let sex = ['未知', '男', '女']
export const columns = (props: Props) => {
    const { getWXInfo, del, get, show, journalHandle, SwitchChange, restart, executionNow } = props

    return [
        {
            title: '任务标题',
            dataIndex: 'name',
            key: 'name',
            align: 'center',
            width: 200,
            render: (a: number, b: any) => {
                return <div>
                    {b.checkStatus === -1 ? <Tooltip title={`未通过原因：${b?.checkRemark ? b?.checkRemark : ''}`}>
                        <div>
                            <div>{a}</div>
                            <div><span style={{ color: 'red', fontSize: 12 }}>(审查未通过)</span></div>
                        </div>
                    </Tooltip> : <span>{a}</span>}
                </div>
            }
        },
        {
            title: '公众号',
            dataIndex: 'appName',
            key: 'appName',
            align: 'center',
            width: 180,
            render: (a: string, b: { mpInfo: any }) => {
                return <span><img src={b?.mpInfo?.headImg || localStorage.bookImg} style={{ width: 25 }} /> <span style={{ marginLeft: 10 }}>{b?.mpInfo?.nickName}</span></span>
            }
        },
        {
            title: '消息模式',
            dataIndex: 'executionType',
            key: 'executionType',
            align: 'center',
            width: 100,
            render: (a: any) => {
                return a === 0 ? '群发模式' : '预览模式'
            }
        },
        {
            title: '消息类型',
            dataIndex: 'msgType',
            key: 'msgType',
            align: 'center',
            width: 100,
            render: (a: string) => {
                return <Tag color={newsTypeStrColor[a]?.color}>{newsTypeStrColor[a]?.text}</Tag>
            }
        },
        {
            title: '创建时间',
            dataIndex: 'createTime',
            key: 'createTime',
            align: 'center',
            width: 120,
            render: (a: any, b: any) => {
                return b?.createTime ? b?.createTime : ''
            }
        },
        {
            title: '发送方式',
            dataIndex: 'triggerType',
            key: 'triggerType',
            align: 'center',
            width: 180,
            render: (a: number, b: { time: string, sendTime: string, weekDay: number, fansFilterSex: number, resDelayHours: number, resDelayMinutes: number, resDelaySecond: number }) => {
                let type = ['立即发送', '特定时间']
                let weekType = ['', '周一', '周二', '周三', '周四', '周五', '周六', '周日']
                let msg = ''
                let sj = ''
                let time = b?.resDelayHours || b?.resDelayMinutes || b?.resDelaySecond
                if (type[a]) {
                    msg = type[a]
                    if (a === 1) {
                        sj = b?.sendTime
                    }
                } else {
                    if (b?.weekDay) {
                        msg = '每周'
                        sj = weekType[b?.weekDay] + b?.time
                    } else {
                        msg = '每日'
                        sj = b?.time
                    }
                }

                return <div style={{ display: 'flex', flexFlow: 'column ' }}>
                    {
                        a === 3 ? <>
                            <span>关注延迟指定时间</span>
                            <span>{time ? `${b?.resDelayHours ? b?.resDelayHours + '小时' : ''} ${b?.resDelayMinutes ? b?.resDelayMinutes + '分' : ''}${b?.resDelaySecond}秒` : '立即发送'}</span>
                        </> : <>
                            <span>{msg}</span>
                            {sj && <span>{sj}</span>}
                        </>
                    }
                </div>

            }
        },
        {
            title: '发送对象',
            dataIndex: 'toAll',
            key: 'toAll',
            align: 'center',
            width: 120,
            render: (a: boolean, b: { fansFilterTags: any, sex: number, tagType: number }) => {
                if (a) {
                    return '全部粉丝'
                } else {
                    return <div style={{ display: 'flex', flexFlow: 'column ' }}>
                        <span>性别：{b?.sex !== null ? sex[b?.sex] : '全部'}</span>
                        <span>
                            {
                                b?.tagType === 0 ? '类型：并集' : b?.tagType === 1 ? '类型：交集' : b?.tagType === 2 ? '类型：取反' : ''
                            }
                        </span>
                        {
                            b?.fansFilterTags?.length > 0 && <span>
                                标签：{
                                    b?.fansFilterTags?.map((item: any, index: number) => {
                                        return <Tag key={item.id} color={item?.id ? bgColor[item?.id] : ''} style={{ marginBottom: 8 }}>{item.name}</Tag>
                                    })
                                }
                            </span>
                        }
                    </div>

                }

            }
        },
        {
            title: '运行状态',
            dataIndex: 'executionStatus',
            key: 'executionStatus',
            align: 'center',
            width: 120,
            render: (a: number, b: any) => {
                return <span>
                    {b.executionStatus === 0 ? <Badge status="warning" text='创建未执行' /> : b.executionStatus === 1 ? <Badge status="processing" text='执行中' /> : b.executionStatus === 2 ? <Badge status="success" text='任务完成' /> : b.executionStatus === -1 ? <Badge status="error" text='任务终止' /> : <Badge status="error" text='执行失败' />}
                </span>
            }
        },
        {
            title: '启用状态',
            dataIndex: 'enabled',
            key: 'enabled',
            align: 'center',
            width: 110,
            render: (enabled: boolean, b: { id: number, executionStatus: number, createUser: { userId: number } }) => {
                return <Switch
                    checkedChildren="启用"
                    unCheckedChildren="暂停"
                    checked={enabled}
                    onChange={(checked: any) => { SwitchChange(checked, b.id) }}
                // disabled={b.createUser.userId !== (userId as unknown) ? access === 'admin' ? false : true : false}
                />
            }
        },
        {
            title: '操作',
            key: 'action',
            dataIndex: 'action',
            width: 280,
            render: (a: any, data: any) => {
                return <div onClick={(e: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
                    e.preventDefault()
                    e.stopPropagation()
                }}>
                    <Space wrap>
                        <Button onClick={() => {
                            journalHandle(data.id)
                        }} size='small'>执行日志</Button>
                        {// 执行失败一键重发
                            data.executionStatus === -2 && <Button onClick={() => {
                                executionNow.run(data.id).then(() => {
                                    get.refresh()
                                })
                            }} size='small' loading={executionNow?.loading}>一键重发</Button>
                        }
                        {//只有在未发送是出现
                            data.executionStatus !== 2 && <Button onClick={() => {
                                show(data, 0)
                            }} size='small' loading={getWXInfo?.loading}>编辑</Button>
                        }
                        { //强行执行
                            data?.executionStatus === 0 && < Button onClick={() => {
                                restart.run(data.id).then(() => {
                                    get.refresh()
                                })
                            }} size='small' loading={restart?.loading}>强行执行</Button>
                        }
                        {//只有在非图文或者图文已发送状态下
                            < Button onClick={() => {
                                show(data, 1)
                            }} size='small' loading={getWXInfo?.loading}>详情</Button>
                        }
                        <Look type='Advanced' strategyId={data?.id} id={data?.mpId} size="small" />
                        {//已发送不存在并且图文必须删除全部内容
                            <Popconfirm
                                title='确定要删除吗?'
                                onConfirm={() => {
                                    del.run({ id: data.id }).then(() => {
                                        get.refresh()
                                    })
                                }}
                            >
                                <Button size='small' loading={del?.loading} danger>删除</Button>
                            </Popconfirm>
                        }

                        {//只有在是图文并且已发送成功并且文章没有被删空
                            //&& (data.executionStatus === 2) 
                            data.msgType === 'mpnews' && <Button onClick={() => show(data, 2)} size='small' loading={getWXInfo?.loading} danger>删除内容</Button>
                        }
                    </Space>
                </div >
            }
        }
    ]
}

