import { Button, Empty, Popover, Space, Tooltip } from 'antd'
import React, { useCallback, useState, useEffect } from 'react'
import style from './content.less'
import MsgWxGraphicListModal from '@/components/MaterialModal/msgWxGraphicListModal'
import WxTextModal from '@/components/MaterialModal/textModal'
import { ArrowDownOutlined, ArrowUpOutlined, DeleteOutlined, EditOutlined, PlusOutlined } from '@ant-design/icons'
import SmMaterialModal from '@/components/MaterialModal/smModalBox'
import { useModel } from 'umi'
import { isArray } from 'lodash'
import filePng from '../../../../../../../public/file.png'
import WeChatImgCard from '@/components/WeChatImgCard'
let config: any = {
    '图文素材': 5,
    '视频': 3,
    '音频': 2,
    '图片': 1,
    '文字': 4,
    '小程序卡片': 6
}
let config1 = {
    1: '图片',
    2: '音频',
    3: '视频',
    4: '文字',
    5: '图文',
    6: '小程序卡片'
}
let config2 = {
    1: 'image',
    2: 'voice',
    3: 'video',
    4: 'text',
    5: 'news',
    6: 'miniprogrampage'
}
/**
 * type  默认 0  延迟消息 1  自动回复 2
 * myHeight true 高度调整
 */

const Content = React.memo((props: { type?: number, myStype?: object, data?: any[], myHeight?: boolean }) => {
    const { myStype = {}, data, myHeight = false } = props
    const [visible, setVisible] = useState<boolean>(false)//图片，视频，音频弹窗
    const [textVisible, setTextVisible] = useState<boolean>(false)//文字弹窗
    const [graphicVisible, setGraphicVisible] = useState<boolean>(false)//图文弹窗
    const [key, setKey] = useState<string>('')//存放选中的key
    const [mouse, setMouse] = useState<number>(-1)//存放鼠标移入的key
    const [indexId, setIndexId] = useState<any>(null)//插入数据存入插入在哪条数据之后
    const [theEdit, setTheEdit] = useState<any>(null)//当前编辑的内容
    const { dispatchMate } = useModel('useOperating.useMsgMaterialDrawer', model => ({ dispatchMate: model.dispatch }))
    const { state, addList, up, delList, down, editList, initData } = useModel('useOperating.useAservice', models => ({
        state: models.state,
        addList: models.addList,
        up: models.up,
        delList: models.delList,
        down: models.down,
        editList: models.editList,
        initData: models.initData
    }))
    useEffect(() => {
        if (isArray(data)) {
            if (data?.length > 0) {
                if (Object.keys(data[0]).length > 0) {
                    let msgContents: any[] = []
                    let web = { video: 3, news: 5, music: 2, image: 1, text: 4 }
                    /**编辑将数据处理存入model */
                    data[0].msgContents.forEach((item: any, index: number) => {
                        if (item.webType === 4) {
                            msgContents.push({ ...item, textContent: item.textContent.replace(/href/ig, '_href').split('<br    />'), indexId: index + 1, webType: 4 })
                        } else if (item.webType === 6) {
                            console.log(item?.platformMediaInfo?.url)
                            msgContents.push({ ...item, indexId: index + 1, webType: web[item.msgType], imageUrl: item?.platformMediaInfo?.url })
                        } else {
                            msgContents.push({ ...item, indexId: index + 1, webType: web[item.msgType] })
                        }
                    })
                    initData({ data: { ...data[0], delId: [], msgContents } })
                }
            }
        }
    }, [data])
    //图片，视频，音频弹窗操作事件
    const closeModal = useCallback((item?: string, indexId?: number, itemData?: any) => {
        if (itemData) {//只有在编辑时才有
            setTheEdit(itemData)
        }
        if (indexId) {//编辑和插入时才有，标记是在操作哪条
            setIndexId(indexId)
        }
        if (item === '图片' || item === '音频' || item === '视频') {
            setVisible(true)
            setKey(item)
            return
        }
        if (item === '文字') {
            setTextVisible(true)
            setKey(item)
            return
        }
        if (item === '图文') {
            dispatchMate({ type: 'initData', params: { data: { dataArr: [{ menuId: 1 }] } } }) //设置成默认
            setGraphicVisible(true)
            setKey(item)
            return
        }
        if (item === '小程序卡片') {
            console.log(itemData)
            setKey(item)
            if (itemData) {
                setTheEdit({ img: itemData?.imageUrl, cardTitle: itemData?.title, appid: itemData?.appId, appPath: itemData?.pagePath, imgInfo: itemData?.platformMediaInfo })
            }
            return
        }
        //关闭时清空相关数据
        setKey('')
        setVisible(false)
        setGraphicVisible(false)
        setTextVisible(false)
        setTheEdit(null)
    }, [])
    //插入数据
    const handleOk = (list: any, type?: number) => {
        console.log('插入数据====>', type, list)
        type = type || 0
        if (list) {
            if (type === 4) {//插入文本
                list.indexId ? editList({ webType: type, textContent: list.textContent, index: indexId, indexId: list.indexId, msgType: 'text', type: 2 }) : addList({ webType: type, textContent: list.textContent, index: indexId, msgType: 'text', type: 2 })
            } else if (type === 5) {//插入图文
                list.indexId ? editList({ webType: type, newsList: list.newsList, index: indexId, msgType: 'news', type: 3 }) : addList({ webType: type, newsList: list.newsList, index: indexId, msgType: 'news', type: 3 })
            } else if (type === 6) {//小程序卡片
                theEdit ? editList(
                    list?.imgInfo ?
                        { webType: type, index: indexId, msgType: 'miniprogrampage', imageUrl: list?.img, title: list?.cardTitle, appId: list?.appid, pagePath: list?.appPath, type: list?.imgInfo?.mediaId ? 0 : 1, platformMediaId: list?.imgInfo?.id }
                        :
                        { webType: type, index: indexId, msgType: 'miniprogrampage', imageUrl: list?.img, title: list?.cardTitle, appId: list?.appid, pagePath: list?.appPath, type: list?.imgInfo?.mediaId ? 0 : 1, }
                ) : addList({ webType: type, msgType: 'miniprogrampage', imageUrl: list?.img, title: list?.cardTitle, appId: list?.appid, pagePath: list?.appPath, type: list?.imgInfo?.mediaId ? 0 : 1, platformMediaId: list?.imgInfo?.id })
            } else {//插入其它
                theEdit ? editList({ webType: type, imageUrl: list.url, msgType: config2[type], platformMediaId: list.id, index: indexId, type: 1, platformMediaInfo: { folder: list?.folder, number: list?.number } }) : addList({ webType: type, imageUrl: list.url, platformMediaId: list.id, msgType: config2[type], index: indexId, type: 1, platformMediaInfo: { folder: list?.folder, number: list?.number } })
            }
        }
        closeModal()
        setIndexId(null)
    }
    //listBox按情况渲染
    const ListBox = useCallback((props: { data: any }) => {
        let { data } = props
        switch (data.webType) {
            case 5:
                if (data?.newsList?.length === 1) {
                    return <div className={style.text_img}>
                        <div>
                            <span>{data?.newsList[0]?.title.replace(new RegExp('&nbsp;', "g"), ' ').replace(/&quot;/ig, '"').replace(/&amp;/ig, '&').replace(/&lt;/ig, '<').replace(/&gt;/ig, '>').replace(/<\s+/g, '<')}</span>
                            <span>{data?.newsList[0]?.description}</span>
                        </div>
                        <Tooltip placement="right" title={<div style={{ display: 'flex', flexFlow: 'column' }}>
                            <span>名称：{data?.newsList[0]?.knewsThumbInfo?.title}</span>
                            <span>编号：{data?.newsList[0]?.knewsThumbInfo?.number}</span>
                        </div>}>
                            {/* <img src={(data?.newsList[0]?.knewsThumbInfo?.folder) ? filePng : data?.newsList[0]?.knewsThumbId ? (data?.newsList[0]?.knewsThumbInfo?.url || data?.newsList[0]?.newsPicUrl) : data?.newsList[0]?.newsPicUrl} /> */}
                            <img src={data?.newsList[0]?.knewsThumbUrl || (data?.newsList[0]?.knewsThumbId ? filePng : 'https://s.weituibao.com/static/1552098829922/bigfm.png')} />
                        </Tooltip>
                    </div>
                } else {
                    return <div className={style.box_card}>
                        {
                            data?.newsList?.map((list: any, index: number) => {
                                let isOne = data?.newsList?.length === 1
                                return <div className={`${style.img_ScwxBox} `} key={index}>
                                    {!isOne && <span>{list?.title.replace(new RegExp('&nbsp;', "g"), ' ').replace(/&quot;/ig, '"').replace(/&amp;/ig, '&').replace(/&lt;/ig, '<').replace(/&gt;/ig, '>').replace(/<\s+/g, '<')}</span>}
                                    <Tooltip placement="right" title={<div style={{ display: 'flex', flexFlow: 'column' }}>
                                        <span>名称：{list?.knewsThumbInfo?.title}</span>
                                        <span>编号：{list?.knewsThumbInfo?.number}</span>
                                    </div>}>
                                        {/* <img src={(list?.knewsThumbInfo?.folder) ? filePng : list?.knewsThumbId ? (list?.knewsThumbInfo?.url || list?.newsPicUrl) : list?.newsPicUrl} /> */}
                                        <img src={list?.knewsThumbUrl || (list?.knewsThumbId ? filePng : 'https://s.weituibao.com/static/1552098829922/bigfm.png')} />
                                    </Tooltip>
                                    {isOne && <div className={style.one}>
                                        <p>{list?.title.replace(new RegExp('&nbsp;', "g"), ' ').replace(/&quot;/ig, '"').replace(/&amp;/ig, '&').replace(/&lt;/ig, '<').replace(/&gt;/ig, '>').replace(/<\s+/g, '<')}</p>
                                        <p>{list?.description}</p>
                                    </div>}
                                </div>
                            })
                        }
                    </div>
                }

            case 1:
                if (data?.platformMediaInfo?.folder) {
                    return <div className={style.img} style={{ width: 200 }}>
                        <img src={filePng} />
                        <span>{data?.platformMediaInfo?.number}</span>
                    </div>
                } else {
                    return <div className={style.img}>
                        <img src={data?.url || data?.imageUrl || data?.platformMediaInfo?.url} />
                    </div>
                }

            case 4:
                let textContent = data?.textContent
                if (textContent && !Array.isArray(textContent)) {
                    textContent = [data?.textContent]
                }
                return <div className={style.text}>
                    {
                        textContent?.map((item: any, index: number) => {
                            // if (item) { //注释保留空格换行
                            return <span dangerouslySetInnerHTML={{ __html: `${item.replace(/href/ig, '_href')}${index !== textContent.length - 1 ? '<br />' : ''}` }} key={item + index} ></span>
                            // }
                            return
                        })
                    }
                </div>
            case 2:
                if (data?.platformMediaInfo?.folder) {
                    return <div className={style.img} style={{ width: 200 }}>
                        <img src={filePng} />
                        <span>{data?.platformMediaInfo?.number}</span>
                    </div>

                } else {
                    return <div className={style.audio}>
                        <audio src={data?.url || data?.imageUrl || data?.platformMediaInfo?.url} controls />
                        <span>{data?.name}</span>
                    </div>
                }
            case 3:
                if (data?.platformMediaInfo?.folder) {
                    return <div className={style.img} style={{ width: 200 }}>
                        <img src={filePng} />
                        <span>{data?.platformMediaInfo?.number}</span>
                    </div>
                } else {
                    return <div className={style.video}>
                        <video src={data?.url || data?.imageUrl || data?.platformMediaInfo?.url} controls />
                        <span>{data?.name}</span>
                    </div>
                }
            case 6:
                return <div className={style.miniprogrampage}>
                    <span className={style.miniprogrampage_title}>{data?.title}</span>
                    <img className={style.miniprogrampage_img} src={data?.imageUrl} />
                    <span className={style.miniprogrampage_bottom}>小程序</span>
                </div>
            default:
                return <div></div>

        }
    }, [])
    return <div className={style.content} style={myHeight ? { flex: "1" } : {}}>
        <div className={style.header} style={myStype}>
            <label >推送内容选择：</label>
            <Space >
                {
                    ['图文', '图片', '文字', '音频', '视频', '小程序卡片'].map((item: string) => {//,
                        return <Button key={item} onClick={() => closeModal(item)}>{item}</Button>
                    })
                }
            </Space>
        </div>
        <div className={style.body} style={myHeight ? { height: "100%" } : {}}>
            {
                state?.msgContents ?
                    <div className={style.list}>
                        <ul>
                            {
                                state?.msgContents?.map((item: any, index: number) => {
                                    /** 不是最后一条*/
                                    let isAfter: boolean = index !== state?.msgContents.length - 1
                                    /** 不是第一条*/
                                    let isBefore: boolean = index !== 0
                                    /**鼠标是否移入*/
                                    let isMouse: boolean = index === mouse
                                    return <li
                                        key={item.indexId}
                                        onMouseOver={() => { setMouse(index) }}
                                        onMouseLeave={() => { setMouse(-1) }}
                                        className={isMouse ? style.mouse : ''}
                                    >
                                        <div className={style.list_content}>
                                            <span>{index + 1}</span>
                                            <ListBox data={item} />
                                        </div>
                                        <div className={style.list_btn}>
                                            <Space>
                                                <Tooltip title="编辑">
                                                    <Button size='small' onClick={() => closeModal(config1[item.webType], item.indexId, item)}><EditOutlined /></Button>
                                                </Tooltip>
                                                {
                                                    isBefore && <Tooltip title="上移">
                                                        <Button size='small' onClick={() => up(item.indexId)}><ArrowUpOutlined /></Button>
                                                    </Tooltip>
                                                }
                                                {
                                                    isAfter && <Tooltip title="下移">
                                                        <Button size='small' onClick={() => down(item.indexId)}><ArrowDownOutlined /></Button>
                                                    </Tooltip>
                                                }
                                                <Popover
                                                    style={{ width: 500 }}
                                                    content={
                                                        <div className={style.list_btn_btn}>
                                                            {
                                                                ['图文', '图片', '文字', '音频', '视频', '小程序卡片'].map((name: string) => {
                                                                    return <Button key={name} onClick={() => closeModal(name, item.indexId)} style={{ fontSize: 10 }}>{name}</Button>
                                                                })
                                                            }
                                                        </div>
                                                    }
                                                    trigger="hover"
                                                >
                                                    <Button size='small'><PlusOutlined /></Button>
                                                </Popover>
                                                <Tooltip title="删除">
                                                    <Button size='small' onClick={() => delList(item.indexId)}> <DeleteOutlined /></Button>
                                                </Tooltip>
                                            </Space>
                                        </div>
                                    </li>
                                })
                            }
                        </ul>
                    </div>
                    :
                    <div className={style.empty}>
                        <Empty description={'点击上方按钮添加推送内容'} />
                    </div>
            }

        </div>
        {
            (visible && key !== '文字' && key !== '图文') && <SmMaterialModal
                visible={visible}
                onCancel={closeModal}
                title={`选择${key}`}
                onOk={(props: any) => {
                    console.log('图片', props)
                    handleOk(props, config[key])
                }}
                mediaType={config[key]}
                isShowWx={false}
                isAllData
            />
        }
        {key === '文字' && <WxTextModal visible={textVisible} onCancel={closeModal} onOK={handleOk} defaultData={theEdit} />}
        {key === '图文' && <MsgWxGraphicListModal
            visible={graphicVisible}
            onCancel={closeModal}
            onOK={handleOk}
            defaultData={theEdit}
            tooltipTxt='只支持单图文'
            historyType={1}
            ImportBtShow={1}
            isProhibitMs={true}
            msgType={1}
        />}
        {
            key === '小程序卡片' && <WeChatImgCard
                onCancel={closeModal}
                title='小程序图片链'
                visible={true}
                onOk={(props: { img: string, appid: string, appPath: string, cardTitle?: string }) => {
                    handleOk(props, config[key])
                }}
                weCathType='card'
                defaultData={theEdit}
            />
        }
    </div>
})

export default Content