import MoreModal from '@/components/ActionModal/more'
import { Button, Col, DatePicker, Drawer, Input, message, Radio, Row, Select, Space, TimePicker, Switch } from 'antd'
import { RadioChangeEvent } from 'antd/lib/radio'
import React, { useCallback, useEffect, useState } from 'react'
import { useModel } from 'umi'
import style from './index.less'
import moment from 'moment'
import Content from './content'
import PreviewModal from '@/components/MaterialModal/previewModal'
import FansSelect from '@/components/FansSelect'

interface Obj { taskName: string, mpIds: any[], fans: number, mpFansListDto: { sex: 'all' | 0 | 1 | 2, tagIds: any[], tagType: any }, msgContents: any, triggerType: number, weekDay: number, time: string, sendTime: string, actionWX: string }
const AddModal = React.memo((props: { defaultData: any, AdvancedDispatch: any, isReview?: boolean }) => {
    const { isReview = false } = props
    const [fansNum, setFansNum] = useState<number>(0)
    const { getActionWX, wx } = useModel('useOperating.useWxGroupList', model => ({ getActionWX: model.state.actionWX, actionWx: model.actionWx, wx: model.state.actionWX }))
    const { addKefuMsgStrategy, dispatch, state, editKefuMsgStrategy, getKefuMsgStrategy } = useModel('useOperating.useAservice')
    const { state: { selectdUserId } } = useModel('useOperating.useUser')
    const { mpIds, triggerType, enabled, msgStrategy, weekDay, sendTime, visible, moreVisible, time, fans, mpFansListDto, taskName, msgContents } = state
    const [fansSelectValue, setFansSelectValue] = useState<any>(null)
    console.log(state)
    /**
   * 假如没有选中微信弹窗选择
   * */
    useEffect(() => {
        if (!wx) {
            dispatch({ type: 'wxShow' })
        }
    }, [wx])
    /**
     * 设置选中微信
     */
    useEffect(() => {
        if (getActionWX) {
            dispatch({ type: 'setActionWX', params: { actionWX: getActionWX } })
        }
    }, [getActionWX])

    /**
     * 日期
     * */
    const setDate = useCallback((m: any, date: string) => {
        dispatch({ type: 'setDate', params: { sendTime: date } })
    }, [time])
    /**
     * 时分
     * */
    const setTime = useCallback((moment: any, time: string) => {
        dispatch({ type: 'setTime', params: { time } })
    }, [])
    /**
     * 发送方式
     * */
    const handelSetTime = useCallback((e: RadioChangeEvent) => {
        let type = e.target.value
        dispatch({ type: 'triggerType', params: { triggerType: type } })
    }, [])
    /**
     * 设置不能选的时间
     * */
    // const disabledTiem = useCallback((type: number) => {
    //     let today = moment(new Date).format('YYYY-MM-DD')//今天日期
    //     let t = type === 1 ? new Date().getHours() : new Date().getMinutes() //1代表时，2代表分
    //     let arr: any = []
    //     Array(type === 1 ? 24 : 60).fill('').forEach((a, b) => {
    //         if (today === date && b < t) {//是否今天并且排除当前时间之后的时间不是今天不处理任何时间
    //             arr.push(b)
    //         }
    //     })
    //     return arr
    // }, [date])
    /**
     * 粉丝选择
     * */
    const handelFans = useCallback((e: RadioChangeEvent) => {
        let v = e.target.value
        dispatch({ type: 'setFans', params: { fans: v } })
    }, [])
    /**
     * 粉丝性别
     */
    const handleSex = useCallback((e: RadioChangeEvent) => {
        let sex = e.target.value
        dispatch({ type: 'setMpFansListDto', params: { sex } })
    }, [])
    /**
     * 任务名称
     */
    const handleName = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let taskName = e.target.value
        dispatch({ type: 'setName', params: { taskName } })
    }, [])
    const handleSubmit = useCallback(() => {
        let { taskName, mpIds, mpFansListDto, fans, msgContents, triggerType, weekDay, time, sendTime, actionWX, enabled, msgStrategy, id } = state
        let newObj: Obj = { taskName, mpIds, fans, mpFansListDto, msgContents, triggerType, weekDay, time, sendTime, actionWX }
        let newMsgContents = msgContents ? JSON.parse(JSON.stringify(msgContents)) : []
        let data: any = {}
        if (newObj.mpIds?.length > 0) {//mpid处理
            data['mpIds'] = []
            newObj.mpIds.forEach((wx: { id: number }) => {
                data['mpIds'].push(wx.id)
            })
        }
        if (!fans) {
            data['fansAll'] = false//是否群发所有粉丝
        } else {
            data['fansAll'] = true
        }
        switch (triggerType) {//发送方式处理
            case 1:
                data['triggerType'] = 1
                data['sendTime'] = newObj.sendTime
                break;
            case 2:
                data['triggerType'] = 2
                data['time'] = newObj.time
                break;
            case 3:
                data['triggerType'] = 2
                data['weekDay'] = newObj.weekDay
                data['time'] = newObj.time
                break;
            default:
                data['triggerType'] = 0
                break;
        }
        data['msgContents'] = newMsgContents?.map((item: { textContent: any, msgType: string, newsList: any[] }) => {
            if (item.msgType === 'text' && Array.isArray(item.textContent)) {
                let textContent = ''
                item.textContent.forEach((key: string, index: number) => {
                    textContent += `${key.replace(/_href/ig, 'href')}${index !== item?.textContent.length - 1 ? '<br/>' : ''}`
                })
                item['textContent'] = textContent
            } else if (item.msgType === 'news') {
                let reg = new RegExp('&nbsp;', "g")
                let newsList = item?.newsList?.map((nl: { title: string }) => {
                    return { ...nl, title: nl?.title.replace(reg, ' ') }
                })
                item['newsList'] = newsList
            }
            return item
        })
        data = { ...data, taskName, enabled, msgStrategy, belongUserId: selectdUserId, ...fansSelectValue }
        if (!data?.mpIds) {
            message.error('请添加公众号！')
            return
        }
        if (!data?.taskName) {
            message.error('请添加消息名称！')
            return
        }
        if (data?.msgContents?.length === 0) {
            message.error('请添加素材！')
            return
        }
        if (id) {
            editKefuMsgStrategy.run({ ...data, strategyId: id }).then((res: any) => {
                if (res) {
                    getKefuMsgStrategy.refresh()
                    dispatch({ type: 'initData' })
                }

            })
        } else {
            addKefuMsgStrategy.run(data).then((res: any) => {
                if (res) {
                    getKefuMsgStrategy.refresh()
                    dispatch({ type: 'initData' })
                }
            })
        }
    }, [state, selectdUserId, fansSelectValue])
    return <>
        <Drawer
            title={<span>客服消息</span>}
            placement="right"
            width='90%'
            onClose={() => {
                dispatch({ type: 'initData' })//初始数据
                props.AdvancedDispatch({ type: 'setDefaultData', params: { defaultData: null } })
            }}
            visible={visible}
            destroyOnClose
            footer={
                <div className={style.drawer_footer}>
                    <Space>
                        <Button onClick={() => { dispatch({ type: 'initData' }), props.AdvancedDispatch({ type: 'setDefaultData', params: { defaultData: null } }) }} >取消</Button>
                        {
                            !isReview && <Button onClick={handleSubmit} type="primary" loading={editKefuMsgStrategy?.loading || addKefuMsgStrategy?.loading} disabled={!!state?.islook}>保存</Button> //disabled={!(access === 'admin' || state?.createUser?.userId === userId || !props?.defaultData)}
                        }
                        <PreviewModal isKf data={{ mpIds, msgContents }} />
                    </Space>

                </div>
            }
        >
            <div className={style.box}>
                <div className={style.left}>
                    <Row className={style.left_content}>
                        <Col className={style.more}>
                            <Button onClick={() => dispatch({ type: 'moreShow' })} type='dashed' >{/*disabled={props?.defaultData}*/}
                                批量添加公众号
                            </Button>
                            <Space>
                                <div className={style.action_wxs}>
                                    {
                                        mpIds?.map((wx: { nickName: string, headImg: string }) => {
                                            return <span key={wx.nickName}>
                                                <img src={wx?.headImg || localStorage.bookImg} style={{ width: 25 }} />
                                                <span style={{ marginLeft: 10 }}>{wx?.nickName}</span>
                                            </span>
                                        })
                                    }
                                </div>
                            </Space>
                            {moreVisible && <MoreModal
                                visible={moreVisible}
                                hideWx={() => {
                                    dispatch({ type: 'moreShow' })
                                }}
                                ok={(arr: any[]) => {
                                    dispatch({
                                        type: 'setActionWXs',
                                        params: { mpIds: arr }
                                    })
                                    dispatch({ type: 'moreShow' })
                                }}
                                defaultDtat={mpIds || []}
                                isSelect
                            />}
                        </Col>
                        <Col>
                            <Content type={0} />
                        </Col>
                        <Col>
                            <div className={style.name}>
                                <label>消息名称：</label>
                                <Input placeholder='输入20字以内的消息名称' maxLength={20} value={taskName} onChange={handleName} />
                            </div>
                        </Col>
                        <Col className={style.left_fans}>
                            <div>
                                <label>群发粉丝：</label>
                                <Radio.Group onChange={handelFans} value={fans}>
                                    <Radio value={0}>按条件筛选粉丝</Radio>
                                    <Radio value={1}>全部粉丝</Radio>
                                </Radio.Group>
                            </div>
                            {
                                fans === 0 && <Row>
                                    <Col>
                                        <FansSelect callback={setFansSelectValue} defaultValue={props?.defaultData} />
                                    </Col>
                                </Row>
                            }
                        </Col>
                        <Col className={style.left_time}>
                            <div>
                                <label>发送方式：</label>
                                <div>
                                    <Radio.Group onChange={handelSetTime}
                                        value={triggerType}
                                    >
                                        {/* <Radio value={0}>立即发送</Radio> */}
                                        <Radio value={2}>每日</Radio>
                                        <Radio value={3}>每周</Radio>
                                        <Radio value={1}>特定时间</Radio>
                                        <Radio value={4}>关注延迟指定时间</Radio>
                                    </Radio.Group>
                                </div>
                            </div>
                            <div />
                        </Col>
                        {
                            triggerType !== 0 && <Col className={style.left_time}>
                                <div>
                                    <label>发送时间：</label>
                                    <div>
                                        {triggerType === 3 && <Select
                                            value={weekDay}
                                            onChange={(a: any) => { dispatch({ type: 'setWeekDay', params: { weekDay: a } }) }}
                                            style={{ marginLeft: 8 }}
                                        >
                                            <Select.Option value={1}>周一</Select.Option>
                                            <Select.Option value={2}>周二</Select.Option>
                                            <Select.Option value={3}>周三</Select.Option>
                                            <Select.Option value={4}>周四</Select.Option>
                                            <Select.Option value={5}>周五</Select.Option>
                                            <Select.Option value={6}>周六</Select.Option>
                                            <Select.Option value={7}>周日</Select.Option>
                                        </Select>
                                        }
                                        {(triggerType === 3 || triggerType === 2) && <TimePicker
                                            value={time ? moment(time, 'HH:mm') : undefined}
                                            format={'HH:mm'}
                                            onChange={setTime}
                                            style={{ width: 90, marginLeft: 8 }}
                                        />}
                                        {
                                            triggerType === 1 && < Space >
                                                <DatePicker
                                                    disabledDate={(current) => {//禁选日期
                                                        let tppday = current && current < moment().startOf('day')
                                                        return tppday
                                                    }}
                                                    format={'YYYY-MM-DD HH:mm:ss'}
                                                    disabledTime={(date) => {//禁选时分秒
                                                        let upDate = moment(date).format('YYYY-MM-DD')//选中的年月日
                                                        let upHours = moment(date).format('HH')//选中的时
                                                        let upMinutes = moment(date).format('mm')//选中的分
                                                        let atDate = moment(new Date()).format('YYYY-MM-DD')//今天的年月日
                                                        let atHours = moment(new Date()).format('HH')//现在的时
                                                        let atMinutes = moment(new Date()).format('mm')//现在的分
                                                        let atSeconds = moment(new Date()).format('ss')//现在的秒
                                                        let range = (num: number, at: string) => {
                                                            if (upDate == atDate) {//假如选中时间的今天
                                                                let arr: number[] = []
                                                                Array(num).fill('').forEach((a, b) => { if (b < Number(at)) { arr.push(b) } })
                                                                return arr
                                                            } else {
                                                                return []
                                                            }
                                                        }
                                                        let minutes = (num: number, at: string) => {
                                                            if (upDate == atDate) {//假如选中时间的今天
                                                                let arr: number[] = []
                                                                if (upHours == atHours) {
                                                                    Array(num).fill('').forEach((a, b) => { if (b < Number(at)) { arr.push(b) } })
                                                                }
                                                                return arr
                                                            } else {
                                                                return []
                                                            }
                                                        }
                                                        let minutess = (num: number, at: string) => {
                                                            if (upDate == atDate) {//假如选中时间的今天
                                                                let arr: number[] = []
                                                                if (upMinutes == atMinutes) {
                                                                    Array(num).fill('').forEach((a, b) => { if (b < Number(at)) { arr.push(b) } })
                                                                }
                                                                return arr
                                                            } else {
                                                                return []
                                                            }
                                                        }
                                                        return {
                                                            disabledHours: () => range(24, atHours),
                                                            disabledMinutes: () => minutes(60, atMinutes),
                                                            disabledSeconds: () => minutess(60, atSeconds),
                                                        }
                                                    }}
                                                    showTime
                                                    value={sendTime ? moment(sendTime) : undefined}
                                                    onChange={setDate}
                                                />
                                                {
                                                    moment(sendTime).format('YYYY-MM-DD') === moment(new Date()).format('YYYY-MM-DD') && <strong style={{ color: 'red' }}>*三块钱友情提示：当前特定时间选择日期为今天！选错是要扣分的！</strong>
                                                }
                                            </Space>
                                        }
                                    </div>
                                </div>
                                <div />
                            </Col>
                        }
                        <Col >
                            <div style={{ display: 'flex' }}>
                                <label>回复方式：</label>
                                <div>
                                    <Radio.Group onChange={(e) => { dispatch({ type: 'setMsgStrategy', params: { msgStrategy: e.target.value } })}} value={msgStrategy}>
                                        <Radio value={0}>全部推送</Radio>
                                        <Radio value={1}>随机回复一条</Radio>
                                    </Radio.Group>
                                </div>
                            </div>
                            <div />
                        </Col>
                        <Col >
                            <div style={{ display: 'flex' }}>
                                <label>消息状态：</label>
                                <div>
                                    <Switch
                                        checkedChildren="启用"
                                        unCheckedChildren="暂停"
                                        defaultChecked={!!enabled}
                                        onChange={(checked) => { dispatch({ type: 'setEnabled', params: { enabled: checked ? 1 : 0 } }) }}
                                        disabled={isReview}
                                    />
                                </div>
                            </div>
                            <div />
                        </Col>
                    </Row>
                </div>
            </div>
        </Drawer>
    </>
})

export default AddModal