import Tables from '@/components/Tables'
import { Button, Drawer, Input, message, Popconfirm, Row, Select, Space, Upload } from 'antd'
import React, { useCallback, useEffect, useState } from 'react'
import { columns } from './tableConfig'
import { daysColumns } from './daysTableConfig'
import style from './index.less'
import { useModel } from 'umi'
import { SelectValue } from 'antd/es/select'
import { useReducer } from 'react'
import AddModal from './components/addModal'
import { DownloadOutlined, PlusOutlined, RedoOutlined, UploadOutlined } from '@ant-design/icons'
const { Option } = Select;
import GroupWxTabs from '@/components/GroupWxTabs/wx'
import NoFoundPage from '@/pages/empty'
import { SearchOutlined } from '@ant-design/icons'
import { downloadFile } from '@/utils/downloadFile'
import { exportKNewsExcle, importKnewsExcle } from '@/services/operating/news'
import { useAjax } from '@/Hook/useAjax'
import './table.less'

type State = {
    visible: boolean,//弹窗开启与否
    defaultData: any,//编辑填数据
    theEditer: any,//当前查看数据栏
    del: boolean,//删除开启
}
export type Action = {
    type: 'show' | 'setDefaultData' | 'theEditer' | 'del',
    params?: any
}
function reducer(state: State, action: Action) {
    let { type, params } = action
    switch (type) {
        case 'show':
            return { ...state, visible: !state.visible }
        case 'setDefaultData':
            return { ...state, defaultData: params.defaultData }
        case 'theEditer':
            return { ...state, theEditer: params.theEditer }
        case 'del':
            return { ...state, del: params.del }
        default:
            return state;
    }
}
function Aservice() {
    const [state, dispatch] = useReducer(reducer, { visible: false, defaultData: null, theEditer: null, del: false })
    const { addDispath, show, getKefuMsgStrategy, daysMsg, deletes, detailKefuMsgStrategy, onKefuMsgStrategy, restart, delskefu } = useModel('useOperating.useAservice', model => ({
        addDispath: model.dispatch,
        show: model.state.visible,
        getKefuMsgStrategy: model.getKefuMsgStrategy,
        daysMsg: model.daysKefuMsgStrategy,
        deletes: model.delKefuMsgStrategy,
        detailKefuMsgStrategy: model.detailKefuMsgStrategy,
        onKefuMsgStrategy: model.onKefuMsgStrategy,
        restart: model.restartKefuMsgStrategy,
        delskefu: model.delskefu
    }))
    const { userId } = useModel('useOperating.useUser', model => ({ userId: model.state.selectdUserId }))
    const { actionWX, filterWxs } = useModel('useOperating.useWxGroupList', model => ({
        actionWX: model.state.actionWX,
        filterWxs: model.state.filterWxs,
    }))
    const { defaultData, } = state
    const [data, setData] = useState<{ mpId: string; status: SelectValue, taskName: string }>({
        mpId: '',
        status: '',
        taskName: ''
    })
    const [drawerVis, setDrawerVis] = useState<boolean>(false)
    const [daysId, setDaysId] = useState<number>(0)
    const [daysMps, setDaysMps] = useState<any[]>([])
    const [select, setSelect] = useState<string>()
    const { getWXInfo } = useModel('useOperating.useMaterialContent', model => ({ getWXInfo: model.getWXInfo }))

    const { access, myuserId } = useModel('@@initialState', model => ({ access: model.initialState?.currentUser?.access, myuserId: model.initialState?.currentUser?.userId }))
    const downLoad = useAjax(() => exportKNewsExcle(), { formatResult: true })//模板下载
    const upLoad = useAjax((params) => importKnewsExcle(params), { formatResult: true })//模板导入
    const [btnUploadLoding, setBtnUploadLoding] = useState<boolean>(false)//按钮loding
    const [selectedRow, setSelectedRow] = useState<any[]>([])//选中的tableRow
    const [selectedRowKeys, setSelectedRowKeys] = useState<any[]>([])//选中的tableRowKey
    /**导出 */
    const onExportKnewsExcle = useCallback(() => {
        downLoad.run().then((res) => {
            if (res) {
                downloadFile(res, 'octet-stream', `客服消息_模板.xlsx`)
            }
        })
    }, [])
    //table多选
    const rowSelection = useCallback((key, selectedRows) => {
        setSelectedRowKeys(key)
        setSelectedRow(selectedRows)
    }, [])
    //批量删除
    const dels = useCallback(() => {
        if (selectedRow.length > 0) {
            selectedRow.forEach((item: { id: number, createUser: { userId: number } }) => {
                handleDel(item.id)
            })
        } else {
            message.warning('请勾选要删除的消息')
        }
    }, [selectedRow])
    //编辑详情打开时查询详情信息插入数据
    const showModal = useCallback((data: any, isCopy?: boolean) => {
        let { id, islook } = data
        detailKefuMsgStrategy.run({ strategyId: id, belongUserId: userId }).then((res: any) => {
            if (res) {
                let data = JSON.parse(JSON.stringify(res))
                let mpIds: any[] = filterWxs.filter((wx: { id: number }) => {
                    if (data.mpIds.some((id: number) => id === wx.id)) {
                        return wx
                    }
                    return null
                })
                if (data?.weekDay) {
                    data.triggerType = 3
                }
                data.mpIds = mpIds
                data.fans = data.fansAll ? 1 : 0
                let { msgContents } = data
                let newMsgContents = msgContents ? JSON.parse(JSON.stringify(msgContents)) : []
                data['msgContents'] = newMsgContents?.map((item: { textContent: any, msgType: string, newsList: any[], platformMediaInfo: any }) => {
                    if (item.msgType === 'news') {
                        let reg = new RegExp(' ', "g") // 
                        let newsList = item?.newsList?.map((nl: { title: string }) => {
                            return { ...nl, title: nl?.title.replace(reg, '&nbsp;') }
                        })
                        item['newsList'] = newsList
                    }
                    if (item.msgType === 'miniprogrampage') {
                        item['imageUrl'] = item?.platformMediaInfo?.url
                    }
                    return item
                })
                addDispath({ type: 'initData', params: { ...data, id: isCopy ? 0 : data.id, visible: true } })
                dispatch({ type: 'setDefaultData', params: { defaultData: { ...data, id: isCopy ? 0 : data.id } } })
            }
        })
    }, [dispatch, addDispath, filterWxs, userId])
    /**强制执行 */
    const forceRestart = useCallback((strategyId: number) => {
        restart.run({ strategyId, belongUserId: userId }).then((res: any) => {
            if (res) {
                getKefuMsgStrategy.refresh()
            }
        })
    }, [getKefuMsgStrategy, userId])
    /**开关 */
    const SwitchChange = useCallback((enabled: boolean, strategyId: number) => {
        onKefuMsgStrategy.run({ enabled, strategyId, belongUserId: userId }).then((res: any) => {
            if (res) {
                getKefuMsgStrategy.refresh()
            }
        })
    }, [getKefuMsgStrategy, userId])
    /** 删除*/
    const handleDel = useCallback((strategyId: number,) => {
        deletes.run({ strategyId, belongUserId: userId }).then((res: any) => {
            if (res) {
                getKefuMsgStrategy.refresh()
                setSelectedRow([])
                setSelectedRowKeys([])
            }
        })
    }, [getKefuMsgStrategy, deletes, userId])
    // 搜索
    const search = useCallback(() => {
        const { mpId, status, taskName } = data
        let param = {}
        if (taskName != "") {
            param['taskName'] = taskName
        }
        if (mpId) {
            param['mpId'] = mpId
        }
        if (status != 'all') {
            param['status'] = status
        }
        getKefuMsgStrategy.run({ pageSize: 20, pageNum: 1, userId, ...param })
    }, [data])
    //状态选择
    const handelSelect = useCallback((value: SelectValue) => {
        setData({ ...data, status: value === 'all' ? '' : value })

    }, [getKefuMsgStrategy, userId])
    // 执行日志打开
    const journalHandle = useCallback((strategyId: number, mpIds: number[]) => {
        let arr: any = []
        filterWxs.forEach((wx: any) => {
            if (mpIds.some((id) => id === wx.id)) {
                arr.push(wx)
            }
        })
        setDaysMps(arr)
        setDaysId(strategyId)
        setDrawerVis(true)
        daysMsg.run({ strategyId, pageNum: 1, pageSize: 20, belongUserId: userId })
    }, [userId])
    // 查询指定公众号
    const searchJournal = useCallback(() => {
        let query: { strategyId: number, pageNum: number, pageSize: number, belongUserId: number, mpId?: string } = { strategyId: daysId, pageNum: 1, pageSize: 20, mpId: select, belongUserId: userId }
        if (!select) {
            query = { strategyId: daysId, pageNum: 1, pageSize: 20, belongUserId: userId }
        }
        daysMsg.run(query)
    }, [select, daysId, userId])
    //选择
    const selectChange = useCallback((value: string, option: any) => {
        setSelect(value)
    }, [daysMps])
    //首次加载搜索
    // useEffect(() => {
    //     getKefuMsgStrategy.run({ pageSize: 20, pageNum: 1, userId })
    // }, [userId])
    //消息回复分页
    const pageSize = useCallback((page: number, pageSize?: number) => {
        getKefuMsgStrategy.run({ userId, pageSize: pageSize, pageNum: page, mpId: data?.mpId })
    }, [userId, data])
    //日志回复分页
    const daysPageSize = useCallback((page: number, pageSize?: number) => {
        daysMsg.run({ strategyId: daysId, pageNum: page, pageSize: pageSize, belongUserId: userId })
    }, [daysId, userId])
    //公众选择变化帮助搜索指定公众号
    useEffect(() => {
        if (actionWX?.id && data.mpId !== actionWX?.id) {
            setData({ ...data, mpId: actionWX?.id })
            const { status, taskName } = data
            let param = {}
            if (taskName != "") {
                param['taskName'] = taskName
            }
            param['mpId'] = actionWX?.id
            if (status != 'all') {
                param['status'] = status
            }
            getKefuMsgStrategy.run({ pageSize: 20, pageNum: 1, userId, ...param })
        }
    }, [actionWX?.id, userId])
    return <>
        {
            actionWX ? <div>
                <div className={style.header}>
                    <Space>
                        <Select style={{ width: 150 }} defaultValue={'all'} onChange={handelSelect}>
                            <Option value={'all'}>全部状态</Option>
                            <Option value={0}>未执行</Option>
                            <Option value={1}>执行中</Option>
                            <Option value={2}>任务完成</Option>
                            <Option value={3}>任务终止</Option>
                        </Select>
                        <Input placeholder='请输入消息名称' value={data.taskName} onChange={e => setData({ ...data, taskName: e.target.value })} allowClear />
                        <Button type="primary" size='middle' icon={<SearchOutlined type="primary" />} onClick={search} loading={getKefuMsgStrategy.loading}>搜索</Button>
                        <Button type="primary" size='middle' icon={<RedoOutlined />} onClick={() => {
                            console.log({ ...data, mpId: '' })
                            setData({ ...data, mpId: '' })
                            getKefuMsgStrategy.run({ pageSize: 20, pageNum: 1, userId })
                        }} loading={getKefuMsgStrategy.loading}>所有公众号数据</Button>
                    </Space>
                    <Space>
                        <Button type='primary' onClick={() => {
                            addDispath({ type: 'show' })
                            addDispath({
                                type: 'setActionWXs',
                                params: { mpIds: [actionWX] }
                            })
                        }}><PlusOutlined />新增客服消息</Button>
                        {/* <Button onClick={onExportKnewsExcle}><DownloadOutlined />导出模板</Button> */}
                        <Button ><DownloadOutlined /><a href={`http://oss.zanxiangnet.com/zx-system/file/excel/客服消息导入模板.xlsx`}>导出模板</a></Button>
                        <Upload
                            accept="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet, application/vnd.ms-excel"
                            action=""
                            listType="text"
                            onChange={() => { }}
                            multiple={true}
                            showUploadList={false}
                            customRequest={(options: any) => {
                                setBtnUploadLoding(true)
                                let formData = new FormData();
                                formData.append("file", options.file);
                                upLoad.run({ data: formData }).then(res => {
                                    if (res) {
                                        getKefuMsgStrategy.refresh()
                                        message.success('创建完成！')
                                        setBtnUploadLoding(false)
                                    }

                                }).catch(() => {
                                    setBtnUploadLoding(false)
                                })
                            }}
                        ><Button type='primary' icon={<UploadOutlined />} loading={btnUploadLoding}>批量创建</Button></Upload>
                        < Popconfirm
                            title='确定要删除吗?'
                            onConfirm={dels}
                        >
                            <Button type='dashed' >批量删除</Button>
                        </Popconfirm>

                    </Space>
                    {show && <AddModal defaultData={defaultData} AdvancedDispatch={dispatch} />}
                </div>
                <GroupWxTabs isDisabled={false} >
                    <Tables
                        dataSource={getKefuMsgStrategy?.data?.records || []}
                        columns={columns({ journalHandle, show: showModal, filterWxs, forceRestart, SwitchChange, handleDel, myuserId, access, del: deletes, getWXInfo })}
                        total={getKefuMsgStrategy?.data?.total}
                        current={getKefuMsgStrategy?.data?.current}
                        rowClassName={(record: any) => {
                            if (record?.checkStatus === -1) {
                                return 'error expanded'
                            } else {
                                return "expanded"
                            }
                        }}
                        pageChange={pageSize}
                        sizeChange={pageSize}
                        rowSelection={{
                            selectedRowKeys,
                            onChange: rowSelection,
                        }}
                        scroll={{ x: 1000}}
                    />
                </GroupWxTabs>
            </div> : <NoFoundPage />
        }
        <Drawer
            title="执行日志"
            placement='top'
            onClose={() => setDrawerVis(false)}
            visible={drawerVis}
            height='450'
        >
            <Space direction="vertical">
                <Row>
                    <Select style={{ width: '200px' }} value={select} onChange={selectChange} showArrow allowClear={true}>
                        {
                            daysMps.map((option: any) => {
                                return <Option key={option.id} value={option.id}>{option?.nickName}</Option>
                            })
                        }
                    </Select>
                    <Button icon={<SearchOutlined />} onClick={searchJournal}>搜索</Button>
                </Row>
                {
                    <Tables
                        dataSource={daysMsg?.data?.records || []}
                        columns={daysColumns()} scroll={{ y: 180 }}
                        total={daysMsg?.data?.total}
                        current={daysMsg?.data?.current}
                        pageChange={daysPageSize}
                        sizeChange={daysPageSize}
                        loading={daysMsg?.loading}
                    />
                }

            </Space>
        </Drawer>
    </>
}

export default Aservice