import WxDetailsBox from '@/components/WxDetailsBox'
import { UndoOutlined } from '@ant-design/icons'
import { Button, Drawer, message, Space, Row, Col, Input, Select, Radio, DatePicker, Switch } from 'antd'
import { RadioChangeEvent } from 'antd/lib/radio'
import React, { ChangeEvent, useCallback, useEffect, useState, useRef } from 'react'
import { useModel } from 'umi'
import ColorPicker from '@/components/ColorPicker'
import moment from 'moment'
import style from './index.less'
import EmilModal from '../emilModal'
import PreviewModal from '@/components/MaterialModal/previewModal'
import FansSelect from '@/components/FansSelect'
const { Option } = Select;
const { TextArea } = Input;

type props = {
    defaultData?: any,
    visible?: boolean,
    onHide?: () => void,
    listOfPage?: any,
    isModify?: boolean,  // 是否允许修改
}

type queryForm = {
    id?: number | undefined
    taskName: string,        // 消息名称
    fansAll: boolean,        // 所有粉丝 按标签
    fansFilterSex?: number | string,  // 性别
    triggerType: number,  // 发送方式
    resDelayHours: number,//时
    resDelayMinutes: number,//分
    resDelaySecond: number,//秒
    sendTime?: any,        // 发送时间
    templateId: number | null,   // 模板ID
    enabled: number,   //启用状态
    isUrl: boolean,  //链接类型 true：使用 url、false：使用小程序
    url?: string,  //跳转链接
    miniprogramAppid?: string,  // APPID
    miniprogramPagepath?: string // 小程序路径
}
type data = {
    taskName?: string
    fansAll?: boolean
    fansFilterSex?: number | string
    triggerType?: number
    sendTime?: any,
    templateId?: number
    enabled?: number
    isUrl?: boolean
    url?: string
    miniprogramAppid?: string
    miniprogramPagepath?: string
    resDelayHours?: number,//时
    resDelayMinutes?: number,//分
    resDelaySecond?: number,//秒
}
const AddModal = React.memo((props: props) => {
    let { defaultData, visible = false, onHide, listOfPage, isModify = true } = props
    const { getActionWX, actionWX, wx } = useModel('useOperating.useWxGroupList', model => ({ getActionWX: model.state.actionWX, actionWX: model.state.actionWX, wx: model.state.actionWX }))
    const { state, dispatch } = useModel('useOperating.useAservice')
    const { catFans } = useModel('useOperating.useFans')
    const { getKefuMsgStrategy, syncTemplate, strategy, modifyStrategy } = useModel('useOperating.useAtemplate', model => ({
        getKefuMsgStrategy: model.getKefuMsgStrategy,
        syncTemplate: model.syncTemplateAjax,
        strategy: model.strategyAjax,
        modifyStrategy: model.modifyStrategyAjax
    }))
    const [temData, setTemData] = useState<{ title: string, dataTem: string }>({ title: "", dataTem: "" })
    const [template, setTemplate] = useState<string>('')
    const [rightMenuVis, setRightMenuVis] = useState<boolean>(false)
    const [menuStyle, setMenuStyle] = useState<{ top: string, left: string, right: string, bottom: string }>({ top: "", left: "", right: "", bottom: "" })
    const [refs, setRefs] = useState<any[]>([])
    const [fields, setFields] = useState<any>([])
    const refEl = useRef<any>(null)
    const [oldfields, setOldfields] = useState<any>([])
    const [fansNum, setFansNum] = useState<number>(0)
    const [queryForm, setQueryForm] = useState<queryForm>({
        id: undefined,
        taskName: '',
        fansAll: true,
        fansFilterSex: 'all',
        triggerType: 0,
        sendTime: null,
        templateId: null,
        enabled: 1,
        isUrl: true,
        url: "",
        miniprogramAppid: "",
        miniprogramPagepath: "",
        resDelayHours: 0,//时
        resDelayMinutes: 0,//分
        resDelaySecond: 0,//秒
    })
    const [tagObj, setTagObj] = useState<{ fansFilterTagType: number, fansFilterTagids: any[] }>({
        fansFilterTagType: 0,
        fansFilterTagids: []
    })
    const [fansSelectValue, setFansSelectValue] = useState<any>(null)


    /** 获取筛选粉丝数量*/
    useEffect(() => {
        if (actionWX) {
            if (!queryForm.fansAll && fansSelectValue && Object.values(fansSelectValue).some((value: any) => {
                return (value !== '' && JSON.stringify(value) !== '[]')
            })) {
                catFans.run({ mpId: actionWX?.id, fansAll: false, ...fansSelectValue }).then((res: any) => {
                    setFansNum(res)
                })
            } else {
                catFans.run({ mpId: actionWX?.id, fansAll: true }).then((res: any) => {
                    setFansNum(res)
                })
            }
        }
    }, [fansSelectValue, actionWX, queryForm.fansAll])

    /** 添加textarea右键监听 */
    useEffect(() => {
        let textarea = document.querySelectorAll('textarea')
        document.addEventListener('click', _handleClick)
        document.addEventListener('scroll', _handleScroll)
        if (textarea.length > 0) {
            textarea.forEach((item: any) => {
                item.addEventListener('contextmenu', _handleContextMenu);
            })
        }
        return () => {
            document.removeEventListener('click', _handleClick)
            document.removeEventListener('scroll', _handleScroll)
            if (textarea.length > 0) {
                textarea.forEach((item: any) => {
                    item.removeEventListener('contextmenu', _handleContextMenu);
                })
            }
        }
    }, [refs])
    const _handleContextMenu = useCallback((event) => {
        event.preventDefault();
        setRightMenuVis(true)
        const clickX = event.clientX;
        const clickY = event.clientY;
        setMenuStyle({ ...menuStyle, left: `${clickX}px`, top: `${clickY}px` })
    }, [rightMenuVis, menuStyle])
    const _handleClick = useCallback(() => {
        setRightMenuVis(false)
    }, [])
    const _handleScroll = useCallback(() => {
        setRightMenuVis(false)
    }, [])
    /**
    * 编辑处理数据
    */
    useEffect(() => {
        getKefuMsgStrategy.run({ mpId: getActionWX.id })
        if (defaultData && JSON.stringify(defaultData) !== '{}') {//初始设置选中微信,方便其他依赖组件
            setTemplate(defaultData?.templateMsgInfo?.template?.content)
            setTemData({ title: defaultData?.templateMsgInfo?.title, dataTem: defaultData?.templateMsgInfo?.template?.content })
            setQueryForm({
                id: defaultData?.id,
                taskName: defaultData?.taskName,
                fansAll: defaultData?.fansAll,
                fansFilterSex: defaultData?.fansFilterSex || "all",
                triggerType: defaultData?.triggerType || 0,
                sendTime: defaultData?.sendTime,
                templateId: defaultData?.templateId || null,
                enabled: defaultData?.enabled ? 1 : 0,
                isUrl: defaultData?.url ? true : defaultData?.miniprogramAppid && defaultData?.miniprogramPagepath ? false : true,
                url: defaultData?.url,
                miniprogramAppid: defaultData?.miniprogramAppid,
                miniprogramPagepath: defaultData?.miniprogramPagepath,
                resDelayHours: defaultData?.resDelayHours || 0,//时
                resDelayMinutes: defaultData?.resDelayMinutes || 0,//分
                resDelaySecond: defaultData?.resDelaySecond || 0,//秒
            })
            setTagObj({
                fansFilterTagType: defaultData?.fansFilterTagType || 0,
                fansFilterTagids: defaultData?.fansFilterTagids || []
            })
            dispatch({ type: 'setMpFansListDto', params: { tagIds: defaultData?.fansFilterTagids || [], tagType: defaultData?.fansFilterTagType || 0 } })
            setFields([...defaultData?.contentFields])
        }
    }, [defaultData, getActionWX.id])

    ////////////////////
    const handleSubmit = useCallback(() => {
        let dataQuery: any = {}
        let { taskName, fansAll, templateId, enabled, fansFilterSex, isUrl, url, miniprogramAppid, miniprogramPagepath, triggerType, sendTime, resDelayHours, resDelayMinutes, resDelaySecond } = queryForm
        dataQuery.mpId = getActionWX.id
        dataQuery.taskName = taskName
        dataQuery.fansAll = fansAll
        dataQuery.enabled = enabled === 1 ? true : false
        // if (!fansAll) {
        //     if (fansFilterSex !== 'all') {
        //         dataQuery.fansFilterSex = fansFilterSex  // 性别
        //     } else if (tagObj.fansFilterTagids.length === 0) {
        //         message.error('请选择标签');
        //         return
        //     }
        //     if (tagObj.fansFilterTagids.length !== 0) {
        //         dataQuery.fansFilterTagType = tagObj.fansFilterTagType
        //         dataQuery.fansFilterTagids = tagObj.fansFilterTagids
        //     } else if (fansFilterSex === 'all') {
        //         message.error('请选择性别');
        //         return
        //     }
        // }

        if (!taskName) { message.error('请输入任务名称'); return }
        if (!templateId) { message.error('请选择模板'); return }
        // if(fields.findIndex((item: any) => item.value === '') !== -1) { message.error('模板内容空'); return }
        dataQuery.templateId = templateId
        dataQuery.contentFields = fields
        if (isUrl) {
            if (url) {
                dataQuery.isUrl = isUrl
                dataQuery.url = url
            }
        } else {
            if (!miniprogramAppid || !miniprogramPagepath) {
            } else {
                dataQuery.isUrl = isUrl
                dataQuery.miniprogramAppid = miniprogramAppid
                dataQuery.miniprogramPagepath = miniprogramPagepath
            }
        }
        dataQuery.triggerType = triggerType
        if (triggerType === 1) {
            if (!sendTime) {
                message.error('请选择时间'); return
            } else {
                dataQuery.sendTime = sendTime
            }
        }
        if (triggerType === 3) {
            dataQuery.resDelayHours = resDelayHours//时
            dataQuery.resDelayMinutes = resDelayMinutes//分
            dataQuery.resDelaySecond = resDelaySecond//秒
        }
        dataQuery = { ...dataQuery, ...fansSelectValue }
        if (queryForm?.id) {
            // 修改
            dataQuery.id = queryForm.id
            modifyStrategy.run(dataQuery).then((res: any) => {
                if (res) {
                    listOfPage && listOfPage?.refresh()
                    handelHide()
                }
            })
        } else {
            // 新增
            strategy.run(dataQuery).then((res: any) => {
                if (res) {
                    listOfPage && listOfPage?.refresh()
                    handelHide()
                }
            })
        }


    }, [queryForm, tagObj, getActionWX.id, listOfPage, fields, fansSelectValue])

    /** 统一设置queryForm */
    const handleQueryForm = useCallback((data: data) => {
        setQueryForm({ ...queryForm, ...data })
    }, [queryForm])
    /** 任务名称 */
    const handleName = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
        let taskName = e.target.value
        handleQueryForm({ taskName })
    }, [queryForm])
    /** 设置粉丝 */
    const handelFans = useCallback((e: RadioChangeEvent) => {
        let v = e.target.value
        handleQueryForm({ fansAll: v === 1 ? true : false })
    }, [queryForm])
    /** 粉丝性别 */
    const handleSex = useCallback((e: RadioChangeEvent) => {
        let sex = e.target.value
        handleQueryForm({ fansFilterSex: sex })
    }, [queryForm])
    /** 设置标签 */
    const handleTag = useCallback((obj: { tagType: number, tagIds: any[] }) => {
        setTagObj({ fansFilterTagType: obj.tagType, fansFilterTagids: obj.tagIds })
    }, [])
    /** 选择模板 */
    const handleTem = useCallback((id: number) => {
        handleQueryForm({ templateId: id })
        setRefs([]);
        let tem = getKefuMsgStrategy?.data?.find((item: any) => item.id == id)
        setTemData({ title: tem?.title, dataTem: tem?.template?.content })
        setTemplate(tem?.template?.content)
        let fields = tem?.template?.fields?.map((item: any) => {
            return {
                field: item,
                value: '',
                color: '#000000'
            }
        })
        setFields(fields)
    }, [getKefuMsgStrategy?.data, queryForm, temData])
    /** 模板输入内容 */
    const handleTextArea = useCallback((e: ChangeEvent<HTMLTextAreaElement>, index: number, field: string) => {
        let value = e.target.value
        fields[index].value = value
        setFields([...fields])
    }, [fields])
    /** 颜色 */
    const handleChangeComplete = useCallback((color: string, index: number) => {
        fields[index].color = color
        setFields([...fields])
    }, [fields])
    /** 发送方式 */
    const handelSetTime = useCallback((e: RadioChangeEvent) => {
        let type = e.target.value
        handleQueryForm({ triggerType: type })
    }, [queryForm])
    /** 日期 */
    const setDate = useCallback((m: any, date: string) => {
        handleQueryForm({ sendTime: date })
    }, [queryForm])

    /** 插入昵称 */
    const insertNick = useCallback((value: string) => {
        try {
            document.execCommand('insertHTML', false, value)
        } catch (e) {
            console.log(e);
        }
    }, [])

    const handelHide = useCallback(() => {
        setQueryForm({
            id: undefined,
            taskName: '',
            fansAll: true,
            fansFilterSex: 'all',
            triggerType: 0,
            sendTime: null,
            templateId: null,
            enabled: 1,
            isUrl: true,
            url: "",
            miniprogramAppid: "",
            miniprogramPagepath: "",
            resDelayHours: 0,//时
            resDelayMinutes: 0,//分
            resDelaySecond: 0,//秒
        })
        setTagObj({
            fansFilterTagType: 0,
            fansFilterTagids: []
        })
        setFields([])
        onHide && onHide()
    }, [queryForm, tagObj, fields, onHide])

    // 本地预览
    const previewBd = useCallback(() => {
        let newDataTem: string = template
        fields.forEach((item: any) => {
            let reg = new RegExp("{{" + item.field + ".DATA}}", "ig")
            if (item) {
                newDataTem = newDataTem.replace(reg, `<span style="color:${item?.color ? item?.color : '#000'}">${item.value}</span>`)
            }
        });
        setTemData({ ...temData, dataTem: newDataTem })
    }, [temData, template, fields])
    ////////////////////////////////
    /**同步公众号模板信息*/
    const refreshTem = useCallback(() => {
        syncTemplate.run({ mpId: getActionWX.id }).then((res: any) => {
            getKefuMsgStrategy.refresh()
        })
    }, [getActionWX.id, getKefuMsgStrategy])
    /////////
    useEffect(() => {
        if (JSON.stringify(oldfields) !== JSON.stringify(fields) && fields.length > 0 && queryForm.templateId) {
            let obj = JSON.parse(JSON.stringify(fields))
            setOldfields(obj)
            refEl.current = <Row className={style.temContent}>
                {
                    fields.map((item: any, index: number) => (
                        <Col key={'a' + index}>
                            <label className={style.label}>{item.field}：</label>
                            <TextArea disabled={!isModify} rows={1} ref={(ref) => { refs[index] = ref; setRefs([...refs]) }} value={item.value} onChange={(e: ChangeEvent<HTMLTextAreaElement>) => handleTextArea(e, index, item.field)} />
                            {isModify && <Space>
                                <ColorPicker onColor={(color: string) => handleChangeComplete(color, index)} defaultColor={item?.color}></ColorPicker>
                            </Space>}
                        </Col>
                    ))
                }
            </Row>
        }
    }, [oldfields, refEl, JSON.stringify(fields), queryForm.templateId, isModify])
    return <div className={style.addModal}>
        <Drawer
            title={<span><img src={wx?.headImg || localStorage.bookImg} style={{ width: 40 }} /> <span style={{ marginLeft: 10 }}>{wx?.nickName}</span>--{queryForm?.id ? '修改' : '新增'}模板消息</span>}
            placement="right"
            width='90%'
            onClose={() => {
                handelHide()
            }}
            visible={visible}
            destroyOnClose
            footer={
                <div className={style.drawer_footer}>
                    <Space>
                        {/* dispatch({ type: 'initData' }), props.AdvancedDispatch({ type: 'setDefaultData', params: { defaultData: null } }) */}
                        <Button onClick={() => {
                            handelHide()
                        }}>取消</Button>
                        {isModify && <Button onClick={handleSubmit} type="primary" loading={strategy?.loading}>{queryForm?.id ? '修改' : '新增'}</Button>}
                        <Button onClick={previewBd} type="primary">本地预览</Button>
                        <PreviewModal isTem data={{ msgContents: { queryForm, tagObj, fields } }} />
                    </Space>
                </div>
            }
        >
            {
                rightMenuVis && <div className={style.menu} style={menuStyle}>
                    <Space>
                        {/* <Button size="small" onClick={() => { insertNick('#粉丝昵称#') }} type="text">插入昵称</Button> */}
                        <EmilModal getStr={(str: string) => { insertNick(str) }}></EmilModal>
                    </Space>
                </div>
            }

            <div className={style.box}>
                <div className={style.left}>

                    <Row className={style.left_content}>
                        <Col>
                            <div className={style.name}>
                                <label>任务名称：</label>
                                <Input placeholder='输入20字以内的任务名称' maxLength={20} value={queryForm.taskName} onChange={handleName} disabled={!isModify} />
                            </div>
                        </Col>
                        <Col className={style.left_fans}>
                            <div>
                                <label>群发粉丝：</label>
                                <Radio.Group onChange={handelFans} value={queryForm.fansAll ? 1 : 0} disabled={!isModify}>
                                    <Radio value={0}>按条件筛选粉丝</Radio>
                                    <Radio value={1}>全部粉丝<span>符合条件约<i>{fansNum || 0}</i> 人（如与实际粉丝数差别大，请同步粉丝）</span></Radio>
                                </Radio.Group>
                            </div>
                            {/* {
                                !queryForm.fansAll && <Row>
                                    <Col>
                                        <label>性别：</label>
                                        <Radio.Group onChange={handleSex} value={queryForm.fansFilterSex} disabled={!isModify}>
                                            <Radio value="all">全部</Radio>
                                            <Radio value={1}>男</Radio>
                                            <Radio value={2}>女</Radio>
                                            <Radio value={0}>未知</Radio>
                                        </Radio.Group>
                                    </Col>
                                    {
                                        <Col>
                                            <TagSelect
                                                labelWith={70}
                                                change={(obj: { tagType: number, tagIds: any[] }) => {
                                                    handleTag(obj)
                                                }}
                                                value={mpFansListDto}
                                            />
                                        </Col>
                                    }
                                </Row>
                            } */}
                            {
                                !queryForm.fansAll && <Row>
                                    <Col>
                                        <FansSelect callback={setFansSelectValue} defaultValue={props?.defaultData} />
                                    </Col>
                                </Row>
                            }
                        </Col>

                        <Col className={style.template}>
                            <div>
                                <label >选择模板：</label>
                                <Space>
                                    <Select disabled={!isModify} style={{ width: 350 }} defaultValue={defaultData.templateId || null} loading={getKefuMsgStrategy.loading} onChange={handleTem}>
                                        {
                                            getKefuMsgStrategy?.data?.map((item: any) => <Option key={item.id} value={item.id}>{item.title}</Option>)
                                        }
                                    </Select>
                                    <Button icon={<UndoOutlined />} onClick={refreshTem} disabled={!isModify}>刷新模板列表</Button>
                                </Space>
                            </div>
                            {refEl.current}
                        </Col>

                        <Col className={style.left_fans}>
                            <div>
                                <label>点击跳转：</label>
                                <Radio.Group disabled={!isModify} onChange={(e: RadioChangeEvent) => { handleQueryForm({ isUrl: e.target.value === 1 ? true : false }) }}
                                    value={queryForm.isUrl ? 1 : 2}
                                >
                                    {/* <Radio value={0}>立即发送</Radio> */}
                                    <Radio value={1}>链接</Radio>
                                    <Radio value={2}>小程序</Radio>
                                </Radio.Group>
                            </div>
                            {
                                queryForm.isUrl ? <Row>
                                    <Col>
                                        <label style={{ width: "120px" }}>跳转链接：</label>
                                        <Input disabled={!isModify} placeholder="用户点击模板后跳转到的网页链接" value={queryForm.url} onChange={(e: React.ChangeEvent<HTMLInputElement>) => handleQueryForm({ url: e.target.value })} />
                                    </Col>
                                </Row> :
                                    <Row>
                                        <Col>
                                            <label style={{ width: "120px" }}>APPID：</label>
                                            <Input disabled={!isModify} placeholder="小程序appid（该小程序appid必须与公众号是绑定关联关系）" value={queryForm.miniprogramAppid} onChange={(e: React.ChangeEvent<HTMLInputElement>) => handleQueryForm({ miniprogramAppid: e.target.value })} />
                                        </Col>
                                        <Col>
                                            <label style={{ width: "120px" }}>页面路径：</label>
                                            <Input disabled={!isModify} placeholder="跳转到小程序的具体页面路径，支持带参数,（示例index?foo=bar）" value={queryForm.miniprogramPagepath} onChange={(e: React.ChangeEvent<HTMLInputElement>) => handleQueryForm({ miniprogramPagepath: e.target.value })} />
                                        </Col>
                                    </Row>
                            }
                        </Col>

                        <Col className={style.left_time}>
                            <div>
                                <label>发送方式：</label>
                                <div>
                                    <Radio.Group onChange={handelSetTime}
                                        value={queryForm.triggerType}
                                        disabled={!isModify}
                                    >
                                        {/* <Radio value={0}>立即发送</Radio> */}
                                        <Radio value={0}>立即发送</Radio>
                                        <Radio value={1}>特定时间</Radio>
                                        <Radio value={3}>关注延迟指定时间</Radio>
                                    </Radio.Group>
                                </div>
                            </div>
                            <div />
                        </Col>
                        {
                            queryForm.triggerType !== 0 && <Col className={style.left_time}>
                                <div>
                                    <label>发送时间：</label>
                                    <div>
                                        {
                                            queryForm.triggerType === 1 && <Space>
                                                <DatePicker
                                                    disabledDate={(current) => {
                                                        let tppday = current && current < moment().startOf('day')
                                                        return tppday
                                                    }}
                                                    format={'YYYY-MM-DD HH:mm:ss'}
                                                    showTime
                                                    value={queryForm.sendTime ? moment(queryForm.sendTime) : undefined}
                                                    onChange={setDate}
                                                    disabled={!isModify}
                                                />
                                            </Space>
                                        }
                                        {
                                            queryForm.triggerType === 3 && <div>
                                                <Input
                                                    disabled={!isModify}
                                                    addonAfter="时"
                                                    style={{ width: 75 }}
                                                    size='small'
                                                    value={queryForm.resDelayHours}
                                                    onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
                                                        let v = Number(event.target.value)
                                                        if (isNaN(v)) {
                                                            message.error('请输入数字')
                                                            return
                                                        } else {
                                                            handleQueryForm({ resDelayHours: v })
                                                        }
                                                    }}
                                                />
                                                <Input
                                                    disabled={!isModify}
                                                    addonAfter="分"
                                                    style={{ width: 75 }}
                                                    size='small'
                                                    value={queryForm.resDelayMinutes}
                                                    onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
                                                        let v = Number(event.target.value)
                                                        if (isNaN(v)) {
                                                            message.error('请输入数字')
                                                            return
                                                        } else {
                                                            handleQueryForm({ resDelayMinutes: v })
                                                        }
                                                    }}
                                                />
                                                <Input
                                                    disabled={!isModify}
                                                    addonAfter="秒"
                                                    style={{ width: 75 }}
                                                    size='small'
                                                    value={queryForm.resDelaySecond}
                                                    onChange={(event: React.ChangeEvent<HTMLInputElement>) => {
                                                        let v = Number(event.target.value)
                                                        if (isNaN(v)) {
                                                            message.error('请输入数字')
                                                            return
                                                        } else {
                                                            handleQueryForm({ resDelaySecond: v })
                                                        }
                                                    }}
                                                />
                                            </div>
                                        }
                                    </div>
                                </div>
                                <div />
                            </Col>
                        }
                        <Col >
                            <div style={{ display: 'flex' }}>
                                <label>消息状态：</label>
                                <div>
                                    <Switch
                                        disabled={!isModify}
                                        checkedChildren="启用"
                                        unCheckedChildren="暂停"
                                        defaultChecked={!!queryForm.enabled}
                                        onChange={(checked) => { handleQueryForm({ enabled: checked ? 1 : 0 }) }}
                                    />
                                </div>
                            </div>
                            <div />
                        </Col>
                    </Row>
                </div>
                <div className={style.right}>
                    <WxDetailsBox data={{ msgType: 'tem', data: temData }}></WxDetailsBox>
                </div>
            </div>

        </Drawer>
    </div>
})

export default AddModal