import Tables from '@/components/Tables'
import { Button, Drawer, Input, Select, Space, Table } from 'antd'
import React, { useCallback, useEffect, useState } from 'react'
import { columns } from './tableConfig'
import style from './index.less'
import { useModel } from 'umi'
import { SelectValue } from 'antd/es/select'
import { PlusOutlined } from '@ant-design/icons'
const { Option } = Select;
import GroupWxTabs from '@/components/GroupWxTabs/wx'
import NoFoundPage from '@/pages/empty'
import { SearchOutlined } from '@ant-design/icons'
import AddModal from './components/addModal'
import { daysColumns } from './daysTableConfig'
import WxDetailsBox from '@/components/WxDetailsBox'

export type Action = {
    type: 'show' | 'setDefaultData' | 'theEditer' | 'del',
    params?: any
}
function Atemplate() {
    const { listOfPage, temDel } = useModel('useOperating.useAtemplate', model => ({
        listOfPage: model.listOfPageAjax,
        temDel: model.temDelAjax
    }))
    const { userId } = useModel('useOperating.useUser', model => ({ userId: model.state.selectdUserId }))
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({
        actionWX: model.state.actionWX,
    }))
    const [addVisible, setAddVisible] = useState<boolean>(false)   // 新增模板消息弹窗
    const [temVisible, setTemVisible] = useState<boolean>(false)   // 新增模板消息弹窗
    const [data, setData] = useState<{ status: SelectValue, taskName: string }>({
        status: '',
        taskName: ''
    })
    const [defaultData, setDefaultData] = useState<any>({})
    const [drawerVis, setDrawerVis] = useState<boolean>(false)
    const [daysMsg, setDaysMsg] = useState<any[]>([])
    const [temData, setTemData] = useState<{ title: string, dataTem: string }>({ title: "", dataTem: "" })
    // 搜索
    const search = useCallback(() => {
        const { status, taskName } = data
        let param = {}
        if (taskName != "") {
            param['taskName'] = taskName
        }
        if (status != 'all') {
            param['executionStatus'] = status
        }
        listOfPage.run({ mpId: actionWX?.id, pageSize: 20, pageNum: 1, ...param })
    }, [data, actionWX?.id])
    //状态选择
    const handelSelect = useCallback((value: SelectValue) => {
        setData({ ...data, status: value === 'all' ? '' : value })

    }, [listOfPage, userId])

    /** 删除 */
    const handleDel = useCallback((id: number) => {
        temDel.run({ id }).then((res: any) => {
            if (res) {
                listOfPage.refresh()
            }
        })
    }, [listOfPage, temDel])
    /** 修改 */
    const show = useCallback((data: any) => {
        setDefaultData(data)
        setAddVisible(true)
    }, [addVisible])
    const journalHandle = useCallback((executionLogs: any) => {
        setDaysMsg(executionLogs || [])
        setDrawerVis(true)
    }, [drawerVis])
    //首次加载搜索
    useEffect(() => {
        listOfPage.run({ mpId: actionWX?.id, pageSize: 20, pageNum: 1 })
    }, [actionWX?.id])
    //消息回复分页
    const pageSize = useCallback((page: number, pageSize?: number) => {
        listOfPage.run({ pageSize: pageSize, pageNum: page, mpId: actionWX?.id })
    }, [actionWX?.id, data])
    const seeHandle = useCallback((tem: string, contentFields: any[], title: string) => {
        let newDataTem: string = tem
        contentFields.forEach((item: any) => {
            let reg = new RegExp("{{" + item.field + ".DATA}}", "ig")
            if (item) {
                newDataTem = newDataTem.replace(reg, `<span style="color:${item?.color ? item?.color : '#000'}">${item.value}</span>`)
            }
        });
        setTemData({ title, dataTem: newDataTem })
        setTemVisible(true)
    }, [temData])
    return <>
        {
            actionWX ? <div>
                <div className={style.header}>
                    <Space>
                        <Select style={{ width: 150 }} defaultValue={'all'} onChange={handelSelect}>
                            <Option value={'all'}>全部状态</Option>
                            <Option value={0}>创建未执行</Option>
                            <Option value={1}>执行中</Option>
                            <Option value={2}>任务完成</Option>
                            <Option value={-1}>任务终止</Option>
                        </Select>
                        <Input placeholder='请输入模板消息名称' value={data.taskName} onChange={e => setData({ ...data, taskName: e.target.value })} allowClear />
                        <Button type="primary" size='middle' icon={<SearchOutlined type="primary" />} onClick={search} loading={listOfPage.loading}>搜索</Button>
                    </Space>
                    <Button type='primary' onClick={() => { setAddVisible(true) }}><PlusOutlined />新增模板消息</Button>
                    {addVisible && <AddModal defaultData={defaultData} visible={addVisible} listOfPage={listOfPage} onHide={() => { setAddVisible(false); setDefaultData({}) }}></AddModal>}

                </div>
                <GroupWxTabs isDisabled={false}>
                    <Tables
                        dataSource={listOfPage?.data?.records || []}
                        columns={columns({ handleDel, del: temDel, show, journalHandle, seeHandle })}
                        total={listOfPage?.data?.total}
                        current={listOfPage?.data?.current}
                        scroll={{x: 1000}}
                        rowClassName={(record: any) => {
                            if (record?.checkStatus === -1) {
                                return 'error'
                            } else {
                                return ""
                            }
                        }}
                        pageChange={pageSize}
                        sizeChange={pageSize}
                        
                    />
                </GroupWxTabs>
            </div> : <NoFoundPage />
        }

        <Drawer
            title="执行日志"
            placement='top'
            onClose={() => setDrawerVis(false)}
            visible={drawerVis}
            height='400'
        >
            <Tables
                dataSource={daysMsg}
                columns={daysColumns()}
                total={daysMsg?.length}
            />
        </Drawer>
        <Drawer
            title="查看模板消息内容"
            placement='right'
            onClose={() => setTemVisible(false)}
            visible={temVisible}
            width='380'
        >
            <WxDetailsBox data={{ msgType: 'tem', data: temData }}></WxDetailsBox>
        </Drawer>
    </>
}

export default Atemplate