import { Badge, Button, Popconfirm, Space, Switch, Tag, Tooltip } from 'antd'
import React from 'react'
import { bgColor } from '@/utils/color'
import Look from '../../examine/components/look'

let sex = ['未知', '男', '女']

type Props = {
    handleDel: (id: number) => void,
    del: any,
    show: (data: any) => void,
    journalHandle: (executionLogs: any) => void,
    seeHandle: (tem: string, contentFields: any[], title: string) => void
}

export const columns = (props: Props) => {
    const { handleDel, del, show, journalHandle, seeHandle } = props
    return [
        {
            title: '模板消息名称',
            dataIndex: 'taskName',
            key: 'taskName',
            align: 'center',
            width: 200,
            render: (a: number, b: any) => {
                return <div>
                    {b.checkStatus === -1 ? <Tooltip title={`未通过原因：${b?.checkRemark ? b?.checkRemark : ''}`}>
                        <div>
                            <div>{a}</div>
                            <div><span style={{color: 'red', fontSize: 12}}>(审查未通过)</span></div>
                        </div>
                    </Tooltip> : <span>{a}</span>}
                </div>
            }
        },
        {
            title: '模板名称',
            dataIndex: 'templateMsgInfo',
            key: 'templateMsgInfo',
            align: 'center',
            width: 200,
            render: (a: any, b: any) => {
                return <span>{a?.title}</span>
            }
        },
        {
            title: '发送对象',
            dataIndex: 'fansAll',
            key: 'fansAll',
            align: 'center',
            width: 200,
            render: (a: string, b: { time: string, sendTime: string, weekDay: number, fansFilterSex: number, fansFilterTags: any[], fansFilterTagType: number }) => {
                if (a) {
                    return '全部粉丝'
                } else {
                    return <div style={{ display: 'flex', flexFlow: 'column ' }}>
                        <span>性别：{b?.fansFilterSex !== null ? sex[b?.fansFilterSex] : '全部'}</span>
                        {/* <span>类型：{fansTagType[b?.tagType]}</span> */}
                        <div>
                            {
                                b?.fansFilterTagType === 0 ? '类型：并集' : b?.fansFilterTagType === 1 ? '类型：交集' : b?.fansFilterTagType === 2 ? '类型：取反' : ''
                            }
                        </div>
                        {
                            b?.fansFilterTags?.length > 0 && <div>
                                标签：{
                                    b?.fansFilterTags?.map((item: any, index: number) => {
                                        return <Tag key={item.id} color={item?.id ? bgColor[item?.id] : ''} style={{ marginBottom: 8 }}>{item.name}</Tag>
                                    })
                                }
                            </div>
                        }


                    </div>

                }
            }
        },
        {
            title: '发送方式',
            dataIndex: 'triggerType',
            key: 'triggerType',
            align: 'center',
            width: 200,
            render: (a: number, b: any) => {
                let type = ['立即发送', '特定时间']
                let msg = ''
                let sj = ''
                let time = b?.resDelayHours || b?.resDelayMinutes || b?.resDelaySecond
                if (type[a]) {
                    msg = type[a]
                    if (a === 1) {
                        sj = b?.sendTime
                    }
                }

                return <div style={{ display: 'flex', flexFlow: 'column ' }}>
                    {
                        a === 3 ? <>
                            <span>关注延迟指定时间</span>
                            <span>{time ? `${b?.resDelayHours ? b?.resDelayHours + '小时' : ''} ${b?.resDelayMinutes ? b?.resDelayMinutes + '分' : ''}${b?.resDelaySecond}秒` : '立即发送'}</span>
                        </> : <>
                                <span>{msg}</span>
                                {sj && <span>{sj}</span>}
                            </>
                    }
                </div>

            }
        },
        {
            title: '运行状态',
            dataIndex: 'executionStatus',
            key: 'executionStatus',
            align: 'center',
            width: 200,
            render: (a: number, b: any) => {
                return <span>
                    {b.executionStatus === 0 ? <Badge status="warning" text='创建未执行' /> : b.executionStatus === 1 ? <Badge status="processing" text='执行中' /> : b.executionStatus === 2 ? <Badge status="success" text='任务完成' /> : <Badge status="error" text='任务终止' />}
                </span>
            }
        },
        {
            title: '启动状态',
            dataIndex: 'enabled',
            key: 'enabled',
            align: 'center',
            width: 100,
            render: (a: any, b: any) => {
                return <span>{a ? <Tag color="#87d068">启动</Tag> : <Tag color="#f50">暂停</Tag>}</span>
            }
        },
        {
            title: '操作',
            key: 'action',
            dataIndex: 'action',
            align: 'center',
            width: 200,
            render: (a: any, data: any) => {
                return <div onClick={(e: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
                    e.preventDefault()
                    e.stopPropagation()
                }}>
                    <Space>
                        < Button onClick={() => {
                            show(data)
                        }} size='small' >编辑</Button>

                        <Button type="dashed" onClick={() => {
                            journalHandle(data?.executionLogs)
                        }} size='small'>执行日志</Button>
                        <Button type="dashed" onClick={() => {
                            seeHandle(data?.templateMsgInfo?.template?.content, data?.contentFields, data?.templateMsgInfo?.title)
                        }} size='small'>查看</Button>
                        <Look type='Atemplate' strategyId={data?.id} id={data?.mpId} size="small" />
                        < Popconfirm
                            title='确定要删除吗?'
                            onConfirm={() => {
                                handleDel(data.id)
                            }}
                        >
                            <Button size='small' loading={del?.loading} danger>删除</Button>
                        </Popconfirm>
                    </Space>
                </div >
            }
        }
    ]
}

