import React, { useState, Suspense, useEffect, useCallback } from 'react'
import DatePickePage from '@/components/DatePicker'
import { useModel } from 'umi'
import style from '../../index.less'
import { Row, Col, Card, Divider, Spin, Table } from 'antd'
import { useBeforeTime } from '@/Hook/useDate'
import Tables from '@/components/Tables'
import { columns } from './tablesCongig'
import { isArray } from 'lodash'
import useEcharts from '@/Hook/useEcharts'

/**
 * 活跃度
 */


interface handleDataIn {
    activeCount: number
    activeCountOfFifteen: number
    activeCountOfSeven: number
    activeRate: number
    fansCount: number
    statisticsDate: string,
    key?: number
}

const Activity: React.FC = () => {
    const { Line } = useEcharts()
    const endDay = useBeforeTime(1, 'day', 'YYYY-MM-DD')
    const beforeDay = useBeforeTime(7, 'day', 'YYYY-MM-DD')
    const [date, setDate] = useState<string[]>([beforeDay, endDay])//存放日期
    const actionWX = useModel('useOperating.useWxGroupList', model => model.state.actionWX)
    const { fansActive } = useModel('useOperating.useOperate', model => ({ fansActive: model.fansActive }))
    const [tableTotal, setTableTotal] = useState<any>({ name: '总计' })//总计
    const [multiLineData, setMultiLineData] = useState<any[]>([])
    const [averageFenCount, setAverageFenCount] = useState<number>(0) // 平均每天活跃粉丝
    const [averageActiveScale, setAverageActiveScale] = useState<string>('0.0%') // 平均活跃比例

    let fansSynergism: any = {
        data: multiLineData.reverse(),
        position: 'date*temperature',
        color: 'name',
        Lineshape: 'smooth',
        Pointshape: 'circle',
        scale: { date: { tickCount: 12 } }
    }

    let DatePickerChange = (m: any, str: string | [string, string]) => {
        setDate(Array.isArray(str) ? str : [str])
    }
    const [listData, setListData] = useState<handleDataIn[]>([]);

    const handleData = useCallback((res: handleDataIn[]) => {
        let fansCountSum = handleSum(res, 'fansCount');
        let activeCountSum = handleSum(res, 'activeCount');
        let activeCountOfFifteenSum = handleSum(res, 'activeCountOfFifteen');
        let activeCountOfSevenSum = handleSum(res, 'activeCountOfSeven');
        let activeRateSum = handleSum(res, 'activeRate');

        setAverageFenCount(Number((activeCountSum / res.length).toFixed(1)))
        if (activeCountSum === 0 || fansCountSum === 0) {
            setAverageActiveScale('0%')
        } else {
            setAverageActiveScale((activeCountSum / fansCountSum * 100).toFixed(1) + '%')
        }
        let data: { legendName: string, [key: string]: any }[] = [
            { legendName: '活动粉丝数' },
            { legendName: '7天内互动粉丝数' },
            { legendName: '15天内互动粉丝数' },
            { legendName: '总粉丝数' },
        ]
        res.forEach((item, i) => {
            Object.keys(item).forEach((key: string) => {
                switch (key) {
                    case 'activeCount':
                        data[0] = { ...data[0], [item.statisticsDate]: item.activeCount }
                        break;
                    case 'activeCountOfSeven':
                        data[1] = { ...data[1], [item.statisticsDate]: item.activeCountOfSeven }
                        break;
                    case 'activeCountOfFifteen':
                        data[2] = { ...data[2], [item.statisticsDate]: item.activeCountOfFifteen }
                        break;
                    case 'fansCount':
                        data[3] = { ...data[3], [item.statisticsDate]: item.fansCount }
                        break;
                }
            })
            item.key = i
            return item
        })
        setMultiLineData(data)
        setTableTotal({
            name: '平均',
            activeCount: Number((activeCountSum / res.length).toFixed(1)),
            activeCountOfSeven: Number((activeCountOfSevenSum / res.length).toFixed(1)),
            activeCountOfFifteen: Number((activeCountOfFifteenSum / res.length).toFixed(1)),
            fansCount: Number((fansCountSum / res.length).toFixed(1)),
            activeRate: Number((activeRateSum / res.length).toFixed(1)),
        })
        setListData(res);
    }, []);

    const handleSum = (res: any[], key: string) => {
        if (!isArray(res)) {
            return
        }
        return res.reduce((total, current) => {
            return total += current[key]
        }, 0)
    }

    useEffect(() => {
        if (actionWX && date.length > 0) {
            fansActive.run({ mpId: actionWX?.id, timeDto: { "beginDate": date[0], "endDate": date[1] } }).then((res) => {
                res && handleData(res)
            })
        }
    }, [date, actionWX])
    return <>
        <div className={style.grow_header}>
            <div className={style.grow_header_top} >
                <Row gutter={[8, 8]}>
                    <Col ><DatePickePage model='RangePicker' DatePickerChange={DatePickerChange} scope={{ num: 33, unit: 'day' }} before={1} date={date} /></Col>
                </Row>
            </div>
            <div className={style.grow_header_bottom}>
                这段时间里，平均每天有 <span style={{ color: '#ff562d' }}>{averageFenCount}</span>   个活跃粉丝，平均活跃比例为  <span style={{ color: '#ff562d' }}>{averageActiveScale}</span>
            </div>
        </div>
        <Suspense fallback='加载中。。。'>
            <Card>
                <Line data={fansSynergism.data} style={{ width: '100%', height: 500 }} />
                <Divider plain style={{ paddingTop: '20px' }} orientation="left" ><strong>详细数据</strong></Divider>
                {fansActive?.loading ? <Spin size="large" /> : <Tables
                    columns={columns} dataSource={listData}
                    summary={() => {
                        return <Table.Summary.Row>
                            {
                                Object.keys(tableTotal).map((k: string, i: number) => {
                                    return <Table.Summary.Cell key={k} index={i} className={style.cell}>{tableTotal[k]}</Table.Summary.Cell>
                                })
                            }
                        </Table.Summary.Row>
                    }}
                />}
            </Card>
        </Suspense>
    </>
}

export default React.memo(Activity)