import React, { useState, useEffect, useCallback } from 'react'
import { Tag, Radio, Row, Card, Divider, } from 'antd'
import style from './index.less'
import { ExclamationCircleOutlined } from '@ant-design/icons'
import { RadioChangeEvent } from 'antd/lib/radio'
import DatePickePage from '@/components/DatePicker'
import Tables from '@/components/Tables'
import { columns } from './tablesCongig'
import { useModel } from 'umi'
import { useBeforeTime } from '@/Hook/useDate'
import useEcharts from '@/Hook/useEcharts'



/**
 * 粉丝属性模块
 */
function Attribute() {
    // let { fansTop, fansSource = [], fansTable = [], fansCount = [], fansArea = [] } = state
    const [tabkey, setTabkey] = useState<string>('新增粉丝')
    const { Map, PieFocus } = useEcharts()
    const { fansAttribute } = useModel('useOperating.useOperate', model => ({ fansAttribute: model.fansAttribute }))
    const actionWX = useModel('useOperating.useWxGroupList', model => model.state.actionWX)
    const endDay = useBeforeTime(1, 'day', 'YYYY-MM-DD')
    const beforeDay = useBeforeTime(7, 'day', 'YYYY-MM-DD')
    const [date, setDate] = useState<any[]>([beforeDay, endDay])//存放日期
    const [fansSource, setFansSource] = useState<any[]>([])//来源数据
    const [fansTable, setFansTable] = useState<any[]>([])//表格数据
    const [fansArea, setFansArea] = useState<any>([])//地图数据
    const [fansCount, setFansCount] = useState<any[]>([])//统计数据
    const [fansTop, setFansTop] = useState<any>()//顶部数据
    /**新增粉丝全部粉丝选择 */
    let handleModeChange = (e: RadioChangeEvent) => {
        let value = e.target.value
        setTabkey(value)
    }
    /**获取日期选择器的值 */
    let DatePickerChange = (m: any, str: string | [string, string]) => {
        setDate(Array.isArray(str) ? str : [str])
    }
    /**处理数据函数 */
    let handleData = useCallback((arr: any[]) => {
        let sourceArr: { name?: string, value?: number, percent: number }[] = []
        let sexArr: { name?: string, value?: number, percent: number }[] = []
        let itemArr: any[] = []
        let areaObj: any = []

        arr?.forEach((item: any) => {
            if (item.name === "subscribeScene") {
                itemArr = item?.stats
            }
            item?.stats?.forEach((sex: any) => {
                if (item.name === "subscribeScene") {
                    sourceArr.push({ name: sex.key, value: sex.value, percent: sex.percentage })
                }
                if (item.name === 'sex') {
                    sexArr.push({ name: sex.key, value: sex.value, percent: sex.percentage })
                }
                if (item.name === "province") {
                    areaObj.push({ name: sex.key, value: sex.value })
                }
            })
        })
        setFansSource(sourceArr)//插入粉丝来源
        setFansTable(itemArr)//插入粉丝来源
        setFansCount(sexArr)//插入粉丝性别数据
        setFansArea(areaObj)//插入粉丝区域
    }, [])
    /**tabs切换重新获取数据 */
    useEffect(() => {
        if (actionWX) {
            if (tabkey === '新增粉丝') {
                fansAttribute.run({ mpId: actionWX?.id, beginDate: date[0], endDate: date[1] }).then((res: any) => {
                    if (res) {
                        let { fansAttributeInnerVo, ...data } = res
                        setFansTop(data)
                        if (Array.isArray(fansAttributeInnerVo)) {
                            handleData(fansAttributeInnerVo)//处理数据
                        } else {
                            setFansSource([])
                            setFansTable([])
                            setFansCount([])
                            setFansArea([])
                        }
                    }
                })
            } else {
                fansAttribute.run({ mpId: actionWX?.id }).then((res: any) => {
                    if (res) {
                        let { fansAttributeInnerVo, ...data } = res
                        setFansTop(data)
                        if (Array.isArray(fansAttributeInnerVo)) {
                            handleData(fansAttributeInnerVo)//处理数据
                        } else {
                            setFansSource([])
                            setFansTable([])
                            setFansCount([])
                            setFansArea([])
                        }
                    }
                })
            }
        }
    }, [tabkey, date, handleData])
    return <div>
        <Row>
            <Tag color="green" className={style.tag} ><ExclamationCircleOutlined style={{ color: 'red', marginRight: 5 }} />观察新增粉丝来源，可以总结出最为有效的粉丝增量渠道，使用【渠道二维码】功能，更精细地利用关注场景。</Tag>
        </Row>
        <Row className={style.tabs}>
            <Radio.Group onChange={handleModeChange} value={tabkey} style={{ marginBottom: 8 }}>
                <Radio.Button value="新增粉丝">新增粉丝</Radio.Button>
                <Radio.Button value="全部粉丝">全部粉丝</Radio.Button>
            </Radio.Group>
        </Row>
        {
            tabkey === '新增粉丝' && <>
                <Row className={style.date}>
                    <DatePickePage model='RangePicker' DatePickerChange={DatePickerChange} scope={{ num: 1, unit: 'month' }} before={1} date={date} />
                </Row>
                <Row className={style.text}>
                    <span>这段时间里，新增粉丝<span> {fansTop?.cumulateUser || 0} </span>人，男粉丝 <span>{fansTop?.male || 0}</span>人，占比 <span>{(fansTop?.malePct * 100).toFixed(2) || 0}%</span> , 女粉丝<span> {fansTop?.female || 0} </span>人，占比 <span>{(fansTop?.femalePct * 100).toFixed(2) || 0}%</span></span>
                </Row>
            </>
        }
        <Row>
            <Card style={{ width: '100%' }}>
                <Divider orientation="left" plain style={{ marginTop: 0 }}><strong>{tabkey}来源</strong></Divider>
                <div style={{ display: 'flex', justifyContent: 'center' }}>
                    {
                        !fansAttribute?.loading && <PieFocus style={{ width: 600, height: 300 }} data={fansSource} name='新增粉丝来源' centerName='总关注' />
                    }
                </div>
                <Divider orientation="left" plain style={{ marginTop: 0 }}><strong>详细数据</strong></Divider>
                <Tables dataSource={fansTable} columns={columns} />
                <Divider orientation="left" plain style={{ marginTop: 0 }}><strong>{tabkey}性别统计</strong></Divider>
                <div style={{ display: 'flex', justifyContent: 'center' }}>
                    { !fansAttribute?.loading && <PieFocus style={{ width: 600, height: 300 }} data={fansCount} name='新增粉丝性别统计' centerName='总关注' />}
                </div>
                <Divider orientation="left" plain style={{ marginTop: 0 }}><strong>{tabkey}地域统计</strong></Divider>
                {!fansAttribute?.loading && <Map data={fansArea} style={{ width: '500', height: 900 }} />}
            </Card>
        </Row>
    </div>
}

export default Attribute


