import React, { useState, Suspense, useEffect } from 'react'
import { Button, Tooltip, Card, Row, Col, Divider } from 'antd'
import style from '../../index.less'
import { QuestionCircleOutlined } from '@ant-design/icons'
import DatePickePage from '@/components/DatePicker'
import Tables from '@/components/Tables'
import { useModel } from 'umi'
import { columns } from './tablesCongig'
import { useBeforeTime, useformatTime } from '@/Hook/useDate'
import useEcharts from '@/Hook/useEcharts'

/**
 * 粉丝增长模块
 */
function Grow(props: { tabName: string }) {
    const { Line } = useEcharts()
    const [isCheck, setIsCheck] = useState<string>('1')//存放点击按钮的key
    const { getFans, dispatch, fansData } = useModel('useOperating.useOperate', model => ({ getFans: model.fanGrowth, dispatch: model.dispatch, fansData: model.state.fansData }))
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const beforeMonths = useBeforeTime(1, 'months', 'YYYY-MM-DD')
    const beforeWeek = useBeforeTime(6, 'weeks', 'YYYY-MM-DD')
    const beforeYear = useBeforeTime(1, 'years', 'YYYY-MM-DD')
    const today = useformatTime()
    const [date, setDate] = useState<any[]>([today, today])//存放日期
    let lineprops: any = {
        data: fansData,
        position: 'date*temperature',
        color: 'name',
        Lineshape: 'smooth',
        Pointshape: 'circle',
        scale: { date: { tickCount: 12 } }
    }
    //按钮点击事件
    let handleCheck = (event: any) => {
        let str = event.target.innerText.replace(/\s/g, '')
        switch (str) {
            case '按小时':
                setIsCheck('1')
                setDate([today, today])
                break;
            case '按天':
                setIsCheck('2')
                setDate([beforeMonths, today])
                break;
            case '按周':
                setIsCheck('3')
                setDate([beforeWeek, today])
                break;
            case '按月':
                setIsCheck('4')
                setDate([beforeYear, today])
                break;
            default:
                return
        }
    }
    //获取日期选择器的值
    let DatePickerChange = (m: any, str: string | [string, string]) => {
        setDate(Array.isArray(str) ? str : [str])
    }
    //时间改变请求数据
    useEffect(() => {
        if (date.length > 0) {
            let beginDate = date[0]
            let endDate = date[1]
            getFans.run({ mpId: actionWX?.id, beginDate, endDate, type: isCheck }).then((res: { vos: any[] }) => {
                let newArr: any[] = [
                    { legendName: '新增关注' },
                    { legendName: '取消关注' },
                    { legendName: '净关注' },
                ]
                if (res?.vos.length > 0) {
                    res?.vos?.forEach((item: any) => {
                        Object.keys(item).forEach((key) => {
                            let { beginRef, hour, endRef } = item
                            let date: string = beginRef.length > 10 ? item.beginRef.replace(/^2[\w]{3}-/, '') : beginRef
                            if (beginRef === endRef) {
                                date += hour < 10 ? ` 0${hour}:00` : ` ${hour}:00`
                            } else {
                                date += '--' + endRef
                            }

                            switch (key) {
                                case 'newUser':
                                    newArr[0] = { ...newArr[0], [date]: item[key] }
                                    break;
                                case 'cancelUser':
                                    newArr[1] = { ...newArr[1], [date]: item[key] }
                                    break;
                                case 'netGrowth':
                                    newArr[2] = { ...newArr[2], [date]: item[key] }
                                    break;
                            }
                        })
                    })
                }
                dispatch({ type: 'setFansData', params: { fansData: newArr } })
            })
        }
    }, [date, isCheck])
    return <>
        <div className={style.grow_header}>
            <div className={style.grow_header_top} onClick={handleCheck} >
                <Row gutter={[8, 8]}>
                    <Col ><Button type={isCheck === '1' ? 'primary' : 'default'}>按小时</Button></Col>
                    {
                        isCheck === '1' && <Col ><DatePickePage model='RangePicker' DatePickerChange={DatePickerChange} scope={{ num: 3, unit: 'day' }} date={date} /></Col>
                    }
                    <Col ><Button type={isCheck === '2' ? 'primary' : 'default'}>按天</Button></Col>
                    {
                        isCheck === '2' && <Col ><DatePickePage model='RangePicker' DatePickerChange={DatePickerChange} scope={{ num: 1, unit: 'month' }} date={date} /></Col>
                    }
                    <Col ><Button type={isCheck === '3' ? 'primary' : 'default'}>按周</Button></Col>
                    {
                        isCheck === '3' && <Col ><DatePickePage model='RangePicker' DatePickerChange={DatePickerChange} scope={{ num: 1, unit: 'year' }} date={date} /></Col>
                    }
                    <Col ><Button type={isCheck === '4' ? 'primary' : 'default'}>按月</Button></Col>
                </Row>
            </div>
            <div className={style.grow_header_bottom}>
                这段时间里，共有<span> {getFans?.data?.totalNews} </span> 人新关注，
                <span>{getFans?.data?.totalCancel}</span>人取关，
                取关率<span>{getFans?.data?.totalCustomsClearanceRate * 100}'%'</span>，
                净增长<span>{getFans?.data?.totalNetGrowth}</span>人，
                平均每月增长<span>{getFans?.data?.avgNetGrowth}</span>人
            <Tooltip title='取关率=取消关注粉丝数/(总粉丝数+取消关注粉丝数）'>
                    <QuestionCircleOutlined style={{ color: 'red', marginLeft: 10 }} />
                </Tooltip>
            </div>
        </div>
        <Suspense fallback='加载中。。。'>
            <Card>
                <Line data={lineprops.data} style={{ width: '100%', height: 500 }} />
                <Divider plain style={{ paddingTop: '20px' }} orientation="left" ><strong>详细数据</strong></Divider>
                <Tables columns={columns} dataSource={
                    getFans?.data?.vos || []
                } />
            </Card>
        </Suspense>
    </>
}

export default React.memo(Grow)




