import React, { useState, Suspense,  useCallback, useEffect } from 'react'
import { Button, Card, Row, Col, Divider, Table, Drawer } from 'antd'
import style from '../../index.less'
import DatePickePage from '@/components/DatePicker'
import Tables from '@/components/Tables'
import { useModel } from 'umi'
import { columns, detialColumn } from './tablesCongig'
import { useBeforeTime } from '@/Hook/useDate'
import useEcharts from '@/Hook/useEcharts'

/**
 * 图文影响力模块
 */
function Impact(props: { tabName: string }) {
    const { Line } = useEcharts()
    const endDay = useBeforeTime(1, 'day', 'YYYY-MM-DD')
    const beforeDay = useBeforeTime(7, 'day', 'YYYY-MM-DD')
    const [isCheck, setIsCheck] = useState<string>('近一周')//存放点击按钮的文本
    const [date, setDate] = useState<any[]>([beforeDay, endDay])//存放日期
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const { articleSummary } = useModel('useOperating.useOperate', model => ({ articleSummary: model.articleSummary }))
    const [topData, setTopData] = useState<{ totalNews: number, totalReadUser: number, totalShareUser: number }>({ totalNews: 0, totalReadUser: 0, totalShareUser: 0 })
    const [tableData, setTableData] = useState<any[]>([])//table数据
    const [lineData, setLineData] = useState<any[]>([])//折线数据
    const [total, setTotal] = useState<any>({ name: '总计' })//总计
    const [visible, setVisible] = useState<boolean>(false);//详情弹窗
    const [xqData, setXqData] = useState<any[]>([]);//详情数据存放
    let lineprops: any = {
        data: lineData,
        position: 'date*value',
        color: 'name',
        Lineshape: 'smooth',
        Pointshape: 'circle'
    }
    const showDrawer = () => {
        setVisible(!visible);
    };
    //按钮点击事件
    let handleCheck = (event: any) => {
        let str = event.target.innerText.replace(/\s/g, '')
        if (str === '近一月' || str === '近一周') {
            setIsCheck(str)
        }
        switch (str) {
            case '近一周':
                setDate([beforeDay, endDay])
                break;
            case '近一月':
                setDate([useBeforeTime(1, 'months', 'YYYY-MM-DD'), endDay])
                break;
            default:
                return
        }
    }
    // useEffect(() => { props.callback(date) }, [date])//日期变化传回给父组件
    //获取日期选择器的值
    let DatePickerChange = (m: any, str: string | [string, string]) => {
        setDate(Array.isArray(str) ? str : [str])

    }
    //首次加载请求
    useEffect(() => {
        if (actionWX) {
            articleSummary.run({ mpId: actionWX?.id, beginDate: date[0], endDate: date[1] }).then((res: any) => {
                if (res) {
                    let { vos, ...topData } = res
                    setTopData(topData)
                    setTableData(vos)
                    let data: { legendName: string, [key: string]: any }[] = [
                        {legendName: '阅读原文次数'},
                       { legendName: '阅读原文人数'},
                        {legendName: '阅读次数'},
                        {legendName: '阅读人数'},
                       { legendName: '分享次数'},
                        {legendName: '分享人数'}
                    ]
                    vos?.forEach((item: any) => {//处理数据符合折线图数据
                        Object.keys(item).forEach((key) => {
                            switch (key) {
                                case 'oriPageReadCount':
                                    data[0] = { ...data[0], [item.refDate]: item.oriPageReadCount || 0 }
                                    break;
                                case 'oriPageReadUser':
                                    data[1] = { ...data[1], [item.refDate]: item.oriPageReadUser || 0 }
                                    break;
                                case 'readCount':
                                    data[2] = { ...data[2], [item.refDate]: item.readCount || 0 }
                                    break;
                                case 'readUser':
                                    data[3] = { ...data[3], [item.refDate]: item.readUser || 0 }
                                    break;
                                case 'shareCount':
                                    data[4] = { ...data[4], [item.refDate]: item.shareCount || 0 }
                                    break;
                                case 'shareUser':
                                    data[5] = { ...data[5], [item.refDate]: item.shareUser || 0 }
                                    break;
                            }
                        })
                    })
                    setTotal({
                        name: '总计',
                        totalNews: topData.totalNews,//发文
                        totalNewss: topData.totalCount,//送达
                        totalRead: topData.totalReadUser + '/' + topData.totalReadCount,//阅读人数/次数
                        totalShare: topData.totalShareUser + '/' + topData.totalShareCount,//分享人数/次数
                        totalText: topData.totalOriPageReadUser + '/' + topData.totalOriPageReadCount,//阅读原文人数/次数
                        action: ''//占位
                    })
                    setLineData(data)
                }
            })
        }
    }, [actionWX, date])
    /**获取columns点击事件中的参数*/
    const xqCallback = useCallback((item: any) => {
        showDrawer();
        if (Array.isArray(item?.details)) {
            setXqData(item?.details)
        }
    }, [])
    return <>
        <div className={style.grow_header}>
            <div className={style.grow_header_top} onClick={handleCheck} >
                <Row gutter={[8, 8]}>
                    <Col ><DatePickePage model='RangePicker' DatePickerChange={DatePickerChange} scope={isCheck === '近一周' ? { num: 1, unit: 'week' } : { num: 1, unit: 'month' }} date={date} before={1} /></Col>
                    <Col ><Button type={isCheck === '近一周' ? 'primary' : 'default'}>近一周</Button></Col>
                    <Col ><Button type={isCheck === '近一月' ? 'primary' : 'default'}>近一月</Button></Col>
                </Row>
            </div>
            <div className={style.grow_header_bottom}>
                这段时间里，共有：<span>{topData?.totalNews}</span> 次推文，
             <span>{topData?.totalNews}</span> 篇文章，
             阅读人数<span>{topData?.totalReadUser}</span>，
            分享人数<span>{topData?.totalShareUser}</span>，数据不去重
        </div>
        </div>
        <Suspense fallback='加载中。。。'>
            <Card>
                <Line data={lineprops.data} style={{ width: '100%', height: 500 }} />
                <Divider plain style={{ paddingTop: '20px' }} orientation="left" ><strong>详细数据</strong></Divider>
                <Tables
                    columns={columns(xqCallback)} dataSource={tableData}
                    summary={() => {
                        return <Table.Summary.Row>
                            {
                                Object.keys(total).map((k: string, i: number) => {
                                    return <Table.Summary.Cell key={k} index={i} className={style.cell}>{total[k]}</Table.Summary.Cell>
                                })
                            }
                        </Table.Summary.Row>
                    }}
                />
            </Card>
        </Suspense>
        <Drawer
            title="详情"
            placement="top"
            closable={false}
            height={420}
            onClose={showDrawer}
            visible={visible}
        >
            <Tables columns={detialColumn} dataSource={xqData} scroll={{ y: 200 }} />
        </Drawer>
    </>
}

export default Impact




