import React, { useState, Suspense, useCallback, useEffect } from 'react'
import { Tooltip, Card, Row, Col, Divider, Spin, Radio } from 'antd'
import style from '../../index.less'
import { QuestionCircleOutlined } from '@ant-design/icons'
import DatePickePage from '@/components/DatePicker'
import Tables from '@/components/Tables'
import { useModel } from 'umi'
import { columns } from './tablesCongig'
import { useBeforeTime } from '@/Hook/useDate'
import useEcharts from '@/Hook/useEcharts'

/**
 * 互动消息
 */

interface ListDataIn {
    key: number
    date: string
    msgCount: number
    clickMenuCount: number
    scanQrcode: number
    subcribe: number
    unsubcribe: number,
    total: number
}
interface multiLineDataIn {
    percent: number
    name: string
    value: number
}

const Grow: React.FC = () => {
    const { Line, PieFocus } = useEcharts()
    const endDay = useBeforeTime(1, 'day', 'YYYY-MM-DD')
    const beforeDay = useBeforeTime(3, 'day', 'YYYY-MM-DD')
    const [date, setDate] = useState<string[]>([beforeDay, endDay])//存放日期
    const actionWX = useModel('useOperating.useWxGroupList', model => model.state.actionWX)
    const { fansInteractive } = useModel('useOperating.useOperate', model => ({ fansInteractive: model.fansInteractive }))
    const [listData, setListData] = useState<ListDataIn[]>([])
    const [multiLineData, setMultiLineData] = useState<multiLineDataIn[]>([])
    const [tabNmae, setTabName] = useState<string>('time')
    const [data, setData] = useState<{ legendName: string, [key: string]: any }[]>([])
    let onChange = (activeKey: any) => {
        setTabName(activeKey.target.value)
    }
    let fansSynergism: any = {
        data: data.reverse(),
        position: 'date*temperature',
        color: 'name',
        Lineshape: 'smooth',
        Pointshape: 'circle',
        scale: { date: { tickCount: 12 } }
    }
    //获取日期选择器的值
    let DatePickerChange = (m: any, str: string | [string, string]) => {
        setDate(Array.isArray(str) ? str : [str])
    }
    let handleData = useCallback((arr: any) => {
        let data: { legendName: string, [key: string]: any }[] = [
            { legendName: '菜单点击' },
            { legendName: '发送消息' },
            { legendName: '扫码' },
            { legendName: '关注' },
            { legendName: '取关' },
        ]
        let listDataz: ListDataIn[] = []
        let clickMenuCountTotal = 0 // 菜单点击总数
        let msgCountTotal = 0  //发送消息总数
        let scanQrcodeTotal = 0  // 扫码总数
        let subcribeTotal = 0  // 关注总数
        let unsubcribeTotal = 0  // 取关总数
        // for (let key in arr) {
        if (arr.length > 0) {
            arr.forEach((item: { clickMenuCount: number, hour: number, msgCount: number, scanQrcode: number, subcribe: number, unsubcribe: number,statDate:string }, i: number) => {
                let myHour = item.hour < 10 ? '0' + item.hour : item.hour;
                let myDate = item.statDate
                clickMenuCountTotal += item?.clickMenuCount ? item.clickMenuCount : 0
                msgCountTotal += item?.msgCount ? item.msgCount : 0
                scanQrcodeTotal += item?.scanQrcode ? item.scanQrcode : 0
                subcribeTotal += item?.subcribe ? item.subcribe : 0
                unsubcribeTotal += item?.unsubcribe ? item.unsubcribe : 0
                Object.keys(item).forEach((key: string) => {
                    switch (key) {
                        case 'clickMenuCount':
                            data[0] = { ...data[0], [`${myDate} ${myHour}:00`]: item.clickMenuCount || 0 }
                            break;
                        case 'msgCount':
                            data[1] = { ...data[1], [`${myDate} ${myHour}:00`]: item.msgCount || 0 }
                            break;
                        case 'scanQrcode':
                            data[2] = { ...data[2], [`${myDate} ${myHour}:00`]: item.scanQrcode || 0 }
                            break;
                        case 'subcribe':
                            data[3] = { ...data[3], [`${myDate} ${myHour}:00`]: item.subcribe || 0 }
                            break;
                        case 'unsubcribe':
                            data[4] = { ...data[4], [`${myDate} ${myHour}:00`]: item.unsubcribe || 0 }
                            break;
                    }
                })
                listDataz.push({
                    key: i,
                    date: `${item.statDate} ${myHour}:00`,
                    msgCount: item?.msgCount ? item.msgCount : 0,
                    clickMenuCount: item?.clickMenuCount ? item.clickMenuCount : 0,
                    scanQrcode: item?.scanQrcode ? item.scanQrcode : 0,
                    subcribe: item?.subcribe ? item.subcribe : 0,
                    unsubcribe: item?.unsubcribe ? item.unsubcribe : 0,
                    total: item?.unsubcribe ? item.unsubcribe : 0 + item?.msgCount ? item.msgCount : 0 + item?.clickMenuCount ? item.clickMenuCount : 0 + item?.scanQrcode ? item.scanQrcode : 0 + item?.subcribe ? item.subcribe : 0
                })
            })
        }
        // }
        setData(data);
        setListData(listDataz);
        let total = clickMenuCountTotal + msgCountTotal + scanQrcodeTotal + subcribeTotal + unsubcribeTotal;
        let MLD: multiLineDataIn[] = [];
        if (clickMenuCountTotal > 0) {
            MLD.push({
                percent: clickMenuCountTotal / total,
                name: "菜单点击",
                value: clickMenuCountTotal
            })
        }
        if (msgCountTotal > 0) {
            MLD.push({
                percent: msgCountTotal / total,
                name: "发送消息",
                value: msgCountTotal
            })
        }
        if (scanQrcodeTotal > 0) {
            MLD.push({
                percent: scanQrcodeTotal / total,
                name: "扫码",
                value: scanQrcodeTotal
            })
        }
        if (subcribeTotal > 0) {
            MLD.push({
                percent: subcribeTotal / total,
                name: "关注",
                value: subcribeTotal
            })
        }
        if (unsubcribeTotal > 0) {
            MLD.push({
                percent: unsubcribeTotal / total,
                name: "取关",
                value: unsubcribeTotal
            })
        }
        setMultiLineData(MLD);
    }, [])

    useEffect(() => {
        if (multiLineData.length > 0) {
            setMultiLineData([])
            console.log('清空')
        }
        if (actionWX && date.length > 0) {
            fansInteractive.run({ mpId: actionWX?.id, timeDto: { "beginDate": date[0], "endDate": date[1] } }).then((res) => {
                if (res) {
                    handleData(res)
                }
            })
        }
    }, [date])
    return <>
        <Radio.Group onChange={onChange} value={tabNmae} style={{ marginTop: 20 }}>
            <Radio.Button value="time">互动时段</Radio.Button>
            <Radio.Button value="type">互动类型</Radio.Button>
        </Radio.Group>
        <Tooltip title='互动消息包括了取关消息；但在平台其他功能处，互动粉丝（活跃粉丝）定义为有以下行为的粉丝：1、用户发送信息 2、点击自定义菜单 3、关注公众号 4、扫描二维码 5、支付成功 6、用户维权'>
            <QuestionCircleOutlined style={{ color: 'red', marginLeft: 10 }} />
        </Tooltip>

        <div className={style.grow_header}>
            <div className={style.grow_header_bottom} style={{ borderBottomWidth: '1px', borderColor: '#91d5ff', backgroundColor: '#e6f7ff' }}>
                <Tooltip title=''>
                    <QuestionCircleOutlined style={{ color: 'red', marginRight: 10 }} />
                </Tooltip>
                在粉丝活跃时段设置定时发送 ，效果最好
            </div>
            <div className={style.grow_header_top} >
                <Row gutter={[8, 8]}>
                    <Col ><DatePickePage model='RangePicker' DatePickerChange={DatePickerChange} scope={{ num: 4, unit: 'day' }} before={1} date={date} /></Col>
                </Row>
            </div>
        </div>
        <Suspense fallback='加载中。。。'>
            {
                tabNmae === "time" ?
                    <Card>
                        <Line data={fansSynergism.data} style={{ width: '100%', height: 500 }} />
                        <Divider plain style={{ paddingTop: '20px' }} orientation="left" ><strong>详细数据</strong></Divider>
                        {fansInteractive?.loading ? <Spin size="large" /> : <Tables columns={columns} dataSource={listData} />}
                    </Card> :
                    <Card>
                        <PieFocus name='互动类型' centerName='总互动' data={multiLineData} style={{ width: '100%', height: 300 }} />
                    </Card>
            }
        </Suspense>
    </>
}
export default Grow
