import WxTextModal from '@/components/MaterialModal/textModal'
import RegExpInput from '@/components/RegExpInput'
import { PlusOutlined } from '@ant-design/icons'
import { Card, Input, Radio } from 'antd'
import ModalPage from '@/components/MaterialModal/wxModalBox'
import { RadioChangeEvent } from 'antd/lib/radio'
import React, { useCallback, useMemo } from 'react'
import { useModel } from 'umi'
import style from './index.less'
import MsgWxGraphicListModal from '@/components/MaterialModal/msgWxGraphicListModal'
/**类型转文字*/
const msgConfig = {
    news: '图文',
    text: '文字',
    voice: '语音',
    video: '视频',
    image: '图片',
    miniprogrampage: '小程序卡片'
}
/**类型转数字*/
const type = {
    'news': 5,
    'video': 3,
    'voice': 2,
    'image': 1,
    'text': 4,
    'miniprogrampage': 6
}
/**类型转派发字段*/
const set = {
    'news': 'graphicVisible',
    'voice': 'msgVisible',
    'video': 'msgVisible',
    'image': 'msgVisible',
    'text': 'textVisible',
    'miniprogrampage': 'imgCardVisible'
}
const OperationBox = (props: { data: any }) => {
    const { state, dispatch } = useModel('useOperating.useWeMenu')
    const {
        actionMenuId, actionItemId,
        msgType, msgVisible, textVisible,
        graphicVisible, imgCardVisible, pagePath, isUserId
    } = state
    const { data } = props
    /**是否是子菜单 */
    const isItem = useMemo(() => actionItemId && actionMenuId, [actionItemId, actionMenuId])
    /**逻辑当菜单被选中并且菜单ID-1索引下的 subMenus长度大于0代表菜单下有子菜单显示提示*/
    const HeadTip = useCallback(() => {
        if (data?.subButtons?.length > 0) {
            return <span className={style.header_tip}>已添加子菜单，仅可设置菜单名称。</span>
        }
        return <></>
    }, [data])
    /**
     * 消息类型选择
     * */
    const handelMgsType = useCallback((e: RadioChangeEvent) => {
        let value = e.target.value
        dispatch({ type: 'msgType', params: { msgType: value } })
    }, [])
    /**
     * 发送类型变更数据处理
     */
    // useEffect(() => {
    //     // dispatch({ type: 'pushData', params: { url: '', appId: '', pagePath: '' } })
    // }, [data.menuType])
    /**删除菜单*/
    const delMenu = useCallback(() => {
        dispatch({ type: 'delMenu', params: { menuId: actionMenuId, itemId: actionItemId } })
    }, [actionItemId, actionMenuId])
    /** */
    const setName = useCallback((name: string) => {
        if (name) {
            dispatch({ type: 'pushData', params: { name } })
        }
    }, [])
    /**box*/
    let Box = useCallback((props: { item: any }) => {
        console.log(props?.item)
        return <div className={style.box}>
            <div className={style.group}>
                <label>点击效果：</label>
                <Radio.Group onChange={(e: RadioChangeEvent) => { dispatch({ type: 'pushData', params: { type: e.target.value } }) }} value={props?.item?.type}>
                    <Radio value='click'>发送消息</Radio>
                    <Radio value='view'>跳转网页</Radio>
                    <Radio value='miniprogram'>跳转小程序</Radio>
                </Radio.Group>
            </div>
            <div className={style.bottom_box}>
                {
                    props?.item?.type === 'click' && <div className={style.news}>
                        <div className={style.left_msgType}>
                            <div>
                                <label>消息类型：</label>
                                <Radio.Group onChange={handelMgsType} value={msgType}>
                                    <Radio value='news'>图文消息</Radio>
                                    <Radio value='image'>图片消息</Radio>
                                    <Radio value='text'>文字消息</Radio>
                                    <Radio value='voice'>语音消息</Radio>
                                    <Radio value='video'>视频消息</Radio>
                                    {/* <Radio value='miniprogrampage'>小程序卡片</Radio> */}
                                </Radio.Group>
                            </div>
                            <div
                                onClick={() => {
                                    dispatch({ type: set[msgType] })
                                }}
                                className={style.span}
                            >
                                {props?.item?.msgContent?.msgType && (props?.item?.msgContent?.msgType === msgType) ? <>你已选中一条{msgConfig[msgType]}消息<a>[修改]</a></> : <> <PlusOutlined style={{ marginRight: 10 }} />请点击选择{msgConfig[msgType]}消息</>}
                            </div>
                        </div>

                    </div>
                }
                {
                    props?.item?.type === 'view' && <div className={style.web}>
                        <Input
                            placeholder='请输入跳转链接，且必须以http://或https://开头'
                            value={props?.item?.url}
                            onChange={(e: React.ChangeEvent<HTMLInputElement>) => dispatch({ type: 'pushData', params: { url: e.target.value } })}
                        />
                    </div>
                }
                {
                    props?.item?.type === 'miniprogram' && <div className={style.app}>
                        <div>
                            <label>小程序AppID：</label>
                            <Input
                                placeholder='填写小程序AppID，跳转小程序需与当前公众号绑定关联关系'
                                value={props?.item?.appId}
                                onChange={(e: React.ChangeEvent<HTMLInputElement>) => dispatch({ type: 'pushData', params: { appId: e.target.value } })}
                            />
                        </div>
                        <div>
                            <label>小程序路径：</label>
                            <Input
                                placeholder='填写小程序路径，例如：pages/index'
                                value={props?.item?.pagePath}
                                onChange={(e: React.ChangeEvent<HTMLInputElement>) => dispatch({ type: 'pushData', params: { pagePath: e.target.value } })}
                            />
                        </div>
                        {/* <div>
                            <label>路径插入用户：</label>
                            <Radio.Group
                                value={isUserId}
                                onChange={(e: any) => {
                                    let v = Number(e.target.value)
                                    dispatch({ type: 'isUserId', params: { isUserId: v } })
                                }} >
                                <Radio value={1}>是</Radio>
                                <Radio value={0}>否</Radio>
                            </Radio.Group>
                        </div> */}
                        <div>
                            <label>备用网页：</label>
                            <Input
                                placeholder='备用网页，且必须以http://或https://开头'
                                value={props?.item?.url}
                                onChange={(e: React.ChangeEvent<HTMLInputElement>) => dispatch({ type: 'pushData', params: { url: e.target.value } })}
                            />
                        </div>
                    </div>
                }
            </div>
            {msgConfig[msgType] !== '文字' && msgConfig[msgType] !== '图文' && msgConfig[msgType] && msgVisible && <ModalPage
                mediaType={type[msgType]}
                onCancel={() => dispatch({ type: 'msgVisible' })}
                title={`公众号${msgConfig[msgType]}素材`}
                visible={msgVisible}
                onOk={(data: any) => {
                    let { mediaId, ...objs } = data
                    let { id, ...obj } = objs
                    dispatch({ type: 'pushData', params: { msgContent: { ...props?.item?.msgContent, ...obj, wxMediaId: mediaId, msgType, type: 0, } } })
                    dispatch({ type: 'msgVisible' })
                }}
                action={props?.item?.msgContent}
            />}
            {msgConfig[msgType] === '文字' && <WxTextModal
                visible={textVisible}
                onCancel={() => dispatch({ type: 'textVisible' })}
                onOK={(data: any) => {
                    dispatch({ type: 'pushData', params: { msgContent: { ...props?.item?.msgContent, ...data, msgType, type: 2, } } })
                    dispatch({ type: 'textVisible' })
                }}
                defaultData={props?.item?.msgContent}
            />}
            {msgConfig[msgType] === '图文' && <MsgWxGraphicListModal
                visible={graphicVisible}
                onCancel={() => dispatch({ type: 'graphicVisible' })}
                onOK={(data: any) => {
                    dispatch({ type: 'pushData', params: { msgContent: { ...props?.item?.msgContent, ...data, msgType, type: 3, } } })
                    dispatch({ type: 'graphicVisible' })
                }}
                defaultData={props?.item?.msgContent}
                tooltipTxt='只支持单图文'
                historyType={1}
                ImportBtShow={2}
                msgType={2}
            />}
            {/* {
                msgConfig[msgType] === '小程序卡片' && <WeChatImgCard
                    onCancel={() => dispatch({ type: 'imgCardVisible' })}
                    title='小程序图片链'
                    visible={imgCardVisible}
                    onOk={(props: { img: string, appid: string, appPath: string, imgInfo: any, cardTitle?: string }) => {
                        dispatch({ type: 'pushData', params: { webType: 6, msgType: 'miniprogrampage', imageUrl: props?.img, title: props?.cardTitle, appId: props?.appid, pagePath: props?.appPath, type: props?.imgInfo?.mediaId ? 0 : 1, mediaId: props?.imgInfo?.id } })
                        dispatch({ type: 'imgCardVisible' })
                    }}
                    weCathType='card'
                    defaultData={{ img: props?.item?.msgContent?.imageUrl, appid: props?.item?.msgContent?.appId, appPath: props?.item?.msgContent?.pagePath, cardTitle: props?.item?.msgContent?.title }}
                />
            } */}
            {//主菜单KEY
                actionMenuId === data.menuId && !actionItemId && (data.type === 'view' || data.type === 'click') && <strong className={style.key}><b>KEY:</b>{data.key || data.url}</strong>
            }
            {//子菜单KEY
                data.subButtons?.map((item: any) => {
                    if (actionItemId === item.itemId && (item.type === 'view' || item.type === 'click')) {
                        return <strong key={item.itemId} className={style.key}><b>KEY:</b>{item.key || item.url}</strong>
                    }
                    return null
                })
            }
        </div>
    }, [msgType, msgVisible, textVisible, graphicVisible, imgCardVisible, pagePath, isUserId, actionItemId])

    return <>
        {
            !actionItemId && <Card
                title={isItem ? `子菜单配置` : '菜单配置'}
                className={style.operation_box}
            >
                <div>
                    <div>
                        {/* 选中子菜单不执行 */}
                        {!actionItemId && <HeadTip />}
                    </div>
                    <RegExpInput
                        callback={setName}
                        rules={!!actionItemId ? { reg: 8 } : { reg: 4 }}
                        errorMsg={`字数不超过${isItem ? 8 : 4}个汉字`}
                        labelName={isItem ? '子菜单名称' : '菜单名称'}
                        inputWidth={350}
                        defaultValue={data?.name}
                    />
                </div>
                {
                    data?.subButtons?.length < 1 && <Box item={data} />
                }
            </Card>
        }
        {
            data?.subButtons?.map((subMenus: any) => {
                return subMenus.itemId === actionItemId && <Card
                    key={subMenus.itemId}
                    title={isItem ? '子菜单配置' : '菜单配置'}
                    className={style.operation_box}
                >
                    <div>
                        <div>
                            {/* 选中子菜单不执行 */}
                            {!actionItemId && <HeadTip />}
                        </div>
                        <RegExpInput
                            callback={setName}
                            rules={!!actionItemId ? { reg: 8 } : { reg: 4 }}
                            errorMsg={`字数不超过${isItem ? 8 : 4}个汉字`}
                            labelName={isItem ? '子菜单名称' : '菜单名称'}
                            inputWidth={350}
                            defaultValue={subMenus?.name}
                        />
                    </div>
                    <Box item={subMenus} />
                </Card>
            })
        }
    </>
}

export default OperationBox