import React, { useCallback, useEffect, useMemo, useState } from 'react'
import GzhMenu from '@/components/gzhMenu'
import ModelBox from './components/modelBox'
import { Button, Card, message, Popconfirm, Radio, Space } from 'antd'
import { useModel } from 'umi'
import OperationBox from './components/operationBox'
import style from './index.less'
import NoFoundPage from '@/pages/empty'
import { DeleteOutlined, PlusOutlined } from '@ant-design/icons'
import { RadioChangeEvent } from 'antd/lib/radio'
import HocError from '@/Hoc/HocError'

const WeMenu = () => {
    const { actionWX } = useModel('useOperating.useWxGroupList', model => ({ actionWX: model.state.actionWX }))
    const { getMenus, state, dispatch, editMenus, syncMenus, delMenus, syncPlatforms } = useModel('useOperating.useWeMenu')
    const { defaultMenu, actionMenuId, addMenuType, conditionalMenus, isSaver, actionItemId, isUserId } = state
    const [visible, setVisible] = useState<boolean>(false)//未保存编辑显示提示窗
    const [ruleClientPlatformType, setRuleClientPlatformType] = useState<number>()
    const [menuIndx, setMenuIndx] = useState<string>('0')
    const [mpMenuId, setMpMenuId] = useState<number | null>(null)
    /**处理获取数据 */
    const handleMenu = useCallback((actionWX: { id: number }) => {
        getMenus.run({ mpId: actionWX?.id }).then((res: { conditionalMenus: any[], defaultMenu: { buttons: any[] } }) => {
            if (res) {
                let conditionalMenus = [].concat(res?.defaultMenu as any, res?.conditionalMenus as any)
                conditionalMenus.forEach((item: any, eq: number) => {
                    if (eq === 0) {
                        setMpMenuId(item.id)
                    }
                    item?.buttons?.map((menus: any, index: number) => {
                        menus.menuId = index + 1//主菜单加上menuId
                        if (menus?.msgContent?.textContent) {//将文本字符串切割成数组
                            menus.msgContent.textContent = menus.msgContent.textContent.replace(/href/ig, '_href').split('<br/>')
                        }
                        if (menus?.msgContent?.webType === 6) {
                            menus.msgContent.imageUrl = menus?.msgContent?.platformMediaInfo?.url
                        }
                        if (!menus.subButtons) {//不存在子菜单赋值空数组
                            menus.subButtons = []
                        }
                        menus?.subButtons?.map((items: any, eq: number) => {//子菜单加上itemId
                            items.itemId = eq + 1
                            if (items?.msgContent?.textContent) {//将文本字符串切割成数组
                                items.msgContent.textContent = items.msgContent.textContent.replace(/href/ig, '_href').split('<br/>')
                            }
                            if (menus?.msgContent?.webType === 6) {
                                items.msgContent.imageUrl = items?.msgContent?.platformMediaInfo?.url
                            }
                        })
                    })
                })
                dispatch({ type: 'defaultData', params: { defaultMenu: conditionalMenus[0], conditionalMenus, resMenu: conditionalMenus[0] } })
            } else {
                dispatch({ type: 'init' })//切换公众号初始化数据
                setMpMenuId(null)
            }
        })
    }, [])
    //获取菜单切换菜单设置初始默认配置
    useEffect(() => {
        if (actionWX) {
            dispatch({ type: 'init' })//切换公众号初始化数据
            handleMenu(actionWX)
        }
    }, [actionWX])
    const submit = useCallback(() => {
        let isName = true
        //处理文本数组转字符串
        defaultMenu?.buttons?.forEach((menus: any) => {
            if (!menus.name) {
                message.error('请输入菜单名称')
                isName = false
            }
            if (Array.isArray(menus?.msgContent?.textContent)) {
                let textContent: string = ''
                menus?.msgContent?.textContent?.forEach((key: string, index: number) => {
                    textContent += index !== menus?.msgContent?.textContent.length - 1 ? key.replace(/_href/ig, 'href') + `<br/>` : key.replace(/_href/ig, 'href')
                })
                menus.msgContent.textContent = textContent
            }
            menus?.subButtons?.forEach((items: any) => {
                if (!items.name) {
                    message.error('请输入子菜单名称')
                    isName = false
                }
                if (Array.isArray(items?.msgContent?.textContent)) {
                    let textContent: string = ''
                    items?.msgContent?.textContent?.forEach((key: string, index: number) => {
                        textContent += index !== items?.msgContent?.textContent.length - 1 ? key.replace(/_href/ig, 'href') + `<br/>` : key.replace(/_href/ig, 'href')
                    })
                    items.msgContent.textContent = textContent
                }
            })
        })
        isName && editMenus.run({ mpId: actionWX?.id, menuId: defaultMenu?.id, mpMenuDtos: defaultMenu }).then((res: any) => {
            if (res) {
                dispatch({ type: 'isSaver', params: { isSaver: false } })
                handleMenu(actionWX)
            }
        })
    }, [defaultMenu, editMenus, actionWX, isUserId])
    /**同步 */
    const sync = useCallback(() => {
        syncMenus.run({ mpId: actionWX.id }).then((res: any) => {
            if (res) {
                handleMenu(actionWX)
            }
        })
    }, [syncMenus, actionWX, getMenus])
    /**是否是子菜单 */
    const isItem = useMemo(() => actionItemId && actionMenuId, [actionItemId, actionMenuId])
    /**删除子菜单*/
    const delMenu = useCallback(() => {
        dispatch({ type: 'delMenu', params: { menuId: actionMenuId, itemId: actionItemId } })
    }, [actionItemId, actionMenuId])
    /**新增个性化菜单操作 */
    const addRuleClientPlatformType = useCallback((e: RadioChangeEvent) => {
        let value = e.target.value
        // if (value === 'add') {//假如是添加菜单
        //     dispatch({ type: 'addConditionalMenus' })
        // }
        if (value !== 'add') {
            if (!isSaver) {//编辑没有保存弹窗
                setVisible(true)
                setMenuIndx(value)//存放本次点击的菜单编号
                return
            }
            if (value === '0') {
                dispatch({ type: 'ruleClientPlatformType', params: { ruleClientPlatformType: null } })
            }
            dispatch({ type: 'defaultData', params: { defaultMenu: conditionalMenus[value], conditionalMenus, resMenu: defaultMenu[value] } })
            dispatch({ type: 'addMenuType', params: { addMenuType: `${value}` } })
        }
    }, [isSaver, conditionalMenus])
    /**假如选择放弃保存*/
    const handleOut = useCallback(() => {
        setVisible(false)
        dispatch({ type: 'isSaver', params: { isSaver: true } })
        dispatch({ type: 'defaultData', params: { defaultMenu: conditionalMenus[menuIndx], conditionalMenus, resMenu: defaultMenu[menuIndx] } })
        dispatch({ type: 'addMenuType', params: { addMenuType: `${menuIndx}` } })
    }, [menuIndx])
    console.log(mpMenuId, conditionalMenus)
    return <>
        {
            actionWX ? <div className={style.box}>
                <GzhMenu isOk={isSaver} isShow={true} h={600} />
                <div className={style.box_div}>
                    <div>
                        <Popconfirm
                            title="有修改未保存！"
                            visible={visible}
                            onConfirm={() => { setVisible(false) }}
                            onCancel={handleOut}
                            okText="去保存修改"
                            cancelText="放弃修改"
                        >
                            <Radio.Group onChange={addRuleClientPlatformType} value={addMenuType} buttonStyle="solid">
                                {
                                    conditionalMenus?.map((menu: any, index: number) => {
                                        return <Radio.Button value={`${index}`} key={index} disabled={getMenus?.loading} onClick={() => {
                                            setMpMenuId(menu?.id)
                                            setRuleClientPlatformType(menu?.ruleClientPlatformType || 0)
                                        }}>
                                            {index ? menu?.ruleClientPlatformType === 1 ? 'IOS菜单' : '安卓菜单' : `默认菜单`}
                                        </Radio.Button>
                                    })
                                }
                                {//存在默认菜单
                                    conditionalMenus.length < 3 && conditionalMenus.length > 0 && <Popconfirm
                                        title={
                                            <>
                                                <p>请选择系统</p>
                                                <Radio.Group onChange={(e: any) => {
                                                    let value = e.target.value
                                                    setRuleClientPlatformType(value)
                                                }} value={ruleClientPlatformType} >
                                                    <Radio value={1} disabled={conditionalMenus.some((menu: { ruleClientPlatformType: number }) => menu?.ruleClientPlatformType === 1)}>IOS</Radio>
                                                    <Radio value={2} disabled={conditionalMenus.some((menu: { ruleClientPlatformType: number }) => menu?.ruleClientPlatformType === 2)}>安卓</Radio>
                                                </Radio.Group>
                                            </>
                                        }
                                        onConfirm={() => {
                                            dispatch({ type: 'addConditionalMenus', params: { ruleClientPlatformType } })
                                        }}
                                    >
                                        <Radio.Button value='add' >
                                            <PlusOutlined />新增个性化菜单
                                    </Radio.Button>
                                    </Popconfirm>
                                }
                                {//不存在任何菜单
                                    conditionalMenus.length === 0 && <Space>
                                        <Radio.Button value='add' onClick={() => {
                                            dispatch({ type: 'addConditionalMenus', params: { ruleClientPlatformType: 0 } })
                                        }}>
                                            <PlusOutlined />新增菜单
                                    </Radio.Button>
                                        <Button danger type="primary" onClick={sync} loading={syncMenus.loading}>同步菜单</Button>
                                    </Space>
                                }
                                {<Popconfirm //addMenuType !== '0' && 
                                    title={mpMenuId ? '是否删除当前菜单' : '当前菜单还未保存不能删除'}
                                    onConfirm={() => {
                                        if (mpMenuId) {
                                            delMenus.run({ menuId: mpMenuId }).then((res: any) => {
                                                if (res) {
                                                    dispatch({ type: 'init' })
                                                    handleMenu(actionWX)
                                                }
                                            })
                                        }
                                    }}
                                >
                                    {mpMenuId && <Button danger>
                                        <DeleteOutlined />
                                        {ruleClientPlatformType === 1 ? '删除IOS菜单' : ruleClientPlatformType === 2 ? '删除安卓菜单' : '删除默认菜单'}
                                    </Button>}
                                </Popconfirm>}
                            </Radio.Group>
                        </Popconfirm>
                    </div>
                    {
                        conditionalMenus?.map((item: any, index: number) => {
                            return addMenuType == index && < div className={style.box} key={index}>
                                <Card
                                    title={`当前编辑的公众号：${actionWX?.nickName || '--'}`}
                                >
                                    <ModelBox />
                                    <Space className={style.btn}>
                                        <Button type='primary' onClick={submit} loading={editMenus.loading}>保存并发布</Button>
                                        <Button danger type="primary" onClick={sync} loading={syncMenus.loading}>同步菜单</Button>
                                        {
                                            !!actionMenuId && <Popconfirm
                                                title={isItem ? '删除后“子菜单名称”菜单下设置的内容将被删除!' : '删除后“菜单名称”菜单下设置的子菜单将一起被删除！'}
                                                onConfirm={delMenu}
                                            >
                                                <Button danger loading={syncMenus.loading}>{isItem ? '删除子菜单' : '删除主菜单'}</Button>
                                            </Popconfirm>
                                        }
                                    </Space>
                                    {
                                        index === 0 && <Space className={style.btn}>
                                            <Button type='primary' onClick={() => {
                                                syncPlatforms.run({ platform: 'android', menuId: item?.id }).then((res: any) => {
                                                    if (res) {
                                                        sync()
                                                    }
                                                })
                                            }} loading={syncMenus.loading}>同步到安卓</Button>
                                            <Button type="primary" onClick={() => {
                                                syncPlatforms.run({ platform: 'ios', menuId: item?.id }).then((res: any) => {
                                                    if (res) {
                                                        sync()
                                                    }
                                                })
                                            }} loading={syncMenus.loading}>同步到IOS</Button>
                                        </Space>
                                    }
                                </Card>
                                {
                                    defaultMenu?.buttons?.map((mens: any) => {
                                        return actionMenuId === mens.menuId && < OperationBox data={mens} key={mens.menuId} />
                                    })
                                }
                            </div>
                        })
                    }
                </div>
            </div > : <NoFoundPage />
        }
    </>
}

export default HocError(WeMenu)